// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3danimation_python.h"

// main header
#include "qt3danimation_qkeyframe_wrapper.h"

// Argument includes
#include <Qt3DAnimation/qkeyframe.h>
#include <QtGui/qvectornd.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

using namespace Qt3DAnimation;


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DAnimation_QKeyFrame_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DAnimation::QKeyFrame >()))
        return -1;

    ::Qt3DAnimation::QKeyFrame *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "QKeyFrame", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QKeyFrame::QKeyFrame()
    // 1: QKeyFrame::QKeyFrame(QVector2D)
    // 2: QKeyFrame::QKeyFrame(QVector2D,QVector2D,QVector2D)
    if (numArgs == 0) {
        overloadId = 0; // QKeyFrame()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QKeyFrame(QVector2D)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArgs[2])))) {
            overloadId = 2; // QKeyFrame(QVector2D,QVector2D,QVector2D)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QKeyFrame()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeyFrame()
                cptr = new ::Qt3DAnimation::QKeyFrame();
            }
            break;
        }
        case 1: // QKeyFrame(QVector2D coords)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector2D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeyFrame(QVector2D)
                cptr = new ::Qt3DAnimation::QKeyFrame(cppArg0);
            }
            break;
        }
        case 2: // QKeyFrame(QVector2D coords, QVector2D lh, QVector2D rh)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVector2D cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QVector2D cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QVector2D cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QKeyFrame(QVector2D,QVector2D,QVector2D)
                cptr = new ::Qt3DAnimation::QKeyFrame(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Qt3DAnimation::QKeyFrame >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Qt3DAnimation_QKeyFrameFunc_coordinates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.coordinates";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // coordinates()const
            QVector2D cppResult = const_cast<const ::Qt3DAnimation::QKeyFrame *>(cppSelf)->coordinates();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QKeyFrameFunc_interpolationType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.interpolationType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // interpolationType()const
            Qt3DAnimation::QKeyFrame::InterpolationType cppResult = const_cast<const ::Qt3DAnimation::QKeyFrame *>(cppSelf)->interpolationType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_InterpolationType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QKeyFrameFunc_leftControlPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.leftControlPoint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // leftControlPoint()const
            QVector2D cppResult = const_cast<const ::Qt3DAnimation::QKeyFrame *>(cppSelf)->leftControlPoint();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QKeyFrameFunc_rightControlPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.rightControlPoint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rightControlPoint()const
            QVector2D cppResult = const_cast<const ::Qt3DAnimation::QKeyFrame *>(cppSelf)->rightControlPoint();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QKeyFrameFunc_setCoordinates(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.setCoordinates";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QKeyFrame::setCoordinates(QVector2D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArg)))) {
        overloadId = 0; // setCoordinates(QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector2D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCoordinates(QVector2D)
            cppSelf->setCoordinates(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DAnimation_QKeyFrameFunc_setInterpolationType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.setInterpolationType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QKeyFrame::setInterpolationType(Qt3DAnimation::QKeyFrame::InterpolationType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_InterpolationType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setInterpolationType(Qt3DAnimation::QKeyFrame::InterpolationType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::Qt3DAnimation::QKeyFrame::InterpolationType cppArg0{Qt3DAnimation::QKeyFrame::ConstantInterpolation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInterpolationType(Qt3DAnimation::QKeyFrame::InterpolationType)
            cppSelf->setInterpolationType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DAnimation_QKeyFrameFunc_setLeftControlPoint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.setLeftControlPoint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QKeyFrame::setLeftControlPoint(QVector2D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArg)))) {
        overloadId = 0; // setLeftControlPoint(QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector2D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLeftControlPoint(QVector2D)
            cppSelf->setLeftControlPoint(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DAnimation_QKeyFrameFunc_setRightControlPoint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.setRightControlPoint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QKeyFrame::setRightControlPoint(QVector2D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArg)))) {
        overloadId = 0; // setRightControlPoint(QVector2D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector2D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRightControlPoint(QVector2D)
            cppSelf->setRightControlPoint(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_Qt3DAnimation_QKeyFrame_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Qt3DAnimation_QKeyFrame_EnumFlagInfo[] = {
    "InterpolationType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DAnimation_QKeyFrame_methods[] = {
    {"coordinates", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QKeyFrameFunc_coordinates), METH_NOARGS, nullptr},
    {"interpolationType", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QKeyFrameFunc_interpolationType), METH_NOARGS, nullptr},
    {"leftControlPoint", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QKeyFrameFunc_leftControlPoint), METH_NOARGS, nullptr},
    {"rightControlPoint", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QKeyFrameFunc_rightControlPoint), METH_NOARGS, nullptr},
    {"setCoordinates", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QKeyFrameFunc_setCoordinates), METH_O, nullptr},
    {"setInterpolationType", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QKeyFrameFunc_setInterpolationType), METH_O, nullptr},
    {"setLeftControlPoint", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QKeyFrameFunc_setLeftControlPoint), METH_O, nullptr},
    {"setRightControlPoint", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QKeyFrameFunc_setRightControlPoint), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_Qt3DAnimation_QKeyFrame_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::Qt3DAnimation::QKeyFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), (pyArg)))) {
                // operator!=(const Qt3DAnimation::QKeyFrame &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Qt3DAnimation::QKeyFrame *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX]), (pyArg)))) {
                // operator==(const Qt3DAnimation::QKeyFrame &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::Qt3DAnimation::QKeyFrame *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_Qt3DAnimation_QKeyFrame_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DAnimation_QKeyFrame_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DAnimation_QKeyFrame_Type = nullptr;
static PyTypeObject *Sbk_Qt3DAnimation_QKeyFrame_TypeF(void)
{
    return _Sbk_Qt3DAnimation_QKeyFrame_Type;
}

static PyType_Slot Sbk_Qt3DAnimation_QKeyFrame_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QKeyFrame_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DAnimation_QKeyFrame_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Qt3DAnimation_QKeyFrame_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DAnimation_QKeyFrame_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DAnimation_QKeyFrame_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DAnimation_QKeyFrame_spec = {
    "2:PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DAnimation_QKeyFrame_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DAnimation_QKeyFrame_InterpolationType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DAnimation::QKeyFrame::InterpolationType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DAnimation::QKeyFrame::InterpolationType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DAnimation_QKeyFrame_InterpolationType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_InterpolationType_IDX])))
        return Enum_PythonToCpp_Qt3DAnimation_QKeyFrame_InterpolationType;
    return {};
}
static PyObject *Qt3DAnimation_QKeyFrame_InterpolationType_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::Qt3DAnimation::QKeyFrame::InterpolationType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_InterpolationType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QKeyFrame_PythonToCpp_QKeyFrame_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DAnimation_QKeyFrame_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QKeyFrame_PythonToCpp_QKeyFrame_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DAnimation_QKeyFrame_TypeF()))
        return QKeyFrame_PythonToCpp_QKeyFrame_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QKeyFrame_PTR_CppToPython_QKeyFrame(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::Qt3DAnimation::QKeyFrame *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_Qt3DAnimation_QKeyFrame_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DAnimation_QKeyFrame_SignatureStrings[] = {
    "2:PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame(self)",
    "1:PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame(self,coords:PySide6.QtGui.QVector2D)",
    "0:PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame(self,coords:PySide6.QtGui.QVector2D,lh:PySide6.QtGui.QVector2D,rh:PySide6.QtGui.QVector2D)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.coordinates(self)->PySide6.QtGui.QVector2D",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.interpolationType(self)->PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.InterpolationType",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.leftControlPoint(self)->PySide6.QtGui.QVector2D",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.rightControlPoint(self)->PySide6.QtGui.QVector2D",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.setCoordinates(self,coords:PySide6.QtGui.QVector2D)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.setInterpolationType(self,interp:PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.InterpolationType)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.setLeftControlPoint(self,lh:PySide6.QtGui.QVector2D)",
    "PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.setRightControlPoint(self,rh:PySide6.QtGui.QVector2D)",
    nullptr}; // Sentinel

PyTypeObject *init_Qt3DAnimation_QKeyFrame(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX].type != nullptr)
        return SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DAnimation_QKeyFrame_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DAnimation_QKeyFrame_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QKeyFrame",
        "Qt3DAnimation::QKeyFrame*",
        &Sbk_Qt3DAnimation_QKeyFrame_spec,
        &Shiboken::callCppDestructor< ::Qt3DAnimation::QKeyFrame >,
        Sbk_Qt3DAnimation_QKeyFrame_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DAnimation_QKeyFrame_TypeF(); // references _Sbk_Qt3DAnimation_QKeyFrame_Type
    InitSignatureStrings(pyType, Qt3DAnimation_QKeyFrame_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DAnimation_QKeyFrame_PropertyStrings);
    SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QKeyFrame_PythonToCpp_QKeyFrame_PTR,
        is_QKeyFrame_PythonToCpp_QKeyFrame_PTR_Convertible,
        QKeyFrame_PTR_CppToPython_QKeyFrame);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QKeyFrame");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QKeyFrame*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QKeyFrame&");
    Shiboken::Conversions::registerConverterName(converter, "QKeyFrame");
    Shiboken::Conversions::registerConverterName(converter, "QKeyFrame*");
    Shiboken::Conversions::registerConverterName(converter, "QKeyFrame&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DAnimation::QKeyFrame).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DAnimation_QKeyFrame_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'InterpolationType'.
    const char *InterpolationType_Initializer[] = {
        "ConstantInterpolation",
        "LinearInterpolation",
        "BezierInterpolation",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t InterpolationType_InitializerValues[] = {
        uint8_t(Qt3DAnimation::QKeyFrame::InterpolationType::ConstantInterpolation), //  0x00  0
        uint8_t(Qt3DAnimation::QKeyFrame::InterpolationType::LinearInterpolation),   //  0x01  1
        uint8_t(Qt3DAnimation::QKeyFrame::InterpolationType::BezierInterpolation)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DAnimation_QKeyFrame_TypeF(),
        "2:PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.InterpolationType",
        InterpolationType_Initializer, InterpolationType_InitializerValues);
    SbkPySide6_Qt3DAnimationTypeStructs[SBK_Qt3DAnimation_QKeyFrame_InterpolationType_IDX].type = EType;
    // Register converter for enum 'Qt3DAnimation::QKeyFrame::InterpolationType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DAnimation_QKeyFrame_InterpolationType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DAnimation_QKeyFrame_InterpolationType,
            is_Enum_PythonToCpp_Qt3DAnimation_QKeyFrame_InterpolationType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QKeyFrame::InterpolationType");
        Shiboken::Conversions::registerConverterName(converter, "QKeyFrame::InterpolationType");
        Shiboken::Conversions::registerConverterName(converter, "InterpolationType");
    }
    // End of 'InterpolationType' enum.

    qRegisterMetaType< ::Qt3DAnimation::QKeyFrame *>();
    qRegisterMetaType< ::Qt3DAnimation::QKeyFrame::InterpolationType >("QKeyFrame::InterpolationType");
    qRegisterMetaType< ::Qt3DAnimation::QKeyFrame::InterpolationType >("Qt3DAnimation::QKeyFrame::InterpolationType");

    return pyType;
}
