// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

// module include
#include "pyside6_qt3dcore_python.h"

// main header
#include "qsharedpointer_qentity_wrapper.h"

// Extra includes
#include <Qt3DCore/qentity.h>
#include <sbksmartpointer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DCore_QEntityPtr_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSharedPointer<Qt3DCore::QEntity> >()))
        return -1;

    ::QSharedPointer<Qt3DCore::QEntity> *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QEntityPtr.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QEntityPtr", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QEntityPtr::QEntityPtr()
    // 1: QEntityPtr::QEntityPtr(Qt3DCore::QEntity*)
    if (numArgs == 0) {
        overloadId = 0; // QEntityPtr()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QEntity_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QEntityPtr(Qt3DCore::QEntity*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QEntityPtr()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QEntityPtr()
                cptr = new ::QSharedPointer<Qt3DCore::QEntity>();
            }
            break;
        }
        case 1: // QEntityPtr(Qt3DCore::QEntity *pointee)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Qt3DCore::QEntity *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QEntityPtr(Qt3DCore::QEntity*)
                cptr = new ::QSharedPointer<Qt3DCore::QEntity>(cppArg0);

                // Ownership transferences.
                Shiboken::Object::releaseOwnership(pyArgs[0]);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSharedPointer<Qt3DCore::QEntity> >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Qt3DCore_QEntityPtrFunc_reset(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DCore::QEntity> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QEntityPtr.reset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "reset", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QEntityPtr::reset()
    // 1: QEntityPtr::reset(Qt3DCore::QEntity*)
    if (numArgs == 0) {
        overloadId = 0; // reset()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QEntity_IDX]), (pyArgs[0])))) {
        overloadId = 1; // reset(Qt3DCore::QEntity*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // reset()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // reset()
                cppSelf->reset();
            }
            break;
        }
        case 1: // reset(Qt3DCore::QEntity *t)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::Qt3DCore::QEntity *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // reset(Qt3DCore::QEntity*)
                cppSelf->reset(cppArg0);

                // Ownership transferences.
                Shiboken::Object::releaseOwnership(pyArgs[0]);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QEntityPtrFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DCore::QEntity> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QEntityPtr.data";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // data()const
            Qt3DCore::QEntity * cppResult = const_cast<const ::QSharedPointer<Qt3DCore::QEntity> *>(cppSelf)->data();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QEntity_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QEntityPtr__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSharedPointer<Qt3DCore::QEntity> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

extern "C"
{
static PyObject *Sbk_Qt3DCore_QEntityPtr__dir__(PyObject *self)
{
    Shiboken::AutoDecRef pointee(PyObject_CallMethod(self, "data", 0));
    return Shiboken::SmartPointer::dir(self, pointee);
}
} // extern C

static PyMethodDef Sbk_Qt3DCore_QEntityPtr_methods[] = {
    {"reset", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QEntityPtrFunc_reset), METH_VARARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QEntityPtrFunc_data), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QEntityPtr__copy__), METH_NOARGS, nullptr},
    {"__dir__", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QEntityPtr__dir__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_Qt3DCore_QEntityPtr_getattro(PyObject *self, PyObject *name)
{
    PyObject *tmp = PyObject_GenericGetAttr(self, name);
    if (tmp)
        return tmp;
    if (PyErr_ExceptionMatches(PyExc_AttributeError) == 0)
        return nullptr;
    PyErr_Clear();
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DCore::QEntity> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    if (cppSelf->isNull()) {
        PyTypeObject *tp = Py_TYPE(self);
        PyErr_Format(PyExc_AttributeError, "Attempt to retrieve '%s' from null object '%s'.",
                     Shiboken::String::toCString(name), tp->tp_name);
        return nullptr;
    }
    // Try to find the 'name' attribute, by retrieving the PyObject for the corresponding C++ object held by the smart pointer.
    if (auto *rawObj = PyObject_CallMethod(self, "data", 0)) {
        if (auto *attribute = PyObject_GetAttr(rawObj, name))
            tmp = attribute;
        Py_DECREF(rawObj);
    }
    if (!tmp) {
        PyTypeObject *tp = Py_TYPE(self);
        PyErr_Format(PyExc_AttributeError,
                     "'%.50s' object has no attribute '%.400s'",
                     tp->tp_name, Shiboken::String::toCString(name));
    }
    return tmp;
}

static int Sbk_Qt3DCore_QEntityPtr_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    // Try to find the 'name' attribute, by retrieving the PyObject for the corresponding C++ object held by the smart pointer.
    if (auto *rawObj = PyObject_CallMethod(self, "data", 0)) {
        if (PyObject_HasAttr(rawObj, name) != 0)
            return PyObject_GenericSetAttr(rawObj, name, value);
        Py_DECREF(rawObj);
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static int Sbk_Qt3DCore_QEntityPtr___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QSharedPointer<Qt3DCore::QEntity> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    return !cppSelf->isNull() ? 1 : 0;
}

static PyObject * Sbk_Qt3DCore_QEntityPtr_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSharedPointer<Qt3DCore::QEntity> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX]), (pyArg)))) {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSharedPointer<Qt3DCore::QEntity> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        const auto *cppSelfPointee = cppSelf.data();
        const auto *cppArg0Pointee = cppArg0.data();
        bool cppResult= false;
        switch (op) {
        case Py_EQ:
            cppResult = cppSelfPointee == cppArg0Pointee;
            break;
        case Py_NE:
            cppResult = cppSelfPointee != cppArg0Pointee;
            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
        }
        pyResult = cppResult ? Py_True : Py_False;
        Py_INCREF(pyResult);
    }
    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_Qt3DCore_QEntityPtr_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DCore_QEntityPtr_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_Qt3DCore_QEntityPtr__repr__(PyObject *self)
{
    Shiboken::AutoDecRef pointee(PyObject_CallMethod(self, "data", 0));
    return Shiboken::SmartPointer::repr(self, pointee);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DCore_QEntityPtr_Type = nullptr;
static PyTypeObject *Sbk_Qt3DCore_QEntityPtr_TypeF(void)
{
    return _Sbk_Qt3DCore_QEntityPtr_Type;
}

static PyType_Slot Sbk_Qt3DCore_QEntityPtr_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_Qt3DCore_QEntityPtr__repr__)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_Qt3DCore_QEntityPtr_getattro)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DCore_QEntityPtr_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DCore_QEntityPtr_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DCore_QEntityPtr_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_Qt3DCore_QEntityPtr_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DCore_QEntityPtr_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DCore_QEntityPtr_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_Qt3DCore_QEntityPtr___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DCore_QEntityPtr_spec = {
    "2:PySide6.Qt3DCore.Qt3DCore.QEntityPtr",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DCore_QEntityPtr_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QEntityPtr_PythonToCpp_QEntityPtr_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DCore_QEntityPtr_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QEntityPtr_PythonToCpp_QEntityPtr_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DCore_QEntityPtr_TypeF()))
        return QEntityPtr_PythonToCpp_QEntityPtr_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QEntityPtr_PTR_CppToPython_QEntityPtr(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QSharedPointer<Qt3DCore::QEntity> *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_Qt3DCore_QEntityPtr_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QEntityPtr_COPY_CppToPython_QEntityPtr(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSharedPointer<Qt3DCore::QEntity> *>(cppIn);
    return Shiboken::Object::newObject(Sbk_Qt3DCore_QEntityPtr_TypeF(), new ::QSharedPointer<Qt3DCore::QEntity>(*source), true, true);
}

// Python to C++ copy conversion.
static void QEntityPtr_PythonToCpp_QEntityPtr_COPY(PyObject *pyIn, void *cppOut)
{
    auto *ptr = reinterpret_cast<::QSharedPointer<Qt3DCore::QEntity> *>(cppOut);
    if (pyIn == Py_None)
        ptr->reset();
    else
        *ptr = *reinterpret_cast< ::QSharedPointer<Qt3DCore::QEntity> *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QEntityPtr_PythonToCpp_QEntityPtr_COPY_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None || PyObject_TypeCheck(pyIn, Sbk_Qt3DCore_QEntityPtr_TypeF()))
        return QEntityPtr_PythonToCpp_QEntityPtr_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DCore_QEntityPtr_SignatureStrings[] = {
    "1:PySide6.Qt3DCore.Qt3DCore.QEntityPtr(self)",
    "0:PySide6.Qt3DCore.Qt3DCore.QEntityPtr(self,pointee:PySide6.Qt3DCore.Qt3DCore.QEntity)",
    "1:PySide6.Qt3DCore.Qt3DCore.QEntityPtr.reset(self)",
    "0:PySide6.Qt3DCore.Qt3DCore.QEntityPtr.reset(self,t:PySide6.Qt3DCore.Qt3DCore.QEntity)",
    "PySide6.Qt3DCore.Qt3DCore.QEntityPtr.data(self)->PySide6.Qt3DCore.Qt3DCore.QEntity",
    "PySide6.Qt3DCore.Qt3DCore.QEntityPtr.__copy__()",
    "PySide6.Qt3DCore.Qt3DCore.QEntityPtr.__dir__()",
    nullptr}; // Sentinel

PyTypeObject *init_Qt3DCore_QEntityPtr(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX].type != nullptr)
        return SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DCore_QEntityPtr_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DCore_QEntityPtr_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QEntityPtr",
        "QSharedPointer<Qt3DCore::QEntity>",
        &Sbk_Qt3DCore_QEntityPtr_spec,
        &Shiboken::callCppDestructor< ::QSharedPointer<Qt3DCore::QEntity> >,
        Sbk_Qt3DCore_QEntityPtr_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DCore_QEntityPtr_TypeF(); // references _Sbk_Qt3DCore_QEntityPtr_Type
    InitSignatureStrings(pyType, Qt3DCore_QEntityPtr_SignatureStrings);
    SbkPySide6_Qt3DCoreTypeStructs[SBK_QSharedPointer_Qt3DCore_QEntity_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QEntityPtr_PythonToCpp_QEntityPtr_PTR,
        is_QEntityPtr_PythonToCpp_QEntityPtr_PTR_Convertible,
        QEntityPtr_PTR_CppToPython_QEntityPtr,
        QEntityPtr_COPY_CppToPython_QEntityPtr);

    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<Qt3DCore::QEntity>");
    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<Qt3DCore::QEntity>*");
    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<Qt3DCore::QEntity>&");
    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<QEntity>");
    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<QEntity>*");
    Shiboken::Conversions::registerConverterName(converter, "QSharedPointer<QEntity>&");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QEntity");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QEntity*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QEntity&");
    Shiboken::Conversions::registerConverterName(converter, "QEntity");
    Shiboken::Conversions::registerConverterName(converter, "QEntity*");
    Shiboken::Conversions::registerConverterName(converter, "QEntity&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSharedPointer<Qt3DCore::QEntity>).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QEntityPtr_PythonToCpp_QEntityPtr_COPY,
        is_QEntityPtr_PythonToCpp_QEntityPtr_COPY_Convertible);

    qRegisterMetaType< ::QSharedPointer<Qt3DCore::QEntity> >("QSharedPointer<Qt3DCore::QEntity>");
    qRegisterMetaType< ::QSharedPointer<Qt3DCore::QEntity> >("Qt3DCore::QSharedPointer<Qt3DCore::QEntity>");

    return pyType;
}
