// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dcore_python.h"

// main header
#include "qt3dcore_qabstractfunctor_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractFunctorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractFunctorWrapper::QAbstractFunctorWrapper() : Qt3DCore::QAbstractFunctor()
{
    resetPyMethodCache();
    // ... middle
}

::qintptr QAbstractFunctorWrapper::id() const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractFunctor.id");
        return ::qintptr();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::qintptr();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "id";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QAbstractFunctor.id");
        return ::qintptr();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return ::qintptr();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractFunctor", funcName, "qintptr", Py_TYPE(pyResult)->tp_name);
        return ::qintptr();
    }
    ::qintptr cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAbstractFunctorWrapper::~QAbstractFunctorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DCore_QAbstractFunctor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractFunctor_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("Qt3DCore::QAbstractFunctor");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DCore::QAbstractFunctor >()))
        return -1;

    QAbstractFunctorWrapper *cptr{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QAbstractFunctor.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractFunctor()
            cptr = new QAbstractFunctorWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DCore::QAbstractFunctor >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Qt3DCore_QAbstractFunctorFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QAbstractFunctor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractFunctor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QAbstractFunctor.id";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // id()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QAbstractFunctor.id");
                return {};
            }
            qintptr cppResult = const_cast<const ::Qt3DCore::QAbstractFunctor *>(cppSelf)->id();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DCore_QAbstractFunctor_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DCore_QAbstractFunctor_methods[] = {
    {"id", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QAbstractFunctorFunc_id), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DCore_QAbstractFunctor_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DCore::QAbstractFunctor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractFunctor_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractFunctorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DCore_QAbstractFunctor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DCore_QAbstractFunctor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DCore_QAbstractFunctor_Type = nullptr;
static PyTypeObject *Sbk_Qt3DCore_QAbstractFunctor_TypeF(void)
{
    return _Sbk_Qt3DCore_QAbstractFunctor_Type;
}

static PyType_Slot Sbk_Qt3DCore_QAbstractFunctor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DCore_QAbstractFunctor_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DCore_QAbstractFunctor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DCore_QAbstractFunctor_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DCore_QAbstractFunctor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DCore_QAbstractFunctor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DCore_QAbstractFunctor_spec = {
    "2:PySide6.Qt3DCore.Qt3DCore.QAbstractFunctor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DCore_QAbstractFunctor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractFunctor_PythonToCpp_QAbstractFunctor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DCore_QAbstractFunctor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractFunctor_PythonToCpp_QAbstractFunctor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DCore_QAbstractFunctor_TypeF()))
        return QAbstractFunctor_PythonToCpp_QAbstractFunctor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractFunctor_PTR_CppToPython_QAbstractFunctor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::Qt3DCore::QAbstractFunctor *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_Qt3DCore_QAbstractFunctor_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DCore_QAbstractFunctor_SignatureStrings[] = {
    "PySide6.Qt3DCore.Qt3DCore.QAbstractFunctor(self)",
    "PySide6.Qt3DCore.Qt3DCore.QAbstractFunctor.id(self)->qintptr",
    nullptr}; // Sentinel

PyTypeObject *init_Qt3DCore_QAbstractFunctor(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractFunctor_IDX].type != nullptr)
        return SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractFunctor_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DCore_QAbstractFunctor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DCore_QAbstractFunctor_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QAbstractFunctor",
        "Qt3DCore::QAbstractFunctor*",
        &Sbk_Qt3DCore_QAbstractFunctor_spec,
        &Shiboken::callCppDestructor< Qt3DCore::QAbstractFunctor >,
        Sbk_Qt3DCore_QAbstractFunctor_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DCore_QAbstractFunctor_TypeF(); // references _Sbk_Qt3DCore_QAbstractFunctor_Type
    InitSignatureStrings(pyType, Qt3DCore_QAbstractFunctor_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DCore_QAbstractFunctor_PropertyStrings);
    SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QAbstractFunctor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractFunctor_PythonToCpp_QAbstractFunctor_PTR,
        is_QAbstractFunctor_PythonToCpp_QAbstractFunctor_PTR_Convertible,
        QAbstractFunctor_PTR_CppToPython_QAbstractFunctor);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAbstractFunctor");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAbstractFunctor*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QAbstractFunctor&");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractFunctor");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractFunctor*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractFunctor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DCore::QAbstractFunctor).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractFunctorWrapper).name());

    qRegisterMetaType< ::Qt3DCore::QAbstractFunctor *>();

    return pyType;
}
