// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dcore_python.h"

// main header
#include "qt3dcore_qbackendnode_wrapper.h"

// Argument includes
#include <Qt3DCore/qbackendnode.h>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QBackendNodeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QBackendNodeWrapper::QBackendNodeWrapper(::Qt3DCore::QBackendNode::Mode mode) : Qt3DCore::QBackendNode(mode)
{
    resetPyMethodCache();
    // ... middle
}

void QBackendNodeWrapper::syncFromFrontEnd(const ::Qt3DCore::QNode * frontEnd, bool firstTime)
{
    if (m_PyMethodCache[0]) {
        return this->::Qt3DCore::QBackendNode::syncFromFrontEnd(frontEnd, firstTime);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "syncFromFrontEnd";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::Qt3DCore::QBackendNode::syncFromFrontEnd(frontEnd, firstTime);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), frontEnd),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &firstTime)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), frontEnd),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &firstTime)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QBackendNodeWrapper::~QBackendNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DCore_QBackendNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DCore::QBackendNode >()))
        return -1;

    QBackendNodeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QBackendNode.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:QBackendNode", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBackendNode::QBackendNode(Qt3DCore::QBackendNode::Mode=)
    if (numArgs == 0) {
        overloadId = 0; // QBackendNode(Qt3DCore::QBackendNode::Mode)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_Mode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QBackendNode(Qt3DCore::QBackendNode::Mode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_Mode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
        }
        ::Qt3DCore::QBackendNode::Mode cppArg0(Qt3DCore::QBackendNode::Mode::ReadOnly);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QBackendNode(Qt3DCore::QBackendNode::Mode)
            cptr = new QBackendNodeWrapper(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DCore::QBackendNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Qt3DCore_QBackendNodeFunc_isEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QBackendNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QBackendNode.isEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEnabled()const
            bool cppResult = const_cast<const ::Qt3DCore::QBackendNode *>(cppSelf)->isEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QBackendNodeFunc_mode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QBackendNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QBackendNode.mode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mode()const
            Qt3DCore::QBackendNode::Mode cppResult = const_cast<const ::Qt3DCore::QBackendNode *>(cppSelf)->mode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_Mode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QBackendNodeFunc_peerId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QBackendNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QBackendNode.peerId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // peerId()const
            Qt3DCore::QNodeId cppResult = const_cast<const ::Qt3DCore::QBackendNode *>(cppSelf)->peerId();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNodeId_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DCore_QBackendNodeFunc_setEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QBackendNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QBackendNode.setEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBackendNode::setEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEnabled(bool)
            cppSelf->setEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DCore_QBackendNodeFunc_syncFromFrontEnd(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DCore::QBackendNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DCore.Qt3DCore.QBackendNode.syncFromFrontEnd";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "syncFromFrontEnd", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBackendNode::syncFromFrontEnd(const Qt3DCore::QNode*,bool)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
        overloadId = 0; // syncFromFrontEnd(const Qt3DCore::QNode*,bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::Qt3DCore::QNode *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // syncFromFrontEnd(const Qt3DCore::QNode*,bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Qt3DCore::QBackendNode::syncFromFrontEnd(cppArg0, cppArg1)
                : cppSelf->syncFromFrontEnd(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_Qt3DCore_QBackendNode_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Qt3DCore_QBackendNode_EnumFlagInfo[] = {
    "Mode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DCore_QBackendNode_methods[] = {
    {"isEnabled", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QBackendNodeFunc_isEnabled), METH_NOARGS, nullptr},
    {"mode", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QBackendNodeFunc_mode), METH_NOARGS, nullptr},
    {"peerId", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QBackendNodeFunc_peerId), METH_NOARGS, nullptr},
    {"setEnabled", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QBackendNodeFunc_setEnabled), METH_O, nullptr},
    {"syncFromFrontEnd", reinterpret_cast<PyCFunction>(Sbk_Qt3DCore_QBackendNodeFunc_syncFromFrontEnd), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DCore_QBackendNode_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DCore::QBackendNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QBackendNodeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DCore_QBackendNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DCore_QBackendNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DCore_QBackendNode_Type = nullptr;
static PyTypeObject *Sbk_Qt3DCore_QBackendNode_TypeF(void)
{
    return _Sbk_Qt3DCore_QBackendNode_Type;
}

static PyType_Slot Sbk_Qt3DCore_QBackendNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DCore_QBackendNode_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DCore_QBackendNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DCore_QBackendNode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DCore_QBackendNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DCore_QBackendNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DCore_QBackendNode_spec = {
    "2:PySide6.Qt3DCore.Qt3DCore.QBackendNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DCore_QBackendNode_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Qt3DCore_QBackendNode_Mode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DCore::QBackendNode::Mode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DCore::QBackendNode::Mode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Qt3DCore_QBackendNode_Mode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_Mode_IDX])))
        return Enum_PythonToCpp_Qt3DCore_QBackendNode_Mode;
    return {};
}
static PyObject *Qt3DCore_QBackendNode_Mode_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::Qt3DCore::QBackendNode::Mode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_Mode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBackendNode_PythonToCpp_QBackendNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DCore_QBackendNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBackendNode_PythonToCpp_QBackendNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DCore_QBackendNode_TypeF()))
        return QBackendNode_PythonToCpp_QBackendNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBackendNode_PTR_CppToPython_QBackendNode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::Qt3DCore::QBackendNode *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_Qt3DCore_QBackendNode_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DCore_QBackendNode_SignatureStrings[] = {
    "PySide6.Qt3DCore.Qt3DCore.QBackendNode(self,mode:PySide6.Qt3DCore.Qt3DCore.QBackendNode.Mode=Qt3DCore.QBackendNode.Mode.ReadOnly)",
    "PySide6.Qt3DCore.Qt3DCore.QBackendNode.isEnabled(self)->bool",
    "PySide6.Qt3DCore.Qt3DCore.QBackendNode.mode(self)->PySide6.Qt3DCore.Qt3DCore.QBackendNode.Mode",
    "PySide6.Qt3DCore.Qt3DCore.QBackendNode.peerId(self)->PySide6.Qt3DCore.Qt3DCore.QNodeId",
    "PySide6.Qt3DCore.Qt3DCore.QBackendNode.setEnabled(self,enabled:bool)",
    "PySide6.Qt3DCore.Qt3DCore.QBackendNode.syncFromFrontEnd(self,frontEnd:PySide6.Qt3DCore.Qt3DCore.QNode,firstTime:bool)",
    nullptr}; // Sentinel

PyTypeObject *init_Qt3DCore_QBackendNode(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_IDX].type != nullptr)
        return SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DCore_QBackendNode_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DCore_QBackendNode_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QBackendNode",
        "Qt3DCore::QBackendNode*",
        &Sbk_Qt3DCore_QBackendNode_spec,
        &Shiboken::callCppDestructor< Qt3DCore::QBackendNode >,
        Sbk_Qt3DCore_QBackendNode_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DCore_QBackendNode_TypeF(); // references _Sbk_Qt3DCore_QBackendNode_Type
    InitSignatureStrings(pyType, Qt3DCore_QBackendNode_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DCore_QBackendNode_PropertyStrings);
    SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBackendNode_PythonToCpp_QBackendNode_PTR,
        is_QBackendNode_PythonToCpp_QBackendNode_PTR_Convertible,
        QBackendNode_PTR_CppToPython_QBackendNode);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QBackendNode");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QBackendNode*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QBackendNode&");
    Shiboken::Conversions::registerConverterName(converter, "QBackendNode");
    Shiboken::Conversions::registerConverterName(converter, "QBackendNode*");
    Shiboken::Conversions::registerConverterName(converter, "QBackendNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DCore::QBackendNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QBackendNodeWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DCore_QBackendNode_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Mode'.
    const char *Mode_Initializer[] = {
        "ReadOnly",
        "ReadWrite",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Mode_InitializerValues[] = {
        uint8_t(Qt3DCore::QBackendNode::Mode::ReadOnly), //  0x00  0
        uint8_t(Qt3DCore::QBackendNode::Mode::ReadWrite) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DCore_QBackendNode_TypeF(),
        "2:PySide6.Qt3DCore.Qt3DCore.QBackendNode.Mode",
        Mode_Initializer, Mode_InitializerValues);
    SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QBackendNode_Mode_IDX].type = EType;
    // Register converter for enum 'Qt3DCore::QBackendNode::Mode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DCore_QBackendNode_Mode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Qt3DCore_QBackendNode_Mode,
            is_Enum_PythonToCpp_Qt3DCore_QBackendNode_Mode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DCore::QBackendNode::Mode");
        Shiboken::Conversions::registerConverterName(converter, "QBackendNode::Mode");
        Shiboken::Conversions::registerConverterName(converter, "Mode");
    }
    // End of 'Mode' enum.

    qRegisterMetaType< ::Qt3DCore::QBackendNode *>();
    qRegisterMetaType< ::Qt3DCore::QBackendNode::Mode >("QBackendNode::Mode");
    qRegisterMetaType< ::Qt3DCore::QBackendNode::Mode >("Qt3DCore::QBackendNode::Mode");

    return pyType;
}
