// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3dextras_python.h"

// main header
#include "qt3dextras_wrapper.h"

// inner classes
#include "qt3dextras_qtorusmesh_wrapper.h"
#include "qt3dextras_qtorusgeometryview_wrapper.h"
#include "qt3dextras_qtorusgeometry_wrapper.h"
#include "qt3dextras_qtexturematerial_wrapper.h"
#include "qt3dextras_qtext2dentity_wrapper.h"
#include "qt3dextras_qt3dwindow_wrapper.h"
#include "qt3dextras_qspritesheetitem_wrapper.h"
#include "qt3dextras_qspheremesh_wrapper.h"
#include "qt3dextras_qspheregeometryview_wrapper.h"
#include "qt3dextras_qspheregeometry_wrapper.h"
#include "qt3dextras_qskyboxentity_wrapper.h"
#include "qt3dextras_qplanemesh_wrapper.h"
#include "qt3dextras_qplanegeometryview_wrapper.h"
#include "qt3dextras_qplanegeometry_wrapper.h"
#include "qt3dextras_qphongmaterial_wrapper.h"
#include "qt3dextras_qphongalphamaterial_wrapper.h"
#include "qt3dextras_qpervertexcolormaterial_wrapper.h"
#include "qt3dextras_qnormaldiffusespecularmapmaterial_wrapper.h"
#include "qt3dextras_qnormaldiffusemapmaterial_wrapper.h"
#include "qt3dextras_qnormaldiffusemapalphamaterial_wrapper.h"
#include "qt3dextras_qmorphphongmaterial_wrapper.h"
#include "qt3dextras_qmetalroughmaterial_wrapper.h"
#include "qt3dextras_qgoochmaterial_wrapper.h"
#include "qt3dextras_qforwardrenderer_wrapper.h"
#include "qt3dextras_qextrudedtextmesh_wrapper.h"
#include "qt3dextras_qextrudedtextgeometry_wrapper.h"
#include "qt3dextras_qdiffusespecularmaterial_wrapper.h"
#include "qt3dextras_qdiffusespecularmapmaterial_wrapper.h"
#include "qt3dextras_qdiffusemapmaterial_wrapper.h"
#include "qt3dextras_qcylindermesh_wrapper.h"
#include "qt3dextras_qcylindergeometryview_wrapper.h"
#include "qt3dextras_qcylindergeometry_wrapper.h"
#include "qt3dextras_qcuboidmesh_wrapper.h"
#include "qt3dextras_qcuboidgeometryview_wrapper.h"
#include "qt3dextras_qcuboidgeometry_wrapper.h"
#include "qt3dextras_qconemesh_wrapper.h"
#include "qt3dextras_qconegeometryview_wrapper.h"
#include "qt3dextras_qconegeometry_wrapper.h"
#include "qt3dextras_qabstractspritesheet_wrapper.h"
#include "qt3dextras_qspritesheet_wrapper.h"
#include "qt3dextras_qspritegrid_wrapper.h"
#include "qt3dextras_qabstractcameracontroller_wrapper.h"
#include "qt3dextras_qorbitcameracontroller_wrapper.h"
#include "qt3dextras_qfirstpersoncameracontroller_wrapper.h"

// Argument includes
#include <Qt3DRender/qrenderapi.h>
#include <QtGui/qwindow.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_Qt3DExtrasFunc_setupWindowSurface(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DExtras.Qt3DExtras.setupWindowSurface";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setupWindowSurface", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static Qt3DExtras::setupWindowSurface(QWindow*,Qt3DRender::API)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_API_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setupWindowSurface(QWindow*,Qt3DRender::API)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWindow *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt3DRender::API cppArg1{Qt3DRender::API::OpenGL};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setupWindowSurface(QWindow*,Qt3DRender::API)
            ::Qt3DExtras::setupWindowSurface(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_Qt3DExtras_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DExtras_methods[] = {
    {"setupWindowSurface", reinterpret_cast<PyCFunction>(Sbk_Qt3DExtrasFunc_setupWindowSurface), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Qt3DExtras_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DExtras_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DExtras_Type = nullptr;
static PyTypeObject *Sbk_Qt3DExtras_TypeF(void)
{
    return _Sbk_Qt3DExtras_Type;
}

static PyType_Slot Sbk_Qt3DExtras_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DExtras_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DExtras_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DExtras_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DExtras_spec = {
    "2:PySide6.Qt3DExtras.Qt3DExtras",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DExtras_slots
};

} //extern "C"

// Type conversion functions.

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DExtrasQt3DExtras_SignatureStrings[] = {
    "PySide6.Qt3DExtras.Qt3DExtras.setupWindowSurface(window:PySide6.QtGui.QWindow,arg__2:PySide6.Qt3DRender.Qt3DRender.API)",
    nullptr}; // Sentinel

PyTypeObject *init_Qt3DExtrasQt3DExtras(PyObject *module)
{
    if (SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtrasQt3DExtras_IDX].type != nullptr)
        return SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtrasQt3DExtras_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DExtras_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DExtras_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "Qt3DExtras",
        "Qt3DExtras",
        &Sbk_Qt3DExtras_spec,
        nullptr,
        Sbk_Qt3DExtras_Type_bases.object(),
        0);
    auto *pyType = Sbk_Qt3DExtras_TypeF(); // references _Sbk_Qt3DExtras_Type
    InitSignatureStrings(pyType, Qt3DExtrasQt3DExtras_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DExtras_PropertyStrings);
    SbkPySide6_Qt3DExtrasTypeStructs[SBK_Qt3DExtrasQt3DExtras_IDX].type = pyType;



    return pyType;
}
