// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergycharacteristic_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtBluetooth/qlowenergycharacteristic.h>
#include <QtBluetooth/qlowenergydescriptor.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLowEnergyCharacteristic_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLowEnergyCharacteristic >()))
        return -1;

    ::QLowEnergyCharacteristic *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyCharacteristic.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLowEnergyCharacteristic", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLowEnergyCharacteristic::QLowEnergyCharacteristic()
    // 1: QLowEnergyCharacteristic::QLowEnergyCharacteristic(QLowEnergyCharacteristic)
    if (numArgs == 0) {
        overloadId = 0; // QLowEnergyCharacteristic()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLowEnergyCharacteristic(QLowEnergyCharacteristic)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLowEnergyCharacteristic()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyCharacteristic()
                cptr = new ::QLowEnergyCharacteristic();
            }
            break;
        }
        case 1: // QLowEnergyCharacteristic(const QLowEnergyCharacteristic &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLowEnergyCharacteristic cppArg0_local;
            ::QLowEnergyCharacteristic *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyCharacteristic(QLowEnergyCharacteristic)
                cptr = new ::QLowEnergyCharacteristic(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLowEnergyCharacteristic >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLowEnergyCharacteristicFunc_clientCharacteristicConfiguration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyCharacteristic.clientCharacteristicConfiguration";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clientCharacteristicConfiguration()const
            QLowEnergyDescriptor cppResult = const_cast<const ::QLowEnergyCharacteristic *>(cppSelf)->clientCharacteristicConfiguration();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicFunc_descriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyCharacteristic.descriptor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyCharacteristic::descriptor(QBluetoothUuid)const->QLowEnergyDescriptor
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArg)))) {
        overloadId = 0; // descriptor(QBluetoothUuid)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothUuid cppArg0_local;
        ::QBluetoothUuid *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // descriptor(QBluetoothUuid)const
            QLowEnergyDescriptor cppResult = const_cast<const ::QLowEnergyCharacteristic *>(cppSelf)->descriptor(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicFunc_descriptors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyCharacteristic.descriptors";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // descriptors()const
            QList<QLowEnergyDescriptor> cppResult = const_cast<const ::QLowEnergyCharacteristic *>(cppSelf)->descriptors();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyDescriptor_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyCharacteristic.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QLowEnergyCharacteristic *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyCharacteristic.name";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // name()const
            QString cppResult = const_cast<const ::QLowEnergyCharacteristic *>(cppSelf)->name();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicFunc_properties(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyCharacteristic.properties";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // properties()const
            QFlags<QLowEnergyCharacteristic::PropertyType> cppResult = const_cast<const ::QLowEnergyCharacteristic *>(cppSelf)->properties();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QLowEnergyCharacteristic_PropertyType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicFunc_uuid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyCharacteristic.uuid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // uuid()const
            QBluetoothUuid cppResult = const_cast<const ::QLowEnergyCharacteristic *>(cppSelf)->uuid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristicFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyCharacteristic.value";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // value()const
            QByteArray cppResult = const_cast<const ::QLowEnergyCharacteristic *>(cppSelf)->value();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyCharacteristic__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLowEnergyCharacteristic_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLowEnergyCharacteristic_EnumFlagInfo[] = {
    "PropertyType:Flag:PropertyTypes",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyCharacteristic_methods[] = {
    {"clientCharacteristicConfiguration", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicFunc_clientCharacteristicConfiguration), METH_NOARGS, nullptr},
    {"descriptor", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicFunc_descriptor), METH_O, nullptr},
    {"descriptors", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicFunc_descriptors), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicFunc_isValid), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicFunc_name), METH_NOARGS, nullptr},
    {"properties", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicFunc_properties), METH_NOARGS, nullptr},
    {"uuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicFunc_uuid), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristicFunc_value), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyCharacteristic__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QLowEnergyCharacteristic_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), (pyArg)))) {
                // operator!=(const QLowEnergyCharacteristic &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyCharacteristic cppArg0_local;
                ::QLowEnergyCharacteristic *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), (pyArg)))) {
                // operator==(const QLowEnergyCharacteristic &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyCharacteristic cppArg0_local;
                ::QLowEnergyCharacteristic *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QLowEnergyCharacteristic_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyCharacteristic_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyCharacteristic_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyCharacteristic_TypeF(void)
{
    return _Sbk_QLowEnergyCharacteristic_Type;
}

static PyType_Slot Sbk_QLowEnergyCharacteristic_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyCharacteristic_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyCharacteristic_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLowEnergyCharacteristic_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyCharacteristic_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLowEnergyCharacteristic_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyCharacteristic_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyCharacteristic",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyCharacteristic_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QLowEnergyCharacteristic_PropertyType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyCharacteristic::PropertyType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyCharacteristic::PropertyType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QLowEnergyCharacteristic_PropertyType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_PropertyType_IDX])))
        return Enum_PythonToCpp_QLowEnergyCharacteristic_PropertyType;
    return {};
}
static PyObject *QLowEnergyCharacteristic_PropertyType_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLowEnergyCharacteristic::PropertyType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_PropertyType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyCharacteristic_PythonToCpp_QLowEnergyCharacteristic_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyCharacteristic_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyCharacteristic_PythonToCpp_QLowEnergyCharacteristic_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyCharacteristic_TypeF()))
        return QLowEnergyCharacteristic_PythonToCpp_QLowEnergyCharacteristic_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyCharacteristic_PTR_CppToPython_QLowEnergyCharacteristic(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QLowEnergyCharacteristic *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QLowEnergyCharacteristic_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QLowEnergyCharacteristic_COPY_CppToPython_QLowEnergyCharacteristic(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLowEnergyCharacteristic *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLowEnergyCharacteristic_TypeF(), new ::QLowEnergyCharacteristic(*source), true, true);
}

// Python to C++ copy conversion.
static void QLowEnergyCharacteristic_PythonToCpp_QLowEnergyCharacteristic_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLowEnergyCharacteristic *>(cppOut) = *reinterpret_cast< ::QLowEnergyCharacteristic *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLowEnergyCharacteristic_PythonToCpp_QLowEnergyCharacteristic_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyCharacteristic_TypeF()))
        return QLowEnergyCharacteristic_PythonToCpp_QLowEnergyCharacteristic_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QLowEnergyCharacteristic_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QLowEnergyCharacteristic(self)",
    "0:PySide6.QtBluetooth.QLowEnergyCharacteristic(self,other:PySide6.QtBluetooth.QLowEnergyCharacteristic)",
    "PySide6.QtBluetooth.QLowEnergyCharacteristic.clientCharacteristicConfiguration(self)->PySide6.QtBluetooth.QLowEnergyDescriptor",
    "PySide6.QtBluetooth.QLowEnergyCharacteristic.descriptor(self,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])->PySide6.QtBluetooth.QLowEnergyDescriptor",
    "PySide6.QtBluetooth.QLowEnergyCharacteristic.descriptors(self)->QList[PySide6.QtBluetooth.QLowEnergyDescriptor]",
    "PySide6.QtBluetooth.QLowEnergyCharacteristic.isValid(self)->bool",
    "PySide6.QtBluetooth.QLowEnergyCharacteristic.name(self)->QString",
    "PySide6.QtBluetooth.QLowEnergyCharacteristic.properties(self)->PySide6.QtBluetooth.QLowEnergyCharacteristic.PropertyType",
    "PySide6.QtBluetooth.QLowEnergyCharacteristic.uuid(self)->PySide6.QtBluetooth.QBluetoothUuid",
    "PySide6.QtBluetooth.QLowEnergyCharacteristic.value(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtBluetooth.QLowEnergyCharacteristic.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QLowEnergyCharacteristic(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyCharacteristic_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLowEnergyCharacteristic_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyCharacteristic",
        "QLowEnergyCharacteristic",
        &Sbk_QLowEnergyCharacteristic_spec,
        &Shiboken::callCppDestructor< ::QLowEnergyCharacteristic >,
        Sbk_QLowEnergyCharacteristic_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLowEnergyCharacteristic_TypeF(); // references _Sbk_QLowEnergyCharacteristic_Type
    InitSignatureStrings(pyType, QLowEnergyCharacteristic_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyCharacteristic_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyCharacteristic_PythonToCpp_QLowEnergyCharacteristic_PTR,
        is_QLowEnergyCharacteristic_PythonToCpp_QLowEnergyCharacteristic_PTR_Convertible,
        QLowEnergyCharacteristic_PTR_CppToPython_QLowEnergyCharacteristic,
        QLowEnergyCharacteristic_COPY_CppToPython_QLowEnergyCharacteristic);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyCharacteristic");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyCharacteristic*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyCharacteristic&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyCharacteristic).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLowEnergyCharacteristic_PythonToCpp_QLowEnergyCharacteristic_COPY,
        is_QLowEnergyCharacteristic_PythonToCpp_QLowEnergyCharacteristic_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLowEnergyCharacteristic_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PropertyType'.
    const char *PropertyType_Initializer[] = {
        "Unknown",
        "Broadcasting",
        "Read",
        "WriteNoResponse",
        "Write",
        "Notify",
        "Indicate",
        "WriteSigned",
        "ExtendedProperty",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PropertyType_InitializerValues[] = {
        uint8_t(QLowEnergyCharacteristic::PropertyType::Unknown),         //  0x00  0
        uint8_t(QLowEnergyCharacteristic::PropertyType::Broadcasting),    //  0x01  1
        uint8_t(QLowEnergyCharacteristic::PropertyType::Read),            //  0x02  2
        uint8_t(QLowEnergyCharacteristic::PropertyType::WriteNoResponse), //  0x04  4
        uint8_t(QLowEnergyCharacteristic::PropertyType::Write),           //  0x08  8
        uint8_t(QLowEnergyCharacteristic::PropertyType::Notify),          //  0x10  16
        uint8_t(QLowEnergyCharacteristic::PropertyType::Indicate),        //  0x20  32
        uint8_t(QLowEnergyCharacteristic::PropertyType::WriteSigned),     //  0x40  64
        uint8_t(QLowEnergyCharacteristic::PropertyType::ExtendedProperty) //  0x80  128
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyCharacteristic_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyCharacteristic.PropertyType",
        PropertyType_Initializer, PropertyType_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_PropertyType_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QLowEnergyCharacteristic_PropertyType_IDX].type =
        EType;
    // Register converter for enum 'QLowEnergyCharacteristic::PropertyType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyCharacteristic_PropertyType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QLowEnergyCharacteristic_PropertyType,
            is_Enum_PythonToCpp_QLowEnergyCharacteristic_PropertyType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyCharacteristic::PropertyType");
        Shiboken::Conversions::registerConverterName(converter, "PropertyType");
        // Register converter for flag 'QFlags<QLowEnergyCharacteristic::PropertyType>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QLowEnergyCharacteristic::PropertyType>");
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyCharacteristic::PropertyTypes");
    }
    // End of 'PropertyType' enum/flags.

    qRegisterMetaType< ::QLowEnergyCharacteristic >("QLowEnergyCharacteristic");
    qRegisterMetaType< ::QLowEnergyCharacteristic::PropertyType >("QLowEnergyCharacteristic::PropertyType");

    return pyType;
}

PyTypeObject *init_QLowEnergyCharacteristicStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QLowEnergyCharacteristic");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "CCCDDisable",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &QLowEnergyCharacteristic::CCCDDisable));
    PyDict_SetItemString(dict, "CCCDEnableNotification",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &QLowEnergyCharacteristic::CCCDEnableNotification));
    PyDict_SetItemString(dict, "CCCDEnableIndication",
                         Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &QLowEnergyCharacteristic::CCCDEnableIndication));
    return type;
}
