// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergyconnectionparameters_wrapper.h"

// Argument includes
#include <QtBluetooth/qlowenergyconnectionparameters.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLowEnergyConnectionParameters_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLowEnergyConnectionParameters >()))
        return -1;

    ::QLowEnergyConnectionParameters *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyConnectionParameters.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLowEnergyConnectionParameters", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLowEnergyConnectionParameters::QLowEnergyConnectionParameters()
    // 1: QLowEnergyConnectionParameters::QLowEnergyConnectionParameters(QLowEnergyConnectionParameters)
    if (numArgs == 0) {
        overloadId = 0; // QLowEnergyConnectionParameters()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLowEnergyConnectionParameters(QLowEnergyConnectionParameters)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLowEnergyConnectionParameters()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyConnectionParameters()
                cptr = new ::QLowEnergyConnectionParameters();
            }
            break;
        }
        case 1: // QLowEnergyConnectionParameters(const QLowEnergyConnectionParameters &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLowEnergyConnectionParameters cppArg0_local;
            ::QLowEnergyConnectionParameters *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyConnectionParameters(QLowEnergyConnectionParameters)
                cptr = new ::QLowEnergyConnectionParameters(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLowEnergyConnectionParameters >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_latency(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyConnectionParameters.latency";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // latency()const
            int cppResult = const_cast<const ::QLowEnergyConnectionParameters *>(cppSelf)->latency();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_maximumInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyConnectionParameters.maximumInterval";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumInterval()const
            double cppResult = const_cast<const ::QLowEnergyConnectionParameters *>(cppSelf)->maximumInterval();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_minimumInterval(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyConnectionParameters.minimumInterval";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumInterval()const
            double cppResult = const_cast<const ::QLowEnergyConnectionParameters *>(cppSelf)->minimumInterval();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_setIntervalRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyConnectionParameters.setIntervalRange";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setIntervalRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLowEnergyConnectionParameters::setIntervalRange(double,double)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // setIntervalRange(double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIntervalRange(double,double)
            cppSelf->setIntervalRange(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_setLatency(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyConnectionParameters.setLatency";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyConnectionParameters::setLatency(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLatency(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLatency(int)
            cppSelf->setLatency(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_setSupervisionTimeout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyConnectionParameters.setSupervisionTimeout";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyConnectionParameters::setSupervisionTimeout(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSupervisionTimeout(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupervisionTimeout(int)
            cppSelf->setSupervisionTimeout(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_supervisionTimeout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyConnectionParameters.supervisionTimeout";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supervisionTimeout()const
            int cppResult = const_cast<const ::QLowEnergyConnectionParameters *>(cppSelf)->supervisionTimeout();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyConnectionParametersFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyConnectionParameters.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyConnectionParameters::swap(QLowEnergyConnectionParameters&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QLowEnergyConnectionParameters&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyConnectionParameters cppArg0_local;
        ::QLowEnergyConnectionParameters *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QLowEnergyConnectionParameters&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyConnectionParameters__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLowEnergyConnectionParameters_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyConnectionParameters_methods[] = {
    {"latency", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_latency), METH_NOARGS, nullptr},
    {"maximumInterval", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_maximumInterval), METH_NOARGS, nullptr},
    {"minimumInterval", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_minimumInterval), METH_NOARGS, nullptr},
    {"setIntervalRange", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_setIntervalRange), METH_VARARGS, nullptr},
    {"setLatency", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_setLatency), METH_O, nullptr},
    {"setSupervisionTimeout", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_setSupervisionTimeout), METH_O, nullptr},
    {"supervisionTimeout", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_supervisionTimeout), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParametersFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyConnectionParameters__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QLowEnergyConnectionParameters_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), (pyArg)))) {
                // operator!=(const QLowEnergyConnectionParameters &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyConnectionParameters cppArg0_local;
                ::QLowEnergyConnectionParameters *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), (pyArg)))) {
                // operator==(const QLowEnergyConnectionParameters &b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyConnectionParameters cppArg0_local;
                ::QLowEnergyConnectionParameters *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QLowEnergyConnectionParameters_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyConnectionParameters_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyConnectionParameters_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyConnectionParameters_TypeF(void)
{
    return _Sbk_QLowEnergyConnectionParameters_Type;
}

static PyType_Slot Sbk_QLowEnergyConnectionParameters_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyConnectionParameters_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyConnectionParameters_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLowEnergyConnectionParameters_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyConnectionParameters_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLowEnergyConnectionParameters_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyConnectionParameters_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyConnectionParameters",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyConnectionParameters_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyConnectionParameters_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyConnectionParameters_TypeF()))
        return QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyConnectionParameters_PTR_CppToPython_QLowEnergyConnectionParameters(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QLowEnergyConnectionParameters *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QLowEnergyConnectionParameters_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QLowEnergyConnectionParameters_COPY_CppToPython_QLowEnergyConnectionParameters(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLowEnergyConnectionParameters *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLowEnergyConnectionParameters_TypeF(), new ::QLowEnergyConnectionParameters(*source), true, true);
}

// Python to C++ copy conversion.
static void QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLowEnergyConnectionParameters *>(cppOut) = *reinterpret_cast< ::QLowEnergyConnectionParameters *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyConnectionParameters_TypeF()))
        return QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QLowEnergyConnectionParameters_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QLowEnergyConnectionParameters(self)",
    "0:PySide6.QtBluetooth.QLowEnergyConnectionParameters(self,other:PySide6.QtBluetooth.QLowEnergyConnectionParameters)",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.latency(self)->int",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.maximumInterval(self)->double",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.minimumInterval(self)->double",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.setIntervalRange(self,minimum:double,maximum:double)",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.setLatency(self,latency:int)",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.setSupervisionTimeout(self,timeout:int)",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.supervisionTimeout(self)->int",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.swap(self,other:PySide6.QtBluetooth.QLowEnergyConnectionParameters)",
    "PySide6.QtBluetooth.QLowEnergyConnectionParameters.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QLowEnergyConnectionParameters(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyConnectionParameters_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLowEnergyConnectionParameters_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyConnectionParameters",
        "QLowEnergyConnectionParameters",
        &Sbk_QLowEnergyConnectionParameters_spec,
        &Shiboken::callCppDestructor< ::QLowEnergyConnectionParameters >,
        Sbk_QLowEnergyConnectionParameters_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLowEnergyConnectionParameters_TypeF(); // references _Sbk_QLowEnergyConnectionParameters_Type
    InitSignatureStrings(pyType, QLowEnergyConnectionParameters_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyConnectionParameters_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyConnectionParameters_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_PTR,
        is_QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_PTR_Convertible,
        QLowEnergyConnectionParameters_PTR_CppToPython_QLowEnergyConnectionParameters,
        QLowEnergyConnectionParameters_COPY_CppToPython_QLowEnergyConnectionParameters);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyConnectionParameters");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyConnectionParameters*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyConnectionParameters&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyConnectionParameters).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_COPY,
        is_QLowEnergyConnectionParameters_PythonToCpp_QLowEnergyConnectionParameters_COPY_Convertible);

    qRegisterMetaType< ::QLowEnergyConnectionParameters >("QLowEnergyConnectionParameters");

    return pyType;
}
