// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcommandlineparser_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <qcommandlineoption.h>
#include <qcommandlineparser.h>
#include <qcoreapplication.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCommandLineParser_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCommandLineParser >()))
        return -1;

    ::QCommandLineParser *cptr{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QCommandLineParser()
            cptr = new ::QCommandLineParser();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCommandLineParser >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCommandLineParserFunc_addHelpOption(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.addHelpOption";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // addHelpOption()
            QCommandLineOption* cppResult = new QCommandLineOption(cppSelf->addHelpOption());
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_addOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.addOption";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::addOption(QCommandLineOption)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), (pyArg)))) {
        overloadId = 0; // addOption(QCommandLineOption)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCommandLineOption *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addOption(QCommandLineOption)
            bool cppResult = cppSelf->addOption(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_addOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.addOptions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::addOptions(QList<QCommandLineOption>)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QCommandLineOption_IDX], (pyArg)))) {
        overloadId = 0; // addOptions(QList<QCommandLineOption>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QCommandLineOption> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addOptions(QList<QCommandLineOption>)
            bool cppResult = cppSelf->addOptions(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_addPositionalArgument(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.addPositionalArgument";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:addPositionalArgument", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCommandLineParser::addPositionalArgument(QString,QString,const QString&=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // addPositionalArgument(QString,QString,QString)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // addPositionalArgument(QString,QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_syntax = Shiboken::String::createStaticString("syntax");
            if (PyDict_Contains(kwds, key_syntax) != 0) {
                value = PyDict_GetItem(kwds, key_syntax);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_syntax);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_syntax);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2 = QString();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addPositionalArgument(QString,QString,QString)
            cppSelf->addPositionalArgument(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_addVersionOption(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.addVersionOption";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // addVersionOption()
            QCommandLineOption* cppResult = new QCommandLineOption(cppSelf->addVersionOption());
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_applicationDescription(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.applicationDescription";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // applicationDescription()const
            QString cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->applicationDescription();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_clearPositionalArguments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.clearPositionalArguments";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearPositionalArguments()
            cppSelf->clearPositionalArguments();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_errorText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.errorText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorText()const
            QString cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->errorText();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_helpText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.helpText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // helpText()const
            QString cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->helpText();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_isSet(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.isSet";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::isSet(QCommandLineOption)const->bool
    // 1: QCommandLineParser::isSet(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // isSet(QString)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), (pyArg)))) {
        overloadId = 0; // isSet(QCommandLineOption)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // isSet(const QCommandLineOption &option) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCommandLineOption *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isSet(QCommandLineOption)const
                bool cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->isSet(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isSet(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isSet(QString)const
                bool cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->isSet(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_optionNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.optionNames";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // optionNames()const
            QStringList cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->optionNames();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_parse(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.parse";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::parse(QStringList)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // parse(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // parse(QStringList)
            bool cppResult = cppSelf->parse(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_positionalArguments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.positionalArguments";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // positionalArguments()const
            QStringList cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->positionalArguments();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_process(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.process";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::process(QCoreApplication)
    // 1: QCommandLineParser::process(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 1; // process(QStringList)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), (pyArg)))) {
        overloadId = 0; // process(QCoreApplication)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // process(const QCoreApplication &app)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCoreApplication *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // process(QCoreApplication)
                cppSelf->process(*cppArg0);
            }
            break;
        }
        case 1: // process(const QStringList &arguments)
        {
            ::QStringList cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // process(QStringList)
                cppSelf->process(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_setApplicationDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.setApplicationDescription";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::setApplicationDescription(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setApplicationDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setApplicationDescription(QString)
            cppSelf->setApplicationDescription(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_setOptionsAfterPositionalArgumentsMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.setOptionsAfterPositionalArgumentsMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::setOptionsAfterPositionalArgumentsMode(QCommandLineParser::OptionsAfterPositionalArgumentsMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_OptionsAfterPositionalArgumentsMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setOptionsAfterPositionalArgumentsMode(QCommandLineParser::OptionsAfterPositionalArgumentsMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCommandLineParser::OptionsAfterPositionalArgumentsMode cppArg0{QCommandLineParser::ParseAsOptions};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOptionsAfterPositionalArgumentsMode(QCommandLineParser::OptionsAfterPositionalArgumentsMode)
            cppSelf->setOptionsAfterPositionalArgumentsMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_setSingleDashWordOptionMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.setSingleDashWordOptionMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::setSingleDashWordOptionMode(QCommandLineParser::SingleDashWordOptionMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_SingleDashWordOptionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSingleDashWordOptionMode(QCommandLineParser::SingleDashWordOptionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCommandLineParser::SingleDashWordOptionMode cppArg0{QCommandLineParser::ParseAsCompactedShortOptions};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSingleDashWordOptionMode(QCommandLineParser::SingleDashWordOptionMode)
            cppSelf->setSingleDashWordOptionMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_showHelp(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.showHelp";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:showHelp", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCommandLineParser::showHelp(int=)
    if (numArgs == 0) {
        overloadId = 0; // showHelp(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // showHelp(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_exitCode = Shiboken::String::createStaticString("exitCode");
            if (PyDict_Contains(kwds, key_exitCode) != 0) {
                value = PyDict_GetItem(kwds, key_exitCode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_exitCode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_exitCode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // showHelp(int)
            cppSelf->showHelp(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_showVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.showVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // showVersion()
            cppSelf->showVersion();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCommandLineParserFunc_unknownOptionNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.unknownOptionNames";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // unknownOptionNames()const
            QStringList cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->unknownOptionNames();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.value";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::value(QCommandLineOption)const->QString
    // 1: QCommandLineParser::value(QString)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // value(QString)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), (pyArg)))) {
        overloadId = 0; // value(QCommandLineOption)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // value(const QCommandLineOption &option) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCommandLineOption *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // value(QCommandLineOption)const
                QString cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->value(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // value(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // value(QString)const
                QString cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->value(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCommandLineParserFunc_values(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCommandLineParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCommandLineParser.values";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCommandLineParser::values(QCommandLineOption)const->QStringList
    // 1: QCommandLineParser::values(QString)const->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // values(QString)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineOption_IDX]), (pyArg)))) {
        overloadId = 0; // values(QCommandLineOption)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // values(const QCommandLineOption &option) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCommandLineOption *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // values(QCommandLineOption)const
                QStringList cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->values(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
            }
            break;
        }
        case 1: // values(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // values(QString)const
                QStringList cppResult = const_cast<const ::QCommandLineParser *>(cppSelf)->values(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCommandLineParser_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCommandLineParser_EnumFlagInfo[] = {
    "OptionsAfterPositionalArgumentsMode:Enum",
    "SingleDashWordOptionMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCommandLineParser_methods[] = {
    {"addHelpOption", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_addHelpOption), METH_NOARGS, nullptr},
    {"addOption", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_addOption), METH_O, nullptr},
    {"addOptions", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_addOptions), METH_O, nullptr},
    {"addPositionalArgument", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_addPositionalArgument), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addVersionOption", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_addVersionOption), METH_NOARGS, nullptr},
    {"applicationDescription", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_applicationDescription), METH_NOARGS, nullptr},
    {"clearPositionalArguments", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_clearPositionalArguments), METH_NOARGS, nullptr},
    {"errorText", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_errorText), METH_NOARGS, nullptr},
    {"helpText", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_helpText), METH_NOARGS, nullptr},
    {"isSet", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_isSet), METH_O, nullptr},
    {"optionNames", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_optionNames), METH_NOARGS, nullptr},
    {"parse", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_parse), METH_O, nullptr},
    {"positionalArguments", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_positionalArguments), METH_NOARGS, nullptr},
    {"process", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_process), METH_O, nullptr},
    {"setApplicationDescription", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_setApplicationDescription), METH_O, nullptr},
    {"setOptionsAfterPositionalArgumentsMode", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_setOptionsAfterPositionalArgumentsMode), METH_O, nullptr},
    {"setSingleDashWordOptionMode", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_setSingleDashWordOptionMode), METH_O, nullptr},
    {"showHelp", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_showHelp), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"showVersion", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_showVersion), METH_NOARGS, nullptr},
    {"unknownOptionNames", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_unknownOptionNames), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_value), METH_O, nullptr},
    {"values", reinterpret_cast<PyCFunction>(Sbk_QCommandLineParserFunc_values), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCommandLineParser_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCommandLineParser_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCommandLineParser_Type = nullptr;
static PyTypeObject *Sbk_QCommandLineParser_TypeF(void)
{
    return _Sbk_QCommandLineParser_Type;
}

static PyType_Slot Sbk_QCommandLineParser_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCommandLineParser_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCommandLineParser_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCommandLineParser_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCommandLineParser_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCommandLineParser_spec = {
    "2:PySide6.QtCore.QCommandLineParser",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCommandLineParser_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QCommandLineParser_SingleDashWordOptionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCommandLineParser::SingleDashWordOptionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCommandLineParser::SingleDashWordOptionMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCommandLineParser_SingleDashWordOptionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_SingleDashWordOptionMode_IDX])))
        return Enum_PythonToCpp_QCommandLineParser_SingleDashWordOptionMode;
    return {};
}
static PyObject *QCommandLineParser_SingleDashWordOptionMode_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCommandLineParser::SingleDashWordOptionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_SingleDashWordOptionMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QCommandLineParser_OptionsAfterPositionalArgumentsMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCommandLineParser::OptionsAfterPositionalArgumentsMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCommandLineParser::OptionsAfterPositionalArgumentsMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QCommandLineParser_OptionsAfterPositionalArgumentsMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_OptionsAfterPositionalArgumentsMode_IDX])))
        return Enum_PythonToCpp_QCommandLineParser_OptionsAfterPositionalArgumentsMode;
    return {};
}
static PyObject *QCommandLineParser_OptionsAfterPositionalArgumentsMode_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCommandLineParser::OptionsAfterPositionalArgumentsMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_OptionsAfterPositionalArgumentsMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCommandLineParser_PythonToCpp_QCommandLineParser_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCommandLineParser_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCommandLineParser_PythonToCpp_QCommandLineParser_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCommandLineParser_TypeF()))
        return QCommandLineParser_PythonToCpp_QCommandLineParser_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCommandLineParser_PTR_CppToPython_QCommandLineParser(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QCommandLineParser *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QCommandLineParser_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QCommandLineParser_SignatureStrings[] = {
    "PySide6.QtCore.QCommandLineParser(self)",
    "PySide6.QtCore.QCommandLineParser.addHelpOption(self)->PySide6.QtCore.QCommandLineOption",
    "PySide6.QtCore.QCommandLineParser.addOption(self,commandLineOption:PySide6.QtCore.QCommandLineOption)->bool",
    "PySide6.QtCore.QCommandLineParser.addOptions(self,options:QList[PySide6.QtCore.QCommandLineOption])->bool",
    "PySide6.QtCore.QCommandLineParser.addPositionalArgument(self,name:QString,description:QString,syntax:QString=QString())",
    "PySide6.QtCore.QCommandLineParser.addVersionOption(self)->PySide6.QtCore.QCommandLineOption",
    "PySide6.QtCore.QCommandLineParser.applicationDescription(self)->QString",
    "PySide6.QtCore.QCommandLineParser.clearPositionalArguments(self)",
    "PySide6.QtCore.QCommandLineParser.errorText(self)->QString",
    "PySide6.QtCore.QCommandLineParser.helpText(self)->QString",
    "1:PySide6.QtCore.QCommandLineParser.isSet(self,option:PySide6.QtCore.QCommandLineOption)->bool",
    "0:PySide6.QtCore.QCommandLineParser.isSet(self,name:QString)->bool",
    "PySide6.QtCore.QCommandLineParser.optionNames(self)->QStringList",
    "PySide6.QtCore.QCommandLineParser.parse(self,arguments:QStringList)->bool",
    "PySide6.QtCore.QCommandLineParser.positionalArguments(self)->QStringList",
    "1:PySide6.QtCore.QCommandLineParser.process(self,app:PySide6.QtCore.QCoreApplication)",
    "0:PySide6.QtCore.QCommandLineParser.process(self,arguments:QStringList)",
    "PySide6.QtCore.QCommandLineParser.setApplicationDescription(self,description:QString)",
    "PySide6.QtCore.QCommandLineParser.setOptionsAfterPositionalArgumentsMode(self,mode:PySide6.QtCore.QCommandLineParser.OptionsAfterPositionalArgumentsMode)",
    "PySide6.QtCore.QCommandLineParser.setSingleDashWordOptionMode(self,parsingMode:PySide6.QtCore.QCommandLineParser.SingleDashWordOptionMode)",
    "PySide6.QtCore.QCommandLineParser.showHelp(self,exitCode:int=0)",
    "PySide6.QtCore.QCommandLineParser.showVersion(self)",
    "PySide6.QtCore.QCommandLineParser.unknownOptionNames(self)->QStringList",
    "1:PySide6.QtCore.QCommandLineParser.value(self,option:PySide6.QtCore.QCommandLineOption)->QString",
    "0:PySide6.QtCore.QCommandLineParser.value(self,name:QString)->QString",
    "1:PySide6.QtCore.QCommandLineParser.values(self,option:PySide6.QtCore.QCommandLineOption)->QStringList",
    "0:PySide6.QtCore.QCommandLineParser.values(self,name:QString)->QStringList",
    nullptr}; // Sentinel

PyTypeObject *init_QCommandLineParser(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX].type;

    Shiboken::AutoDecRef Sbk_QCommandLineParser_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCommandLineParser_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCommandLineParser",
        "QCommandLineParser*",
        &Sbk_QCommandLineParser_spec,
        &Shiboken::callCppDestructor< ::QCommandLineParser >,
        Sbk_QCommandLineParser_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCommandLineParser_TypeF(); // references _Sbk_QCommandLineParser_Type
    InitSignatureStrings(pyType, QCommandLineParser_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCommandLineParser_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCommandLineParser_PythonToCpp_QCommandLineParser_PTR,
        is_QCommandLineParser_PythonToCpp_QCommandLineParser_PTR_Convertible,
        QCommandLineParser_PTR_CppToPython_QCommandLineParser);

    Shiboken::Conversions::registerConverterName(converter, "QCommandLineParser");
    Shiboken::Conversions::registerConverterName(converter, "QCommandLineParser*");
    Shiboken::Conversions::registerConverterName(converter, "QCommandLineParser&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCommandLineParser).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCommandLineParser_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SingleDashWordOptionMode'.
    const char *SingleDashWordOptionMode_Initializer[] = {
        "ParseAsCompactedShortOptions",
        "ParseAsLongOptions",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SingleDashWordOptionMode_InitializerValues[] = {
        uint8_t(QCommandLineParser::SingleDashWordOptionMode::ParseAsCompactedShortOptions), //  0x00  0
        uint8_t(QCommandLineParser::SingleDashWordOptionMode::ParseAsLongOptions)            //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCommandLineParser_TypeF(),
        "2:PySide6.QtCore.QCommandLineParser.SingleDashWordOptionMode",
        SingleDashWordOptionMode_Initializer, SingleDashWordOptionMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_SingleDashWordOptionMode_IDX].type = EType;
    // Register converter for enum 'QCommandLineParser::SingleDashWordOptionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCommandLineParser_SingleDashWordOptionMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCommandLineParser_SingleDashWordOptionMode,
            is_Enum_PythonToCpp_QCommandLineParser_SingleDashWordOptionMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCommandLineParser::SingleDashWordOptionMode");
        Shiboken::Conversions::registerConverterName(converter, "SingleDashWordOptionMode");
    }
    // End of 'SingleDashWordOptionMode' enum.

    // Initialization of enum 'OptionsAfterPositionalArgumentsMode'.
    const char *OptionsAfterPositionalArgumentsMode_Initializer[] = {
        "ParseAsOptions",
        "ParseAsPositionalArguments",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OptionsAfterPositionalArgumentsMode_InitializerValues[] = {
        uint8_t(QCommandLineParser::OptionsAfterPositionalArgumentsMode::ParseAsOptions),            //  0x00  0
        uint8_t(QCommandLineParser::OptionsAfterPositionalArgumentsMode::ParseAsPositionalArguments) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCommandLineParser_TypeF(),
        "2:PySide6.QtCore.QCommandLineParser.OptionsAfterPositionalArgumentsMode",
        OptionsAfterPositionalArgumentsMode_Initializer, OptionsAfterPositionalArgumentsMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCommandLineParser_OptionsAfterPositionalArgumentsMode_IDX].type = EType;
    // Register converter for enum 'QCommandLineParser::OptionsAfterPositionalArgumentsMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCommandLineParser_OptionsAfterPositionalArgumentsMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QCommandLineParser_OptionsAfterPositionalArgumentsMode,
            is_Enum_PythonToCpp_QCommandLineParser_OptionsAfterPositionalArgumentsMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCommandLineParser::OptionsAfterPositionalArgumentsMode");
        Shiboken::Conversions::registerConverterName(converter, "OptionsAfterPositionalArgumentsMode");
    }
    // End of 'OptionsAfterPositionalArgumentsMode' enum.

    qRegisterMetaType< ::QCommandLineParser *>();
    qRegisterMetaType< ::QCommandLineParser::SingleDashWordOptionMode >("QCommandLineParser::SingleDashWordOptionMode");
    qRegisterMetaType< ::QCommandLineParser::OptionsAfterPositionalArgumentsMode >("QCommandLineParser::OptionsAfterPositionalArgumentsMode");

    return pyType;
}
