// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcoreapplication_wrapper.h"

// Extra includes
#include <QStringList>
#include <QTranslator>
#include <pysidecleanup.h>
#include <pysideqapp.h>

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <qabstracteventdispatcher.h>
#include <qabstractnativeeventfilter.h>
#include <qbytearray.h>
#include <qcoreapplication.h>
#include <qcoreevent.h>
#include <qdeadlinetimer.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpermissions.h>
#include <qthread.h>
#include <qtranslator.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-init)]
static void QCoreApplicationConstructor(PyObject *self, PyObject *pyargv, QCoreApplicationWrapper **cptr)
{
    static int argc;
    static char **argv;
    PyObject *stringlist = PyTuple_GET_ITEM(pyargv, 0);
    if (Shiboken::listToArgcArgv(stringlist, &argc, &argv, "PySideApp")) {
        *cptr = new QCoreApplicationWrapper(argc, argv);
        Shiboken::Object::releaseOwnership(reinterpret_cast<SbkObject *>(self));
        PySide::registerCleanupFunction(&PySide::destroyQCoreApplication);
    }
}
// END of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-init)]
// ========================================================================
// End of code injection


// Native ---------------------------------------------------------

void QCoreApplicationWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QCoreApplicationWrapper::QCoreApplicationWrapper(int & argc, char ** argv, int arg__3) : QCoreApplication(argc, argv, arg__3)
{
    resetPyMethodCache();
    // ... middle
}

void QCoreApplicationWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCoreApplicationWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCoreApplicationWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCoreApplicationWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QCoreApplicationWrapper::event(::QEvent * arg__1)
{
    if (m_PyMethodCache[4])
        return this->::QCoreApplication::event(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QCoreApplication::event(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCoreApplication", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCoreApplicationWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCoreApplication", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCoreApplicationWrapper::notify(::QObject * arg__1, ::QEvent * arg__2)
{
    if (m_PyMethodCache[6])
        return this->::QCoreApplication::notify(arg__1, arg__2);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "notify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QCoreApplication::notify(arg__1, arg__2);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCoreApplication", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCoreApplicationWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QCoreApplicationWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QCoreApplication::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QCoreApplicationWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QCoreApplication::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QCoreApplicationWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QCoreApplicationWrapper *>(this));
    return QCoreApplication::qt_metacast(_clname);
}

QCoreApplicationWrapper::~QCoreApplicationWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCoreApplication_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCoreApplication >()))
        return -1;

    QCoreApplicationWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCoreApplication", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCoreApplication::QCoreApplication()
    // 1: QCoreApplication::QCoreApplication(QStringList)
    if (numArgs == 0) {
        overloadId = 0; // QCoreApplication()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[0])))) {
        overloadId = 1; // QCoreApplication(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCoreApplication()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCoreApplication()
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-2)]
                PyObject *empty = PyTuple_New(2);
                if (!PyTuple_SetItem(empty, 0, PyList_New(0))) {
                    QCoreApplicationConstructor(self, empty, &cptr);
                }
                // END of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-2)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // QCoreApplication(QStringList args)
        {
            ::QStringList cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCoreApplication(QStringList)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-1)]
                QCoreApplicationConstructor(self, args, &cptr);
                // END of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-1)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QCoreApplication >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QCoreApplicationFunc_addLibraryPath(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.addLibraryPath";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::addLibraryPath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // addLibraryPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addLibraryPath(QString)
            ::QCoreApplication::addLibraryPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_applicationDirPath(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.applicationDirPath";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // applicationDirPath()
            QString cppResult = ::QCoreApplication::applicationDirPath();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_applicationFilePath(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.applicationFilePath";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // applicationFilePath()
            QString cppResult = ::QCoreApplication::applicationFilePath();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_applicationName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.applicationName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // applicationName()
            QString cppResult = ::QCoreApplication::applicationName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_applicationPid(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.applicationPid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // applicationPid()
            qint64 cppResult = ::QCoreApplication::applicationPid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_applicationVersion(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.applicationVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // applicationVersion()
            QString cppResult = ::QCoreApplication::applicationVersion();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_arguments(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.arguments";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // arguments()
            QStringList cppResult = ::QCoreApplication::arguments();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_checkPermission(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCoreApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.checkPermission";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCoreApplication::checkPermission(QBluetoothPermission)->Qt::PermissionStatus
    // 1: QCoreApplication::checkPermission(QCalendarPermission)->Qt::PermissionStatus
    // 2: QCoreApplication::checkPermission(QCameraPermission)->Qt::PermissionStatus
    // 3: QCoreApplication::checkPermission(QContactsPermission)->Qt::PermissionStatus
    // 4: QCoreApplication::checkPermission(QLocationPermission)->Qt::PermissionStatus
    // 5: QCoreApplication::checkPermission(QMicrophonePermission)->Qt::PermissionStatus
    // 6: QCoreApplication::checkPermission(QPermission)->Qt::PermissionStatus
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), (pyArg)))) {
        overloadId = 6; // checkPermission(QPermission)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]), (pyArg)))) {
        overloadId = 5; // checkPermission(QMicrophonePermission)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), (pyArg)))) {
        overloadId = 4; // checkPermission(QLocationPermission)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]), (pyArg)))) {
        overloadId = 3; // checkPermission(QContactsPermission)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCameraPermission_IDX]), (pyArg)))) {
        overloadId = 2; // checkPermission(QCameraPermission)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendarPermission_IDX]), (pyArg)))) {
        overloadId = 1; // checkPermission(QCalendarPermission)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]), (pyArg)))) {
        overloadId = 0; // checkPermission(QBluetoothPermission)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // checkPermission(const QBluetoothPermission &permission)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QBluetoothPermission cppArg0_local;
            ::QBluetoothPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // checkPermission(QBluetoothPermission)
                Qt::PermissionStatus cppResult = cppSelf->checkPermission(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PermissionStatus_IDX])))->converter, &cppResult);
            }
            break;
        }
        case 1: // checkPermission(const QCalendarPermission &permission)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCalendarPermission cppArg0_local;
            ::QCalendarPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // checkPermission(QCalendarPermission)
                Qt::PermissionStatus cppResult = cppSelf->checkPermission(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PermissionStatus_IDX])))->converter, &cppResult);
            }
            break;
        }
        case 2: // checkPermission(const QCameraPermission &permission)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QCameraPermission cppArg0_local;
            ::QCameraPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // checkPermission(QCameraPermission)
                Qt::PermissionStatus cppResult = cppSelf->checkPermission(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PermissionStatus_IDX])))->converter, &cppResult);
            }
            break;
        }
        case 3: // checkPermission(const QContactsPermission &permission)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QContactsPermission cppArg0_local;
            ::QContactsPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // checkPermission(QContactsPermission)
                Qt::PermissionStatus cppResult = cppSelf->checkPermission(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PermissionStatus_IDX])))->converter, &cppResult);
            }
            break;
        }
        case 4: // checkPermission(const QLocationPermission &permission)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QLocationPermission cppArg0_local;
            ::QLocationPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // checkPermission(QLocationPermission)
                Qt::PermissionStatus cppResult = cppSelf->checkPermission(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PermissionStatus_IDX])))->converter, &cppResult);
            }
            break;
        }
        case 5: // checkPermission(const QMicrophonePermission &permission)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QMicrophonePermission cppArg0_local;
            ::QMicrophonePermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // checkPermission(QMicrophonePermission)
                Qt::PermissionStatus cppResult = cppSelf->checkPermission(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PermissionStatus_IDX])))->converter, &cppResult);
            }
            break;
        }
        case 6: // checkPermission(const QPermission &permission)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPermission cppArg0_local;
            ::QPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // checkPermission(QPermission)
                Qt::PermissionStatus cppResult = cppSelf->checkPermission(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PermissionStatus_IDX])))->converter, &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_closingDown(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.closingDown";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // closingDown()
            bool cppResult = ::QCoreApplication::closingDown();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCoreApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.event";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCoreApplication::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_eventDispatcher(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.eventDispatcher";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // eventDispatcher()
            QAbstractEventDispatcher * cppResult = ::QCoreApplication::eventDispatcher();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractEventDispatcher_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_exec(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.exec";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // exec()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = ::QCoreApplication::exec();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_exec_(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCoreApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.exec_";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    pcm.setBlocking();

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // exec_()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (exec_)]
            if (PyErr_WarnEx(PyExc_DeprecationWarning,
                             "'exec_' will be removed in the future. "
                             "Use 'exec' instead.",
                             1)) {
                return nullptr;
            }
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = cppSelf->exec();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            // END of custom code block [file: ../glue/qtcore.cpp (exec_)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_exit(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.exit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:exit", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCoreApplication::exit(int=)
    if (numArgs == 0) {
        overloadId = 0; // exit(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // exit(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_retcode = Shiboken::String::createStaticString("retcode");
            if (PyDict_Contains(kwds, key_retcode) != 0) {
                value = PyDict_GetItem(kwds, key_retcode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_retcode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_retcode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // exit(int)
            ::QCoreApplication::exit(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_installNativeEventFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCoreApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.installNativeEventFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCoreApplication::installNativeEventFilter(QAbstractNativeEventFilter*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractNativeEventFilter_IDX]), (pyArg)))) {
        overloadId = 0; // installNativeEventFilter(QAbstractNativeEventFilter*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractNativeEventFilter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // installNativeEventFilter(QAbstractNativeEventFilter*)
            cppSelf->installNativeEventFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_installTranslator(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.installTranslator";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::installTranslator(QTranslator*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTranslator_IDX]), (pyArg)))) {
        overloadId = 0; // installTranslator(QTranslator*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTranslator *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // installTranslator(QTranslator*)
            bool cppResult = ::QCoreApplication::installTranslator(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_instance(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.instance";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // instance()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-instance)]
            PyObject *pyApp = Py_None;
            if (qApp) {
                pyApp = reinterpret_cast<PyObject *>(
                    Shiboken::BindingManager::instance().retrieveWrapper(qApp));
                if (!pyApp)
                    pyApp = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), qApp);
                    // this will keep app live after python exit (extra ref)
            }
            // PYSIDE-571: make sure that we return the singleton "None"
            if (Py_TYPE(pyApp) == Py_TYPE(Py_None))
                Py_DECREF(MakeQAppWrapper(nullptr));
            pyResult = pyApp;
            Py_XINCREF(pyResult);
            // END of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-instance)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_isQuitLockEnabled(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.isQuitLockEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isQuitLockEnabled()
            bool cppResult = ::QCoreApplication::isQuitLockEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_isSetuidAllowed(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.isSetuidAllowed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSetuidAllowed()
            bool cppResult = ::QCoreApplication::isSetuidAllowed();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_libraryPaths(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.libraryPaths";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // libraryPaths()
            QStringList cppResult = ::QCoreApplication::libraryPaths();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_notify(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCoreApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.notify";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "notify", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCoreApplication::notify(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // notify(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // notify(QObject*,QEvent*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QCoreApplication::notify(cppArg0, cppArg1)
                : cppSelf->notify(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_organizationDomain(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.organizationDomain";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // organizationDomain()
            QString cppResult = ::QCoreApplication::organizationDomain();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_organizationName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.organizationName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // organizationName()
            QString cppResult = ::QCoreApplication::organizationName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_postEvent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.postEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:postEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCoreApplication::postEvent(QObject*,QEvent*,int=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // postEvent(QObject*,QEvent*,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // postEvent(QObject*,QEvent*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_priority = Shiboken::String::createStaticString("priority");
            if (PyDict_Contains(kwds, key_priority) != 0) {
                value = PyDict_GetItem(kwds, key_priority);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_priority);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_priority);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = Qt::NormalEventPriority;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // postEvent(QObject*,QEvent*,int)
            ::QCoreApplication::postEvent(cppArg0, cppArg1, cppArg2);

            // Ownership transferences.
            Shiboken::Object::releaseOwnership(pyArgs[1]);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_processEvents(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.processEvents";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:processEvents", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCoreApplication::processEvents(QFlags<QEventLoop::ProcessEventsFlag>=)
    // 1: static QCoreApplication::processEvents(QFlags<QEventLoop::ProcessEventsFlag>,QDeadlineTimer)
    // 2: static QCoreApplication::processEvents(QFlags<QEventLoop::ProcessEventsFlag>,int)
    if (numArgs == 0) {
        overloadId = 0; // processEvents(QFlags<QEventLoop::ProcessEventsFlag>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QEventLoop_ProcessEventsFlag_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // processEvents(QFlags<QEventLoop::ProcessEventsFlag>)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 2; // processEvents(QFlags<QEventLoop::ProcessEventsFlag>,int)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1])))) {
            overloadId = 1; // processEvents(QFlags<QEventLoop::ProcessEventsFlag>,QDeadlineTimer)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // processEvents(QFlags<QEventLoop::ProcessEventsFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QEventLoop_ProcessEventsFlag_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QFlags<QEventLoop::ProcessEventsFlag> cppArg0(QEventLoop::AllEvents);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // processEvents(QFlags<QEventLoop::ProcessEventsFlag>)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                ::QCoreApplication::processEvents(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // processEvents(QFlags<QEventLoop::ProcessEventsFlag> flags, QDeadlineTimer deadline)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            ::QFlags<QEventLoop::ProcessEventsFlag> cppArg0 = QFlags<QEventLoop::ProcessEventsFlag>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QDeadlineTimer cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // processEvents(QFlags<QEventLoop::ProcessEventsFlag>,QDeadlineTimer)
                ::QCoreApplication::processEvents(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // processEvents(QFlags<QEventLoop::ProcessEventsFlag> flags, int maxtime)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            ::QFlags<QEventLoop::ProcessEventsFlag> cppArg0 = QFlags<QEventLoop::ProcessEventsFlag>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // processEvents(QFlags<QEventLoop::ProcessEventsFlag>,int)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                ::QCoreApplication::processEvents(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_quit(PyObject *self)
{
    SBK_UNUSED(self)
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.quit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // quit()
            ::QCoreApplication::quit();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_removeLibraryPath(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.removeLibraryPath";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::removeLibraryPath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeLibraryPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeLibraryPath(QString)
            ::QCoreApplication::removeLibraryPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_removeNativeEventFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCoreApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.removeNativeEventFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCoreApplication::removeNativeEventFilter(QAbstractNativeEventFilter*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractNativeEventFilter_IDX]), (pyArg)))) {
        overloadId = 0; // removeNativeEventFilter(QAbstractNativeEventFilter*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractNativeEventFilter *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeNativeEventFilter(QAbstractNativeEventFilter*)
            cppSelf->removeNativeEventFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_removePostedEvents(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.removePostedEvents";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:removePostedEvents", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCoreApplication::removePostedEvents(QObject*,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // removePostedEvents(QObject*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // removePostedEvents(QObject*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_eventType = Shiboken::String::createStaticString("eventType");
            if (PyDict_Contains(kwds, key_eventType) != 0) {
                value = PyDict_GetItem(kwds, key_eventType);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_eventType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_eventType);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removePostedEvents(QObject*,int)
            ::QCoreApplication::removePostedEvents(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_removeTranslator(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.removeTranslator";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::removeTranslator(QTranslator*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTranslator_IDX]), (pyArg)))) {
        overloadId = 0; // removeTranslator(QTranslator*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTranslator *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeTranslator(QTranslator*)
            bool cppResult = ::QCoreApplication::removeTranslator(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_requestPermission(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCoreApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.requestPermission";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "requestPermission", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCoreApplication::requestPermission(QBluetoothPermission,const QObject*,PyCallable*)
    // 1: QCoreApplication::requestPermission(QCalendarPermission,const QObject*,PyCallable*)
    // 2: QCoreApplication::requestPermission(QCameraPermission,const QObject*,PyCallable*)
    // 3: QCoreApplication::requestPermission(QContactsPermission,const QObject*,PyCallable*)
    // 4: QCoreApplication::requestPermission(QLocationPermission,const QObject*,PyCallable*)
    // 5: QCoreApplication::requestPermission(QMicrophonePermission,const QObject*,PyCallable*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMicrophonePermission_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && PyCallable_Check(pyArgs[2])) {
        overloadId = 5; // requestPermission(QMicrophonePermission,const QObject*,PyCallable*)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocationPermission_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && PyCallable_Check(pyArgs[2])) {
        overloadId = 4; // requestPermission(QLocationPermission,const QObject*,PyCallable*)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QContactsPermission_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && PyCallable_Check(pyArgs[2])) {
        overloadId = 3; // requestPermission(QContactsPermission,const QObject*,PyCallable*)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCameraPermission_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && PyCallable_Check(pyArgs[2])) {
        overloadId = 2; // requestPermission(QCameraPermission,const QObject*,PyCallable*)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendarPermission_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && PyCallable_Check(pyArgs[2])) {
        overloadId = 1; // requestPermission(QCalendarPermission,const QObject*,PyCallable*)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QBluetoothPermission_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && PyCallable_Check(pyArgs[2])) {
        overloadId = 0; // requestPermission(QBluetoothPermission,const QObject*,PyCallable*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // requestPermission(const QBluetoothPermission &permission, const QObject *context, PyCallable *functor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QBluetoothPermission cppArg0_local;
            ::QBluetoothPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // requestPermission(QBluetoothPermission,const QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                auto permission = (*cppArg0);
                auto callable = pyArgs[3-1];

                // check if callable
                if (!PyCallable_Check(callable)) {
                    qWarning("Functor of requestPermission is not a callable");
                    return {};
                }

                // find the number of arguments of callable. It should either be empy or accept a QPermission
                // object
                int count = 0;
                PyObject* fc = nullptr;
                bool classMethod = false;
                Shiboken::AutoDecRef func_ob(PyObject_GetAttr(callable, Shiboken::PyMagicName::func()));

                if (func_ob.isNull() && PyObject_HasAttr(callable, Shiboken::PyMagicName::code())) {
                    // variable `callable` is a function
                    fc = PyObject_GetAttr(callable, Shiboken::PyMagicName::code());
                } else {
                    // variable `callable` is a class method
                    fc = PyObject_GetAttr(func_ob, Shiboken::PyMagicName::code());
                    classMethod = true;
                }

                if (fc) {
                    PyObject* ac = PyObject_GetAttrString(fc, "co_argcount");
                    if (ac) {
                        count = PyLong_AsLong(ac);
                        Py_DECREF(ac);
                    }
                    Py_DECREF(fc);
                }

                if ((classMethod && (count > 2)) || (!classMethod && (count > 1))) {
                    qWarning("Functor of requestPermission must either have QPermission object as argument or none."
                             "The QPermission object store the result of requestPermission()");
                    return {};
                }

                bool arg_qpermission = (classMethod && (count == 2)) || (!classMethod && (count == 1));

                auto callback = [callable, arg_qpermission](const QPermission &permission) -> void
                {
                    Shiboken::GilState state;
                    if (arg_qpermission) {
                        Shiboken::AutoDecRef arglist(PyTuple_New(1));
                        PyTuple_SET_ITEM(arglist.object(), 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), &permission));
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                    } else {
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, nullptr));
                    }
                    Py_DECREF(callable);
                };
                Py_INCREF(callable);

                Py_BEGIN_ALLOW_THREADS
                cppSelf->requestPermission(permission, cppArg1, callback);
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // requestPermission(const QCalendarPermission &permission, const QObject *context, PyCallable *functor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCalendarPermission cppArg0_local;
            ::QCalendarPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // requestPermission(QCalendarPermission,const QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                auto permission = (*cppArg0);
                auto callable = pyArgs[3-1];

                // check if callable
                if (!PyCallable_Check(callable)) {
                    qWarning("Functor of requestPermission is not a callable");
                    return {};
                }

                // find the number of arguments of callable. It should either be empy or accept a QPermission
                // object
                int count = 0;
                PyObject* fc = nullptr;
                bool classMethod = false;
                Shiboken::AutoDecRef func_ob(PyObject_GetAttr(callable, Shiboken::PyMagicName::func()));

                if (func_ob.isNull() && PyObject_HasAttr(callable, Shiboken::PyMagicName::code())) {
                    // variable `callable` is a function
                    fc = PyObject_GetAttr(callable, Shiboken::PyMagicName::code());
                } else {
                    // variable `callable` is a class method
                    fc = PyObject_GetAttr(func_ob, Shiboken::PyMagicName::code());
                    classMethod = true;
                }

                if (fc) {
                    PyObject* ac = PyObject_GetAttrString(fc, "co_argcount");
                    if (ac) {
                        count = PyLong_AsLong(ac);
                        Py_DECREF(ac);
                    }
                    Py_DECREF(fc);
                }

                if ((classMethod && (count > 2)) || (!classMethod && (count > 1))) {
                    qWarning("Functor of requestPermission must either have QPermission object as argument or none."
                             "The QPermission object store the result of requestPermission()");
                    return {};
                }

                bool arg_qpermission = (classMethod && (count == 2)) || (!classMethod && (count == 1));

                auto callback = [callable, arg_qpermission](const QPermission &permission) -> void
                {
                    Shiboken::GilState state;
                    if (arg_qpermission) {
                        Shiboken::AutoDecRef arglist(PyTuple_New(1));
                        PyTuple_SET_ITEM(arglist.object(), 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), &permission));
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                    } else {
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, nullptr));
                    }
                    Py_DECREF(callable);
                };
                Py_INCREF(callable);

                Py_BEGIN_ALLOW_THREADS
                cppSelf->requestPermission(permission, cppArg1, callback);
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 2: // requestPermission(const QCameraPermission &permission, const QObject *context, PyCallable *functor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QCameraPermission cppArg0_local;
            ::QCameraPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // requestPermission(QCameraPermission,const QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                auto permission = (*cppArg0);
                auto callable = pyArgs[3-1];

                // check if callable
                if (!PyCallable_Check(callable)) {
                    qWarning("Functor of requestPermission is not a callable");
                    return {};
                }

                // find the number of arguments of callable. It should either be empy or accept a QPermission
                // object
                int count = 0;
                PyObject* fc = nullptr;
                bool classMethod = false;
                Shiboken::AutoDecRef func_ob(PyObject_GetAttr(callable, Shiboken::PyMagicName::func()));

                if (func_ob.isNull() && PyObject_HasAttr(callable, Shiboken::PyMagicName::code())) {
                    // variable `callable` is a function
                    fc = PyObject_GetAttr(callable, Shiboken::PyMagicName::code());
                } else {
                    // variable `callable` is a class method
                    fc = PyObject_GetAttr(func_ob, Shiboken::PyMagicName::code());
                    classMethod = true;
                }

                if (fc) {
                    PyObject* ac = PyObject_GetAttrString(fc, "co_argcount");
                    if (ac) {
                        count = PyLong_AsLong(ac);
                        Py_DECREF(ac);
                    }
                    Py_DECREF(fc);
                }

                if ((classMethod && (count > 2)) || (!classMethod && (count > 1))) {
                    qWarning("Functor of requestPermission must either have QPermission object as argument or none."
                             "The QPermission object store the result of requestPermission()");
                    return {};
                }

                bool arg_qpermission = (classMethod && (count == 2)) || (!classMethod && (count == 1));

                auto callback = [callable, arg_qpermission](const QPermission &permission) -> void
                {
                    Shiboken::GilState state;
                    if (arg_qpermission) {
                        Shiboken::AutoDecRef arglist(PyTuple_New(1));
                        PyTuple_SET_ITEM(arglist.object(), 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), &permission));
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                    } else {
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, nullptr));
                    }
                    Py_DECREF(callable);
                };
                Py_INCREF(callable);

                Py_BEGIN_ALLOW_THREADS
                cppSelf->requestPermission(permission, cppArg1, callback);
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 3: // requestPermission(const QContactsPermission &permission, const QObject *context, PyCallable *functor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QContactsPermission cppArg0_local;
            ::QContactsPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // requestPermission(QContactsPermission,const QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                auto permission = (*cppArg0);
                auto callable = pyArgs[3-1];

                // check if callable
                if (!PyCallable_Check(callable)) {
                    qWarning("Functor of requestPermission is not a callable");
                    return {};
                }

                // find the number of arguments of callable. It should either be empy or accept a QPermission
                // object
                int count = 0;
                PyObject* fc = nullptr;
                bool classMethod = false;
                Shiboken::AutoDecRef func_ob(PyObject_GetAttr(callable, Shiboken::PyMagicName::func()));

                if (func_ob.isNull() && PyObject_HasAttr(callable, Shiboken::PyMagicName::code())) {
                    // variable `callable` is a function
                    fc = PyObject_GetAttr(callable, Shiboken::PyMagicName::code());
                } else {
                    // variable `callable` is a class method
                    fc = PyObject_GetAttr(func_ob, Shiboken::PyMagicName::code());
                    classMethod = true;
                }

                if (fc) {
                    PyObject* ac = PyObject_GetAttrString(fc, "co_argcount");
                    if (ac) {
                        count = PyLong_AsLong(ac);
                        Py_DECREF(ac);
                    }
                    Py_DECREF(fc);
                }

                if ((classMethod && (count > 2)) || (!classMethod && (count > 1))) {
                    qWarning("Functor of requestPermission must either have QPermission object as argument or none."
                             "The QPermission object store the result of requestPermission()");
                    return {};
                }

                bool arg_qpermission = (classMethod && (count == 2)) || (!classMethod && (count == 1));

                auto callback = [callable, arg_qpermission](const QPermission &permission) -> void
                {
                    Shiboken::GilState state;
                    if (arg_qpermission) {
                        Shiboken::AutoDecRef arglist(PyTuple_New(1));
                        PyTuple_SET_ITEM(arglist.object(), 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), &permission));
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                    } else {
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, nullptr));
                    }
                    Py_DECREF(callable);
                };
                Py_INCREF(callable);

                Py_BEGIN_ALLOW_THREADS
                cppSelf->requestPermission(permission, cppArg1, callback);
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 4: // requestPermission(const QLocationPermission &permission, const QObject *context, PyCallable *functor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLocationPermission cppArg0_local;
            ::QLocationPermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // requestPermission(QLocationPermission,const QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                auto permission = (*cppArg0);
                auto callable = pyArgs[3-1];

                // check if callable
                if (!PyCallable_Check(callable)) {
                    qWarning("Functor of requestPermission is not a callable");
                    return {};
                }

                // find the number of arguments of callable. It should either be empy or accept a QPermission
                // object
                int count = 0;
                PyObject* fc = nullptr;
                bool classMethod = false;
                Shiboken::AutoDecRef func_ob(PyObject_GetAttr(callable, Shiboken::PyMagicName::func()));

                if (func_ob.isNull() && PyObject_HasAttr(callable, Shiboken::PyMagicName::code())) {
                    // variable `callable` is a function
                    fc = PyObject_GetAttr(callable, Shiboken::PyMagicName::code());
                } else {
                    // variable `callable` is a class method
                    fc = PyObject_GetAttr(func_ob, Shiboken::PyMagicName::code());
                    classMethod = true;
                }

                if (fc) {
                    PyObject* ac = PyObject_GetAttrString(fc, "co_argcount");
                    if (ac) {
                        count = PyLong_AsLong(ac);
                        Py_DECREF(ac);
                    }
                    Py_DECREF(fc);
                }

                if ((classMethod && (count > 2)) || (!classMethod && (count > 1))) {
                    qWarning("Functor of requestPermission must either have QPermission object as argument or none."
                             "The QPermission object store the result of requestPermission()");
                    return {};
                }

                bool arg_qpermission = (classMethod && (count == 2)) || (!classMethod && (count == 1));

                auto callback = [callable, arg_qpermission](const QPermission &permission) -> void
                {
                    Shiboken::GilState state;
                    if (arg_qpermission) {
                        Shiboken::AutoDecRef arglist(PyTuple_New(1));
                        PyTuple_SET_ITEM(arglist.object(), 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), &permission));
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                    } else {
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, nullptr));
                    }
                    Py_DECREF(callable);
                };
                Py_INCREF(callable);

                Py_BEGIN_ALLOW_THREADS
                cppSelf->requestPermission(permission, cppArg1, callback);
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 5: // requestPermission(const QMicrophonePermission &permission, const QObject *context, PyCallable *functor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMicrophonePermission cppArg0_local;
            ::QMicrophonePermission *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // requestPermission(QMicrophonePermission,const QObject*,PyCallable*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                auto permission = (*cppArg0);
                auto callable = pyArgs[3-1];

                // check if callable
                if (!PyCallable_Check(callable)) {
                    qWarning("Functor of requestPermission is not a callable");
                    return {};
                }

                // find the number of arguments of callable. It should either be empy or accept a QPermission
                // object
                int count = 0;
                PyObject* fc = nullptr;
                bool classMethod = false;
                Shiboken::AutoDecRef func_ob(PyObject_GetAttr(callable, Shiboken::PyMagicName::func()));

                if (func_ob.isNull() && PyObject_HasAttr(callable, Shiboken::PyMagicName::code())) {
                    // variable `callable` is a function
                    fc = PyObject_GetAttr(callable, Shiboken::PyMagicName::code());
                } else {
                    // variable `callable` is a class method
                    fc = PyObject_GetAttr(func_ob, Shiboken::PyMagicName::code());
                    classMethod = true;
                }

                if (fc) {
                    PyObject* ac = PyObject_GetAttrString(fc, "co_argcount");
                    if (ac) {
                        count = PyLong_AsLong(ac);
                        Py_DECREF(ac);
                    }
                    Py_DECREF(fc);
                }

                if ((classMethod && (count > 2)) || (!classMethod && (count > 1))) {
                    qWarning("Functor of requestPermission must either have QPermission object as argument or none."
                             "The QPermission object store the result of requestPermission()");
                    return {};
                }

                bool arg_qpermission = (classMethod && (count == 2)) || (!classMethod && (count == 1));

                auto callback = [callable, arg_qpermission](const QPermission &permission) -> void
                {
                    Shiboken::GilState state;
                    if (arg_qpermission) {
                        Shiboken::AutoDecRef arglist(PyTuple_New(1));
                        PyTuple_SET_ITEM(arglist.object(), 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPermission_IDX]), &permission));
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                    } else {
                        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, nullptr));
                    }
                    Py_DECREF(callable);
                };
                Py_INCREF(callable);

                Py_BEGIN_ALLOW_THREADS
                cppSelf->requestPermission(permission, cppArg1, callback);
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qcoreapplication-requestpermission)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_resolveInterface(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCoreApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.resolveInterface";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resolveInterface", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCoreApplication::resolveInterface(const char*,int)const->void*
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // resolveInterface(const char*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resolveInterface(const char*,int)const
            void * cppResult = const_cast<const ::QCoreApplication *>(cppSelf)->resolveInterface(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_sendEvent(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.sendEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sendEvent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCoreApplication::sendEvent(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // sendEvent(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sendEvent(QObject*,QEvent*)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = ::QCoreApplication::sendEvent(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_sendPostedEvents(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.sendPostedEvents";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:sendPostedEvents", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCoreApplication::sendPostedEvents(QObject*=,int=)
    if (numArgs == 0) {
        overloadId = 0; // sendPostedEvents(QObject*,int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sendPostedEvents(QObject*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // sendPostedEvents(QObject*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_receiver = Shiboken::String::createStaticString("receiver");
            if (PyDict_Contains(kwds, key_receiver) != 0) {
                value = PyDict_GetItem(kwds, key_receiver);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_receiver);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_receiver);
            }
            static PyObject *const key_event_type = Shiboken::String::createStaticString("event_type");
            if (PyDict_Contains(kwds, key_event_type) != 0) {
                value = PyDict_GetItem(kwds, key_event_type);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_event_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_event_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sendPostedEvents(QObject*,int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QCoreApplication::sendPostedEvents(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_setApplicationName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.setApplicationName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::setApplicationName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setApplicationName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setApplicationName(QString)
            ::QCoreApplication::setApplicationName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_setApplicationVersion(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.setApplicationVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::setApplicationVersion(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setApplicationVersion(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setApplicationVersion(QString)
            ::QCoreApplication::setApplicationVersion(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_setAttribute(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.setAttribute";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setAttribute", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCoreApplication::setAttribute(Qt::ApplicationAttribute,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ApplicationAttribute_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setAttribute(Qt::ApplicationAttribute,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setAttribute(Qt::ApplicationAttribute,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_on = Shiboken::String::createStaticString("on");
            if (PyDict_Contains(kwds, key_on) != 0) {
                value = PyDict_GetItem(kwds, key_on);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_on);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_on);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::Qt::ApplicationAttribute cppArg0 = static_cast< ::Qt::ApplicationAttribute>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAttribute(Qt::ApplicationAttribute,bool)
            ::QCoreApplication::setAttribute(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_setEventDispatcher(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.setEventDispatcher";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::setEventDispatcher(QAbstractEventDispatcher*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractEventDispatcher_IDX]), (pyArg)))) {
        overloadId = 0; // setEventDispatcher(QAbstractEventDispatcher*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractEventDispatcher *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEventDispatcher(QAbstractEventDispatcher*)
            ::QCoreApplication::setEventDispatcher(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_setLibraryPaths(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.setLibraryPaths";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::setLibraryPaths(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setLibraryPaths(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLibraryPaths(QStringList)
            ::QCoreApplication::setLibraryPaths(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_setOrganizationDomain(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.setOrganizationDomain";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::setOrganizationDomain(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setOrganizationDomain(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOrganizationDomain(QString)
            ::QCoreApplication::setOrganizationDomain(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_setOrganizationName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.setOrganizationName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::setOrganizationName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setOrganizationName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOrganizationName(QString)
            ::QCoreApplication::setOrganizationName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_setQuitLockEnabled(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.setQuitLockEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::setQuitLockEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setQuitLockEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQuitLockEnabled(bool)
            ::QCoreApplication::setQuitLockEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_setSetuidAllowed(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.setSetuidAllowed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::setSetuidAllowed(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSetuidAllowed(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSetuidAllowed(bool)
            ::QCoreApplication::setSetuidAllowed(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_shutdown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCoreApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.shutdown";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // shutdown()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (moduleshutdown)]
            PySide::runCleanupFunctions();
            // END of custom code block [file: ../glue/qtcore.cpp (moduleshutdown)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCoreApplicationFunc_startingUp(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.startingUp";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // startingUp()
            bool cppResult = ::QCoreApplication::startingUp();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_testAttribute(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.testAttribute";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCoreApplication::testAttribute(Qt::ApplicationAttribute)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ApplicationAttribute_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // testAttribute(Qt::ApplicationAttribute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::Qt::ApplicationAttribute cppArg0 = static_cast< ::Qt::ApplicationAttribute>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // testAttribute(Qt::ApplicationAttribute)
            bool cppResult = ::QCoreApplication::testAttribute(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCoreApplicationFunc_translate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCoreApplication.translate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:translate", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCoreApplication::translate(const char*,const char*,const char*=,int=)->QString
    if (numArgs >= 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // translate(const char*,const char*,const char*,int)
        } else if (numArgs >= 3
            && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // translate(const char*,const char*,const char*,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 0; // translate(const char*,const char*,const char*,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_disambiguation = Shiboken::String::createStaticString("disambiguation");
            if (PyDict_Contains(kwds, key_disambiguation) != 0) {
                value = PyDict_GetItem(kwds, key_disambiguation);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_disambiguation);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_disambiguation);
            }
            static PyObject *const key_n = Shiboken::String::createStaticString("n");
            if (PyDict_Contains(kwds, key_n) != 0) {
                value = PyDict_GetItem(kwds, key_n);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_n);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_n);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        const char* cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = -1;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // translate(const char*,const char*,const char*,int)
            QString cppResult = ::QCoreApplication::translate(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCoreApplication_PropertyStrings[] = {
    "applicationName::",
    "applicationVersion::",
    "organizationDomain::",
    "organizationName::",
    "quitLockEnabled:isQuitLockEnabled:",
    nullptr // Sentinel
};

static const char *Sbk_QCoreApplication_EnumFlagInfo[] = {
    "ApplicationFlags:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCoreApplication_methods[] = {
    {"addLibraryPath", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_addLibraryPath), METH_O|METH_STATIC, nullptr},
    {"applicationDirPath", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_applicationDirPath), METH_NOARGS|METH_STATIC, nullptr},
    {"applicationFilePath", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_applicationFilePath), METH_NOARGS|METH_STATIC, nullptr},
    {"applicationName", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_applicationName), METH_NOARGS|METH_STATIC, nullptr},
    {"applicationPid", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_applicationPid), METH_NOARGS|METH_STATIC, nullptr},
    {"applicationVersion", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_applicationVersion), METH_NOARGS|METH_STATIC, nullptr},
    {"arguments", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_arguments), METH_NOARGS|METH_STATIC, nullptr},
    {"checkPermission", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_checkPermission), METH_O, nullptr},
    {"closingDown", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_closingDown), METH_NOARGS|METH_STATIC, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_event), METH_O, nullptr},
    {"eventDispatcher", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_eventDispatcher), METH_NOARGS|METH_STATIC, nullptr},
    {"exec", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_exec), METH_NOARGS|METH_STATIC, nullptr},
    {"exec_", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_exec_), METH_NOARGS, nullptr},
    {"exit", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_exit), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"installNativeEventFilter", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_installNativeEventFilter), METH_O, nullptr},
    {"installTranslator", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_installTranslator), METH_O|METH_STATIC, nullptr},
    {"instance", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_instance), METH_NOARGS|METH_STATIC, nullptr},
    {"isQuitLockEnabled", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_isQuitLockEnabled), METH_NOARGS|METH_STATIC, nullptr},
    {"isSetuidAllowed", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_isSetuidAllowed), METH_NOARGS|METH_STATIC, nullptr},
    {"libraryPaths", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_libraryPaths), METH_NOARGS|METH_STATIC, nullptr},
    {"notify", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_notify), METH_VARARGS, nullptr},
    {"organizationDomain", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_organizationDomain), METH_NOARGS|METH_STATIC, nullptr},
    {"organizationName", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_organizationName), METH_NOARGS|METH_STATIC, nullptr},
    {"postEvent", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_postEvent), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"processEvents", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_processEvents), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"quit", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_quit), METH_NOARGS|METH_STATIC, nullptr},
    {"removeLibraryPath", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_removeLibraryPath), METH_O|METH_STATIC, nullptr},
    {"removeNativeEventFilter", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_removeNativeEventFilter), METH_O, nullptr},
    {"removePostedEvents", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_removePostedEvents), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"removeTranslator", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_removeTranslator), METH_O|METH_STATIC, nullptr},
    {"requestPermission", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_requestPermission), METH_VARARGS, nullptr},
    {"resolveInterface", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_resolveInterface), METH_VARARGS, nullptr},
    {"sendEvent", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_sendEvent), METH_VARARGS|METH_STATIC, nullptr},
    {"sendPostedEvents", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_sendPostedEvents), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"setApplicationName", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_setApplicationName), METH_O|METH_STATIC, nullptr},
    {"setApplicationVersion", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_setApplicationVersion), METH_O|METH_STATIC, nullptr},
    {"setAttribute", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_setAttribute), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"setEventDispatcher", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_setEventDispatcher), METH_O|METH_STATIC, nullptr},
    {"setLibraryPaths", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_setLibraryPaths), METH_O|METH_STATIC, nullptr},
    {"setOrganizationDomain", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_setOrganizationDomain), METH_O|METH_STATIC, nullptr},
    {"setOrganizationName", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_setOrganizationName), METH_O|METH_STATIC, nullptr},
    {"setQuitLockEnabled", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_setQuitLockEnabled), METH_O|METH_STATIC, nullptr},
    {"setSetuidAllowed", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_setSetuidAllowed), METH_O|METH_STATIC, nullptr},
    {"shutdown", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_shutdown), METH_NOARGS, nullptr},
    {"startingUp", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_startingUp), METH_NOARGS|METH_STATIC, nullptr},
    {"testAttribute", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_testAttribute), METH_O|METH_STATIC, nullptr},
    {"translate", reinterpret_cast<PyCFunction>(Sbk_QCoreApplicationFunc_translate), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCoreApplication_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QCoreApplication *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QCoreApplicationWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QCoreApplication_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCoreApplication_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCoreApplication_Type = nullptr;
static PyTypeObject *Sbk_QCoreApplication_TypeF(void)
{
    return _Sbk_QCoreApplication_Type;
}

static PyType_Slot Sbk_QCoreApplication_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocQAppWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QCoreApplication_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCoreApplication_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCoreApplication_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCoreApplication_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCoreApplication_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkQApp_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCoreApplication_spec = {
    "2:PySide6.QtCore.QCoreApplication",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCoreApplication_slots
};

} //extern "C"

static void *Sbk_QCoreApplication_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QCoreApplication *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCoreApplication_PythonToCpp_QCoreApplication_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCoreApplication_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCoreApplication_PythonToCpp_QCoreApplication_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCoreApplication_TypeF()))
        return QCoreApplication_PythonToCpp_QCoreApplication_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCoreApplication_PTR_CppToPython_QCoreApplication(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QCoreApplication *>(const_cast<void *>(cppIn)), Sbk_QCoreApplication_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QCoreApplication_SignatureStrings[] = {
    "1:PySide6.QtCore.QCoreApplication(self)",
    "0:PySide6.QtCore.QCoreApplication(self,args:QStringList)",
    "PySide6.QtCore.QCoreApplication.addLibraryPath(arg__1:QString)",
    "PySide6.QtCore.QCoreApplication.applicationDirPath()->QString",
    "PySide6.QtCore.QCoreApplication.applicationFilePath()->QString",
    "PySide6.QtCore.QCoreApplication.applicationName()->QString",
    "PySide6.QtCore.QCoreApplication.applicationPid()->qint64",
    "PySide6.QtCore.QCoreApplication.applicationVersion()->QString",
    "PySide6.QtCore.QCoreApplication.arguments()->QStringList",
    "6:PySide6.QtCore.QCoreApplication.checkPermission(self,permission:PySide6.QtCore.QBluetoothPermission)->PySide6.QtCore.Qt.PermissionStatus",
    "5:PySide6.QtCore.QCoreApplication.checkPermission(self,permission:PySide6.QtCore.QCalendarPermission)->PySide6.QtCore.Qt.PermissionStatus",
    "4:PySide6.QtCore.QCoreApplication.checkPermission(self,permission:PySide6.QtCore.QCameraPermission)->PySide6.QtCore.Qt.PermissionStatus",
    "3:PySide6.QtCore.QCoreApplication.checkPermission(self,permission:PySide6.QtCore.QContactsPermission)->PySide6.QtCore.Qt.PermissionStatus",
    "2:PySide6.QtCore.QCoreApplication.checkPermission(self,permission:PySide6.QtCore.QLocationPermission)->PySide6.QtCore.Qt.PermissionStatus",
    "1:PySide6.QtCore.QCoreApplication.checkPermission(self,permission:PySide6.QtCore.QMicrophonePermission)->PySide6.QtCore.Qt.PermissionStatus",
    "0:PySide6.QtCore.QCoreApplication.checkPermission(self,permission:PySide6.QtCore.QPermission)->PySide6.QtCore.Qt.PermissionStatus",
    "PySide6.QtCore.QCoreApplication.closingDown()->bool",
    "PySide6.QtCore.QCoreApplication.event(self,arg__1:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtCore.QCoreApplication.eventDispatcher()->PySide6.QtCore.QAbstractEventDispatcher",
    "PySide6.QtCore.QCoreApplication.exec()->int",
    "PySide6.QtCore.QCoreApplication.exec_(self)->int",
    "PySide6.QtCore.QCoreApplication.exit(retcode:int=0)",
    "PySide6.QtCore.QCoreApplication.installNativeEventFilter(self,filterObj:PySide6.QtCore.QAbstractNativeEventFilter)",
    "PySide6.QtCore.QCoreApplication.installTranslator(messageFile:PySide6.QtCore.QTranslator)->bool",
    "PySide6.QtCore.QCoreApplication.instance()->Optional[PySide6.QtCore.QCoreApplication]",
    "PySide6.QtCore.QCoreApplication.isQuitLockEnabled()->bool",
    "PySide6.QtCore.QCoreApplication.isSetuidAllowed()->bool",
    "PySide6.QtCore.QCoreApplication.libraryPaths()->QStringList",
    "PySide6.QtCore.QCoreApplication.notify(self,arg__1:PySide6.QtCore.QObject,arg__2:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtCore.QCoreApplication.organizationDomain()->QString",
    "PySide6.QtCore.QCoreApplication.organizationName()->QString",
    "PySide6.QtCore.QCoreApplication.postEvent(receiver:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent,priority:int=Qt.NormalEventPriority)",
    "2:PySide6.QtCore.QCoreApplication.processEvents(flags:PySide6.QtCore.QEventLoop.ProcessEventsFlag=QEventLoop.AllEvents)",
    "1:PySide6.QtCore.QCoreApplication.processEvents(flags:PySide6.QtCore.QEventLoop.ProcessEventsFlag,deadline:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])",
    "0:PySide6.QtCore.QCoreApplication.processEvents(flags:PySide6.QtCore.QEventLoop.ProcessEventsFlag,maxtime:int)",
    "PySide6.QtCore.QCoreApplication.quit()",
    "PySide6.QtCore.QCoreApplication.removeLibraryPath(arg__1:QString)",
    "PySide6.QtCore.QCoreApplication.removeNativeEventFilter(self,filterObj:PySide6.QtCore.QAbstractNativeEventFilter)",
    "PySide6.QtCore.QCoreApplication.removePostedEvents(receiver:PySide6.QtCore.QObject,eventType:int=0)",
    "PySide6.QtCore.QCoreApplication.removeTranslator(messageFile:PySide6.QtCore.QTranslator)->bool",
    "5:PySide6.QtCore.QCoreApplication.requestPermission(self,permission:PySide6.QtCore.QBluetoothPermission,context:PySide6.QtCore.QObject,functor:PyCallable)",
    "4:PySide6.QtCore.QCoreApplication.requestPermission(self,permission:PySide6.QtCore.QCalendarPermission,context:PySide6.QtCore.QObject,functor:PyCallable)",
    "3:PySide6.QtCore.QCoreApplication.requestPermission(self,permission:PySide6.QtCore.QCameraPermission,context:PySide6.QtCore.QObject,functor:PyCallable)",
    "2:PySide6.QtCore.QCoreApplication.requestPermission(self,permission:PySide6.QtCore.QContactsPermission,context:PySide6.QtCore.QObject,functor:PyCallable)",
    "1:PySide6.QtCore.QCoreApplication.requestPermission(self,permission:PySide6.QtCore.QLocationPermission,context:PySide6.QtCore.QObject,functor:PyCallable)",
    "0:PySide6.QtCore.QCoreApplication.requestPermission(self,permission:PySide6.QtCore.QMicrophonePermission,context:PySide6.QtCore.QObject,functor:PyCallable)",
    "PySide6.QtCore.QCoreApplication.resolveInterface(self,name:char*,revision:int)->void",
    "PySide6.QtCore.QCoreApplication.sendEvent(receiver:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtCore.QCoreApplication.sendPostedEvents(receiver:PySide6.QtCore.QObject=nullptr,event_type:int=0)",
    "PySide6.QtCore.QCoreApplication.setApplicationName(application:QString)",
    "PySide6.QtCore.QCoreApplication.setApplicationVersion(version:QString)",
    "PySide6.QtCore.QCoreApplication.setAttribute(attribute:PySide6.QtCore.Qt.ApplicationAttribute,on:bool=true)",
    "PySide6.QtCore.QCoreApplication.setEventDispatcher(eventDispatcher:PySide6.QtCore.QAbstractEventDispatcher)",
    "PySide6.QtCore.QCoreApplication.setLibraryPaths(arg__1:QStringList)",
    "PySide6.QtCore.QCoreApplication.setOrganizationDomain(orgDomain:QString)",
    "PySide6.QtCore.QCoreApplication.setOrganizationName(orgName:QString)",
    "PySide6.QtCore.QCoreApplication.setQuitLockEnabled(enabled:bool)",
    "PySide6.QtCore.QCoreApplication.setSetuidAllowed(allow:bool)",
    "PySide6.QtCore.QCoreApplication.shutdown(self)",
    "PySide6.QtCore.QCoreApplication.startingUp()->bool",
    "PySide6.QtCore.QCoreApplication.testAttribute(attribute:PySide6.QtCore.Qt.ApplicationAttribute)->bool",
    "PySide6.QtCore.QCoreApplication.translate(context:str,key:str,disambiguation:Optional[str]=nullptr,n:int=-1)->QString",
    nullptr}; // Sentinel

PyTypeObject *init_QCoreApplication(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX].type;

    Shiboken::AutoDecRef Sbk_QCoreApplication_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QCoreApplication_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCoreApplication",
        "QCoreApplication*",
        &Sbk_QCoreApplication_spec,
        &Shiboken::callCppDestructor< QCoreApplication >,
        Sbk_QCoreApplication_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCoreApplication_TypeF(); // references _Sbk_QCoreApplication_Type
    InitSignatureStrings(pyType, QCoreApplication_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCoreApplication_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCoreApplication_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCoreApplication_PythonToCpp_QCoreApplication_PTR,
        is_QCoreApplication_PythonToCpp_QCoreApplication_PTR_Convertible,
        QCoreApplication_PTR_CppToPython_QCoreApplication);

    Shiboken::Conversions::registerConverterName(converter, "QCoreApplication");
    Shiboken::Conversions::registerConverterName(converter, "QCoreApplication*");
    Shiboken::Conversions::registerConverterName(converter, "QCoreApplication&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCoreApplication).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QCoreApplicationWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QCoreApplication_TypeF(), &Sbk_QCoreApplication_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCoreApplication_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of anonymous enum identified by enum value 'ApplicationFlags'.
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t ApplicationFlags_InitializerValues[] = {
        uint32_t(QCoreApplication::ApplicationFlags) //  0x00060703  395011
        };
    tpDict.reset(PepType_GetDict(reinterpret_cast<PyTypeObject *>(Sbk_QCoreApplication_TypeF())));
    PyDict_SetItemString(tpDict.object(), "ApplicationFlags",
        PyLong_FromUnsignedLongLong(ApplicationFlags_InitializerValues[0]));
    // End of 'ApplicationFlags' enum.

    SBK_UNUSED(EType)
    PySide::Signal::registerSignals(pyType, &::QCoreApplication::staticMetaObject);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QCoreApplication::staticMetaObject, sizeof(QCoreApplicationWrapper));

    return pyType;
}

