// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qdynamicpropertychangeevent_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDynamicPropertyChangeEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDynamicPropertyChangeEventWrapper::QDynamicPropertyChangeEventWrapper(const ::QByteArray & name) : QDynamicPropertyChangeEvent(name)
{
    resetPyMethodCache();
    // ... middle
}

::QDynamicPropertyChangeEvent * QDynamicPropertyChangeEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QDynamicPropertyChangeEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QDynamicPropertyChangeEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDynamicPropertyChangeEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDynamicPropertyChangeEvent", funcName, Shiboken::SbkType< QDynamicPropertyChangeEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QDynamicPropertyChangeEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDynamicPropertyChangeEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QDynamicPropertyChangeEventWrapper::~QDynamicPropertyChangeEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDynamicPropertyChangeEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDynamicPropertyChangeEvent >()))
        return -1;

    QDynamicPropertyChangeEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QDynamicPropertyChangeEvent.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDynamicPropertyChangeEvent", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent(QByteArray)
    // 1: QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent(QDynamicPropertyChangeEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDynamicPropertyChangeEvent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDynamicPropertyChangeEvent(QDynamicPropertyChangeEvent)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QDynamicPropertyChangeEvent(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDynamicPropertyChangeEvent(const QByteArray &name)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDynamicPropertyChangeEvent(QByteArray)
                cptr = new QDynamicPropertyChangeEventWrapper(*cppArg0);
            }
            break;
        }
        case 1: // QDynamicPropertyChangeEvent(const QDynamicPropertyChangeEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDynamicPropertyChangeEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDynamicPropertyChangeEvent(QDynamicPropertyChangeEvent)
                cptr = new QDynamicPropertyChangeEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDynamicPropertyChangeEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDynamicPropertyChangeEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDynamicPropertyChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDynamicPropertyChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDynamicPropertyChangeEvent.clone";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clone()const
            QDynamicPropertyChangeEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QDynamicPropertyChangeEvent *>(cppSelf)->::QDynamicPropertyChangeEvent::clone()
                : const_cast<const ::QDynamicPropertyChangeEvent *>(cppSelf)->clone();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDynamicPropertyChangeEvent_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDynamicPropertyChangeEventFunc_propertyName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDynamicPropertyChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDynamicPropertyChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QDynamicPropertyChangeEvent.propertyName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // propertyName()const
            QByteArray cppResult = const_cast<const ::QDynamicPropertyChangeEvent *>(cppSelf)->propertyName();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDynamicPropertyChangeEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDynamicPropertyChangeEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QDynamicPropertyChangeEventFunc_clone), METH_NOARGS, nullptr},
    {"propertyName", reinterpret_cast<PyCFunction>(Sbk_QDynamicPropertyChangeEventFunc_propertyName), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDynamicPropertyChangeEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDynamicPropertyChangeEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDynamicPropertyChangeEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDynamicPropertyChangeEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDynamicPropertyChangeEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDynamicPropertyChangeEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDynamicPropertyChangeEvent_Type = nullptr;
static PyTypeObject *Sbk_QDynamicPropertyChangeEvent_TypeF(void)
{
    return _Sbk_QDynamicPropertyChangeEvent_Type;
}

static PyType_Slot Sbk_QDynamicPropertyChangeEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDynamicPropertyChangeEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDynamicPropertyChangeEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDynamicPropertyChangeEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDynamicPropertyChangeEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDynamicPropertyChangeEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDynamicPropertyChangeEvent_spec = {
    "2:PySide6.QtCore.QDynamicPropertyChangeEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDynamicPropertyChangeEvent_slots
};

} //extern "C"

static void *Sbk_QDynamicPropertyChangeEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::DynamicPropertyChange)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDynamicPropertyChangeEvent_PythonToCpp_QDynamicPropertyChangeEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDynamicPropertyChangeEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDynamicPropertyChangeEvent_PythonToCpp_QDynamicPropertyChangeEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDynamicPropertyChangeEvent_TypeF()))
        return QDynamicPropertyChangeEvent_PythonToCpp_QDynamicPropertyChangeEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDynamicPropertyChangeEvent_PTR_CppToPython_QDynamicPropertyChangeEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QDynamicPropertyChangeEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QDynamicPropertyChangeEvent_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QDynamicPropertyChangeEvent_SignatureStrings[] = {
    "1:PySide6.QtCore.QDynamicPropertyChangeEvent(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "0:PySide6.QtCore.QDynamicPropertyChangeEvent(self,arg__1:PySide6.QtCore.QDynamicPropertyChangeEvent)",
    "PySide6.QtCore.QDynamicPropertyChangeEvent.clone(self)->PySide6.QtCore.QDynamicPropertyChangeEvent",
    "PySide6.QtCore.QDynamicPropertyChangeEvent.propertyName(self)->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel

PyTypeObject *init_QDynamicPropertyChangeEvent(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QDynamicPropertyChangeEvent_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QDynamicPropertyChangeEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QDynamicPropertyChangeEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QDynamicPropertyChangeEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDynamicPropertyChangeEvent",
        "QDynamicPropertyChangeEvent*",
        &Sbk_QDynamicPropertyChangeEvent_spec,
        &Shiboken::callCppDestructor< QDynamicPropertyChangeEvent >,
        Sbk_QDynamicPropertyChangeEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDynamicPropertyChangeEvent_TypeF(); // references _Sbk_QDynamicPropertyChangeEvent_Type
    InitSignatureStrings(pyType, QDynamicPropertyChangeEvent_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDynamicPropertyChangeEvent_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QDynamicPropertyChangeEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDynamicPropertyChangeEvent_PythonToCpp_QDynamicPropertyChangeEvent_PTR,
        is_QDynamicPropertyChangeEvent_PythonToCpp_QDynamicPropertyChangeEvent_PTR_Convertible,
        QDynamicPropertyChangeEvent_PTR_CppToPython_QDynamicPropertyChangeEvent);

    Shiboken::Conversions::registerConverterName(converter, "QDynamicPropertyChangeEvent");
    Shiboken::Conversions::registerConverterName(converter, "QDynamicPropertyChangeEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QDynamicPropertyChangeEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDynamicPropertyChangeEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDynamicPropertyChangeEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDynamicPropertyChangeEvent_TypeF(), &Sbk_QDynamicPropertyChangeEvent_typeDiscovery);


    return pyType;
}
