// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qevent_wrapper.h"

// Argument includes
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QEventWrapper::QEventWrapper(::QEvent::Type type) : QEvent(type)
{
    resetPyMethodCache();
    // ... middle
}

::QEvent * QEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QEvent", funcName, Shiboken::SbkType< QEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QEventWrapper::~QEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QEvent >()))
        return -1;

    QEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QEvent.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QEvent", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QEvent::QEvent(QEvent::Type)
    // 1: QEvent::QEvent(QEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QEvent(QEvent)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QEvent(QEvent::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QEvent(QEvent::Type type)
        {
            ::QEvent::Type cppArg0{QEvent::None};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QEvent(QEvent::Type)
                cptr = new QEventWrapper(cppArg0);
            }
            break;
        }
        case 1: // QEvent(const QEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QEvent(QEvent)
                cptr = new QEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QEventFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QEvent.__repr__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __repr__()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (repr-qevent)]
            QString result;
            QDebug(&result).nospace() << "<PySide6.QtCore.QEvent(" << cppSelf->type() << ")>";
            pyResult = Shiboken::String::fromCString(qPrintable(result));
            // END of custom code block [file: ../glue/qtcore.cpp (repr-qevent)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventFunc_accept(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QEvent.accept";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // accept()
            cppSelf->accept();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QEvent.clone";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clone()const
            QEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QEvent *>(cppSelf)->::QEvent::clone()
                : const_cast<const ::QEvent *>(cppSelf)->clone();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventFunc_ignore(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QEvent.ignore";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // ignore()
            cppSelf->ignore();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEventFunc_isAccepted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QEvent.isAccepted";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAccepted()const
            bool cppResult = const_cast<const ::QEvent *>(cppSelf)->isAccepted();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventFunc_isInputEvent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QEvent.isInputEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isInputEvent()const
            bool cppResult = const_cast<const ::QEvent *>(cppSelf)->isInputEvent();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventFunc_isPointerEvent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QEvent.isPointerEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isPointerEvent()const
            bool cppResult = const_cast<const ::QEvent *>(cppSelf)->isPointerEvent();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventFunc_isSinglePointEvent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QEvent.isSinglePointEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSinglePointEvent()const
            bool cppResult = const_cast<const ::QEvent *>(cppSelf)->isSinglePointEvent();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventFunc_registerEventType(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QEvent.registerEventType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:registerEventType", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QEvent::registerEventType(int=)->int
    if (numArgs == 0) {
        overloadId = 0; // registerEventType(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // registerEventType(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_hint = Shiboken::String::createStaticString("hint");
            if (PyDict_Contains(kwds, key_hint) != 0) {
                value = PyDict_GetItem(kwds, key_hint);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_hint);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_hint);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0 = -1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerEventType(int)
            int cppResult = ::QEvent::registerEventType(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventFunc_setAccepted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QEvent.setAccepted";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QEvent::setAccepted(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAccepted(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAccepted(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QEvent::setAccepted(cppArg0)
                : cppSelf->setAccepted(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QEventFunc_spontaneous(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QEvent.spontaneous";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // spontaneous()const
            bool cppResult = const_cast<const ::QEvent *>(cppSelf)->spontaneous();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QEventFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QEvent.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QEvent::Type cppResult = const_cast<const ::QEvent *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QEvent_EnumFlagInfo[] = {
    "Type:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QEvent_methods[] = {
    {"accept", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_accept), METH_NOARGS, nullptr},
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_clone), METH_NOARGS, nullptr},
    {"ignore", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_ignore), METH_NOARGS, nullptr},
    {"isAccepted", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_isAccepted), METH_NOARGS, nullptr},
    {"isInputEvent", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_isInputEvent), METH_NOARGS, nullptr},
    {"isPointerEvent", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_isPointerEvent), METH_NOARGS, nullptr},
    {"isSinglePointEvent", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_isSinglePointEvent), METH_NOARGS, nullptr},
    {"registerEventType", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_registerEventType), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"setAccepted", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_setAccepted), METH_O, nullptr},
    {"spontaneous", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_spontaneous), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QEventFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QEvent_Type = nullptr;
static PyTypeObject *Sbk_QEvent_TypeF(void)
{
    return _Sbk_QEvent_Type;
}

static PyType_Slot Sbk_QEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QEventFunc___repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QEvent_spec = {
    "2:PySide6.QtCore.QEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QEvent_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QEvent_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QEvent::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QEvent::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QEvent_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))
        return Enum_PythonToCpp_QEvent_Type;
    return {};
}
static PyObject *QEvent_Type_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QEvent::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QEvent_PythonToCpp_QEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QEvent_PythonToCpp_QEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QEvent_TypeF()))
        return QEvent_PythonToCpp_QEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QEvent_PTR_CppToPython_QEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QEvent_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QEvent_SignatureStrings[] = {
    "1:PySide6.QtCore.QEvent(self,type:PySide6.QtCore.QEvent.Type)",
    "0:PySide6.QtCore.QEvent(self,arg__1:PySide6.QtCore.QEvent)",
    "PySide6.QtCore.QEvent.__repr__(self)->PyObject",
    "PySide6.QtCore.QEvent.accept(self)",
    "PySide6.QtCore.QEvent.clone(self)->PySide6.QtCore.QEvent",
    "PySide6.QtCore.QEvent.ignore(self)",
    "PySide6.QtCore.QEvent.isAccepted(self)->bool",
    "PySide6.QtCore.QEvent.isInputEvent(self)->bool",
    "PySide6.QtCore.QEvent.isPointerEvent(self)->bool",
    "PySide6.QtCore.QEvent.isSinglePointEvent(self)->bool",
    "PySide6.QtCore.QEvent.registerEventType(hint:int=-1)->int",
    "PySide6.QtCore.QEvent.setAccepted(self,accepted:bool)",
    "PySide6.QtCore.QEvent.spontaneous(self)->bool",
    "PySide6.QtCore.QEvent.type(self)->PySide6.QtCore.QEvent.Type",
    nullptr}; // Sentinel

PyTypeObject *init_QEvent(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QEvent_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QEvent",
        "QEvent*",
        &Sbk_QEvent_spec,
        &Shiboken::callCppDestructor< QEvent >,
        Sbk_QEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QEvent_TypeF(); // references _Sbk_QEvent_Type
    InitSignatureStrings(pyType, QEvent_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QEvent_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QEvent_PythonToCpp_QEvent_PTR,
        is_QEvent_PythonToCpp_QEvent_PTR_Convertible,
        QEvent_PTR_CppToPython_QEvent);

    Shiboken::Conversions::registerConverterName(converter, "QEvent");
    Shiboken::Conversions::registerConverterName(converter, "QEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QEventWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QEvent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "None_",
        "Timer",
        "MouseButtonPress",
        "MouseButtonRelease",
        "MouseButtonDblClick",
        "MouseMove",
        "KeyPress",
        "KeyRelease",
        "FocusIn",
        "FocusOut",
        "FocusAboutToChange",
        "Enter",
        "Leave",
        "Paint",
        "Move",
        "Resize",
        "Create",
        "Destroy",
        "Show",
        "Hide",
        "Close",
        "Quit",
        "ParentChange",
        "ParentAboutToChange",
        "ThreadChange",
        "WindowActivate",
        "WindowDeactivate",
        "ShowToParent",
        "HideToParent",
        "Wheel",
        "WindowTitleChange",
        "WindowIconChange",
        "ApplicationWindowIconChange",
        "ApplicationFontChange",
        "ApplicationLayoutDirectionChange",
        "ApplicationPaletteChange",
        "PaletteChange",
        "Clipboard",
        "Speech",
        "MetaCall",
        "SockAct",
        "WinEventAct",
        "DeferredDelete",
        "DragEnter",
        "DragMove",
        "DragLeave",
        "Drop",
        "DragResponse",
        "ChildAdded",
        "ChildPolished",
        "ChildRemoved",
        "ShowWindowRequest",
        "PolishRequest",
        "Polish",
        "LayoutRequest",
        "UpdateRequest",
        "UpdateLater",
        "EmbeddingControl",
        "ActivateControl",
        "DeactivateControl",
        "ContextMenu",
        "InputMethod",
        "TabletMove",
        "LocaleChange",
        "LanguageChange",
        "LayoutDirectionChange",
        "Style",
        "TabletPress",
        "TabletRelease",
        "OkRequest",
        "HelpRequest",
        "IconDrag",
        "FontChange",
        "EnabledChange",
        "ActivationChange",
        "StyleChange",
        "IconTextChange",
        "ModifiedChange",
        "MouseTrackingChange",
        "WindowBlocked",
        "WindowUnblocked",
        "WindowStateChange",
        "ReadOnlyChange",
        "ToolTip",
        "WhatsThis",
        "StatusTip",
        "ActionChanged",
        "ActionAdded",
        "ActionRemoved",
        "FileOpen",
        "Shortcut",
        "ShortcutOverride",
        "WhatsThisClicked",
        "ToolBarChange",
        "ApplicationActivate",
        "ApplicationActivated",
        "ApplicationDeactivate",
        "ApplicationDeactivated",
        "QueryWhatsThis",
        "EnterWhatsThisMode",
        "LeaveWhatsThisMode",
        "ZOrderChange",
        "HoverEnter",
        "HoverLeave",
        "HoverMove",
        "AcceptDropsChange",
        "ZeroTimerEvent",
        "GraphicsSceneMouseMove",
        "GraphicsSceneMousePress",
        "GraphicsSceneMouseRelease",
        "GraphicsSceneMouseDoubleClick",
        "GraphicsSceneContextMenu",
        "GraphicsSceneHoverEnter",
        "GraphicsSceneHoverMove",
        "GraphicsSceneHoverLeave",
        "GraphicsSceneHelp",
        "GraphicsSceneDragEnter",
        "GraphicsSceneDragMove",
        "GraphicsSceneDragLeave",
        "GraphicsSceneDrop",
        "GraphicsSceneWheel",
        "GraphicsSceneLeave",
        "KeyboardLayoutChange",
        "DynamicPropertyChange",
        "TabletEnterProximity",
        "TabletLeaveProximity",
        "NonClientAreaMouseMove",
        "NonClientAreaMouseButtonPress",
        "NonClientAreaMouseButtonRelease",
        "NonClientAreaMouseButtonDblClick",
        "MacSizeChange",
        "ContentsRectChange",
        "MacGLWindowChange",
        "FutureCallOut",
        "GraphicsSceneResize",
        "GraphicsSceneMove",
        "CursorChange",
        "ToolTipChange",
        "NetworkReplyUpdated",
        "GrabMouse",
        "UngrabMouse",
        "GrabKeyboard",
        "UngrabKeyboard",
        "StateMachineSignal",
        "StateMachineWrapped",
        "TouchBegin",
        "TouchUpdate",
        "TouchEnd",
        "NativeGesture",
        "RequestSoftwareInputPanel",
        "CloseSoftwareInputPanel",
        "WinIdChange",
        "Gesture",
        "GestureOverride",
        "ScrollPrepare",
        "Scroll",
        "Expose",
        "InputMethodQuery",
        "OrientationChange",
        "TouchCancel",
        "ThemeChange",
        "SockClose",
        "PlatformPanel",
        "StyleAnimationUpdate",
        "ApplicationStateChange",
        "WindowChangeInternal",
        "ScreenChangeInternal",
        "PlatformSurface",
        "Pointer",
        "TabletTrackingChange",
        "WindowAboutToChangeInternal",
        "DevicePixelRatioChange",
        "ChildWindowAdded",
        "ChildWindowRemoved",
        "ParentWindowAboutToChange",
        "ParentWindowChange",
        "User",
        "MaxUser",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Type_InitializerValues[] = {
        uint16_t(QEvent::Type::None),                             //  0x0000  0
        uint16_t(QEvent::Type::Timer),                            //  0x0001  1
        uint16_t(QEvent::Type::MouseButtonPress),                 //  0x0002  2
        uint16_t(QEvent::Type::MouseButtonRelease),               //  0x0003  3
        uint16_t(QEvent::Type::MouseButtonDblClick),              //  0x0004  4
        uint16_t(QEvent::Type::MouseMove),                        //  0x0005  5
        uint16_t(QEvent::Type::KeyPress),                         //  0x0006  6
        uint16_t(QEvent::Type::KeyRelease),                       //  0x0007  7
        uint16_t(QEvent::Type::FocusIn),                          //  0x0008  8
        uint16_t(QEvent::Type::FocusOut),                         //  0x0009  9
        uint16_t(QEvent::Type::FocusAboutToChange),               //  0x0017  23
        uint16_t(QEvent::Type::Enter),                            //  0x000a  10
        uint16_t(QEvent::Type::Leave),                            //  0x000b  11
        uint16_t(QEvent::Type::Paint),                            //  0x000c  12
        uint16_t(QEvent::Type::Move),                             //  0x000d  13
        uint16_t(QEvent::Type::Resize),                           //  0x000e  14
        uint16_t(QEvent::Type::Create),                           //  0x000f  15
        uint16_t(QEvent::Type::Destroy),                          //  0x0010  16
        uint16_t(QEvent::Type::Show),                             //  0x0011  17
        uint16_t(QEvent::Type::Hide),                             //  0x0012  18
        uint16_t(QEvent::Type::Close),                            //  0x0013  19
        uint16_t(QEvent::Type::Quit),                             //  0x0014  20
        uint16_t(QEvent::Type::ParentChange),                     //  0x0015  21
        uint16_t(QEvent::Type::ParentAboutToChange),              //  0x0083  131
        uint16_t(QEvent::Type::ThreadChange),                     //  0x0016  22
        uint16_t(QEvent::Type::WindowActivate),                   //  0x0018  24
        uint16_t(QEvent::Type::WindowDeactivate),                 //  0x0019  25
        uint16_t(QEvent::Type::ShowToParent),                     //  0x001a  26
        uint16_t(QEvent::Type::HideToParent),                     //  0x001b  27
        uint16_t(QEvent::Type::Wheel),                            //  0x001f  31
        uint16_t(QEvent::Type::WindowTitleChange),                //  0x0021  33
        uint16_t(QEvent::Type::WindowIconChange),                 //  0x0022  34
        uint16_t(QEvent::Type::ApplicationWindowIconChange),      //  0x0023  35
        uint16_t(QEvent::Type::ApplicationFontChange),            //  0x0024  36
        uint16_t(QEvent::Type::ApplicationLayoutDirectionChange), //  0x0025  37
        uint16_t(QEvent::Type::ApplicationPaletteChange),         //  0x0026  38
        uint16_t(QEvent::Type::PaletteChange),                    //  0x0027  39
        uint16_t(QEvent::Type::Clipboard),                        //  0x0028  40
        uint16_t(QEvent::Type::Speech),                           //  0x002a  42
        uint16_t(QEvent::Type::MetaCall),                         //  0x002b  43
        uint16_t(QEvent::Type::SockAct),                          //  0x0032  50
        uint16_t(QEvent::Type::WinEventAct),                      //  0x0084  132
        uint16_t(QEvent::Type::DeferredDelete),                   //  0x0034  52
        uint16_t(QEvent::Type::DragEnter),                        //  0x003c  60
        uint16_t(QEvent::Type::DragMove),                         //  0x003d  61
        uint16_t(QEvent::Type::DragLeave),                        //  0x003e  62
        uint16_t(QEvent::Type::Drop),                             //  0x003f  63
        uint16_t(QEvent::Type::DragResponse),                     //  0x0040  64
        uint16_t(QEvent::Type::ChildAdded),                       //  0x0044  68
        uint16_t(QEvent::Type::ChildPolished),                    //  0x0045  69
        uint16_t(QEvent::Type::ChildRemoved),                     //  0x0047  71
        uint16_t(QEvent::Type::ShowWindowRequest),                //  0x0049  73
        uint16_t(QEvent::Type::PolishRequest),                    //  0x004a  74
        uint16_t(QEvent::Type::Polish),                           //  0x004b  75
        uint16_t(QEvent::Type::LayoutRequest),                    //  0x004c  76
        uint16_t(QEvent::Type::UpdateRequest),                    //  0x004d  77
        uint16_t(QEvent::Type::UpdateLater),                      //  0x004e  78
        uint16_t(QEvent::Type::EmbeddingControl),                 //  0x004f  79
        uint16_t(QEvent::Type::ActivateControl),                  //  0x0050  80
        uint16_t(QEvent::Type::DeactivateControl),                //  0x0051  81
        uint16_t(QEvent::Type::ContextMenu),                      //  0x0052  82
        uint16_t(QEvent::Type::InputMethod),                      //  0x0053  83
        uint16_t(QEvent::Type::TabletMove),                       //  0x0057  87
        uint16_t(QEvent::Type::LocaleChange),                     //  0x0058  88
        uint16_t(QEvent::Type::LanguageChange),                   //  0x0059  89
        uint16_t(QEvent::Type::LayoutDirectionChange),            //  0x005a  90
        uint16_t(QEvent::Type::Style),                            //  0x005b  91
        uint16_t(QEvent::Type::TabletPress),                      //  0x005c  92
        uint16_t(QEvent::Type::TabletRelease),                    //  0x005d  93
        uint16_t(QEvent::Type::OkRequest),                        //  0x005e  94
        uint16_t(QEvent::Type::HelpRequest),                      //  0x005f  95
        uint16_t(QEvent::Type::IconDrag),                         //  0x0060  96
        uint16_t(QEvent::Type::FontChange),                       //  0x0061  97
        uint16_t(QEvent::Type::EnabledChange),                    //  0x0062  98
        uint16_t(QEvent::Type::ActivationChange),                 //  0x0063  99
        uint16_t(QEvent::Type::StyleChange),                      //  0x0064  100
        uint16_t(QEvent::Type::IconTextChange),                   //  0x0065  101
        uint16_t(QEvent::Type::ModifiedChange),                   //  0x0066  102
        uint16_t(QEvent::Type::MouseTrackingChange),              //  0x006d  109
        uint16_t(QEvent::Type::WindowBlocked),                    //  0x0067  103
        uint16_t(QEvent::Type::WindowUnblocked),                  //  0x0068  104
        uint16_t(QEvent::Type::WindowStateChange),                //  0x0069  105
        uint16_t(QEvent::Type::ReadOnlyChange),                   //  0x006a  106
        uint16_t(QEvent::Type::ToolTip),                          //  0x006e  110
        uint16_t(QEvent::Type::WhatsThis),                        //  0x006f  111
        uint16_t(QEvent::Type::StatusTip),                        //  0x0070  112
        uint16_t(QEvent::Type::ActionChanged),                    //  0x0071  113
        uint16_t(QEvent::Type::ActionAdded),                      //  0x0072  114
        uint16_t(QEvent::Type::ActionRemoved),                    //  0x0073  115
        uint16_t(QEvent::Type::FileOpen),                         //  0x0074  116
        uint16_t(QEvent::Type::Shortcut),                         //  0x0075  117
        uint16_t(QEvent::Type::ShortcutOverride),                 //  0x0033  51
        uint16_t(QEvent::Type::WhatsThisClicked),                 //  0x0076  118
        uint16_t(QEvent::Type::ToolBarChange),                    //  0x0078  120
        uint16_t(QEvent::Type::ApplicationActivate),              //  0x0079  121
        uint16_t(QEvent::Type::ApplicationActivated),             //  0x0079  121
        uint16_t(QEvent::Type::ApplicationDeactivate),            //  0x007a  122
        uint16_t(QEvent::Type::ApplicationDeactivated),           //  0x007a  122
        uint16_t(QEvent::Type::QueryWhatsThis),                   //  0x007b  123
        uint16_t(QEvent::Type::EnterWhatsThisMode),               //  0x007c  124
        uint16_t(QEvent::Type::LeaveWhatsThisMode),               //  0x007d  125
        uint16_t(QEvent::Type::ZOrderChange),                     //  0x007e  126
        uint16_t(QEvent::Type::HoverEnter),                       //  0x007f  127
        uint16_t(QEvent::Type::HoverLeave),                       //  0x0080  128
        uint16_t(QEvent::Type::HoverMove),                        //  0x0081  129
        uint16_t(QEvent::Type::AcceptDropsChange),                //  0x0098  152
        uint16_t(QEvent::Type::ZeroTimerEvent),                   //  0x009a  154
        uint16_t(QEvent::Type::GraphicsSceneMouseMove),           //  0x009b  155
        uint16_t(QEvent::Type::GraphicsSceneMousePress),          //  0x009c  156
        uint16_t(QEvent::Type::GraphicsSceneMouseRelease),        //  0x009d  157
        uint16_t(QEvent::Type::GraphicsSceneMouseDoubleClick),    //  0x009e  158
        uint16_t(QEvent::Type::GraphicsSceneContextMenu),         //  0x009f  159
        uint16_t(QEvent::Type::GraphicsSceneHoverEnter),          //  0x00a0  160
        uint16_t(QEvent::Type::GraphicsSceneHoverMove),           //  0x00a1  161
        uint16_t(QEvent::Type::GraphicsSceneHoverLeave),          //  0x00a2  162
        uint16_t(QEvent::Type::GraphicsSceneHelp),                //  0x00a3  163
        uint16_t(QEvent::Type::GraphicsSceneDragEnter),           //  0x00a4  164
        uint16_t(QEvent::Type::GraphicsSceneDragMove),            //  0x00a5  165
        uint16_t(QEvent::Type::GraphicsSceneDragLeave),           //  0x00a6  166
        uint16_t(QEvent::Type::GraphicsSceneDrop),                //  0x00a7  167
        uint16_t(QEvent::Type::GraphicsSceneWheel),               //  0x00a8  168
        uint16_t(QEvent::Type::GraphicsSceneLeave),               //  0x00dc  220
        uint16_t(QEvent::Type::KeyboardLayoutChange),             //  0x00a9  169
        uint16_t(QEvent::Type::DynamicPropertyChange),            //  0x00aa  170
        uint16_t(QEvent::Type::TabletEnterProximity),             //  0x00ab  171
        uint16_t(QEvent::Type::TabletLeaveProximity),             //  0x00ac  172
        uint16_t(QEvent::Type::NonClientAreaMouseMove),           //  0x00ad  173
        uint16_t(QEvent::Type::NonClientAreaMouseButtonPress),    //  0x00ae  174
        uint16_t(QEvent::Type::NonClientAreaMouseButtonRelease),  //  0x00af  175
        uint16_t(QEvent::Type::NonClientAreaMouseButtonDblClick), //  0x00b0  176
        uint16_t(QEvent::Type::MacSizeChange),                    //  0x00b1  177
        uint16_t(QEvent::Type::ContentsRectChange),               //  0x00b2  178
        uint16_t(QEvent::Type::MacGLWindowChange),                //  0x00b3  179
        uint16_t(QEvent::Type::FutureCallOut),                    //  0x00b4  180
        uint16_t(QEvent::Type::GraphicsSceneResize),              //  0x00b5  181
        uint16_t(QEvent::Type::GraphicsSceneMove),                //  0x00b6  182
        uint16_t(QEvent::Type::CursorChange),                     //  0x00b7  183
        uint16_t(QEvent::Type::ToolTipChange),                    //  0x00b8  184
        uint16_t(QEvent::Type::NetworkReplyUpdated),              //  0x00b9  185
        uint16_t(QEvent::Type::GrabMouse),                        //  0x00ba  186
        uint16_t(QEvent::Type::UngrabMouse),                      //  0x00bb  187
        uint16_t(QEvent::Type::GrabKeyboard),                     //  0x00bc  188
        uint16_t(QEvent::Type::UngrabKeyboard),                   //  0x00bd  189
        uint16_t(QEvent::Type::StateMachineSignal),               //  0x00c0  192
        uint16_t(QEvent::Type::StateMachineWrapped),              //  0x00c1  193
        uint16_t(QEvent::Type::TouchBegin),                       //  0x00c2  194
        uint16_t(QEvent::Type::TouchUpdate),                      //  0x00c3  195
        uint16_t(QEvent::Type::TouchEnd),                         //  0x00c4  196
        uint16_t(QEvent::Type::NativeGesture),                    //  0x00c5  197
        uint16_t(QEvent::Type::RequestSoftwareInputPanel),        //  0x00c7  199
        uint16_t(QEvent::Type::CloseSoftwareInputPanel),          //  0x00c8  200
        uint16_t(QEvent::Type::WinIdChange),                      //  0x00cb  203
        uint16_t(QEvent::Type::Gesture),                          //  0x00c6  198
        uint16_t(QEvent::Type::GestureOverride),                  //  0x00ca  202
        uint16_t(QEvent::Type::ScrollPrepare),                    //  0x00cc  204
        uint16_t(QEvent::Type::Scroll),                           //  0x00cd  205
        uint16_t(QEvent::Type::Expose),                           //  0x00ce  206
        uint16_t(QEvent::Type::InputMethodQuery),                 //  0x00cf  207
        uint16_t(QEvent::Type::OrientationChange),                //  0x00d0  208
        uint16_t(QEvent::Type::TouchCancel),                      //  0x00d1  209
        uint16_t(QEvent::Type::ThemeChange),                      //  0x00d2  210
        uint16_t(QEvent::Type::SockClose),                        //  0x00d3  211
        uint16_t(QEvent::Type::PlatformPanel),                    //  0x00d4  212
        uint16_t(QEvent::Type::StyleAnimationUpdate),             //  0x00d5  213
        uint16_t(QEvent::Type::ApplicationStateChange),           //  0x00d6  214
        uint16_t(QEvent::Type::WindowChangeInternal),             //  0x00d7  215
        uint16_t(QEvent::Type::ScreenChangeInternal),             //  0x00d8  216
        uint16_t(QEvent::Type::PlatformSurface),                  //  0x00d9  217
        uint16_t(QEvent::Type::Pointer),                          //  0x00da  218
        uint16_t(QEvent::Type::TabletTrackingChange),             //  0x00db  219
        uint16_t(QEvent::Type::WindowAboutToChangeInternal),      //  0x00dd  221
        uint16_t(QEvent::Type::DevicePixelRatioChange),           //  0x00de  222
        uint16_t(QEvent::Type::ChildWindowAdded),                 //  0x00df  223
        uint16_t(QEvent::Type::ChildWindowRemoved),               //  0x00e0  224
        uint16_t(QEvent::Type::ParentWindowAboutToChange),        //  0x00e1  225
        uint16_t(QEvent::Type::ParentWindowChange),               //  0x00e2  226
        uint16_t(QEvent::Type::User),                             //  0x03e8  1000
        uint16_t(QEvent::Type::MaxUser)                           //  0xffff  65535
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QEvent_TypeF(),
        "2:PySide6.QtCore.QEvent.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX].type = EType;
    // Register converter for enum 'QEvent::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QEvent_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QEvent_Type,
            is_Enum_PythonToCpp_QEvent_Type_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QEvent::Type");
        Shiboken::Conversions::registerConverterName(converter, "Type");
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::QEvent *>();
    qRegisterMetaType< ::QEvent::Type >("QEvent::Type");

    return pyType;
}
