// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QFileWrapper_H
#define SBK_QFileWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <qfile.h>

namespace PySide { class DynamicQMetaObject; }

// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
class QFileWrapper : public QFile
{
public:
    QFileWrapper(const QFileWrapper &) = delete;
    QFileWrapper& operator=(const QFileWrapper &) = delete;
    QFileWrapper(QFileWrapper &&) = delete;
    QFileWrapper& operator=(QFileWrapper &&) = delete;

    QFileWrapper();
    QFileWrapper(::QObject * parent);
    QFileWrapper(const ::QString & name);
    QFileWrapper(const ::QString & name, ::QObject * parent);
    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(::QChildEvent * event) override;
    void close() override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * event) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    ::QString fileName() const override;
    bool isSequential() const override;
    bool open(::QFlags<QIODeviceBase::OpenModeFlag> flags) override;
    ::QFlags<QFileDevice::Permission> permissions() const override;
    qint64 pos() const override;
    qint64 readData(char * data, qint64 maxlen) override;
    qint64 readLineData(char * data, qint64 maxlen) override;
    bool reset() override;
    bool resize(qint64 sz) override;
    bool seek(qint64 offset) override;
    bool setPermissions(::QFlags<QFileDevice::Permission> permissionSpec) override;
    qint64 size() const override;
    qint64 skipData(qint64 maxSize) override;
    void timerEvent(::QTimerEvent * event) override;
    bool waitForBytesWritten(int msecs) override;
    bool waitForReadyRead(int msecs) override;
    qint64 writeData(const char * data, qint64 len) override;
    ~QFileWrapper() override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    // Inherited overloads, because the using keyword sux
    inline bool open(int fd, ::QFlags<QIODeviceBase::OpenModeFlag> ioFlags, ::QFlags<QFileDevice::FileHandleFlag> handleFlags = QFileDevice::FileHandleFlag::DontCloseHandle) { return QFile::open(fd, QFlags<QIODeviceBase::OpenModeFlag>(ioFlags), QFlags<QFileDevice::FileHandleFlag>(handleFlags)); }
    inline bool open(::QFlags<QIODeviceBase::OpenModeFlag> flags, ::QFlags<QFileDevice::Permission> permissions) { return QFile::open(QFlags<QIODeviceBase::OpenModeFlag>(flags), QFlags<QFileDevice::Permission>(permissions)); }
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[28];
};

#endif // SBK_QFileWrapper_H

