// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qhashseed_wrapper.h"

// Argument includes
#include <qhashfunctions.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHashSeed_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHashSeed >()))
        return -1;

    ::QHashSeed *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QHashSeed.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:QHashSeed", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHashSeed::QHashSeed(QHashSeed)
    // 1: QHashSeed::QHashSeed(size_t=)
    if (numArgs == 0) {
        overloadId = 1; // QHashSeed(size_t)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[0])))) {
        overloadId = 1; // QHashSeed(size_t)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QHashSeed_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QHashSeed(QHashSeed)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHashSeed(const QHashSeed &QHashSeed)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHashSeed cppArg0_local;
            ::QHashSeed *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QHashSeed(QHashSeed)
                cptr = new ::QHashSeed(*cppArg0);
            }
            break;
        }
        case 1: // QHashSeed(size_t d)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_d = Shiboken::String::createStaticString("d");
                if (PyDict_Contains(kwds, key_d) != 0) {
                    value = PyDict_GetItem(kwds, key_d);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_d);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_d);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            size_t cppArg0 = 0;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHashSeed(size_t)
                cptr = new ::QHashSeed(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHashSeed >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHashSeedFunc_globalSeed(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QHashSeed.globalSeed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // globalSeed()
            QHashSeed cppResult = ::QHashSeed::globalSeed();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QHashSeed_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHashSeedFunc_resetRandomGlobalSeed(PyObject *self)
{
    SBK_UNUSED(self)
    static const char fullName[] = "PySide6.QtCore.QHashSeed.resetRandomGlobalSeed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // resetRandomGlobalSeed()
            ::QHashSeed::resetRandomGlobalSeed();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHashSeedFunc_setDeterministicGlobalSeed(PyObject *self)
{
    SBK_UNUSED(self)
    static const char fullName[] = "PySide6.QtCore.QHashSeed.setDeterministicGlobalSeed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDeterministicGlobalSeed()
            ::QHashSeed::setDeterministicGlobalSeed();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHashSeed__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHashSeed *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QHashSeed_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QHashSeed_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHashSeed_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHashSeed_methods[] = {
    {"globalSeed", reinterpret_cast<PyCFunction>(Sbk_QHashSeedFunc_globalSeed), METH_NOARGS|METH_STATIC, nullptr},
    {"resetRandomGlobalSeed", reinterpret_cast<PyCFunction>(Sbk_QHashSeedFunc_resetRandomGlobalSeed), METH_NOARGS|METH_STATIC, nullptr},
    {"setDeterministicGlobalSeed", reinterpret_cast<PyCFunction>(Sbk_QHashSeedFunc_setDeterministicGlobalSeed), METH_NOARGS|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QHashSeed__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QHashSeed_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHashSeed_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHashSeed_Type = nullptr;
static PyTypeObject *Sbk_QHashSeed_TypeF(void)
{
    return _Sbk_QHashSeed_Type;
}

static PyType_Slot Sbk_QHashSeed_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHashSeed_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHashSeed_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHashSeed_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHashSeed_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHashSeed_spec = {
    "2:PySide6.QtCore.QHashSeed",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHashSeed_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHashSeed_PythonToCpp_QHashSeed_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHashSeed_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHashSeed_PythonToCpp_QHashSeed_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHashSeed_TypeF()))
        return QHashSeed_PythonToCpp_QHashSeed_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHashSeed_PTR_CppToPython_QHashSeed(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QHashSeed *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QHashSeed_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QHashSeed_COPY_CppToPython_QHashSeed(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QHashSeed *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QHashSeed_TypeF(), new ::QHashSeed(*source), true, true);
}

// Python to C++ copy conversion.
static void QHashSeed_PythonToCpp_QHashSeed_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QHashSeed *>(cppOut) = *reinterpret_cast< ::QHashSeed *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QHashSeed_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QHashSeed_PythonToCpp_QHashSeed_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QHashSeed_TypeF()))
        return QHashSeed_PythonToCpp_QHashSeed_COPY;
    return {};
}

// Implicit conversions.
static void size_t_PythonToCpp_QHashSeed(PyObject *pyIn, void *cppOut)
{
    size_t cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), pyIn, &cppIn);
    *reinterpret_cast<::QHashSeed *>(cppOut) = ::QHashSeed(cppIn);
}
static PythonToCppFunc is_size_t_PythonToCpp_QHashSeed_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return size_t_PythonToCpp_QHashSeed;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QHashSeed_SignatureStrings[] = {
    "1:PySide6.QtCore.QHashSeed(self,QHashSeed:typing.Union[PySide6.QtCore.QHashSeed, size_t])",
    "0:PySide6.QtCore.QHashSeed(self,d:size_t=0)",
    "PySide6.QtCore.QHashSeed.globalSeed()->PySide6.QtCore.QHashSeed",
    "PySide6.QtCore.QHashSeed.resetRandomGlobalSeed()",
    "PySide6.QtCore.QHashSeed.setDeterministicGlobalSeed()",
    "PySide6.QtCore.QHashSeed.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QHashSeed(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QHashSeed_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QHashSeed_IDX].type;

    Shiboken::AutoDecRef Sbk_QHashSeed_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHashSeed_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHashSeed",
        "QHashSeed",
        &Sbk_QHashSeed_spec,
        &Shiboken::callCppDestructor< ::QHashSeed >,
        Sbk_QHashSeed_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QHashSeed_TypeF(); // references _Sbk_QHashSeed_Type
    InitSignatureStrings(pyType, QHashSeed_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHashSeed_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QHashSeed_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHashSeed_PythonToCpp_QHashSeed_PTR,
        is_QHashSeed_PythonToCpp_QHashSeed_PTR_Convertible,
        QHashSeed_PTR_CppToPython_QHashSeed,
        QHashSeed_COPY_CppToPython_QHashSeed);

    Shiboken::Conversions::registerConverterName(converter, "QHashSeed");
    Shiboken::Conversions::registerConverterName(converter, "QHashSeed*");
    Shiboken::Conversions::registerConverterName(converter, "QHashSeed&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHashSeed).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QHashSeed_PythonToCpp_QHashSeed_COPY,
        is_QHashSeed_PythonToCpp_QHashSeed_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        size_t_PythonToCpp_QHashSeed,
        is_size_t_PythonToCpp_QHashSeed_Convertible);

    qRegisterMetaType< ::QHashSeed >("QHashSeed");

    return pyType;
}
