// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qrecursivemutex_wrapper.h"

// Argument includes
#include <qdeadlinetimer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRecursiveMutex_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRecursiveMutex >()))
        return -1;

    ::QRecursiveMutex *cptr{};
    static const char fullName[] = "PySide6.QtCore.QRecursiveMutex.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QRecursiveMutex()
            cptr = new ::QRecursiveMutex();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRecursiveMutex >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRecursiveMutexFunc_lock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRecursiveMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QRecursiveMutex.lock";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // lock()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->lock();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRecursiveMutexFunc_tryLock(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRecursiveMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QRecursiveMutex.tryLock";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:tryLock", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRecursiveMutex::tryLock(QDeadlineTimer=)->bool
    // 1: QRecursiveMutex::tryLock(int)->bool
    if (numArgs == 0) {
        overloadId = 0; // tryLock(QDeadlineTimer)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // tryLock(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0])))) {
        overloadId = 0; // tryLock(QDeadlineTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // tryLock(QDeadlineTimer timer)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timer = Shiboken::String::createStaticString("timer");
                if (PyDict_Contains(kwds, key_timer) != 0) {
                    value = PyDict_GetItem(kwds, key_timer);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_timer);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_timer);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDeadlineTimer cppArg0{};
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryLock(QDeadlineTimer)
                bool cppResult = cppSelf->tryLock(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // tryLock(int timeout)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // tryLock(int)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->tryLock(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRecursiveMutexFunc_try_lock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRecursiveMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QRecursiveMutex.try_lock";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // try_lock()
            bool cppResult = cppSelf->try_lock();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRecursiveMutexFunc_unlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRecursiveMutex *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QRecursiveMutex.unlock";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // unlock()
            cppSelf->unlock();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QRecursiveMutex_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRecursiveMutex_methods[] = {
    {"lock", reinterpret_cast<PyCFunction>(Sbk_QRecursiveMutexFunc_lock), METH_NOARGS, nullptr},
    {"tryLock", reinterpret_cast<PyCFunction>(Sbk_QRecursiveMutexFunc_tryLock), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"try_lock", reinterpret_cast<PyCFunction>(Sbk_QRecursiveMutexFunc_try_lock), METH_NOARGS, nullptr},
    {"unlock", reinterpret_cast<PyCFunction>(Sbk_QRecursiveMutexFunc_unlock), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRecursiveMutex_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRecursiveMutex_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRecursiveMutex_Type = nullptr;
static PyTypeObject *Sbk_QRecursiveMutex_TypeF(void)
{
    return _Sbk_QRecursiveMutex_Type;
}

static PyType_Slot Sbk_QRecursiveMutex_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRecursiveMutex_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRecursiveMutex_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRecursiveMutex_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRecursiveMutex_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRecursiveMutex_spec = {
    "2:PySide6.QtCore.QRecursiveMutex",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRecursiveMutex_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRecursiveMutex_PythonToCpp_QRecursiveMutex_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRecursiveMutex_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRecursiveMutex_PythonToCpp_QRecursiveMutex_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRecursiveMutex_TypeF()))
        return QRecursiveMutex_PythonToCpp_QRecursiveMutex_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRecursiveMutex_PTR_CppToPython_QRecursiveMutex(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QRecursiveMutex *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QRecursiveMutex_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRecursiveMutex_SignatureStrings[] = {
    "PySide6.QtCore.QRecursiveMutex(self)",
    "PySide6.QtCore.QRecursiveMutex.lock(self)",
    "1:PySide6.QtCore.QRecursiveMutex.tryLock(self,timer:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64]={})->bool",
    "0:PySide6.QtCore.QRecursiveMutex.tryLock(self,timeout:int)->bool",
    "PySide6.QtCore.QRecursiveMutex.try_lock(self)->bool",
    "PySide6.QtCore.QRecursiveMutex.unlock(self)",
    nullptr}; // Sentinel

PyTypeObject *init_QRecursiveMutex(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX].type;

    Shiboken::AutoDecRef Sbk_QRecursiveMutex_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRecursiveMutex_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRecursiveMutex",
        "QRecursiveMutex*",
        &Sbk_QRecursiveMutex_spec,
        &Shiboken::callCppDestructor< ::QRecursiveMutex >,
        Sbk_QRecursiveMutex_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRecursiveMutex_TypeF(); // references _Sbk_QRecursiveMutex_Type
    InitSignatureStrings(pyType, QRecursiveMutex_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRecursiveMutex_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QRecursiveMutex_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRecursiveMutex_PythonToCpp_QRecursiveMutex_PTR,
        is_QRecursiveMutex_PythonToCpp_QRecursiveMutex_PTR_Convertible,
        QRecursiveMutex_PTR_CppToPython_QRecursiveMutex);

    Shiboken::Conversions::registerConverterName(converter, "QRecursiveMutex");
    Shiboken::Conversions::registerConverterName(converter, "QRecursiveMutex*");
    Shiboken::Conversions::registerConverterName(converter, "QRecursiveMutex&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRecursiveMutex).name());

    qRegisterMetaType< ::QRecursiveMutex *>();

    return pyType;
}
