// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qxmlstreamentityresolver_wrapper.h"

// Argument includes
#include <QString>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QXmlStreamEntityResolverWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QXmlStreamEntityResolverWrapper::QXmlStreamEntityResolverWrapper() : QXmlStreamEntityResolver()
{
    resetPyMethodCache();
    // ... middle
}

::QString QXmlStreamEntityResolverWrapper::resolveEntity(const ::QString & publicId, const ::QString & systemId)
{
    if (m_PyMethodCache[0])
        return this->::QXmlStreamEntityResolver::resolveEntity(publicId, systemId);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QString();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resolveEntity";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QXmlStreamEntityResolver::resolveEntity(publicId, systemId);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &publicId),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &systemId)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &publicId),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &systemId)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QXmlStreamEntityResolver", funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QString QXmlStreamEntityResolverWrapper::resolveUndeclaredEntity(const ::QString & name)
{
    if (m_PyMethodCache[1])
        return this->::QXmlStreamEntityResolver::resolveUndeclaredEntity(name);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QString();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resolveUndeclaredEntity";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QXmlStreamEntityResolver::resolveUndeclaredEntity(name);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &name)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QXmlStreamEntityResolver", funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QXmlStreamEntityResolverWrapper::~QXmlStreamEntityResolverWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamEntityResolver_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QXmlStreamEntityResolver >()))
        return -1;

    QXmlStreamEntityResolverWrapper *cptr{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamEntityResolver.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QXmlStreamEntityResolver()
            cptr = new QXmlStreamEntityResolverWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QXmlStreamEntityResolver >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QXmlStreamEntityResolverFunc_resolveEntity(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamEntityResolver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamEntityResolver.resolveEntity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resolveEntity", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QXmlStreamEntityResolver::resolveEntity(QString,QString)->QString
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // resolveEntity(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resolveEntity(QString,QString)
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QXmlStreamEntityResolver::resolveEntity(cppArg0, cppArg1)
                : cppSelf->resolveEntity(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QXmlStreamEntityResolverFunc_resolveUndeclaredEntity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QXmlStreamEntityResolver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QXmlStreamEntityResolver.resolveUndeclaredEntity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QXmlStreamEntityResolver::resolveUndeclaredEntity(QString)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // resolveUndeclaredEntity(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resolveUndeclaredEntity(QString)
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QXmlStreamEntityResolver::resolveUndeclaredEntity(cppArg0)
                : cppSelf->resolveUndeclaredEntity(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QXmlStreamEntityResolver_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QXmlStreamEntityResolver_methods[] = {
    {"resolveEntity", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamEntityResolverFunc_resolveEntity), METH_VARARGS, nullptr},
    {"resolveUndeclaredEntity", reinterpret_cast<PyCFunction>(Sbk_QXmlStreamEntityResolverFunc_resolveUndeclaredEntity), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QXmlStreamEntityResolver_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QXmlStreamEntityResolver *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QXmlStreamEntityResolverWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QXmlStreamEntityResolver_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QXmlStreamEntityResolver_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QXmlStreamEntityResolver_Type = nullptr;
static PyTypeObject *Sbk_QXmlStreamEntityResolver_TypeF(void)
{
    return _Sbk_QXmlStreamEntityResolver_Type;
}

static PyType_Slot Sbk_QXmlStreamEntityResolver_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QXmlStreamEntityResolver_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QXmlStreamEntityResolver_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QXmlStreamEntityResolver_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QXmlStreamEntityResolver_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QXmlStreamEntityResolver_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QXmlStreamEntityResolver_spec = {
    "2:PySide6.QtCore.QXmlStreamEntityResolver",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QXmlStreamEntityResolver_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QXmlStreamEntityResolver_PythonToCpp_QXmlStreamEntityResolver_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QXmlStreamEntityResolver_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QXmlStreamEntityResolver_PythonToCpp_QXmlStreamEntityResolver_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QXmlStreamEntityResolver_TypeF()))
        return QXmlStreamEntityResolver_PythonToCpp_QXmlStreamEntityResolver_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QXmlStreamEntityResolver_PTR_CppToPython_QXmlStreamEntityResolver(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QXmlStreamEntityResolver *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QXmlStreamEntityResolver_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QXmlStreamEntityResolver_SignatureStrings[] = {
    "PySide6.QtCore.QXmlStreamEntityResolver(self)",
    "PySide6.QtCore.QXmlStreamEntityResolver.resolveEntity(self,publicId:QString,systemId:QString)->QString",
    "PySide6.QtCore.QXmlStreamEntityResolver.resolveUndeclaredEntity(self,name:QString)->QString",
    nullptr}; // Sentinel

PyTypeObject *init_QXmlStreamEntityResolver(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX].type;

    Shiboken::AutoDecRef Sbk_QXmlStreamEntityResolver_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QXmlStreamEntityResolver_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QXmlStreamEntityResolver",
        "QXmlStreamEntityResolver*",
        &Sbk_QXmlStreamEntityResolver_spec,
        &Shiboken::callCppDestructor< QXmlStreamEntityResolver >,
        Sbk_QXmlStreamEntityResolver_Type_bases.object(),
        0);
    auto *pyType = Sbk_QXmlStreamEntityResolver_TypeF(); // references _Sbk_QXmlStreamEntityResolver_Type
    InitSignatureStrings(pyType, QXmlStreamEntityResolver_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QXmlStreamEntityResolver_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QXmlStreamEntityResolver_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QXmlStreamEntityResolver_PythonToCpp_QXmlStreamEntityResolver_PTR,
        is_QXmlStreamEntityResolver_PythonToCpp_QXmlStreamEntityResolver_PTR_Convertible,
        QXmlStreamEntityResolver_PTR_CppToPython_QXmlStreamEntityResolver);

    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamEntityResolver");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamEntityResolver*");
    Shiboken::Conversions::registerConverterName(converter, "QXmlStreamEntityResolver&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QXmlStreamEntityResolver).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QXmlStreamEntityResolverWrapper).name());

    qRegisterMetaType< ::QXmlStreamEntityResolver *>();

    return pyType;
}
