// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbusconnection_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <QtDBus/qdbusconnection.h>
#include <QtDBus/qdbusconnectioninterface.h>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>
#include <QtDBus/qdbuspendingcall.h>
#include <QtDBus/qdbusvirtualobject.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusConnection_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusConnection >()))
        return -1;

    ::QDBusConnection *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusConnection", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusConnection::QDBusConnection(QDBusConnection)
    // 1: QDBusConnection::QDBusConnection(QString)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // QDBusConnection(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QDBusConnection(QDBusConnection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDBusConnection(const QDBusConnection &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDBusConnection cppArg0_local = ::QDBusConnection(::QString());
            ::QDBusConnection *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusConnection(QDBusConnection)
                cptr = new ::QDBusConnection(*cppArg0);
            }
            break;
        }
        case 1: // QDBusConnection(const QString &name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusConnection(QString)
                cptr = new ::QDBusConnection(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDBusConnection >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDBusConnectionFunc_asyncCall(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.asyncCall";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:asyncCall", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusConnection::asyncCall(QDBusMessage,int=)const->QDBusPendingCall
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // asyncCall(QDBusMessage,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // asyncCall(QDBusMessage,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
            if (PyDict_Contains(kwds, key_timeout) != 0) {
                value = PyDict_GetItem(kwds, key_timeout);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_timeout);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_timeout);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDBusMessage cppArg0_local;
        ::QDBusMessage *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1 = -1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // asyncCall(QDBusMessage,int)const
            QDBusPendingCall* cppResult = new QDBusPendingCall(const_cast<const ::QDBusConnection *>(cppSelf)->asyncCall(*cppArg0, cppArg1));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_baseService(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.baseService";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // baseService()const
            QString cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->baseService();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_call(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.call";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:call", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusConnection::call(QDBusMessage,QDBus::CallMode=,int=)const->QDBusMessage
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // call(QDBusMessage,QDBus::CallMode,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBus_CallMode_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // call(QDBusMessage,QDBus::CallMode,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // call(QDBusMessage,QDBus::CallMode,int)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBus_CallMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
            if (PyDict_Contains(kwds, key_timeout) != 0) {
                value = PyDict_GetItem(kwds, key_timeout);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_timeout);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_timeout);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDBusMessage cppArg0_local;
        ::QDBusMessage *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QDBus::CallMode cppArg1(QDBus::Block);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = -1;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // call(QDBusMessage,QDBus::CallMode,int)const
            QDBusMessage cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->call(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_callWithCallback(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.callWithCallback";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:callWithCallback", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusConnection::callWithCallback(QDBusMessage,QObject*,const char*,const char*,int=)const->bool
    // 1: QDBusConnection::callWithCallback(QDBusMessage,QObject*,const char*,int=)const->bool
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 1; // callWithCallback(QDBusMessage,QObject*,const char*,int)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 1; // callWithCallback(QDBusMessage,QObject*,const char*,int)const
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // callWithCallback(QDBusMessage,QObject*,const char*,const char*,int)const
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                overloadId = 0; // callWithCallback(QDBusMessage,QObject*,const char*,const char*,int)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // callWithCallback(const QDBusMessage &message, QObject *receiver, const char *returnMethod, const char *errorMethod, int timeout) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
                if (PyDict_Contains(kwds, key_timeout) != 0) {
                    value = PyDict_GetItem(kwds, key_timeout);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_timeout);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_timeout);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDBusMessage cppArg0_local;
            ::QDBusMessage *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // callWithCallback(QDBusMessage,QObject*,const char*,const char*,int)const
                bool cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->callWithCallback(*cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // callWithCallback(const QDBusMessage &message, QObject *receiver, const char *slot, int timeout) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
                if (PyDict_Contains(kwds, key_timeout) != 0) {
                    value = PyDict_GetItem(kwds, key_timeout);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_timeout);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_timeout);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDBusMessage cppArg0_local;
            ::QDBusMessage *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // callWithCallback(QDBusMessage,QObject*,const char*,int)const
                bool cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->callWithCallback(*cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_connect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.connect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "connect", 6, 8, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusConnection::connect(QString,QString,QString,QString,QObject*,const char*)->bool
    // 1: QDBusConnection::connect(QString,QString,QString,QString,QString,QObject*,const char*)->bool
    // 2: QDBusConnection::connect(QString,QString,QString,QString,QStringList,QString,QObject*,const char*)->bool
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
        if (numArgs == 8
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[6])))
            && Shiboken::String::check(pyArgs[7]) && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[7])))) {
            overloadId = 2; // connect(QString,QString,QString,QString,QStringList,QString,QObject*,const char*)
        } else if (numArgs == 6
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4])))
            && Shiboken::String::check(pyArgs[5]) && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[5])))) {
            overloadId = 0; // connect(QString,QString,QString,QString,QObject*,const char*)
        } else if (numArgs == 7
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[5])))
            && Shiboken::String::check(pyArgs[6]) && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[6])))) {
            overloadId = 1; // connect(QString,QString,QString,QString,QString,QObject*,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // connect(const QString &service, const QString &path, const QString &interface, const QString &name, QObject *receiver, const char *slot)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QObject *cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            const char* cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connect(QString,QString,QString,QString,QObject*,const char*)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->connect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // connect(const QString &service, const QString &path, const QString &interface, const QString &name, const QString &signature, QObject *receiver, const char *slot)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QObject *cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            const char* cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connect(QString,QString,QString,QString,QString,QObject*,const char*)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->connect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // connect(const QString &service, const QString &path, const QString &interface, const QString &name, const QStringList &argumentMatch, const QString &signature, QObject *receiver, const char *slot)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QStringList cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QString cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QObject *cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            const char* cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connect(QString,QString,QString,QString,QStringList,QString,QObject*,const char*)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->connect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_connectToBus(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.connectToBus";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "connectToBus", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDBusConnection::connectToBus(QDBusConnection::BusType,QString)->QDBusConnection
    // 1: static QDBusConnection::connectToBus(QString,QString)->QDBusConnection
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // connectToBus(QString,QString)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_BusType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // connectToBus(QDBusConnection::BusType,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // connectToBus(QDBusConnection::BusType type, const QString &name)
        {
            ::QDBusConnection::BusType cppArg0{QDBusConnection::SessionBus};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectToBus(QDBusConnection::BusType,QString)
                QDBusConnection cppResult = ::QDBusConnection::connectToBus(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), &cppResult);
            }
            break;
        }
        case 1: // connectToBus(const QString &address, const QString &name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectToBus(QString,QString)
                QDBusConnection cppResult = ::QDBusConnection::connectToBus(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_connectToPeer(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.connectToPeer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "connectToPeer", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDBusConnection::connectToPeer(QString,QString)->QDBusConnection
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // connectToPeer(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // connectToPeer(QString,QString)
            QDBusConnection cppResult = ::QDBusConnection::connectToPeer(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_connectionCapabilities(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.connectionCapabilities";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // connectionCapabilities()const
            QFlags<QDBusConnection::ConnectionCapability> cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->connectionCapabilities();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QFlags_QDBusConnection_ConnectionCapability_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_disconnect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.disconnect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "disconnect", 6, 8, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusConnection::disconnect(QString,QString,QString,QString,QObject*,const char*)->bool
    // 1: QDBusConnection::disconnect(QString,QString,QString,QString,QString,QObject*,const char*)->bool
    // 2: QDBusConnection::disconnect(QString,QString,QString,QString,QStringList,QString,QObject*,const char*)->bool
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
        if (numArgs == 8
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[6])))
            && Shiboken::String::check(pyArgs[7]) && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[7])))) {
            overloadId = 2; // disconnect(QString,QString,QString,QString,QStringList,QString,QObject*,const char*)
        } else if (numArgs == 6
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4])))
            && Shiboken::String::check(pyArgs[5]) && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[5])))) {
            overloadId = 0; // disconnect(QString,QString,QString,QString,QObject*,const char*)
        } else if (numArgs == 7
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[5])))
            && Shiboken::String::check(pyArgs[6]) && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[6])))) {
            overloadId = 1; // disconnect(QString,QString,QString,QString,QString,QObject*,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // disconnect(const QString &service, const QString &path, const QString &interface, const QString &name, QObject *receiver, const char *slot)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QObject *cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            const char* cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // disconnect(QString,QString,QString,QString,QObject*,const char*)
                bool cppResult = cppSelf->disconnect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // disconnect(const QString &service, const QString &path, const QString &interface, const QString &name, const QString &signature, QObject *receiver, const char *slot)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QObject *cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            const char* cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // disconnect(QString,QString,QString,QString,QString,QObject*,const char*)
                bool cppResult = cppSelf->disconnect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // disconnect(const QString &service, const QString &path, const QString &interface, const QString &name, const QStringList &argumentMatch, const QString &signature, QObject *receiver, const char *slot)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QStringList cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QString cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QObject *cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            const char* cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // disconnect(QString,QString,QString,QString,QStringList,QString,QObject*,const char*)
                bool cppResult = cppSelf->disconnect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_disconnectFromBus(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.disconnectFromBus";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDBusConnection::disconnectFromBus(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // disconnectFromBus(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // disconnectFromBus(QString)
            ::QDBusConnection::disconnectFromBus(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusConnectionFunc_disconnectFromPeer(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.disconnectFromPeer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDBusConnection::disconnectFromPeer(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // disconnectFromPeer(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // disconnectFromPeer(QString)
            ::QDBusConnection::disconnectFromPeer(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusConnectionFunc_interface(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.interface";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // interface()const
            QDBusConnectionInterface * cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->interface();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnectionInterface_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_internalPointer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.internalPointer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // internalPointer()const
            void * cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->internalPointer();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_isConnected(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.isConnected";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isConnected()const
            bool cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->isConnected();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_lastError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.lastError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // lastError()const
            QDBusError cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->lastError();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusError_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_localMachineId(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.localMachineId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // localMachineId()
            QByteArray cppResult = ::QDBusConnection::localMachineId();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.name";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // name()const
            QString cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->name();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_objectRegisteredAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.objectRegisteredAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnection::objectRegisteredAt(QString)const->QObject*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // objectRegisteredAt(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // objectRegisteredAt(QString)const
            QObject * cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->objectRegisteredAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_registerObject(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.registerObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:registerObject", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusConnection::registerObject(QString,QObject*,QFlags<QDBusConnection::RegisterOption>=)->bool
    // 1: QDBusConnection::registerObject(QString,QString,QObject*,QFlags<QDBusConnection::RegisterOption>=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // registerObject(QString,QObject*,QFlags<QDBusConnection::RegisterOption>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QFlags_QDBusConnection_RegisterOption_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 0; // registerObject(QString,QObject*,QFlags<QDBusConnection::RegisterOption>)
            }
        } else if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // registerObject(QString,QString,QObject*,QFlags<QDBusConnection::RegisterOption>)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QFlags_QDBusConnection_RegisterOption_IDX])))->converter, (pyArgs[3])))) {
                overloadId = 1; // registerObject(QString,QString,QObject*,QFlags<QDBusConnection::RegisterOption>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // registerObject(const QString &path, QObject *object, QFlags<QDBusConnection::RegisterOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QFlags_QDBusConnection_RegisterOption_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QDBusConnection::RegisterOption> cppArg2(QDBusConnection::RegisterOption::ExportAdaptors);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // registerObject(QString,QObject*,QFlags<QDBusConnection::RegisterOption>)
                bool cppResult = cppSelf->registerObject(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // registerObject(const QString &path, const QString &interface, QObject *object, QFlags<QDBusConnection::RegisterOption> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QFlags_QDBusConnection_RegisterOption_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<QDBusConnection::RegisterOption> cppArg3(QDBusConnection::RegisterOption::ExportAdaptors);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // registerObject(QString,QString,QObject*,QFlags<QDBusConnection::RegisterOption>)
                bool cppResult = cppSelf->registerObject(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_registerService(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.registerService";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnection::registerService(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // registerService(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerService(QString)
            bool cppResult = cppSelf->registerService(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_registerVirtualObject(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.registerVirtualObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:registerVirtualObject", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusConnection::registerVirtualObject(QString,QDBusVirtualObject*,QDBusConnection::VirtualObjectRegisterOption=)->bool
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusVirtualObject_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // registerVirtualObject(QString,QDBusVirtualObject*,QDBusConnection::VirtualObjectRegisterOption)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_VirtualObjectRegisterOption_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // registerVirtualObject(QString,QDBusVirtualObject*,QDBusConnection::VirtualObjectRegisterOption)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_VirtualObjectRegisterOption_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDBusVirtualObject *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QDBusConnection::VirtualObjectRegisterOption cppArg2(QDBusConnection::VirtualObjectRegisterOption::SingleNode);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerVirtualObject(QString,QDBusVirtualObject*,QDBusConnection::VirtualObjectRegisterOption)
            bool cppResult = cppSelf->registerVirtualObject(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_send(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.send";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnection::send(QDBusMessage)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), (pyArg)))) {
        overloadId = 0; // send(QDBusMessage)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusMessage cppArg0_local;
        ::QDBusMessage *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // send(QDBusMessage)const
            bool cppResult = const_cast<const ::QDBusConnection *>(cppSelf)->send(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_sessionBus(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.sessionBus";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // sessionBus()
            QDBusConnection cppResult = ::QDBusConnection::sessionBus();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnection::swap(QDBusConnection&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QDBusConnection&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDBusConnection cppArg0_local = ::QDBusConnection(::QString());
        ::QDBusConnection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QDBusConnection&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusConnectionFunc_systemBus(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.systemBus";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // systemBus()
            QDBusConnection cppResult = ::QDBusConnection::systemBus();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnectionFunc_unregisterObject(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.unregisterObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:unregisterObject", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusConnection::unregisterObject(QString,QDBusConnection::UnregisterMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // unregisterObject(QString,QDBusConnection::UnregisterMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_UnregisterMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // unregisterObject(QString,QDBusConnection::UnregisterMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_UnregisterMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QDBusConnection::UnregisterMode cppArg1(QDBusConnection::UnregisterMode::UnregisterNode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unregisterObject(QString,QDBusConnection::UnregisterMode)
            cppSelf->unregisterObject(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusConnectionFunc_unregisterService(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusConnection.unregisterService";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusConnection::unregisterService(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // unregisterService(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unregisterService(QString)
            bool cppResult = cppSelf->unregisterService(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusConnection__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDBusConnection_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDBusConnection_EnumFlagInfo[] = {
    "BusType:Enum",
    "ConnectionCapability:Flag:ConnectionCapabilities",
    "RegisterOption:Flag:RegisterOptions",
    "UnregisterMode:Enum",
    "VirtualObjectRegisterOption:Flag:VirtualObjectRegisterOptions",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusConnection_methods[] = {
    {"asyncCall", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_asyncCall), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"baseService", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_baseService), METH_NOARGS, nullptr},
    {"call", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_call), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"callWithCallback", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_callWithCallback), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"connect", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_connect), METH_VARARGS, nullptr},
    {"connectToBus", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_connectToBus), METH_VARARGS|METH_STATIC, nullptr},
    {"connectToPeer", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_connectToPeer), METH_VARARGS|METH_STATIC, nullptr},
    {"connectionCapabilities", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_connectionCapabilities), METH_NOARGS, nullptr},
    {"disconnect", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_disconnect), METH_VARARGS, nullptr},
    {"disconnectFromBus", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_disconnectFromBus), METH_O|METH_STATIC, nullptr},
    {"disconnectFromPeer", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_disconnectFromPeer), METH_O|METH_STATIC, nullptr},
    {"interface", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_interface), METH_NOARGS, nullptr},
    {"internalPointer", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_internalPointer), METH_NOARGS, nullptr},
    {"isConnected", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_isConnected), METH_NOARGS, nullptr},
    {"lastError", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_lastError), METH_NOARGS, nullptr},
    {"localMachineId", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_localMachineId), METH_NOARGS|METH_STATIC, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_name), METH_NOARGS, nullptr},
    {"objectRegisteredAt", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_objectRegisteredAt), METH_O, nullptr},
    {"registerObject", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_registerObject), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"registerService", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_registerService), METH_O, nullptr},
    {"registerVirtualObject", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_registerVirtualObject), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"send", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_send), METH_O, nullptr},
    {"sessionBus", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_sessionBus), METH_NOARGS|METH_STATIC, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_swap), METH_O, nullptr},
    {"systemBus", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_systemBus), METH_NOARGS|METH_STATIC, nullptr},
    {"unregisterObject", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_unregisterObject), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"unregisterService", reinterpret_cast<PyCFunction>(Sbk_QDBusConnectionFunc_unregisterService), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDBusConnection__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDBusConnection_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusConnection_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusConnection_Type = nullptr;
static PyTypeObject *Sbk_QDBusConnection_TypeF(void)
{
    return _Sbk_QDBusConnection_Type;
}

static PyType_Slot Sbk_QDBusConnection_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusConnection_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusConnection_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusConnection_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusConnection_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusConnection_spec = {
    "2:PySide6.QtDBus.QDBusConnection",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusConnection_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDBusConnection_BusType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDBusConnection::BusType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDBusConnection::BusType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDBusConnection_BusType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_BusType_IDX])))
        return Enum_PythonToCpp_QDBusConnection_BusType;
    return {};
}
static PyObject *QDBusConnection_BusType_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDBusConnection::BusType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_BusType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDBusConnection_RegisterOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDBusConnection::RegisterOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDBusConnection::RegisterOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDBusConnection_RegisterOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_RegisterOption_IDX])))
        return Enum_PythonToCpp_QDBusConnection_RegisterOption;
    return {};
}
static PyObject *QDBusConnection_RegisterOption_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDBusConnection::RegisterOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_RegisterOption_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDBusConnection_UnregisterMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDBusConnection::UnregisterMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDBusConnection::UnregisterMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDBusConnection_UnregisterMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_UnregisterMode_IDX])))
        return Enum_PythonToCpp_QDBusConnection_UnregisterMode;
    return {};
}
static PyObject *QDBusConnection_UnregisterMode_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDBusConnection::UnregisterMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_UnregisterMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDBusConnection_VirtualObjectRegisterOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDBusConnection::VirtualObjectRegisterOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDBusConnection::VirtualObjectRegisterOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDBusConnection_VirtualObjectRegisterOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_VirtualObjectRegisterOption_IDX])))
        return Enum_PythonToCpp_QDBusConnection_VirtualObjectRegisterOption;
    return {};
}
static PyObject *QDBusConnection_VirtualObjectRegisterOption_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDBusConnection::VirtualObjectRegisterOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_VirtualObjectRegisterOption_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDBusConnection_ConnectionCapability(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDBusConnection::ConnectionCapability>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDBusConnection::ConnectionCapability *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDBusConnection_ConnectionCapability_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_ConnectionCapability_IDX])))
        return Enum_PythonToCpp_QDBusConnection_ConnectionCapability;
    return {};
}
static PyObject *QDBusConnection_ConnectionCapability_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QDBusConnection::ConnectionCapability *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_ConnectionCapability_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusConnection_PythonToCpp_QDBusConnection_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusConnection_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusConnection_PythonToCpp_QDBusConnection_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusConnection_TypeF()))
        return QDBusConnection_PythonToCpp_QDBusConnection_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusConnection_PTR_CppToPython_QDBusConnection(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QDBusConnection *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QDBusConnection_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QDBusConnection_COPY_CppToPython_QDBusConnection(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDBusConnection *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDBusConnection_TypeF(), new ::QDBusConnection(*source), true, true);
}

// Python to C++ copy conversion.
static void QDBusConnection_PythonToCpp_QDBusConnection_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDBusConnection *>(cppOut) = *reinterpret_cast< ::QDBusConnection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDBusConnection_PythonToCpp_QDBusConnection_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusConnection_TypeF()))
        return QDBusConnection_PythonToCpp_QDBusConnection_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QDBusConnection_SignatureStrings[] = {
    "1:PySide6.QtDBus.QDBusConnection(self,other:PySide6.QtDBus.QDBusConnection)",
    "0:PySide6.QtDBus.QDBusConnection(self,name:QString)",
    "PySide6.QtDBus.QDBusConnection.asyncCall(self,message:PySide6.QtDBus.QDBusMessage,timeout:int=-1)->PySide6.QtDBus.QDBusPendingCall",
    "PySide6.QtDBus.QDBusConnection.baseService(self)->QString",
    "PySide6.QtDBus.QDBusConnection.call(self,message:PySide6.QtDBus.QDBusMessage,mode:PySide6.QtDBus.QDBus.CallMode=QDBus.Block,timeout:int=-1)->PySide6.QtDBus.QDBusMessage",
    "1:PySide6.QtDBus.QDBusConnection.callWithCallback(self,message:PySide6.QtDBus.QDBusMessage,receiver:PySide6.QtCore.QObject,returnMethod:char*,errorMethod:char*,timeout:int=-1)->bool",
    "0:PySide6.QtDBus.QDBusConnection.callWithCallback(self,message:PySide6.QtDBus.QDBusMessage,receiver:PySide6.QtCore.QObject,slot:char*,timeout:int=-1)->bool",
    "2:PySide6.QtDBus.QDBusConnection.connect(self,service:QString,path:QString,interface:QString,name:QString,receiver:PySide6.QtCore.QObject,slot:char*)->bool",
    "1:PySide6.QtDBus.QDBusConnection.connect(self,service:QString,path:QString,interface:QString,name:QString,signature:QString,receiver:PySide6.QtCore.QObject,slot:char*)->bool",
    "0:PySide6.QtDBus.QDBusConnection.connect(self,service:QString,path:QString,interface:QString,name:QString,argumentMatch:QStringList,signature:QString,receiver:PySide6.QtCore.QObject,slot:char*)->bool",
    "1:PySide6.QtDBus.QDBusConnection.connectToBus(type:PySide6.QtDBus.QDBusConnection.BusType,name:QString)->PySide6.QtDBus.QDBusConnection",
    "0:PySide6.QtDBus.QDBusConnection.connectToBus(address:QString,name:QString)->PySide6.QtDBus.QDBusConnection",
    "PySide6.QtDBus.QDBusConnection.connectToPeer(address:QString,name:QString)->PySide6.QtDBus.QDBusConnection",
    "PySide6.QtDBus.QDBusConnection.connectionCapabilities(self)->PySide6.QtDBus.QDBusConnection.ConnectionCapability",
    "2:PySide6.QtDBus.QDBusConnection.disconnect(self,service:QString,path:QString,interface:QString,name:QString,receiver:PySide6.QtCore.QObject,slot:char*)->bool",
    "1:PySide6.QtDBus.QDBusConnection.disconnect(self,service:QString,path:QString,interface:QString,name:QString,signature:QString,receiver:PySide6.QtCore.QObject,slot:char*)->bool",
    "0:PySide6.QtDBus.QDBusConnection.disconnect(self,service:QString,path:QString,interface:QString,name:QString,argumentMatch:QStringList,signature:QString,receiver:PySide6.QtCore.QObject,slot:char*)->bool",
    "PySide6.QtDBus.QDBusConnection.disconnectFromBus(name:QString)",
    "PySide6.QtDBus.QDBusConnection.disconnectFromPeer(name:QString)",
    "PySide6.QtDBus.QDBusConnection.interface(self)->PySide6.QtDBus.QDBusConnectionInterface",
    "PySide6.QtDBus.QDBusConnection.internalPointer(self)->void",
    "PySide6.QtDBus.QDBusConnection.isConnected(self)->bool",
    "PySide6.QtDBus.QDBusConnection.lastError(self)->PySide6.QtDBus.QDBusError",
    "PySide6.QtDBus.QDBusConnection.localMachineId()->PySide6.QtCore.QByteArray",
    "PySide6.QtDBus.QDBusConnection.name(self)->QString",
    "PySide6.QtDBus.QDBusConnection.objectRegisteredAt(self,path:QString)->PySide6.QtCore.QObject",
    "1:PySide6.QtDBus.QDBusConnection.registerObject(self,path:QString,object:PySide6.QtCore.QObject,options:PySide6.QtDBus.QDBusConnection.RegisterOption=QDBusConnection.RegisterOption.ExportAdaptors)->bool",
    "0:PySide6.QtDBus.QDBusConnection.registerObject(self,path:QString,interface:QString,object:PySide6.QtCore.QObject,options:PySide6.QtDBus.QDBusConnection.RegisterOption=QDBusConnection.RegisterOption.ExportAdaptors)->bool",
    "PySide6.QtDBus.QDBusConnection.registerService(self,serviceName:QString)->bool",
    "PySide6.QtDBus.QDBusConnection.registerVirtualObject(self,path:QString,object:PySide6.QtDBus.QDBusVirtualObject,options:PySide6.QtDBus.QDBusConnection.VirtualObjectRegisterOption=QDBusConnection.VirtualObjectRegisterOption.SingleNode)->bool",
    "PySide6.QtDBus.QDBusConnection.send(self,message:PySide6.QtDBus.QDBusMessage)->bool",
    "PySide6.QtDBus.QDBusConnection.sessionBus()->PySide6.QtDBus.QDBusConnection",
    "PySide6.QtDBus.QDBusConnection.swap(self,other:PySide6.QtDBus.QDBusConnection)",
    "PySide6.QtDBus.QDBusConnection.systemBus()->PySide6.QtDBus.QDBusConnection",
    "PySide6.QtDBus.QDBusConnection.unregisterObject(self,path:QString,mode:PySide6.QtDBus.QDBusConnection.UnregisterMode=QDBusConnection.UnregisterMode.UnregisterNode)",
    "PySide6.QtDBus.QDBusConnection.unregisterService(self,serviceName:QString)->bool",
    "PySide6.QtDBus.QDBusConnection.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QDBusConnection(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusConnection_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDBusConnection_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusConnection",
        "QDBusConnection",
        &Sbk_QDBusConnection_spec,
        &Shiboken::callCppDestructor< ::QDBusConnection >,
        Sbk_QDBusConnection_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDBusConnection_TypeF(); // references _Sbk_QDBusConnection_Type
    InitSignatureStrings(pyType, QDBusConnection_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusConnection_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusConnection_PythonToCpp_QDBusConnection_PTR,
        is_QDBusConnection_PythonToCpp_QDBusConnection_PTR_Convertible,
        QDBusConnection_PTR_CppToPython_QDBusConnection,
        QDBusConnection_COPY_CppToPython_QDBusConnection);

    Shiboken::Conversions::registerConverterName(converter, "QDBusConnection");
    Shiboken::Conversions::registerConverterName(converter, "QDBusConnection*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusConnection&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusConnection).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDBusConnection_PythonToCpp_QDBusConnection_COPY,
        is_QDBusConnection_PythonToCpp_QDBusConnection_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDBusConnection_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'BusType'.
    const char *BusType_Initializer[] = {
        "SessionBus",
        "SystemBus",
        "ActivationBus",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t BusType_InitializerValues[] = {
        uint8_t(QDBusConnection::BusType::SessionBus),   //  0x00  0
        uint8_t(QDBusConnection::BusType::SystemBus),    //  0x01  1
        uint8_t(QDBusConnection::BusType::ActivationBus) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDBusConnection_TypeF(),
        "2:PySide6.QtDBus.QDBusConnection.BusType",
        BusType_Initializer, BusType_InitializerValues);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_BusType_IDX].type = EType;
    // Register converter for enum 'QDBusConnection::BusType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDBusConnection_BusType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDBusConnection_BusType,
            is_Enum_PythonToCpp_QDBusConnection_BusType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnection::BusType");
        Shiboken::Conversions::registerConverterName(converter, "BusType");
    }
    // End of 'BusType' enum.

    // Initialization of enum 'RegisterOption'.
    const char *RegisterOption_Initializer[] = {
        "ExportAdaptors",
        "ExportScriptableSlots",
        "ExportScriptableSignals",
        "ExportScriptableProperties",
        "ExportScriptableInvokables",
        "ExportScriptableContents",
        "ExportNonScriptableSlots",
        "ExportNonScriptableSignals",
        "ExportNonScriptableProperties",
        "ExportNonScriptableInvokables",
        "ExportNonScriptableContents",
        "ExportAllSlots",
        "ExportAllSignals",
        "ExportAllProperties",
        "ExportAllInvokables",
        "ExportAllContents",
        "ExportAllSignal",
        "ExportChildObjects",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t RegisterOption_InitializerValues[] = {
        uint16_t(QDBusConnection::RegisterOption::ExportAdaptors),                //  0x0001  1
        uint16_t(QDBusConnection::RegisterOption::ExportScriptableSlots),         //  0x0010  16
        uint16_t(QDBusConnection::RegisterOption::ExportScriptableSignals),       //  0x0020  32
        uint16_t(QDBusConnection::RegisterOption::ExportScriptableProperties),    //  0x0040  64
        uint16_t(QDBusConnection::RegisterOption::ExportScriptableInvokables),    //  0x0080  128
        uint16_t(QDBusConnection::RegisterOption::ExportScriptableContents),      //  0x00f0  240
        uint16_t(QDBusConnection::RegisterOption::ExportNonScriptableSlots),      //  0x0100  256
        uint16_t(QDBusConnection::RegisterOption::ExportNonScriptableSignals),    //  0x0200  512
        uint16_t(QDBusConnection::RegisterOption::ExportNonScriptableProperties), //  0x0400  1024
        uint16_t(QDBusConnection::RegisterOption::ExportNonScriptableInvokables), //  0x0800  2048
        uint16_t(QDBusConnection::RegisterOption::ExportNonScriptableContents),   //  0x0f00  3840
        uint16_t(QDBusConnection::RegisterOption::ExportAllSlots),                //  0x0110  272
        uint16_t(QDBusConnection::RegisterOption::ExportAllSignals),              //  0x0220  544
        uint16_t(QDBusConnection::RegisterOption::ExportAllProperties),           //  0x0440  1088
        uint16_t(QDBusConnection::RegisterOption::ExportAllInvokables),           //  0x0880  2176
        uint16_t(QDBusConnection::RegisterOption::ExportAllContents),             //  0x0ff0  4080
        uint16_t(QDBusConnection::RegisterOption::ExportAllSignal),               //  0x0220  544
        uint16_t(QDBusConnection::RegisterOption::ExportChildObjects)             //  0x1000  4096
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDBusConnection_TypeF(),
        "2:PySide6.QtDBus.QDBusConnection.RegisterOption",
        RegisterOption_Initializer, RegisterOption_InitializerValues);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_RegisterOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtDBusTypeStructs[SBK_QFlags_QDBusConnection_RegisterOption_IDX].type =
        EType;
    // Register converter for enum 'QDBusConnection::RegisterOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDBusConnection_RegisterOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDBusConnection_RegisterOption,
            is_Enum_PythonToCpp_QDBusConnection_RegisterOption_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnection::RegisterOption");
        Shiboken::Conversions::registerConverterName(converter, "RegisterOption");
        // Register converter for flag 'QFlags<QDBusConnection::RegisterOption>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QDBusConnection::RegisterOption>");
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnection::RegisterOptions");
    }
    // End of 'RegisterOption' enum/flags.

    // Initialization of enum 'UnregisterMode'.
    const char *UnregisterMode_Initializer[] = {
        "UnregisterNode",
        "UnregisterTree",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t UnregisterMode_InitializerValues[] = {
        uint8_t(QDBusConnection::UnregisterMode::UnregisterNode), //  0x00  0
        uint8_t(QDBusConnection::UnregisterMode::UnregisterTree)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDBusConnection_TypeF(),
        "2:PySide6.QtDBus.QDBusConnection.UnregisterMode",
        UnregisterMode_Initializer, UnregisterMode_InitializerValues);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_UnregisterMode_IDX].type = EType;
    // Register converter for enum 'QDBusConnection::UnregisterMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDBusConnection_UnregisterMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDBusConnection_UnregisterMode,
            is_Enum_PythonToCpp_QDBusConnection_UnregisterMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnection::UnregisterMode");
        Shiboken::Conversions::registerConverterName(converter, "UnregisterMode");
    }
    // End of 'UnregisterMode' enum.

    // Initialization of enum 'VirtualObjectRegisterOption'.
    const char *VirtualObjectRegisterOption_Initializer[] = {
        "SingleNode",
        "SubPath",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t VirtualObjectRegisterOption_InitializerValues[] = {
        uint8_t(QDBusConnection::VirtualObjectRegisterOption::SingleNode), //  0x00  0
        uint8_t(QDBusConnection::VirtualObjectRegisterOption::SubPath)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDBusConnection_TypeF(),
        "2:PySide6.QtDBus.QDBusConnection.VirtualObjectRegisterOption",
        VirtualObjectRegisterOption_Initializer, VirtualObjectRegisterOption_InitializerValues);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_VirtualObjectRegisterOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtDBusTypeStructs[SBK_QFlags_QDBusConnection_VirtualObjectRegisterOption_IDX].type =
        EType;
    // Register converter for enum 'QDBusConnection::VirtualObjectRegisterOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDBusConnection_VirtualObjectRegisterOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDBusConnection_VirtualObjectRegisterOption,
            is_Enum_PythonToCpp_QDBusConnection_VirtualObjectRegisterOption_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnection::VirtualObjectRegisterOption");
        Shiboken::Conversions::registerConverterName(converter, "VirtualObjectRegisterOption");
        // Register converter for flag 'QFlags<QDBusConnection::VirtualObjectRegisterOption>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QDBusConnection::VirtualObjectRegisterOption>");
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnection::VirtualObjectRegisterOptions");
    }
    // End of 'VirtualObjectRegisterOption' enum/flags.

    // Initialization of enum 'ConnectionCapability'.
    const char *ConnectionCapability_Initializer[] = {
        "UnixFileDescriptorPassing",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ConnectionCapability_InitializerValues[] = {
        uint8_t(QDBusConnection::ConnectionCapability::UnixFileDescriptorPassing) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDBusConnection_TypeF(),
        "2:PySide6.QtDBus.QDBusConnection.ConnectionCapability",
        ConnectionCapability_Initializer, ConnectionCapability_InitializerValues);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_ConnectionCapability_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtDBusTypeStructs[SBK_QFlags_QDBusConnection_ConnectionCapability_IDX].type =
        EType;
    // Register converter for enum 'QDBusConnection::ConnectionCapability'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDBusConnection_ConnectionCapability_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDBusConnection_ConnectionCapability,
            is_Enum_PythonToCpp_QDBusConnection_ConnectionCapability_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnection::ConnectionCapability");
        Shiboken::Conversions::registerConverterName(converter, "ConnectionCapability");
        // Register converter for flag 'QFlags<QDBusConnection::ConnectionCapability>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QDBusConnection::ConnectionCapability>");
        Shiboken::Conversions::registerConverterName(converter, "QDBusConnection::ConnectionCapabilities");
    }
    // End of 'ConnectionCapability' enum/flags.

    qRegisterMetaType< ::QDBusConnection::BusType >("QDBusConnection::BusType");
    qRegisterMetaType< ::QDBusConnection::RegisterOption >("QDBusConnection::RegisterOption");
    qRegisterMetaType< ::QDBusConnection::UnregisterMode >("QDBusConnection::UnregisterMode");
    qRegisterMetaType< ::QDBusConnection::VirtualObjectRegisterOption >("QDBusConnection::VirtualObjectRegisterOption");
    qRegisterMetaType< ::QDBusConnection::ConnectionCapability >("QDBusConnection::ConnectionCapability");

    return pyType;
}
