// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbuscontext_wrapper.h"

// Argument includes
#include <QString>
#include <QtDBus/qdbusconnection.h>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusContext_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusContext >()))
        return -1;

    ::QDBusContext *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusContext.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusContext", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusContext::QDBusContext()
    // 1: QDBusContext::QDBusContext(QDBusContext)
    if (numArgs == 0) {
        overloadId = 0; // QDBusContext()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDBusContext(QDBusContext)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDBusContext()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusContext()
                cptr = new ::QDBusContext();
            }
            break;
        }
        case 1: // QDBusContext(const QDBusContext &QDBusContext)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDBusContext cppArg0_local;
            ::QDBusContext *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDBusContext(QDBusContext)
                cptr = new ::QDBusContext(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDBusContext >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDBusContextFunc_calledFromDBus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusContext.calledFromDBus";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // calledFromDBus()const
            bool cppResult = const_cast<const ::QDBusContext *>(cppSelf)->calledFromDBus();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusContextFunc_connection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusContext.connection";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // connection()const
            QDBusConnection cppResult = const_cast<const ::QDBusContext *>(cppSelf)->connection();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusContextFunc_isDelayedReply(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusContext.isDelayedReply";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDelayedReply()const
            bool cppResult = const_cast<const ::QDBusContext *>(cppSelf)->isDelayedReply();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusContextFunc_message(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusContext.message";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // message()const
            const QDBusMessage & cppResult = const_cast<const ::QDBusContext *>(cppSelf)->message();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusContextFunc_sendErrorReply(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusContext.sendErrorReply";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:sendErrorReply", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusContext::sendErrorReply(QDBusError::ErrorType,const QString&=)const
    // 1: QDBusContext::sendErrorReply(QString,const QString&=)const
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // sendErrorReply(QString,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // sendErrorReply(QString,QString)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusError_ErrorType_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sendErrorReply(QDBusError::ErrorType,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // sendErrorReply(QDBusError::ErrorType,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // sendErrorReply(QDBusError::ErrorType type, const QString &msg) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_msg = Shiboken::String::createStaticString("msg");
                if (PyDict_Contains(kwds, key_msg) != 0) {
                    value = PyDict_GetItem(kwds, key_msg);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_msg);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_msg);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QDBusError::ErrorType cppArg0{QDBusError::NoError};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendErrorReply(QDBusError::ErrorType,QString)const
                const_cast<const ::QDBusContext *>(cppSelf)->sendErrorReply(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // sendErrorReply(const QString &name, const QString &msg) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_msg = Shiboken::String::createStaticString("msg");
                if (PyDict_Contains(kwds, key_msg) != 0) {
                    value = PyDict_GetItem(kwds, key_msg);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_msg);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_msg);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendErrorReply(QString,QString)const
                const_cast<const ::QDBusContext *>(cppSelf)->sendErrorReply(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusContextFunc_setDelayedReply(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusContext.setDelayedReply";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusContext::setDelayedReply(bool)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDelayedReply(bool)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDelayedReply(bool)const
            const_cast<const ::QDBusContext *>(cppSelf)->setDelayedReply(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusContext__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDBusContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDBusContext_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusContext_methods[] = {
    {"calledFromDBus", reinterpret_cast<PyCFunction>(Sbk_QDBusContextFunc_calledFromDBus), METH_NOARGS, nullptr},
    {"connection", reinterpret_cast<PyCFunction>(Sbk_QDBusContextFunc_connection), METH_NOARGS, nullptr},
    {"isDelayedReply", reinterpret_cast<PyCFunction>(Sbk_QDBusContextFunc_isDelayedReply), METH_NOARGS, nullptr},
    {"message", reinterpret_cast<PyCFunction>(Sbk_QDBusContextFunc_message), METH_NOARGS, nullptr},
    {"sendErrorReply", reinterpret_cast<PyCFunction>(Sbk_QDBusContextFunc_sendErrorReply), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setDelayedReply", reinterpret_cast<PyCFunction>(Sbk_QDBusContextFunc_setDelayedReply), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDBusContext__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDBusContext_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusContext_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusContext_Type = nullptr;
static PyTypeObject *Sbk_QDBusContext_TypeF(void)
{
    return _Sbk_QDBusContext_Type;
}

static PyType_Slot Sbk_QDBusContext_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusContext_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusContext_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusContext_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusContext_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusContext_spec = {
    "2:PySide6.QtDBus.QDBusContext",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusContext_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusContext_PythonToCpp_QDBusContext_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusContext_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusContext_PythonToCpp_QDBusContext_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusContext_TypeF()))
        return QDBusContext_PythonToCpp_QDBusContext_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusContext_PTR_CppToPython_QDBusContext(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QDBusContext *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QDBusContext_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QDBusContext_COPY_CppToPython_QDBusContext(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDBusContext *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDBusContext_TypeF(), new ::QDBusContext(*source), true, true);
}

// Python to C++ copy conversion.
static void QDBusContext_PythonToCpp_QDBusContext_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDBusContext *>(cppOut) = *reinterpret_cast< ::QDBusContext *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDBusContext_PythonToCpp_QDBusContext_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusContext_TypeF()))
        return QDBusContext_PythonToCpp_QDBusContext_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QDBusContext_SignatureStrings[] = {
    "1:PySide6.QtDBus.QDBusContext(self)",
    "0:PySide6.QtDBus.QDBusContext(self,QDBusContext:PySide6.QtDBus.QDBusContext)",
    "PySide6.QtDBus.QDBusContext.calledFromDBus(self)->bool",
    "PySide6.QtDBus.QDBusContext.connection(self)->PySide6.QtDBus.QDBusConnection",
    "PySide6.QtDBus.QDBusContext.isDelayedReply(self)->bool",
    "PySide6.QtDBus.QDBusContext.message(self)->PySide6.QtDBus.QDBusMessage",
    "1:PySide6.QtDBus.QDBusContext.sendErrorReply(self,type:PySide6.QtDBus.QDBusError.ErrorType,msg:QString=QString())",
    "0:PySide6.QtDBus.QDBusContext.sendErrorReply(self,name:QString,msg:QString=QString())",
    "PySide6.QtDBus.QDBusContext.setDelayedReply(self,enable:bool)",
    "PySide6.QtDBus.QDBusContext.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QDBusContext(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusContext_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDBusContext_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusContext",
        "QDBusContext",
        &Sbk_QDBusContext_spec,
        &Shiboken::callCppDestructor< ::QDBusContext >,
        Sbk_QDBusContext_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDBusContext_TypeF(); // references _Sbk_QDBusContext_Type
    InitSignatureStrings(pyType, QDBusContext_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusContext_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusContext_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusContext_PythonToCpp_QDBusContext_PTR,
        is_QDBusContext_PythonToCpp_QDBusContext_PTR_Convertible,
        QDBusContext_PTR_CppToPython_QDBusContext,
        QDBusContext_COPY_CppToPython_QDBusContext);

    Shiboken::Conversions::registerConverterName(converter, "QDBusContext");
    Shiboken::Conversions::registerConverterName(converter, "QDBusContext*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusContext&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusContext).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDBusContext_PythonToCpp_QDBusContext_COPY,
        is_QDBusContext_PythonToCpp_QDBusContext_COPY_Convertible);

    qRegisterMetaType< ::QDBusContext >("QDBusContext");

    return pyType;
}
