// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qabstractfileiconprovider_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qabstractfileiconprovider.h>
#include <QtGui/qicon.h>
#include <qfileinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractFileIconProviderWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractFileIconProviderWrapper::QAbstractFileIconProviderWrapper() : QAbstractFileIconProvider()
{
    resetPyMethodCache();
    // ... middle
}

::QIcon QAbstractFileIconProviderWrapper::icon(::QAbstractFileIconProvider::IconType arg__1) const
{
    if (m_PyMethodCache[0])
        return this->::QAbstractFileIconProvider::icon(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "icon";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QAbstractFileIconProvider::icon(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IconType_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IconType_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractFileIconProvider", funcName, Shiboken::SbkType< QIcon >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QIcon cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QIcon QAbstractFileIconProviderWrapper::icon(const ::QFileInfo & arg__1) const
{
    if (m_PyMethodCache[1])
        return this->::QAbstractFileIconProvider::icon(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "icon";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QAbstractFileIconProvider::icon(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractFileIconProvider", funcName, Shiboken::SbkType< QIcon >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QIcon cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QFlags<QAbstractFileIconProvider::Option> QAbstractFileIconProviderWrapper::options() const
{
    if (m_PyMethodCache[2])
        return this->::QAbstractFileIconProvider::options();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QFlags<QAbstractFileIconProvider::Option>(0);
    static PyObject *nameCache[2] = {};
    static const char *funcName = "options";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QAbstractFileIconProvider::options();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QFlags<QAbstractFileIconProvider::Option>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAbstractFileIconProvider_Option_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractFileIconProvider", funcName, Shiboken::SbkType< QFlags<QAbstractFileIconProvider::Option> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QAbstractFileIconProvider::Option>(0);
    }
    ::QFlags<QAbstractFileIconProvider::Option> cppResult = QFlags<QAbstractFileIconProvider::Option>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractFileIconProviderWrapper::setOptions(::QFlags<QAbstractFileIconProvider::Option> arg__1)
{
    if (m_PyMethodCache[3]) {
        return this->::QAbstractFileIconProvider::setOptions(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setOptions";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QAbstractFileIconProvider::setOptions(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAbstractFileIconProvider_Option_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAbstractFileIconProvider_Option_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QString QAbstractFileIconProviderWrapper::type(const ::QFileInfo & arg__1) const
{
    if (m_PyMethodCache[4])
        return this->::QAbstractFileIconProvider::type(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QString();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "type";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QAbstractFileIconProvider::type(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return ::QString();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractFileIconProvider", funcName, "QString", Py_TYPE(pyResult)->tp_name);
        return ::QString();
    }
    ::QString cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QAbstractFileIconProviderWrapper::~QAbstractFileIconProviderWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractFileIconProvider_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractFileIconProvider >()))
        return -1;

    QAbstractFileIconProviderWrapper *cptr{};
    static const char fullName[] = "PySide6.QtGui.QAbstractFileIconProvider.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractFileIconProvider()
            cptr = new QAbstractFileIconProviderWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractFileIconProvider >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAbstractFileIconProviderFunc_icon(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractFileIconProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QAbstractFileIconProvider.icon";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractFileIconProvider::icon(QFileInfo)const->QIcon
    // 1: QAbstractFileIconProvider::icon(QAbstractFileIconProvider::IconType)const->QIcon
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IconType_IDX])))->converter, (pyArg)))) {
        overloadId = 1; // icon(QAbstractFileIconProvider::IconType)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), (pyArg)))) {
        overloadId = 0; // icon(QFileInfo)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // icon(const QFileInfo &arg__1) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QFileInfo cppArg0_local;
            ::QFileInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // icon(QFileInfo)const
                QIcon cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? const_cast<const ::QAbstractFileIconProvider *>(cppSelf)->::QAbstractFileIconProvider::icon(*cppArg0)
                    : const_cast<const ::QAbstractFileIconProvider *>(cppSelf)->icon(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &cppResult);
            }
            break;
        }
        case 1: // icon(QAbstractFileIconProvider::IconType arg__1) const
        {
            ::QAbstractFileIconProvider::IconType cppArg0{QAbstractFileIconProvider::Computer};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // icon(QAbstractFileIconProvider::IconType)const
                QIcon cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? const_cast<const ::QAbstractFileIconProvider *>(cppSelf)->::QAbstractFileIconProvider::icon(cppArg0)
                    : const_cast<const ::QAbstractFileIconProvider *>(cppSelf)->icon(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractFileIconProviderFunc_options(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractFileIconProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QAbstractFileIconProvider.options";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // options()const
            QFlags<QAbstractFileIconProvider::Option> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractFileIconProvider *>(cppSelf)->::QAbstractFileIconProvider::options()
                : const_cast<const ::QAbstractFileIconProvider *>(cppSelf)->options();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAbstractFileIconProvider_Option_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractFileIconProviderFunc_setOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractFileIconProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QAbstractFileIconProvider.setOptions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractFileIconProvider::setOptions(QFlags<QAbstractFileIconProvider::Option>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAbstractFileIconProvider_Option_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setOptions(QFlags<QAbstractFileIconProvider::Option>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QAbstractFileIconProvider::Option> cppArg0 = QFlags<QAbstractFileIconProvider::Option>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOptions(QFlags<QAbstractFileIconProvider::Option>)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractFileIconProvider::setOptions(cppArg0)
                : cppSelf->setOptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractFileIconProviderFunc_type(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractFileIconProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QAbstractFileIconProvider.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractFileIconProvider::type(QFileInfo)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), (pyArg)))) {
        overloadId = 0; // type(QFileInfo)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFileInfo cppArg0_local;
        ::QFileInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // type(QFileInfo)const
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QAbstractFileIconProvider *>(cppSelf)->::QAbstractFileIconProvider::type(*cppArg0)
                : const_cast<const ::QAbstractFileIconProvider *>(cppSelf)->type(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAbstractFileIconProvider_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QAbstractFileIconProvider_EnumFlagInfo[] = {
    "IconType:Enum",
    "Option:Flag:Options",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractFileIconProvider_methods[] = {
    {"icon", reinterpret_cast<PyCFunction>(Sbk_QAbstractFileIconProviderFunc_icon), METH_O, nullptr},
    {"options", reinterpret_cast<PyCFunction>(Sbk_QAbstractFileIconProviderFunc_options), METH_NOARGS, nullptr},
    {"setOptions", reinterpret_cast<PyCFunction>(Sbk_QAbstractFileIconProviderFunc_setOptions), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QAbstractFileIconProviderFunc_type), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractFileIconProvider_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractFileIconProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractFileIconProviderWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractFileIconProvider_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractFileIconProvider_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractFileIconProvider_Type = nullptr;
static PyTypeObject *Sbk_QAbstractFileIconProvider_TypeF(void)
{
    return _Sbk_QAbstractFileIconProvider_Type;
}

static PyType_Slot Sbk_QAbstractFileIconProvider_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractFileIconProvider_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractFileIconProvider_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractFileIconProvider_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractFileIconProvider_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractFileIconProvider_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractFileIconProvider_spec = {
    "2:PySide6.QtGui.QAbstractFileIconProvider",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractFileIconProvider_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstractFileIconProvider_IconType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractFileIconProvider::IconType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractFileIconProvider::IconType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractFileIconProvider_IconType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IconType_IDX])))
        return Enum_PythonToCpp_QAbstractFileIconProvider_IconType;
    return {};
}
static PyObject *QAbstractFileIconProvider_IconType_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAbstractFileIconProvider::IconType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IconType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractFileIconProvider_Option(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractFileIconProvider::Option>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractFileIconProvider::Option *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractFileIconProvider_Option_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_Option_IDX])))
        return Enum_PythonToCpp_QAbstractFileIconProvider_Option;
    return {};
}
static PyObject *QAbstractFileIconProvider_Option_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAbstractFileIconProvider::Option *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_Option_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractFileIconProvider_PythonToCpp_QAbstractFileIconProvider_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractFileIconProvider_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractFileIconProvider_PythonToCpp_QAbstractFileIconProvider_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractFileIconProvider_TypeF()))
        return QAbstractFileIconProvider_PythonToCpp_QAbstractFileIconProvider_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractFileIconProvider_PTR_CppToPython_QAbstractFileIconProvider(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QAbstractFileIconProvider *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QAbstractFileIconProvider_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QAbstractFileIconProvider_SignatureStrings[] = {
    "PySide6.QtGui.QAbstractFileIconProvider(self)",
    "1:PySide6.QtGui.QAbstractFileIconProvider.icon(self,arg__1:PySide6.QtCore.QFileInfo)->PySide6.QtGui.QIcon",
    "0:PySide6.QtGui.QAbstractFileIconProvider.icon(self,arg__1:PySide6.QtGui.QAbstractFileIconProvider.IconType)->PySide6.QtGui.QIcon",
    "PySide6.QtGui.QAbstractFileIconProvider.options(self)->PySide6.QtGui.QAbstractFileIconProvider.Option",
    "PySide6.QtGui.QAbstractFileIconProvider.setOptions(self,arg__1:PySide6.QtGui.QAbstractFileIconProvider.Option)",
    "PySide6.QtGui.QAbstractFileIconProvider.type(self,arg__1:PySide6.QtCore.QFileInfo)->QString",
    nullptr}; // Sentinel

PyTypeObject *init_QAbstractFileIconProvider(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractFileIconProvider_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAbstractFileIconProvider_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractFileIconProvider",
        "QAbstractFileIconProvider*",
        &Sbk_QAbstractFileIconProvider_spec,
        &Shiboken::callCppDestructor< QAbstractFileIconProvider >,
        Sbk_QAbstractFileIconProvider_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractFileIconProvider_TypeF(); // references _Sbk_QAbstractFileIconProvider_Type
    InitSignatureStrings(pyType, QAbstractFileIconProvider_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractFileIconProvider_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractFileIconProvider_PythonToCpp_QAbstractFileIconProvider_PTR,
        is_QAbstractFileIconProvider_PythonToCpp_QAbstractFileIconProvider_PTR_Convertible,
        QAbstractFileIconProvider_PTR_CppToPython_QAbstractFileIconProvider);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractFileIconProvider");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractFileIconProvider*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractFileIconProvider&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractFileIconProvider).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractFileIconProviderWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstractFileIconProvider_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'IconType'.
    const char *IconType_Initializer[] = {
        "Computer",
        "Desktop",
        "Trashcan",
        "Network",
        "Drive",
        "Folder",
        "File",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t IconType_InitializerValues[] = {
        uint8_t(QAbstractFileIconProvider::IconType::Computer), //  0x00  0
        uint8_t(QAbstractFileIconProvider::IconType::Desktop),  //  0x01  1
        uint8_t(QAbstractFileIconProvider::IconType::Trashcan), //  0x02  2
        uint8_t(QAbstractFileIconProvider::IconType::Network),  //  0x03  3
        uint8_t(QAbstractFileIconProvider::IconType::Drive),    //  0x04  4
        uint8_t(QAbstractFileIconProvider::IconType::Folder),   //  0x05  5
        uint8_t(QAbstractFileIconProvider::IconType::File)      //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractFileIconProvider_TypeF(),
        "2:PySide6.QtGui.QAbstractFileIconProvider.IconType",
        IconType_Initializer, IconType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IconType_IDX].type = EType;
    // Register converter for enum 'QAbstractFileIconProvider::IconType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractFileIconProvider_IconType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractFileIconProvider_IconType,
            is_Enum_PythonToCpp_QAbstractFileIconProvider_IconType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractFileIconProvider::IconType");
        Shiboken::Conversions::registerConverterName(converter, "IconType");
    }
    // End of 'IconType' enum.

    // Initialization of enum 'Option'.
    const char *Option_Initializer[] = {
        "DontUseCustomDirectoryIcons",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Option_InitializerValues[] = {
        uint8_t(QAbstractFileIconProvider::Option::DontUseCustomDirectoryIcons) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractFileIconProvider_TypeF(),
        "2:PySide6.QtGui.QAbstractFileIconProvider.Option",
        Option_Initializer, Option_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_Option_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAbstractFileIconProvider_Option_IDX].type =
        EType;
    // Register converter for enum 'QAbstractFileIconProvider::Option'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractFileIconProvider_Option_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractFileIconProvider_Option,
            is_Enum_PythonToCpp_QAbstractFileIconProvider_Option_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractFileIconProvider::Option");
        Shiboken::Conversions::registerConverterName(converter, "Option");
        // Register converter for flag 'QFlags<QAbstractFileIconProvider::Option>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QAbstractFileIconProvider::Option>");
        Shiboken::Conversions::registerConverterName(converter, "QAbstractFileIconProvider::Options");
    }
    // End of 'Option' enum/flags.

    qRegisterMetaType< ::QAbstractFileIconProvider *>();
    qRegisterMetaType< ::QAbstractFileIconProvider::IconType >("QAbstractFileIconProvider::IconType");
    qRegisterMetaType< ::QAbstractFileIconProvider::Option >("QAbstractFileIconProvider::Option");

    return pyType;
}
