// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qdesktopservices_wrapper.h"

// Argument includes
#include <QString>
#include <qobject.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDesktopServices_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDesktopServices >()))
        return -1;

    ::QDesktopServices *cptr{};
    static const char fullName[] = "PySide6.QtGui.QDesktopServices.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QDesktopServices()
            cptr = new ::QDesktopServices();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDesktopServices >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDesktopServicesFunc_openUrl(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QDesktopServices.openUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDesktopServices::openUrl(QUrl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // openUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // openUrl(QUrl)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = ::QDesktopServices::openUrl(*cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDesktopServicesFunc_setUrlHandler(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QDesktopServices.setUrlHandler";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setUrlHandler", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QDesktopServices::setUrlHandler(QString,QObject*,const char*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
        overloadId = 0; // setUrlHandler(QString,QObject*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        const char* cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrlHandler(QString,QObject*,const char*)
            ::QDesktopServices::setUrlHandler(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDesktopServicesFunc_unsetUrlHandler(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QDesktopServices.unsetUrlHandler";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QDesktopServices::unsetUrlHandler(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // unsetUrlHandler(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unsetUrlHandler(QString)
            ::QDesktopServices::unsetUrlHandler(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QDesktopServices_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDesktopServices_methods[] = {
    {"openUrl", reinterpret_cast<PyCFunction>(Sbk_QDesktopServicesFunc_openUrl), METH_O|METH_STATIC, nullptr},
    {"setUrlHandler", reinterpret_cast<PyCFunction>(Sbk_QDesktopServicesFunc_setUrlHandler), METH_VARARGS|METH_STATIC, nullptr},
    {"unsetUrlHandler", reinterpret_cast<PyCFunction>(Sbk_QDesktopServicesFunc_unsetUrlHandler), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QDesktopServices_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDesktopServices_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDesktopServices_Type = nullptr;
static PyTypeObject *Sbk_QDesktopServices_TypeF(void)
{
    return _Sbk_QDesktopServices_Type;
}

static PyType_Slot Sbk_QDesktopServices_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDesktopServices_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDesktopServices_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDesktopServices_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDesktopServices_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDesktopServices_spec = {
    "2:PySide6.QtGui.QDesktopServices",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDesktopServices_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDesktopServices_PythonToCpp_QDesktopServices_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDesktopServices_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDesktopServices_PythonToCpp_QDesktopServices_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDesktopServices_TypeF()))
        return QDesktopServices_PythonToCpp_QDesktopServices_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDesktopServices_PTR_CppToPython_QDesktopServices(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QDesktopServices *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QDesktopServices_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QDesktopServices_SignatureStrings[] = {
    "PySide6.QtGui.QDesktopServices(self)",
    "PySide6.QtGui.QDesktopServices.openUrl(url:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    "PySide6.QtGui.QDesktopServices.setUrlHandler(scheme:QString,receiver:PySide6.QtCore.QObject,method:char*)",
    "PySide6.QtGui.QDesktopServices.unsetUrlHandler(scheme:QString)",
    nullptr}; // Sentinel

PyTypeObject *init_QDesktopServices(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QDesktopServices_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QDesktopServices_IDX].type;

    Shiboken::AutoDecRef Sbk_QDesktopServices_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDesktopServices_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDesktopServices",
        "QDesktopServices*",
        &Sbk_QDesktopServices_spec,
        &Shiboken::callCppDestructor< ::QDesktopServices >,
        Sbk_QDesktopServices_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDesktopServices_TypeF(); // references _Sbk_QDesktopServices_Type
    InitSignatureStrings(pyType, QDesktopServices_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDesktopServices_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QDesktopServices_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDesktopServices_PythonToCpp_QDesktopServices_PTR,
        is_QDesktopServices_PythonToCpp_QDesktopServices_PTR_Convertible,
        QDesktopServices_PTR_CppToPython_QDesktopServices);

    Shiboken::Conversions::registerConverterName(converter, "QDesktopServices");
    Shiboken::Conversions::registerConverterName(converter, "QDesktopServices*");
    Shiboken::Conversions::registerConverterName(converter, "QDesktopServices&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDesktopServices).name());

    qRegisterMetaType< ::QDesktopServices *>();

    return pyType;
}
