// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qfileopenevent_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qevent.h>
#include <qcoreevent.h>
#include <qfile.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QFileOpenEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QFileOpenEventWrapper::QFileOpenEventWrapper(const ::QString & file) : QFileOpenEvent(file)
{
    resetPyMethodCache();
    // ... middle
}

QFileOpenEventWrapper::QFileOpenEventWrapper(const ::QUrl & url) : QFileOpenEvent(url)
{
    resetPyMethodCache();
    // ... middle
}

::QFileOpenEvent * QFileOpenEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QFileOpenEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QFileOpenEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileOpenEvent", funcName, Shiboken::SbkType< QFileOpenEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QFileOpenEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QFileOpenEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QFileOpenEventWrapper::~QFileOpenEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFileOpenEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFileOpenEvent >()))
        return -1;

    QFileOpenEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QFileOpenEvent.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QFileOpenEvent", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFileOpenEvent::QFileOpenEvent(QFileOpenEvent)
    // 1: QFileOpenEvent::QFileOpenEvent(QString)
    // 2: QFileOpenEvent::QFileOpenEvent(QUrl)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // QFileOpenEvent(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QFileOpenEvent(QUrl)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QFileOpenEvent(QFileOpenEvent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFileOpenEvent(const QFileOpenEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFileOpenEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFileOpenEvent(QFileOpenEvent)
                cptr = new QFileOpenEventWrapper(*cppArg0);
            }
            break;
        }
        case 1: // QFileOpenEvent(const QString &file)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFileOpenEvent(QString)
                cptr = new QFileOpenEventWrapper(cppArg0);
            }
            break;
        }
        case 2: // QFileOpenEvent(const QUrl &url)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFileOpenEvent(QUrl)
                cptr = new QFileOpenEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QFileOpenEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFileOpenEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileOpenEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QFileOpenEvent.clone";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clone()const
            QFileOpenEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QFileOpenEvent *>(cppSelf)->::QFileOpenEvent::clone()
                : const_cast<const ::QFileOpenEvent *>(cppSelf)->clone();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileOpenEventFunc_file(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileOpenEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QFileOpenEvent.file";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // file()const
            QString cppResult = const_cast<const ::QFileOpenEvent *>(cppSelf)->file();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileOpenEventFunc_openFile(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileOpenEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QFileOpenEvent.openFile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "openFile", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileOpenEvent::openFile(QFile&,QFlags<QIODeviceBase::OpenModeFlag>)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFile_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // openFile(QFile&,QFlags<QIODeviceBase::OpenModeFlag>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFileOpenEvent", "openFile(QFile &file, QFlags<QIODeviceBase.OpenModeFlag> flags) const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QFile *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg1 = QFlags<QIODeviceBase::OpenModeFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // openFile(QFile&,QFlags<QIODeviceBase::OpenModeFlag>)const
            bool cppResult = const_cast<const ::QFileOpenEvent *>(cppSelf)->openFile(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileOpenEventFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileOpenEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QFileOpenEvent.url";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // url()const
            QUrl cppResult = const_cast<const ::QFileOpenEvent *>(cppSelf)->url();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QFileOpenEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFileOpenEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QFileOpenEventFunc_clone), METH_NOARGS, nullptr},
    {"file", reinterpret_cast<PyCFunction>(Sbk_QFileOpenEventFunc_file), METH_NOARGS, nullptr},
    {"openFile", reinterpret_cast<PyCFunction>(Sbk_QFileOpenEventFunc_openFile), METH_VARARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QFileOpenEventFunc_url), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QFileOpenEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QFileOpenEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QFileOpenEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QFileOpenEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFileOpenEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFileOpenEvent_Type = nullptr;
static PyTypeObject *Sbk_QFileOpenEvent_TypeF(void)
{
    return _Sbk_QFileOpenEvent_Type;
}

static PyType_Slot Sbk_QFileOpenEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QFileOpenEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFileOpenEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFileOpenEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFileOpenEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFileOpenEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFileOpenEvent_spec = {
    "2:PySide6.QtGui.QFileOpenEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFileOpenEvent_slots
};

} //extern "C"

static void *Sbk_QFileOpenEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::FileOpen)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFileOpenEvent_PythonToCpp_QFileOpenEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFileOpenEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFileOpenEvent_PythonToCpp_QFileOpenEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFileOpenEvent_TypeF()))
        return QFileOpenEvent_PythonToCpp_QFileOpenEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFileOpenEvent_PTR_CppToPython_QFileOpenEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QFileOpenEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QFileOpenEvent_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QFileOpenEvent_SignatureStrings[] = {
    "2:PySide6.QtGui.QFileOpenEvent(self,arg__1:PySide6.QtGui.QFileOpenEvent)",
    "1:PySide6.QtGui.QFileOpenEvent(self,file:QString)",
    "0:PySide6.QtGui.QFileOpenEvent(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtGui.QFileOpenEvent.clone(self)->PySide6.QtGui.QFileOpenEvent",
    "PySide6.QtGui.QFileOpenEvent.file(self)->QString",
    "PySide6.QtGui.QFileOpenEvent.openFile(self,file:PySide6.QtCore.QFile,flags:PySide6.QtCore.QIODeviceBase.OpenModeFlag)->bool",
    "PySide6.QtGui.QFileOpenEvent.url(self)->PySide6.QtCore.QUrl",
    nullptr}; // Sentinel

PyTypeObject *init_QFileOpenEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QFileOpenEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QFileOpenEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFileOpenEvent",
        "QFileOpenEvent*",
        &Sbk_QFileOpenEvent_spec,
        &Shiboken::callCppDestructor< QFileOpenEvent >,
        Sbk_QFileOpenEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QFileOpenEvent_TypeF(); // references _Sbk_QFileOpenEvent_Type
    InitSignatureStrings(pyType, QFileOpenEvent_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFileOpenEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QFileOpenEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFileOpenEvent_PythonToCpp_QFileOpenEvent_PTR,
        is_QFileOpenEvent_PythonToCpp_QFileOpenEvent_PTR_Convertible,
        QFileOpenEvent_PTR_CppToPython_QFileOpenEvent);

    Shiboken::Conversions::registerConverterName(converter, "QFileOpenEvent");
    Shiboken::Conversions::registerConverterName(converter, "QFileOpenEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QFileOpenEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFileOpenEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QFileOpenEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QFileOpenEvent_TypeF(), &Sbk_QFileOpenEvent_typeDiscovery);


    return pyType;
}
