// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QMouseEventWrapper_H
#define SBK_QMouseEventWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qevent.h>

// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
class QMouseEventWrapper : public QMouseEvent
{
public:
    QMouseEventWrapper(const QMouseEventWrapper &) = delete;
    QMouseEventWrapper& operator=(const QMouseEventWrapper &) = delete;
    QMouseEventWrapper(QMouseEventWrapper &&) = delete;
    QMouseEventWrapper& operator=(QMouseEventWrapper &&) = delete;

    QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, ::Qt::MouseEventSource source, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QMouseEventWrapper(::QEvent::Type type, const ::QPointF & localPos, const ::QPointF & scenePos, const ::QPointF & globalPos, ::Qt::MouseButton button, ::QFlags<Qt::MouseButton> buttons, ::QFlags<Qt::KeyboardModifier> modifiers, const ::QPointingDevice * device = QPointingDevice::primaryPointingDevice());
    QMouseEventWrapper(const QMouseEvent& self) : QMouseEvent(self)
    {
    }

    ::QMouseEvent * clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted) override;
    void setTimestamp(quint64 timestamp) override;
    ~QMouseEventWrapper() override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[6];
};

#endif // SBK_QMouseEventWrapper_H

