// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpaintenginestate_wrapper.h"

// Extra includes
#include <QPainterPath>

// Argument includes
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpen.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#include <qnamespace.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPaintEngineState_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPaintEngineState >()))
        return -1;

    ::QPaintEngineState *cptr{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPaintEngineState()
            cptr = new ::QPaintEngineState();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPaintEngineState >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPaintEngineStateFunc_backgroundBrush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.backgroundBrush";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // backgroundBrush()const
            QBrush cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->backgroundBrush();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_backgroundMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.backgroundMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // backgroundMode()const
            Qt::BGMode cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->backgroundMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_BGMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_brush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.brush";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // brush()const
            QBrush cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->brush();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_brushNeedsResolving(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.brushNeedsResolving";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // brushNeedsResolving()const
            bool cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->brushNeedsResolving();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_brushOrigin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.brushOrigin";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // brushOrigin()const
            QPointF cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->brushOrigin();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_clipOperation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.clipOperation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clipOperation()const
            Qt::ClipOperation cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->clipOperation();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_clipPath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.clipPath";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clipPath()const
            QPainterPath cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->clipPath();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_clipRegion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.clipRegion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clipRegion()const
            QRegion cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->clipRegion();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_compositionMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.compositionMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // compositionMode()const
            QPainter::CompositionMode cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->compositionMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_CompositionMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_font(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.font";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // font()const
            QFont cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->font();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_isClipEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.isClipEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isClipEnabled()const
            bool cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->isClipEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_opacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.opacity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // opacity()const
            qreal cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->opacity();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_painter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.painter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // painter()const
            QPainter * cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->painter();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_pen(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.pen";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pen()const
            QPen cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->pen();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_penNeedsResolving(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.penNeedsResolving";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // penNeedsResolving()const
            bool cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->penNeedsResolving();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_renderHints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.renderHints";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // renderHints()const
            QFlags<QPainter::RenderHint> cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->renderHints();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPainter_RenderHint_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.state";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // state()const
            QFlags<QPaintEngine::DirtyFlag> cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->state();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_DirtyFlag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPaintEngineStateFunc_transform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPaintEngineState.transform";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // transform()const
            QTransform cppResult = const_cast<const ::QPaintEngineState *>(cppSelf)->transform();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPaintEngineState_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPaintEngineState_methods[] = {
    {"backgroundBrush", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_backgroundBrush), METH_NOARGS, nullptr},
    {"backgroundMode", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_backgroundMode), METH_NOARGS, nullptr},
    {"brush", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_brush), METH_NOARGS, nullptr},
    {"brushNeedsResolving", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_brushNeedsResolving), METH_NOARGS, nullptr},
    {"brushOrigin", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_brushOrigin), METH_NOARGS, nullptr},
    {"clipOperation", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_clipOperation), METH_NOARGS, nullptr},
    {"clipPath", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_clipPath), METH_NOARGS, nullptr},
    {"clipRegion", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_clipRegion), METH_NOARGS, nullptr},
    {"compositionMode", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_compositionMode), METH_NOARGS, nullptr},
    {"font", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_font), METH_NOARGS, nullptr},
    {"isClipEnabled", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_isClipEnabled), METH_NOARGS, nullptr},
    {"opacity", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_opacity), METH_NOARGS, nullptr},
    {"painter", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_painter), METH_NOARGS, nullptr},
    {"pen", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_pen), METH_NOARGS, nullptr},
    {"penNeedsResolving", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_penNeedsResolving), METH_NOARGS, nullptr},
    {"renderHints", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_renderHints), METH_NOARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_state), METH_NOARGS, nullptr},
    {"transform", reinterpret_cast<PyCFunction>(Sbk_QPaintEngineStateFunc_transform), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QPaintEngineState_get_dirtyFlags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_DirtyFlag_IDX])))->converter, &cppSelf->dirtyFlags);
    return pyOut;
}
static int Sbk_QPaintEngineState_set_dirtyFlags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QPaintEngineState *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("dirtyFlags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPaintEngine_DirtyFlag_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("dirtyFlags", "DirtyFlags");
        return -1;
    }

    auto cppOut_local = cppSelf->dirtyFlags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->dirtyFlags = cppOut_local;

    return 0;
}

// Getters and Setters for QPaintEngineState
static PyGetSetDef Sbk_QPaintEngineState_getsetlist[] = {
    {const_cast<char *>("dirtyFlags"), Sbk_QPaintEngineState_get_dirtyFlags, Sbk_QPaintEngineState_set_dirtyFlags, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPaintEngineState_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPaintEngineState_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPaintEngineState_Type = nullptr;
static PyTypeObject *Sbk_QPaintEngineState_TypeF(void)
{
    return _Sbk_QPaintEngineState_Type;
}

static PyType_Slot Sbk_QPaintEngineState_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPaintEngineState_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPaintEngineState_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPaintEngineState_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QPaintEngineState_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPaintEngineState_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPaintEngineState_spec = {
    "2:PySide6.QtGui.QPaintEngineState",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPaintEngineState_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPaintEngineState_PythonToCpp_QPaintEngineState_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPaintEngineState_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPaintEngineState_PythonToCpp_QPaintEngineState_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPaintEngineState_TypeF()))
        return QPaintEngineState_PythonToCpp_QPaintEngineState_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPaintEngineState_PTR_CppToPython_QPaintEngineState(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QPaintEngineState *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QPaintEngineState_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPaintEngineState_SignatureStrings[] = {
    "PySide6.QtGui.QPaintEngineState(self)",
    "PySide6.QtGui.QPaintEngineState.backgroundBrush(self)->PySide6.QtGui.QBrush",
    "PySide6.QtGui.QPaintEngineState.backgroundMode(self)->PySide6.QtCore.Qt.BGMode",
    "PySide6.QtGui.QPaintEngineState.brush(self)->PySide6.QtGui.QBrush",
    "PySide6.QtGui.QPaintEngineState.brushNeedsResolving(self)->bool",
    "PySide6.QtGui.QPaintEngineState.brushOrigin(self)->PySide6.QtCore.QPointF",
    "PySide6.QtGui.QPaintEngineState.clipOperation(self)->PySide6.QtCore.Qt.ClipOperation",
    "PySide6.QtGui.QPaintEngineState.clipPath(self)->PySide6.QtGui.QPainterPath",
    "PySide6.QtGui.QPaintEngineState.clipRegion(self)->PySide6.QtGui.QRegion",
    "PySide6.QtGui.QPaintEngineState.compositionMode(self)->PySide6.QtGui.QPainter.CompositionMode",
    "PySide6.QtGui.QPaintEngineState.font(self)->PySide6.QtGui.QFont",
    "PySide6.QtGui.QPaintEngineState.isClipEnabled(self)->bool",
    "PySide6.QtGui.QPaintEngineState.opacity(self)->qreal",
    "PySide6.QtGui.QPaintEngineState.painter(self)->PySide6.QtGui.QPainter",
    "PySide6.QtGui.QPaintEngineState.pen(self)->PySide6.QtGui.QPen",
    "PySide6.QtGui.QPaintEngineState.penNeedsResolving(self)->bool",
    "PySide6.QtGui.QPaintEngineState.renderHints(self)->PySide6.QtGui.QPainter.RenderHint",
    "PySide6.QtGui.QPaintEngineState.state(self)->PySide6.QtGui.QPaintEngine.DirtyFlag",
    "PySide6.QtGui.QPaintEngineState.transform(self)->PySide6.QtGui.QTransform",
    nullptr}; // Sentinel

PyTypeObject *init_QPaintEngineState(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX].type;

    Shiboken::AutoDecRef Sbk_QPaintEngineState_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPaintEngineState_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPaintEngineState",
        "QPaintEngineState*",
        &Sbk_QPaintEngineState_spec,
        &Shiboken::callCppDestructor< ::QPaintEngineState >,
        Sbk_QPaintEngineState_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPaintEngineState_TypeF(); // references _Sbk_QPaintEngineState_Type
    InitSignatureStrings(pyType, QPaintEngineState_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPaintEngineState_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngineState_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPaintEngineState_PythonToCpp_QPaintEngineState_PTR,
        is_QPaintEngineState_PythonToCpp_QPaintEngineState_PTR_Convertible,
        QPaintEngineState_PTR_CppToPython_QPaintEngineState);

    Shiboken::Conversions::registerConverterName(converter, "QPaintEngineState");
    Shiboken::Conversions::registerConverterName(converter, "QPaintEngineState*");
    Shiboken::Conversions::registerConverterName(converter, "QPaintEngineState&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPaintEngineState).name());

    qRegisterMetaType< ::QPaintEngineState *>();

    return pyType;
}
