// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qplatformsurfaceevent_wrapper.h"

// Argument includes
#include <QtGui/qevent.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPlatformSurfaceEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

::QPlatformSurfaceEvent * QPlatformSurfaceEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QPlatformSurfaceEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QPlatformSurfaceEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlatformSurfaceEvent", funcName, Shiboken::SbkType< QPlatformSurfaceEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPlatformSurfaceEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlatformSurfaceEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QPlatformSurfaceEventWrapper::~QPlatformSurfaceEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlatformSurfaceEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlatformSurfaceEvent >()))
        return -1;

    QPlatformSurfaceEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPlatformSurfaceEvent.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPlatformSurfaceEvent", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlatformSurfaceEvent::QPlatformSurfaceEvent(QPlatformSurfaceEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPlatformSurfaceEvent(QPlatformSurfaceEvent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QPlatformSurfaceEvent *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPlatformSurfaceEvent(QPlatformSurfaceEvent)
            cptr = new QPlatformSurfaceEventWrapper(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPlatformSurfaceEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPlatformSurfaceEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlatformSurfaceEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPlatformSurfaceEvent.clone";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clone()const
            QPlatformSurfaceEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPlatformSurfaceEvent *>(cppSelf)->::QPlatformSurfaceEvent::clone()
                : const_cast<const ::QPlatformSurfaceEvent *>(cppSelf)->clone();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlatformSurfaceEventFunc_surfaceEventType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlatformSurfaceEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPlatformSurfaceEvent.surfaceEventType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // surfaceEventType()const
            QPlatformSurfaceEvent::SurfaceEventType cppResult = const_cast<const ::QPlatformSurfaceEvent *>(cppSelf)->surfaceEventType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_SurfaceEventType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPlatformSurfaceEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPlatformSurfaceEvent_EnumFlagInfo[] = {
    "SurfaceEventType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlatformSurfaceEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QPlatformSurfaceEventFunc_clone), METH_NOARGS, nullptr},
    {"surfaceEventType", reinterpret_cast<PyCFunction>(Sbk_QPlatformSurfaceEventFunc_surfaceEventType), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPlatformSurfaceEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPlatformSurfaceEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPlatformSurfaceEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPlatformSurfaceEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlatformSurfaceEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlatformSurfaceEvent_Type = nullptr;
static PyTypeObject *Sbk_QPlatformSurfaceEvent_TypeF(void)
{
    return _Sbk_QPlatformSurfaceEvent_Type;
}

static PyType_Slot Sbk_QPlatformSurfaceEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPlatformSurfaceEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlatformSurfaceEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlatformSurfaceEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlatformSurfaceEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlatformSurfaceEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlatformSurfaceEvent_spec = {
    "2:PySide6.QtGui.QPlatformSurfaceEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlatformSurfaceEvent_slots
};

} //extern "C"

static void *Sbk_QPlatformSurfaceEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::PlatformSurface)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPlatformSurfaceEvent_SurfaceEventType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPlatformSurfaceEvent::SurfaceEventType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPlatformSurfaceEvent::SurfaceEventType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPlatformSurfaceEvent_SurfaceEventType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_SurfaceEventType_IDX])))
        return Enum_PythonToCpp_QPlatformSurfaceEvent_SurfaceEventType;
    return {};
}
static PyObject *QPlatformSurfaceEvent_SurfaceEventType_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPlatformSurfaceEvent::SurfaceEventType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_SurfaceEventType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlatformSurfaceEvent_PythonToCpp_QPlatformSurfaceEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlatformSurfaceEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlatformSurfaceEvent_PythonToCpp_QPlatformSurfaceEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlatformSurfaceEvent_TypeF()))
        return QPlatformSurfaceEvent_PythonToCpp_QPlatformSurfaceEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlatformSurfaceEvent_PTR_CppToPython_QPlatformSurfaceEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QPlatformSurfaceEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QPlatformSurfaceEvent_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPlatformSurfaceEvent_SignatureStrings[] = {
    "PySide6.QtGui.QPlatformSurfaceEvent(self,arg__1:PySide6.QtGui.QPlatformSurfaceEvent)",
    "PySide6.QtGui.QPlatformSurfaceEvent.clone(self)->PySide6.QtGui.QPlatformSurfaceEvent",
    "PySide6.QtGui.QPlatformSurfaceEvent.surfaceEventType(self)->PySide6.QtGui.QPlatformSurfaceEvent.SurfaceEventType",
    nullptr}; // Sentinel

PyTypeObject *init_QPlatformSurfaceEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlatformSurfaceEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QPlatformSurfaceEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlatformSurfaceEvent",
        "QPlatformSurfaceEvent*",
        &Sbk_QPlatformSurfaceEvent_spec,
        &Shiboken::callCppDestructor< QPlatformSurfaceEvent >,
        Sbk_QPlatformSurfaceEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPlatformSurfaceEvent_TypeF(); // references _Sbk_QPlatformSurfaceEvent_Type
    InitSignatureStrings(pyType, QPlatformSurfaceEvent_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlatformSurfaceEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlatformSurfaceEvent_PythonToCpp_QPlatformSurfaceEvent_PTR,
        is_QPlatformSurfaceEvent_PythonToCpp_QPlatformSurfaceEvent_PTR_Convertible,
        QPlatformSurfaceEvent_PTR_CppToPython_QPlatformSurfaceEvent);

    Shiboken::Conversions::registerConverterName(converter, "QPlatformSurfaceEvent");
    Shiboken::Conversions::registerConverterName(converter, "QPlatformSurfaceEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QPlatformSurfaceEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlatformSurfaceEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPlatformSurfaceEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPlatformSurfaceEvent_TypeF(), &Sbk_QPlatformSurfaceEvent_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPlatformSurfaceEvent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SurfaceEventType'.
    const char *SurfaceEventType_Initializer[] = {
        "SurfaceCreated",
        "SurfaceAboutToBeDestroyed",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SurfaceEventType_InitializerValues[] = {
        uint8_t(QPlatformSurfaceEvent::SurfaceEventType::SurfaceCreated),           //  0x00  0
        uint8_t(QPlatformSurfaceEvent::SurfaceEventType::SurfaceAboutToBeDestroyed) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPlatformSurfaceEvent_TypeF(),
        "2:PySide6.QtGui.QPlatformSurfaceEvent.SurfaceEventType",
        SurfaceEventType_Initializer, SurfaceEventType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPlatformSurfaceEvent_SurfaceEventType_IDX].type = EType;
    // Register converter for enum 'QPlatformSurfaceEvent::SurfaceEventType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPlatformSurfaceEvent_SurfaceEventType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPlatformSurfaceEvent_SurfaceEventType,
            is_Enum_PythonToCpp_QPlatformSurfaceEvent_SurfaceEventType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPlatformSurfaceEvent::SurfaceEventType");
        Shiboken::Conversions::registerConverterName(converter, "SurfaceEventType");
    }
    // End of 'SurfaceEventType' enum.

    qRegisterMetaType< ::QPlatformSurfaceEvent::SurfaceEventType >("QPlatformSurfaceEvent::SurfaceEventType");

    return pyType;
}
