// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhibuffer_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiBufferWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QRhiBufferWrapper::create()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiBuffer.create");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiBuffer.create");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiBuffer", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiBufferWrapper::destroy()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiBuffer.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiBuffer.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QRhiBufferWrapper::endFullDynamicBufferUpdateForCurrentFrame()
{
    if (m_PyMethodCache[2]) {
        return this->::QRhiBuffer::endFullDynamicBufferUpdateForCurrentFrame();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "endFullDynamicBufferUpdateForCurrentFrame";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QRhiBuffer::endFullDynamicBufferUpdateForCurrentFrame();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QRhiResource::Type QRhiBufferWrapper::resourceType() const
{
    if (m_PyMethodCache[3])
        return this->::QRhiBuffer::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QRhiBuffer::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiBuffer", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiBufferWrapper::~QRhiBufferWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiBufferFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiBuffer.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // create()
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QRhiBuffer.create");
                return {};
            }
            bool cppResult = cppSelf->create();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiBufferFunc_endFullDynamicBufferUpdateForCurrentFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtGui.QRhiBuffer.endFullDynamicBufferUpdateForCurrentFrame";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // endFullDynamicBufferUpdateForCurrentFrame()
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QRhiBuffer::endFullDynamicBufferUpdateForCurrentFrame()
                : cppSelf->endFullDynamicBufferUpdateForCurrentFrame();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiBufferFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiBuffer.resourceType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // resourceType()const
            QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QRhiBuffer *>(cppSelf)->::QRhiBuffer::resourceType()
                : const_cast<const ::QRhiBuffer *>(cppSelf)->resourceType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiBufferFunc_setSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiBuffer.setSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiBuffer::setSize(quint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // setSize(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSize(quint32)
            cppSelf->setSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiBufferFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiBuffer.setType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiBuffer::setType(QRhiBuffer::Type)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setType(QRhiBuffer::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiBuffer::Type cppArg0{QRhiBuffer::Immutable};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setType(QRhiBuffer::Type)
            cppSelf->setType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiBufferFunc_setUsage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiBuffer.setUsage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiBuffer::setUsage(QFlags<QRhiBuffer::UsageFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setUsage(QFlags<QRhiBuffer::UsageFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QRhiBuffer::UsageFlag> cppArg0 = QFlags<QRhiBuffer::UsageFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUsage(QFlags<QRhiBuffer::UsageFlag>)
            cppSelf->setUsage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiBufferFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiBuffer.size";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // size()const
            quint32 cppResult = const_cast<const ::QRhiBuffer *>(cppSelf)->size();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiBufferFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiBuffer.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QRhiBuffer::Type cppResult = const_cast<const ::QRhiBuffer *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiBufferFunc_usage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiBuffer.usage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // usage()const
            QFlags<QRhiBuffer::UsageFlag> cppResult = const_cast<const ::QRhiBuffer *>(cppSelf)->usage();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiBuffer_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiBuffer_EnumFlagInfo[] = {
    "Type:Enum",
    "UsageFlag:Flag:UsageFlags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiBuffer_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_create), METH_NOARGS, nullptr},
    {"endFullDynamicBufferUpdateForCurrentFrame", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_endFullDynamicBufferUpdateForCurrentFrame), METH_NOARGS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_resourceType), METH_NOARGS, nullptr},
    {"setSize", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_setSize), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_setType), METH_O, nullptr},
    {"setUsage", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_setUsage), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_size), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_type), METH_NOARGS, nullptr},
    {"usage", reinterpret_cast<PyCFunction>(Sbk_QRhiBufferFunc_usage), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiBuffer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiBufferWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiBuffer_get_m_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiBuffer::Type cppOut_local = cppSelf->m_type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiBuffer_set_m_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_type", "Type");
        return -1;
    }

    auto cppOut_local = cppSelf->m_type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_type = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiBuffer_get_m_usage(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX])))->converter, &cppSelf->m_usage);
    return pyOut;
}
static int Sbk_QRhiBuffer_set_m_usage(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_usage");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_usage", "UsageFlags");
        return -1;
    }

    auto cppOut_local = cppSelf->m_usage;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_usage = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiBuffer_get_m_size(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint32 cppOut_local = cppSelf->m_size;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiBuffer_set_m_size(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_size");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_size", "quint32");
        return -1;
    }

    auto cppOut_local = cppSelf->m_size;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_size = cppOut_local;

    return 0;
}

// Getters and Setters for QRhiBuffer
static PyGetSetDef Sbk_QRhiBuffer_getsetlist[] = {
    {const_cast<char *>("m_type"), Sbk_QRhiBuffer_get_m_type, Sbk_QRhiBuffer_set_m_type, nullptr, nullptr},
    {const_cast<char *>("m_usage"), Sbk_QRhiBuffer_get_m_usage, Sbk_QRhiBuffer_set_m_usage, nullptr, nullptr},
    {const_cast<char *>("m_size"), Sbk_QRhiBuffer_get_m_size, Sbk_QRhiBuffer_set_m_size, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiBuffer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiBuffer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiBuffer_Type = nullptr;
static PyTypeObject *Sbk_QRhiBuffer_TypeF(void)
{
    return _Sbk_QRhiBuffer_Type;
}

static PyType_Slot Sbk_QRhiBuffer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiBuffer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiBuffer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiBuffer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiBuffer_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiBuffer_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiBuffer_spec = {
    "2:PySide6.QtGui.QRhiBuffer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiBuffer_slots
};

} //extern "C"

static void *Sbk_QRhiBuffer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiBuffer *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRhiBuffer_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiBuffer::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiBuffer::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiBuffer_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))
        return Enum_PythonToCpp_QRhiBuffer_Type;
    return {};
}
static PyObject *QRhiBuffer_Type_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiBuffer::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiBuffer_UsageFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiBuffer::UsageFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiBuffer::UsageFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiBuffer_UsageFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_UsageFlag_IDX])))
        return Enum_PythonToCpp_QRhiBuffer_UsageFlag;
    return {};
}
static PyObject *QRhiBuffer_UsageFlag_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiBuffer::UsageFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_UsageFlag_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiBuffer_PythonToCpp_QRhiBuffer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiBuffer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiBuffer_PythonToCpp_QRhiBuffer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiBuffer_TypeF()))
        return QRhiBuffer_PythonToCpp_QRhiBuffer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiBuffer_PTR_CppToPython_QRhiBuffer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QRhiBuffer *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QRhiBuffer_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRhiBuffer_SignatureStrings[] = {
    "PySide6.QtGui.QRhiBuffer.create(self)->bool",
    "PySide6.QtGui.QRhiBuffer.endFullDynamicBufferUpdateForCurrentFrame(self)",
    "PySide6.QtGui.QRhiBuffer.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiBuffer.setSize(self,sz:quint32)",
    "PySide6.QtGui.QRhiBuffer.setType(self,t:PySide6.QtGui.QRhiBuffer.Type)",
    "PySide6.QtGui.QRhiBuffer.setUsage(self,u:PySide6.QtGui.QRhiBuffer.UsageFlag)",
    "PySide6.QtGui.QRhiBuffer.size(self)->quint32",
    "PySide6.QtGui.QRhiBuffer.type(self)->PySide6.QtGui.QRhiBuffer.Type",
    "PySide6.QtGui.QRhiBuffer.usage(self)->PySide6.QtGui.QRhiBuffer.UsageFlag",
    nullptr}; // Sentinel

PyTypeObject *init_QRhiBuffer(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiBuffer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]))));

    _Sbk_QRhiBuffer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiBuffer",
        "QRhiBuffer*",
        &Sbk_QRhiBuffer_spec,
        &Shiboken::callCppDestructor< QRhiBuffer >,
        Sbk_QRhiBuffer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiBuffer_TypeF(); // references _Sbk_QRhiBuffer_Type
    InitSignatureStrings(pyType, QRhiBuffer_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiBuffer_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiBuffer_PythonToCpp_QRhiBuffer_PTR,
        is_QRhiBuffer_PythonToCpp_QRhiBuffer_PTR_Convertible,
        QRhiBuffer_PTR_CppToPython_QRhiBuffer);

    Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer");
    Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiBuffer).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiBufferWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiBuffer_TypeF(), &Sbk_QRhiBuffer_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiBuffer_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "Immutable",
        "Static",
        "Dynamic",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QRhiBuffer::Type::Immutable), //  0x00  0
        uint8_t(QRhiBuffer::Type::Static),    //  0x01  1
        uint8_t(QRhiBuffer::Type::Dynamic)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiBuffer_TypeF(),
        "2:PySide6.QtGui.QRhiBuffer.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX].type = EType;
    // Register converter for enum 'QRhiBuffer::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiBuffer_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiBuffer_Type,
            is_Enum_PythonToCpp_QRhiBuffer_Type_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer::Type");
        Shiboken::Conversions::registerConverterName(converter, "Type");
    }
    // End of 'Type' enum.

    // Initialization of enum 'UsageFlag'.
    const char *UsageFlag_Initializer[] = {
        "VertexBuffer",
        "IndexBuffer",
        "UniformBuffer",
        "StorageBuffer",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t UsageFlag_InitializerValues[] = {
        uint8_t(QRhiBuffer::UsageFlag::VertexBuffer),  //  0x01  1
        uint8_t(QRhiBuffer::UsageFlag::IndexBuffer),   //  0x02  2
        uint8_t(QRhiBuffer::UsageFlag::UniformBuffer), //  0x04  4
        uint8_t(QRhiBuffer::UsageFlag::StorageBuffer)  //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiBuffer_TypeF(),
        "2:PySide6.QtGui.QRhiBuffer.UsageFlag",
        UsageFlag_Initializer, UsageFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_UsageFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX].type =
        EType;
    // Register converter for enum 'QRhiBuffer::UsageFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiBuffer_UsageFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiBuffer_UsageFlag,
            is_Enum_PythonToCpp_QRhiBuffer_UsageFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer::UsageFlag");
        Shiboken::Conversions::registerConverterName(converter, "UsageFlag");
        // Register converter for flag 'QFlags<QRhiBuffer::UsageFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRhiBuffer::UsageFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QRhiBuffer::UsageFlags");
    }
    // End of 'UsageFlag' enum/flags.

    qRegisterMetaType< ::QRhiBuffer *>();
    qRegisterMetaType< ::QRhiBuffer::Type >("QRhiBuffer::Type");
    qRegisterMetaType< ::QRhiBuffer::UsageFlag >("QRhiBuffer::UsageFlag");

    return pyType;
}
