// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhirendertarget_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <qsize.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiRenderTargetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QRhiRenderTargetWrapper::destroy()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

float QRhiRenderTargetWrapper::devicePixelRatio() const
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.devicePixelRatio");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "devicePixelRatio";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.devicePixelRatio");
        return 0;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiRenderTarget", funcName, "float", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    float cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSize QRhiRenderTargetWrapper::pixelSize() const
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.pixelSize");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "pixelSize";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.pixelSize");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiRenderTarget", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QRhiResource::Type QRhiRenderTargetWrapper::resourceType() const
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.resourceType");
        return QRhiResource::Buffer;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.resourceType");
        return QRhiResource::Buffer;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiRenderTarget", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QRhiRenderTargetWrapper::sampleCount() const
{
    if (m_PyMethodCache[4]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.sampleCount");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sampleCount";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.sampleCount");
        return 0;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiRenderTarget", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiRenderTargetWrapper::~QRhiRenderTargetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiRenderTargetFunc_devicePixelRatio(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiRenderTarget.devicePixelRatio";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // devicePixelRatio()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.devicePixelRatio");
                return {};
            }
            float cppResult = const_cast<const ::QRhiRenderTarget *>(cppSelf)->devicePixelRatio();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiRenderTargetFunc_pixelSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiRenderTarget.pixelSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pixelSize()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.pixelSize");
                return {};
            }
            QSize cppResult = const_cast<const ::QRhiRenderTarget *>(cppSelf)->pixelSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiRenderTargetFunc_renderPassDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiRenderTarget.renderPassDescriptor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // renderPassDescriptor()const
            QRhiRenderPassDescriptor * cppResult = const_cast<const ::QRhiRenderTarget *>(cppSelf)->renderPassDescriptor();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiRenderTargetFunc_sampleCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiRenderTarget.sampleCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // sampleCount()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QRhiRenderTarget.sampleCount");
                return {};
            }
            int cppResult = const_cast<const ::QRhiRenderTarget *>(cppSelf)->sampleCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiRenderTargetFunc_setRenderPassDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiRenderTarget.setRenderPassDescriptor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiRenderTarget::setRenderPassDescriptor(QRhiRenderPassDescriptor*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), (pyArg)))) {
        overloadId = 0; // setRenderPassDescriptor(QRhiRenderPassDescriptor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiRenderPassDescriptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRenderPassDescriptor(QRhiRenderPassDescriptor*)
            cppSelf->setRenderPassDescriptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QRhiRenderTarget_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiRenderTarget_methods[] = {
    {"devicePixelRatio", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderTargetFunc_devicePixelRatio), METH_NOARGS, nullptr},
    {"pixelSize", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderTargetFunc_pixelSize), METH_NOARGS, nullptr},
    {"renderPassDescriptor", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderTargetFunc_renderPassDescriptor), METH_NOARGS, nullptr},
    {"sampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderTargetFunc_sampleCount), METH_NOARGS, nullptr},
    {"setRenderPassDescriptor", reinterpret_cast<PyCFunction>(Sbk_QRhiRenderTargetFunc_setRenderPassDescriptor), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiRenderTarget_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiRenderTargetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiRenderTarget_get_m_renderPassDesc(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), cppSelf->m_renderPassDesc);
    return pyOut;
}
static int Sbk_QRhiRenderTarget_set_m_renderPassDesc(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiRenderTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_renderPassDesc");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_renderPassDesc", "QRhiRenderPassDescriptor");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->m_renderPassDesc;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "m_renderPassDesc", pyIn);
    return 0;
}

// Getters and Setters for QRhiRenderTarget
static PyGetSetDef Sbk_QRhiRenderTarget_getsetlist[] = {
    {const_cast<char *>("m_renderPassDesc"), Sbk_QRhiRenderTarget_get_m_renderPassDesc, Sbk_QRhiRenderTarget_set_m_renderPassDesc, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiRenderTarget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiRenderTarget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiRenderTarget_Type = nullptr;
static PyTypeObject *Sbk_QRhiRenderTarget_TypeF(void)
{
    return _Sbk_QRhiRenderTarget_Type;
}

static PyType_Slot Sbk_QRhiRenderTarget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiRenderTarget_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiRenderTarget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiRenderTarget_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiRenderTarget_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiRenderTarget_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiRenderTarget_spec = {
    "2:PySide6.QtGui.QRhiRenderTarget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiRenderTarget_slots
};

} //extern "C"

static void *Sbk_QRhiRenderTarget_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiRenderTarget *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiRenderTarget_PythonToCpp_QRhiRenderTarget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiRenderTarget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiRenderTarget_PythonToCpp_QRhiRenderTarget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiRenderTarget_TypeF()))
        return QRhiRenderTarget_PythonToCpp_QRhiRenderTarget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiRenderTarget_PTR_CppToPython_QRhiRenderTarget(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QRhiRenderTarget *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QRhiRenderTarget_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRhiRenderTarget_SignatureStrings[] = {
    "PySide6.QtGui.QRhiRenderTarget.devicePixelRatio(self)->float",
    "PySide6.QtGui.QRhiRenderTarget.pixelSize(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QRhiRenderTarget.renderPassDescriptor(self)->PySide6.QtGui.QRhiRenderPassDescriptor",
    "PySide6.QtGui.QRhiRenderTarget.sampleCount(self)->int",
    "PySide6.QtGui.QRhiRenderTarget.setRenderPassDescriptor(self,desc:PySide6.QtGui.QRhiRenderPassDescriptor)",
    nullptr}; // Sentinel

PyTypeObject *init_QRhiRenderTarget(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiRenderTarget_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]))));

    _Sbk_QRhiRenderTarget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiRenderTarget",
        "QRhiRenderTarget*",
        &Sbk_QRhiRenderTarget_spec,
        &Shiboken::callCppDestructor< QRhiRenderTarget >,
        Sbk_QRhiRenderTarget_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiRenderTarget_TypeF(); // references _Sbk_QRhiRenderTarget_Type
    InitSignatureStrings(pyType, QRhiRenderTarget_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiRenderTarget_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderTarget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiRenderTarget_PythonToCpp_QRhiRenderTarget_PTR,
        is_QRhiRenderTarget_PythonToCpp_QRhiRenderTarget_PTR_Convertible,
        QRhiRenderTarget_PTR_CppToPython_QRhiRenderTarget);

    Shiboken::Conversions::registerConverterName(converter, "QRhiRenderTarget");
    Shiboken::Conversions::registerConverterName(converter, "QRhiRenderTarget*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiRenderTarget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiRenderTarget).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiRenderTargetWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiRenderTarget_TypeF(), &Sbk_QRhiRenderTarget_typeDiscovery);

    qRegisterMetaType< ::QRhiRenderTarget *>();

    return pyType;
}
