// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qwhatsthisclickedevent_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qevent.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWhatsThisClickedEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QWhatsThisClickedEventWrapper::QWhatsThisClickedEventWrapper(const ::QString & href) : QWhatsThisClickedEvent(href)
{
    resetPyMethodCache();
    // ... middle
}

::QWhatsThisClickedEvent * QWhatsThisClickedEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QWhatsThisClickedEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QWhatsThisClickedEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWhatsThisClickedEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWhatsThisClickedEvent", funcName, Shiboken::SbkType< QWhatsThisClickedEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWhatsThisClickedEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWhatsThisClickedEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QWhatsThisClickedEventWrapper::~QWhatsThisClickedEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWhatsThisClickedEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWhatsThisClickedEvent >()))
        return -1;

    QWhatsThisClickedEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QWhatsThisClickedEvent.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWhatsThisClickedEvent", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWhatsThisClickedEvent::QWhatsThisClickedEvent(QString)
    // 1: QWhatsThisClickedEvent::QWhatsThisClickedEvent(QWhatsThisClickedEvent)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWhatsThisClickedEvent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QWhatsThisClickedEvent(QWhatsThisClickedEvent)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // QWhatsThisClickedEvent(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QWhatsThisClickedEvent(const QString &href)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QWhatsThisClickedEvent(QString)
                cptr = new QWhatsThisClickedEventWrapper(cppArg0);
            }
            break;
        }
        case 1: // QWhatsThisClickedEvent(const QWhatsThisClickedEvent &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWhatsThisClickedEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QWhatsThisClickedEvent(QWhatsThisClickedEvent)
                cptr = new QWhatsThisClickedEventWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QWhatsThisClickedEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWhatsThisClickedEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWhatsThisClickedEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWhatsThisClickedEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QWhatsThisClickedEvent.clone";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clone()const
            QWhatsThisClickedEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QWhatsThisClickedEvent *>(cppSelf)->::QWhatsThisClickedEvent::clone()
                : const_cast<const ::QWhatsThisClickedEvent *>(cppSelf)->clone();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWhatsThisClickedEvent_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWhatsThisClickedEventFunc_href(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWhatsThisClickedEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWhatsThisClickedEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QWhatsThisClickedEvent.href";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // href()const
            QString cppResult = const_cast<const ::QWhatsThisClickedEvent *>(cppSelf)->href();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWhatsThisClickedEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWhatsThisClickedEvent_methods[] = {
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QWhatsThisClickedEventFunc_clone), METH_NOARGS, nullptr},
    {"href", reinterpret_cast<PyCFunction>(Sbk_QWhatsThisClickedEventFunc_href), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWhatsThisClickedEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWhatsThisClickedEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWhatsThisClickedEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWhatsThisClickedEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWhatsThisClickedEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWhatsThisClickedEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWhatsThisClickedEvent_Type = nullptr;
static PyTypeObject *Sbk_QWhatsThisClickedEvent_TypeF(void)
{
    return _Sbk_QWhatsThisClickedEvent_Type;
}

static PyType_Slot Sbk_QWhatsThisClickedEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWhatsThisClickedEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWhatsThisClickedEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWhatsThisClickedEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWhatsThisClickedEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWhatsThisClickedEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWhatsThisClickedEvent_spec = {
    "2:PySide6.QtGui.QWhatsThisClickedEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWhatsThisClickedEvent_slots
};

} //extern "C"

static void *Sbk_QWhatsThisClickedEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::WhatsThisClicked)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWhatsThisClickedEvent_PythonToCpp_QWhatsThisClickedEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWhatsThisClickedEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWhatsThisClickedEvent_PythonToCpp_QWhatsThisClickedEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWhatsThisClickedEvent_TypeF()))
        return QWhatsThisClickedEvent_PythonToCpp_QWhatsThisClickedEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWhatsThisClickedEvent_PTR_CppToPython_QWhatsThisClickedEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QWhatsThisClickedEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QWhatsThisClickedEvent_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QWhatsThisClickedEvent_SignatureStrings[] = {
    "1:PySide6.QtGui.QWhatsThisClickedEvent(self,href:QString)",
    "0:PySide6.QtGui.QWhatsThisClickedEvent(self,arg__1:PySide6.QtGui.QWhatsThisClickedEvent)",
    "PySide6.QtGui.QWhatsThisClickedEvent.clone(self)->PySide6.QtGui.QWhatsThisClickedEvent",
    "PySide6.QtGui.QWhatsThisClickedEvent.href(self)->QString",
    nullptr}; // Sentinel

PyTypeObject *init_QWhatsThisClickedEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QWhatsThisClickedEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QWhatsThisClickedEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QWhatsThisClickedEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QWhatsThisClickedEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWhatsThisClickedEvent",
        "QWhatsThisClickedEvent*",
        &Sbk_QWhatsThisClickedEvent_spec,
        &Shiboken::callCppDestructor< QWhatsThisClickedEvent >,
        Sbk_QWhatsThisClickedEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWhatsThisClickedEvent_TypeF(); // references _Sbk_QWhatsThisClickedEvent_Type
    InitSignatureStrings(pyType, QWhatsThisClickedEvent_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWhatsThisClickedEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QWhatsThisClickedEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWhatsThisClickedEvent_PythonToCpp_QWhatsThisClickedEvent_PTR,
        is_QWhatsThisClickedEvent_PythonToCpp_QWhatsThisClickedEvent_PTR_Convertible,
        QWhatsThisClickedEvent_PTR_CppToPython_QWhatsThisClickedEvent);

    Shiboken::Conversions::registerConverterName(converter, "QWhatsThisClickedEvent");
    Shiboken::Conversions::registerConverterName(converter, "QWhatsThisClickedEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QWhatsThisClickedEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWhatsThisClickedEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWhatsThisClickedEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWhatsThisClickedEvent_TypeF(), &Sbk_QWhatsThisClickedEvent_typeDiscovery);


    return pyType;
}
