// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qhttpserver_wrapper.h"

// Extra includes
#include <QtHttpServer/QHttpServerRequest>
#include <QtHttpServer/QHttpServerRouterRule>

// Argument includes
#include <QList>
#include <QString>
#include <QtCore/qfuture.h>
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtHttpServer/qhttpserverresponder.h>
#include <QtHttpServer/qhttpserverresponse.h>
#include <QtHttpServer/qhttpserverrouter.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qlocalserver.h>
#include <QtNetwork/qssl.h>
#include <QtNetwork/qsslcertificate.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetwork/qsslkey.h>
#include <QtNetwork/qtcpserver.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHttpServer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHttpServer >()))
        return -1;

    ::QHttpServer *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServer.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QHttpServer", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHttpServer::QHttpServer(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QHttpServer(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QHttpServer(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QHttpServer(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) ::QHttpServer(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new ::QHttpServer(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHttpServer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QHttpServerFunc_afterRequest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServer.afterRequest";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpServer::afterRequest(PyCallable)
    if (PyCallable_Check(pyArg)) {
        overloadId = 0; // afterRequest(PyCallable)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // afterRequest(PyCallable)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qhttpserver.cpp (qhttpserver-afterrequest)]
            auto *callable = pyArg;

            cppSelf->afterRequest([callable](QHttpServerResponse &&response,
                                               const QHttpServerRequest &request) {
                Shiboken::GilState state;
                Shiboken::AutoDecRef arglist(PyTuple_New(2));
                auto *responsePtr = &response;
                auto *requestPtr = &request;
                PyTuple_SET_ITEM(arglist, 0,
                                 Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponse_IDX]), responsePtr));
                PyTuple_SET_ITEM(arglist, 1,
                                 Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), requestPtr));
                PyObject_CallObject(callable, arglist);
                if (PyErr_Occurred())
                    PyErr_Print();
                return std::move(response);
            });
            // END of custom code block [file: ../glue/qhttpserver.cpp (qhttpserver-afterrequest)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpServerFunc_handleRequest(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServer.handleRequest";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "handleRequest", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractHttpServer::handleRequest(QHttpServerRequest,QHttpServerResponder&)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerResponder_IDX]), (pyArgs[1])))) {
        overloadId = 0; // handleRequest(QHttpServerRequest,QHttpServerResponder&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        Shiboken::Errors::setPrivateMethod("handleRequest(const QHttpServerRequest &request, QHttpServerResponder &responder)");
        return {};
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerFunc_route(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServer.route";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "route", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpServer::route(QString,PyCallable)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && PyCallable_Check(pyArgs[1])) {
        overloadId = 0; // route(QString,PyCallable)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // route(QString,PyCallable)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qhttpserver.cpp (qhttpserver-route)]
            ::QString rule;
            Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyArgs[1-1], &(rule));
            auto *callable = pyArgs[2-1];

            bool cppResult = cppSelf->route(rule,
                                                     [callable](const QHttpServerRequest &request) -> QString {
                Shiboken::GilState state;
                auto *requestPtr = &request;
                Shiboken::AutoDecRef arglist(PyTuple_New(1));
                PyTuple_SET_ITEM(arglist, 0,
                                 Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRequest_IDX]), requestPtr));
                PyObject *ret = PyObject_CallObject(callable, arglist);
                if (PyErr_Occurred())
                    PyErr_Print();
                if (ret == nullptr)
                    return QString{};
                ::QString cppResult;
            Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], ret, &(cppResult));
                return cppResult;
            });

            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            // END of custom code block [file: ../glue/qhttpserver.cpp (qhttpserver-route)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpServerFunc_router(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtHttpServer.QHttpServer.router";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // router()
            QHttpServerRouter * cppResult = cppSelf->router();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServerRouter_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHttpServer_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttpServer_methods[] = {
    {"afterRequest", reinterpret_cast<PyCFunction>(Sbk_QHttpServerFunc_afterRequest), METH_O, nullptr},
    {"handleRequest", reinterpret_cast<PyCFunction>(Sbk_QHttpServerFunc_handleRequest), METH_VARARGS, nullptr},
    {"route", reinterpret_cast<PyCFunction>(Sbk_QHttpServerFunc_route), METH_VARARGS, nullptr},
    {"router", reinterpret_cast<PyCFunction>(Sbk_QHttpServerFunc_router), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QHttpServer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QHttpServer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttpServer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttpServer_Type = nullptr;
static PyTypeObject *Sbk_QHttpServer_TypeF(void)
{
    return _Sbk_QHttpServer_Type;
}

static PyType_Slot Sbk_QHttpServer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QHttpServer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttpServer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttpServer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttpServer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHttpServer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttpServer_spec = {
    "2:PySide6.QtHttpServer.QHttpServer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttpServer_slots
};

} //extern "C"

static void *Sbk_QHttpServer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QHttpServer *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttpServer_PythonToCpp_QHttpServer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttpServer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttpServer_PythonToCpp_QHttpServer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttpServer_TypeF()))
        return QHttpServer_PythonToCpp_QHttpServer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttpServer_PTR_CppToPython_QHttpServer(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QHttpServer *>(const_cast<void *>(cppIn)), Sbk_QHttpServer_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QHttpServer_SignatureStrings[] = {
    "PySide6.QtHttpServer.QHttpServer(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtHttpServer.QHttpServer.afterRequest(self,callback:PyCallable)",
    "PySide6.QtHttpServer.QHttpServer.handleRequest(self,request:PySide6.QtHttpServer.QHttpServerRequest,responder:PySide6.QtHttpServer.QHttpServerResponder)->bool",
    "PySide6.QtHttpServer.QHttpServer.route(self,rule:QString,callback:PyCallable)->bool",
    "PySide6.QtHttpServer.QHttpServer.router(self)->PySide6.QtHttpServer.QHttpServerRouter",
    nullptr}; // Sentinel

PyTypeObject *init_QHttpServer(PyObject *module)
{
    if (SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServer_IDX].type != nullptr)
        return SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServer_IDX].type;

    Shiboken::AutoDecRef Sbk_QHttpServer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]))));

    _Sbk_QHttpServer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttpServer",
        "QHttpServer*",
        &Sbk_QHttpServer_spec,
        &Shiboken::callCppDestructor< ::QHttpServer >,
        Sbk_QHttpServer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QHttpServer_TypeF(); // references _Sbk_QHttpServer_Type
    InitSignatureStrings(pyType, QHttpServer_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttpServer_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QHttpServer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttpServer_PythonToCpp_QHttpServer_PTR,
        is_QHttpServer_PythonToCpp_QHttpServer_PTR_Convertible,
        QHttpServer_PTR_CppToPython_QHttpServer);

    Shiboken::Conversions::registerConverterName(converter, "QHttpServer");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServer*");
    Shiboken::Conversions::registerConverterName(converter, "QHttpServer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttpServer).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QHttpServer_TypeF(), &Sbk_QHttpServer_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QHttpServer::staticMetaObject, sizeof(::QHttpServer));

    return pyType;
}
