// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qgeoroute_wrapper.h"

// Argument includes
#include <QList>
#include <QMap>
#include <QString>
#include <QtLocation/qgeoroute.h>
#include <QtLocation/qgeorouterequest.h>
#include <QtLocation/qgeoroutesegment.h>
#include <QtPositioning/qgeocoordinate.h>
#include <QtPositioning/qgeorectangle.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoRoute_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoRoute >()))
        return -1;

    ::QGeoRoute *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGeoRoute", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoRoute::QGeoRoute()
    // 1: QGeoRoute::QGeoRoute(QGeoRoute)
    if (numArgs == 0) {
        overloadId = 0; // QGeoRoute()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QGeoRoute(QGeoRoute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGeoRoute()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRoute()
                cptr = new ::QGeoRoute();
            }
            break;
        }
        case 1: // QGeoRoute(const QGeoRoute &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGeoRoute cppArg0_local;
            ::QGeoRoute *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGeoRoute(QGeoRoute)
                cptr = new ::QGeoRoute(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGeoRoute >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGeoRouteFunc_bounds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.bounds";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // bounds()const
            QGeoRectangle cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->bounds();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_distance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.distance";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // distance()const
            qreal cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->distance();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_extendedAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.extendedAttributes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // extendedAttributes()const
            QMap<QString,QVariant> cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->extendedAttributes();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_firstRouteSegment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.firstRouteSegment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // firstRouteSegment()const
            QGeoRouteSegment cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->firstRouteSegment();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_legIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.legIndex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // legIndex()const
            int cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->legIndex();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_overallRoute(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.overallRoute";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // overallRoute()const
            QGeoRoute cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->overallRoute();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_path(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.path";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // path()const
            QList<QGeoCoordinate> cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->path();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoCoordinate_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_request(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.request";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // request()const
            QGeoRouteRequest* cppResult = new QGeoRouteRequest(const_cast<const ::QGeoRoute *>(cppSelf)->request());
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_routeId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.routeId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // routeId()const
            QString cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->routeId();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_routeLegs(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.routeLegs";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // routeLegs()const
            QList<QGeoRoute> cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->routeLegs();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoRoute_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_segments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.segments";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // segments()const
            QList<QGeoRouteSegment> cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->segments();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoRouteSegment_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_segmentsCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.segmentsCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // segmentsCount()const
            qsizetype cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->segmentsCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_setBounds(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setBounds";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setBounds(QGeoRectangle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoRectangle_IDX]), (pyArg)))) {
        overloadId = 0; // setBounds(QGeoRectangle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRectangle cppArg0_local;
        ::QGeoRectangle *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBounds(QGeoRectangle)
            cppSelf->setBounds(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setDistance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setDistance";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setDistance(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDistance(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDistance(qreal)
            cppSelf->setDistance(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setExtendedAttributes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setExtendedAttributes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setExtendedAttributes(QMap<QString,QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setExtendedAttributes(QMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExtendedAttributes(QMap<QString,QVariant>)
            cppSelf->setExtendedAttributes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setFirstRouteSegment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setFirstRouteSegment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setFirstRouteSegment(QGeoRouteSegment)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteSegment_IDX]), (pyArg)))) {
        overloadId = 0; // setFirstRouteSegment(QGeoRouteSegment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRouteSegment cppArg0_local;
        ::QGeoRouteSegment *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFirstRouteSegment(QGeoRouteSegment)
            cppSelf->setFirstRouteSegment(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setLegIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setLegIndex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setLegIndex(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLegIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLegIndex(int)
            cppSelf->setLegIndex(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setOverallRoute(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setOverallRoute";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setOverallRoute(QGeoRoute)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArg)))) {
        overloadId = 0; // setOverallRoute(QGeoRoute)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRoute cppArg0_local;
        ::QGeoRoute *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setOverallRoute(QGeoRoute)
            cppSelf->setOverallRoute(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setPath";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setPath(QList<QGeoCoordinate>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoCoordinate_IDX], (pyArg)))) {
        overloadId = 0; // setPath(QList<QGeoCoordinate>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QGeoCoordinate> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPath(QList<QGeoCoordinate>)
            cppSelf->setPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setRequest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setRequest";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setRequest(QGeoRouteRequest)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_IDX]), (pyArg)))) {
        overloadId = 0; // setRequest(QGeoRouteRequest)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRouteRequest *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRequest(QGeoRouteRequest)
            cppSelf->setRequest(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setRouteId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setRouteId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setRouteId(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRouteId(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRouteId(QString)
            cppSelf->setRouteId(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setRouteLegs(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setRouteLegs";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setRouteLegs(QList<QGeoRoute>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QGeoRoute_IDX], (pyArg)))) {
        overloadId = 0; // setRouteLegs(QList<QGeoRoute>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QGeoRoute> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRouteLegs(QList<QGeoRoute>)
            cppSelf->setRouteLegs(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setTravelMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setTravelMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setTravelMode(QGeoRouteRequest::TravelMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_TravelMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTravelMode(QGeoRouteRequest::TravelMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QGeoRouteRequest::TravelMode cppArg0 = static_cast< ::QGeoRouteRequest::TravelMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTravelMode(QGeoRouteRequest::TravelMode)
            cppSelf->setTravelMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_setTravelTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.setTravelTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::setTravelTime(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTravelTime(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTravelTime(int)
            cppSelf->setTravelTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoRoute::swap(QGeoRoute&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QGeoRoute&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoRoute cppArg0_local;
        ::QGeoRoute *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QGeoRoute&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoRouteFunc_travelMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.travelMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // travelMode()const
            QGeoRouteRequest::TravelMode cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->travelMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRouteRequest_TravelMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRouteFunc_travelTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoRoute.travelTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // travelTime()const
            int cppResult = const_cast<const ::QGeoRoute *>(cppSelf)->travelTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoRoute__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGeoRoute_PropertyStrings[] = {
    "bounds:",
    "distance:",
    "extendedAttributes:",
    "legIndex:",
    "overallRoute:",
    "path::",
    "routeId:",
    "routeLegs:",
    "segments:",
    "segmentsCount:",
    "travelTime:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoRoute_methods[] = {
    {"bounds", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_bounds), METH_NOARGS, nullptr},
    {"distance", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_distance), METH_NOARGS, nullptr},
    {"extendedAttributes", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_extendedAttributes), METH_NOARGS, nullptr},
    {"firstRouteSegment", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_firstRouteSegment), METH_NOARGS, nullptr},
    {"legIndex", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_legIndex), METH_NOARGS, nullptr},
    {"overallRoute", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_overallRoute), METH_NOARGS, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_path), METH_NOARGS, nullptr},
    {"request", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_request), METH_NOARGS, nullptr},
    {"routeId", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_routeId), METH_NOARGS, nullptr},
    {"routeLegs", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_routeLegs), METH_NOARGS, nullptr},
    {"segments", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_segments), METH_NOARGS, nullptr},
    {"segmentsCount", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_segmentsCount), METH_NOARGS, nullptr},
    {"setBounds", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setBounds), METH_O, nullptr},
    {"setDistance", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setDistance), METH_O, nullptr},
    {"setExtendedAttributes", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setExtendedAttributes), METH_O, nullptr},
    {"setFirstRouteSegment", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setFirstRouteSegment), METH_O, nullptr},
    {"setLegIndex", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setLegIndex), METH_O, nullptr},
    {"setOverallRoute", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setOverallRoute), METH_O, nullptr},
    {"setPath", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setPath), METH_O, nullptr},
    {"setRequest", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setRequest), METH_O, nullptr},
    {"setRouteId", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setRouteId), METH_O, nullptr},
    {"setRouteLegs", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setRouteLegs), METH_O, nullptr},
    {"setTravelMode", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setTravelMode), METH_O, nullptr},
    {"setTravelTime", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_setTravelTime), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_swap), METH_O, nullptr},
    {"travelMode", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_travelMode), METH_NOARGS, nullptr},
    {"travelTime", reinterpret_cast<PyCFunction>(Sbk_QGeoRouteFunc_travelTime), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGeoRoute__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QGeoRoute_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArg)))) {
                // operator!=(const QGeoRoute &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoRoute cppArg0_local;
                ::QGeoRoute *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), (pyArg)))) {
                // operator==(const QGeoRoute &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGeoRoute cppArg0_local;
                ::QGeoRoute *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QGeoRoute_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoRoute_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoRoute_Type = nullptr;
static PyTypeObject *Sbk_QGeoRoute_TypeF(void)
{
    return _Sbk_QGeoRoute_Type;
}

static PyType_Slot Sbk_QGeoRoute_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoRoute_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoRoute_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGeoRoute_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoRoute_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoRoute_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoRoute_spec = {
    "2:PySide6.QtLocation.QGeoRoute",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoRoute_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoRoute_PythonToCpp_QGeoRoute_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoRoute_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoRoute_PythonToCpp_QGeoRoute_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoRoute_TypeF()))
        return QGeoRoute_PythonToCpp_QGeoRoute_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoRoute_PTR_CppToPython_QGeoRoute(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QGeoRoute *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QGeoRoute_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QGeoRoute_COPY_CppToPython_QGeoRoute(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGeoRoute *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGeoRoute_TypeF(), new ::QGeoRoute(*source), true, true);
}

// Python to C++ copy conversion.
static void QGeoRoute_PythonToCpp_QGeoRoute_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGeoRoute *>(cppOut) = *reinterpret_cast< ::QGeoRoute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGeoRoute_PythonToCpp_QGeoRoute_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoRoute_TypeF()))
        return QGeoRoute_PythonToCpp_QGeoRoute_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QGeoRoute_SignatureStrings[] = {
    "1:PySide6.QtLocation.QGeoRoute(self)",
    "0:PySide6.QtLocation.QGeoRoute(self,other:PySide6.QtLocation.QGeoRoute)",
    "PySide6.QtLocation.QGeoRoute.bounds(self)->PySide6.QtPositioning.QGeoRectangle",
    "PySide6.QtLocation.QGeoRoute.distance(self)->qreal",
    "PySide6.QtLocation.QGeoRoute.extendedAttributes(self)->QMap[QString, QVariant]",
    "PySide6.QtLocation.QGeoRoute.firstRouteSegment(self)->PySide6.QtLocation.QGeoRouteSegment",
    "PySide6.QtLocation.QGeoRoute.legIndex(self)->int",
    "PySide6.QtLocation.QGeoRoute.overallRoute(self)->PySide6.QtLocation.QGeoRoute",
    "PySide6.QtLocation.QGeoRoute.path(self)->QList[PySide6.QtPositioning.QGeoCoordinate]",
    "PySide6.QtLocation.QGeoRoute.request(self)->PySide6.QtLocation.QGeoRouteRequest",
    "PySide6.QtLocation.QGeoRoute.routeId(self)->QString",
    "PySide6.QtLocation.QGeoRoute.routeLegs(self)->QList[PySide6.QtLocation.QGeoRoute]",
    "PySide6.QtLocation.QGeoRoute.segments(self)->QList[PySide6.QtLocation.QGeoRouteSegment]",
    "PySide6.QtLocation.QGeoRoute.segmentsCount(self)->qsizetype",
    "PySide6.QtLocation.QGeoRoute.setBounds(self,bounds:typing.Union[PySide6.QtPositioning.QGeoRectangle, PySide6.QtPositioning.QGeoShape, QList[PySide6.QtPositioning.QGeoCoordinate]])",
    "PySide6.QtLocation.QGeoRoute.setDistance(self,distance:qreal)",
    "PySide6.QtLocation.QGeoRoute.setExtendedAttributes(self,extendedAttributes:QMap[QString, QVariant])",
    "PySide6.QtLocation.QGeoRoute.setFirstRouteSegment(self,routeSegment:PySide6.QtLocation.QGeoRouteSegment)",
    "PySide6.QtLocation.QGeoRoute.setLegIndex(self,idx:int)",
    "PySide6.QtLocation.QGeoRoute.setOverallRoute(self,route:PySide6.QtLocation.QGeoRoute)",
    "PySide6.QtLocation.QGeoRoute.setPath(self,path:QList[PySide6.QtPositioning.QGeoCoordinate])",
    "PySide6.QtLocation.QGeoRoute.setRequest(self,request:PySide6.QtLocation.QGeoRouteRequest)",
    "PySide6.QtLocation.QGeoRoute.setRouteId(self,id:QString)",
    "PySide6.QtLocation.QGeoRoute.setRouteLegs(self,legs:QList[PySide6.QtLocation.QGeoRoute])",
    "PySide6.QtLocation.QGeoRoute.setTravelMode(self,mode:PySide6.QtLocation.QGeoRouteRequest.TravelMode)",
    "PySide6.QtLocation.QGeoRoute.setTravelTime(self,secs:int)",
    "PySide6.QtLocation.QGeoRoute.swap(self,other:PySide6.QtLocation.QGeoRoute)",
    "PySide6.QtLocation.QGeoRoute.travelMode(self)->PySide6.QtLocation.QGeoRouteRequest.TravelMode",
    "PySide6.QtLocation.QGeoRoute.travelTime(self)->int",
    "PySide6.QtLocation.QGeoRoute.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QGeoRoute(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoRoute_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGeoRoute_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoRoute",
        "QGeoRoute",
        &Sbk_QGeoRoute_spec,
        &Shiboken::callCppDestructor< ::QGeoRoute >,
        Sbk_QGeoRoute_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGeoRoute_TypeF(); // references _Sbk_QGeoRoute_Type
    InitSignatureStrings(pyType, QGeoRoute_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoRoute_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoute_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoRoute_PythonToCpp_QGeoRoute_PTR,
        is_QGeoRoute_PythonToCpp_QGeoRoute_PTR_Convertible,
        QGeoRoute_PTR_CppToPython_QGeoRoute,
        QGeoRoute_COPY_CppToPython_QGeoRoute);

    Shiboken::Conversions::registerConverterName(converter, "QGeoRoute");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRoute*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoRoute&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoRoute).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGeoRoute_PythonToCpp_QGeoRoute_COPY,
        is_QGeoRoute_PythonToCpp_QGeoRoute_COPY_Convertible);

    qRegisterMetaType< ::QGeoRoute >("QGeoRoute");

    return pyType;
}
