// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qhttp1configuration_wrapper.h"

// Argument includes
#include <QtNetwork/qhttp1configuration.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHttp1Configuration_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHttp1Configuration >()))
        return -1;

    ::QHttp1Configuration *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp1Configuration.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QHttp1Configuration", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHttp1Configuration::QHttp1Configuration()
    // 1: QHttp1Configuration::QHttp1Configuration(QHttp1Configuration)
    if (numArgs == 0) {
        overloadId = 0; // QHttp1Configuration()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QHttp1Configuration(QHttp1Configuration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHttp1Configuration()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttp1Configuration()
                cptr = new ::QHttp1Configuration();
            }
            break;
        }
        case 1: // QHttp1Configuration(const QHttp1Configuration &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHttp1Configuration cppArg0_local;
            ::QHttp1Configuration *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttp1Configuration(QHttp1Configuration)
                cptr = new ::QHttp1Configuration(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHttp1Configuration >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHttp1ConfigurationFunc_numberOfConnectionsPerHost(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp1Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp1Configuration.numberOfConnectionsPerHost";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // numberOfConnectionsPerHost()const
            qsizetype cppResult = const_cast<const ::QHttp1Configuration *>(cppSelf)->numberOfConnectionsPerHost();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttp1ConfigurationFunc_setNumberOfConnectionsPerHost(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp1Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp1Configuration.setNumberOfConnectionsPerHost";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp1Configuration::setNumberOfConnectionsPerHost(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // setNumberOfConnectionsPerHost(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumberOfConnectionsPerHost(qsizetype)
            cppSelf->setNumberOfConnectionsPerHost(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttp1ConfigurationFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp1Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttp1Configuration.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttp1Configuration::swap(QHttp1Configuration&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QHttp1Configuration&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttp1Configuration cppArg0_local;
        ::QHttp1Configuration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QHttp1Configuration&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttp1Configuration__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHttp1Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHttp1Configuration_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttp1Configuration_methods[] = {
    {"numberOfConnectionsPerHost", reinterpret_cast<PyCFunction>(Sbk_QHttp1ConfigurationFunc_numberOfConnectionsPerHost), METH_NOARGS, nullptr},
    {"setNumberOfConnectionsPerHost", reinterpret_cast<PyCFunction>(Sbk_QHttp1ConfigurationFunc_setNumberOfConnectionsPerHost), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QHttp1ConfigurationFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QHttp1Configuration__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QHttp1Configuration_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHttp1Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), (pyArg)))) {
                // operator!=(const QHttp1Configuration &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHttp1Configuration cppArg0_local;
                ::QHttp1Configuration *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), (pyArg)))) {
                // operator==(const QHttp1Configuration &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QHttp1Configuration cppArg0_local;
                ::QHttp1Configuration *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QHttp1Configuration_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttp1Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QHttp1Configuration_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttp1Configuration_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttp1Configuration_Type = nullptr;
static PyTypeObject *Sbk_QHttp1Configuration_TypeF(void)
{
    return _Sbk_QHttp1Configuration_Type;
}

static PyType_Slot Sbk_QHttp1Configuration_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QHttp1Configuration_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttp1Configuration_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttp1Configuration_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QHttp1Configuration_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttp1Configuration_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHttp1Configuration_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttp1Configuration_spec = {
    "2:PySide6.QtNetwork.QHttp1Configuration",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttp1Configuration_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttp1Configuration_PythonToCpp_QHttp1Configuration_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttp1Configuration_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttp1Configuration_PythonToCpp_QHttp1Configuration_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttp1Configuration_TypeF()))
        return QHttp1Configuration_PythonToCpp_QHttp1Configuration_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttp1Configuration_PTR_CppToPython_QHttp1Configuration(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QHttp1Configuration *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QHttp1Configuration_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QHttp1Configuration_COPY_CppToPython_QHttp1Configuration(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QHttp1Configuration *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QHttp1Configuration_TypeF(), new ::QHttp1Configuration(*source), true, true);
}

// Python to C++ copy conversion.
static void QHttp1Configuration_PythonToCpp_QHttp1Configuration_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QHttp1Configuration *>(cppOut) = *reinterpret_cast< ::QHttp1Configuration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QHttp1Configuration_PythonToCpp_QHttp1Configuration_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QHttp1Configuration_TypeF()))
        return QHttp1Configuration_PythonToCpp_QHttp1Configuration_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QHttp1Configuration_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QHttp1Configuration(self)",
    "0:PySide6.QtNetwork.QHttp1Configuration(self,other:PySide6.QtNetwork.QHttp1Configuration)",
    "PySide6.QtNetwork.QHttp1Configuration.numberOfConnectionsPerHost(self)->qsizetype",
    "PySide6.QtNetwork.QHttp1Configuration.setNumberOfConnectionsPerHost(self,amount:qsizetype)",
    "PySide6.QtNetwork.QHttp1Configuration.swap(self,other:PySide6.QtNetwork.QHttp1Configuration)",
    "PySide6.QtNetwork.QHttp1Configuration.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QHttp1Configuration(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX].type;

    Shiboken::AutoDecRef Sbk_QHttp1Configuration_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHttp1Configuration_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttp1Configuration",
        "QHttp1Configuration",
        &Sbk_QHttp1Configuration_spec,
        &Shiboken::callCppDestructor< ::QHttp1Configuration >,
        Sbk_QHttp1Configuration_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QHttp1Configuration_TypeF(); // references _Sbk_QHttp1Configuration_Type
    InitSignatureStrings(pyType, QHttp1Configuration_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttp1Configuration_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHttp1Configuration_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttp1Configuration_PythonToCpp_QHttp1Configuration_PTR,
        is_QHttp1Configuration_PythonToCpp_QHttp1Configuration_PTR_Convertible,
        QHttp1Configuration_PTR_CppToPython_QHttp1Configuration,
        QHttp1Configuration_COPY_CppToPython_QHttp1Configuration);

    Shiboken::Conversions::registerConverterName(converter, "QHttp1Configuration");
    Shiboken::Conversions::registerConverterName(converter, "QHttp1Configuration*");
    Shiboken::Conversions::registerConverterName(converter, "QHttp1Configuration&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttp1Configuration).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QHttp1Configuration_PythonToCpp_QHttp1Configuration_COPY,
        is_QHttp1Configuration_PythonToCpp_QHttp1Configuration_COPY_Convertible);

    qRegisterMetaType< ::QHttp1Configuration >("QHttp1Configuration");

    return pyType;
}
