// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qhttpheaders_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QMultiHash>
#include <QMultiMap>
#include <QtCore/qlatin1stringview.h>
#include <QtNetwork/qhttpheaders.h>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHttpHeaders_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHttpHeaders >()))
        return -1;

    ::QHttpHeaders *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QHttpHeaders", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QHttpHeaders::QHttpHeaders()
    // 1: QHttpHeaders::QHttpHeaders(QHttpHeaders)
    if (numArgs == 0) {
        overloadId = 0; // QHttpHeaders()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QHttpHeaders(QHttpHeaders)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QHttpHeaders()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttpHeaders()
                cptr = new ::QHttpHeaders();
            }
            break;
        }
        case 1: // QHttpHeaders(const QHttpHeaders &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHttpHeaders cppArg0_local;
            ::QHttpHeaders *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QHttpHeaders(QHttpHeaders)
                cptr = new ::QHttpHeaders(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHttpHeaders >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QHttpHeadersFunc_append(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.append";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "append", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpHeaders::append(QAnyStringView,QAnyStringView)->bool
    // 1: QHttpHeaders::append(QHttpHeaders::WellKnownHeader,QAnyStringView)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // append(QHttpHeaders::WellKnownHeader,QAnyStringView)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // append(QAnyStringView,QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // append(QAnyStringView name, QAnyStringView value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QAnyStringView,QAnyStringView)
                bool cppResult = cppSelf->append(QAnyStringView(cppArg0), QAnyStringView(cppArg1));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // append(QHttpHeaders::WellKnownHeader name, QAnyStringView value)
        {
            ::QHttpHeaders::WellKnownHeader cppArg0{QHttpHeaders::WellKnownHeader::AIM};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QHttpHeaders::WellKnownHeader,QAnyStringView)
                bool cppResult = cppSelf->append(cppArg0, QAnyStringView(cppArg1));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.clear";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear()
            cppSelf->clear();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpHeadersFunc_combinedValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.combinedValue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpHeaders::combinedValue(QAnyStringView)const->QByteArray
    // 1: QHttpHeaders::combinedValue(QHttpHeaders::WellKnownHeader)const->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX])))->converter, (pyArg)))) {
        overloadId = 1; // combinedValue(QHttpHeaders::WellKnownHeader)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // combinedValue(QAnyStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // combinedValue(QAnyStringView name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // combinedValue(QAnyStringView)const
                QByteArray cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->combinedValue(QAnyStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // combinedValue(QHttpHeaders::WellKnownHeader name) const
        {
            ::QHttpHeaders::WellKnownHeader cppArg0{QHttpHeaders::WellKnownHeader::AIM};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // combinedValue(QHttpHeaders::WellKnownHeader)const
                QByteArray cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->combinedValue(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.contains";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpHeaders::contains(QAnyStringView)const->bool
    // 1: QHttpHeaders::contains(QHttpHeaders::WellKnownHeader)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX])))->converter, (pyArg)))) {
        overloadId = 1; // contains(QHttpHeaders::WellKnownHeader)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // contains(QAnyStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // contains(QAnyStringView name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // contains(QAnyStringView)const
                bool cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->contains(QAnyStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // contains(QHttpHeaders::WellKnownHeader name) const
        {
            ::QHttpHeaders::WellKnownHeader cppArg0{QHttpHeaders::WellKnownHeader::AIM};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // contains(QHttpHeaders::WellKnownHeader)const
                bool cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->contains(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_fromListOfPairs(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.fromListOfPairs";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QHttpHeaders::fromListOfPairs(QList<std::pair<QByteArray,QByteArray>>)->QHttpHeaders
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_std_pair_QByteArray_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // fromListOfPairs(QList<std::pair<QByteArray,QByteArray>>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<std::pair< QByteArray,QByteArray>> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromListOfPairs(QList<std::pair<QByteArray,QByteArray>>)
            QHttpHeaders cppResult = ::QHttpHeaders::fromListOfPairs(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_fromMultiHash(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.fromMultiHash";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QHttpHeaders::fromMultiHash(QMultiHash<QByteArray,QByteArray>)->QHttpHeaders
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiHash_QByteArray_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // fromMultiHash(QMultiHash<QByteArray,QByteArray>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QMultiHash<QByteArray,QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromMultiHash(QMultiHash<QByteArray,QByteArray>)
            QHttpHeaders cppResult = ::QHttpHeaders::fromMultiHash(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_fromMultiMap(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.fromMultiMap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QHttpHeaders::fromMultiMap(QMultiMap<QByteArray,QByteArray>)->QHttpHeaders
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiMap_QByteArray_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // fromMultiMap(QMultiMap<QByteArray,QByteArray>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QMultiMap<QByteArray,QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromMultiMap(QMultiMap<QByteArray,QByteArray>)
            QHttpHeaders cppResult = ::QHttpHeaders::fromMultiMap(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.insert";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpHeaders::insert(qsizetype,QAnyStringView,QAnyStringView)->bool
    // 1: QHttpHeaders::insert(qsizetype,QHttpHeaders::WellKnownHeader,QAnyStringView)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX])))->converter, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 1; // insert(qsizetype,QHttpHeaders::WellKnownHeader,QAnyStringView)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // insert(qsizetype,QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // insert(qsizetype i, QAnyStringView name, QAnyStringView value)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(qsizetype,QAnyStringView,QAnyStringView)
                bool cppResult = cppSelf->insert(cppArg0, QAnyStringView(cppArg1), QAnyStringView(cppArg2));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // insert(qsizetype i, QHttpHeaders::WellKnownHeader name, QAnyStringView value)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QHttpHeaders::WellKnownHeader cppArg1{QHttpHeaders::WellKnownHeader::AIM};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(qsizetype,QHttpHeaders::WellKnownHeader,QAnyStringView)
                bool cppResult = cppSelf->insert(cppArg0, cppArg1, QAnyStringView(cppArg2));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.isEmpty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEmpty()const
            bool cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->isEmpty();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_nameAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.nameAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpHeaders::nameAt(qsizetype)const->QLatin1String
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // nameAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // nameAt(qsizetype)const
            QLatin1String cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->nameAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_removeAll(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.removeAll";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpHeaders::removeAll(QAnyStringView)
    // 1: QHttpHeaders::removeAll(QHttpHeaders::WellKnownHeader)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX])))->converter, (pyArg)))) {
        overloadId = 1; // removeAll(QHttpHeaders::WellKnownHeader)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeAll(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // removeAll(QAnyStringView name)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // removeAll(QAnyStringView)
                cppSelf->removeAll(QAnyStringView(cppArg0));
            }
            break;
        }
        case 1: // removeAll(QHttpHeaders::WellKnownHeader name)
        {
            ::QHttpHeaders::WellKnownHeader cppArg0{QHttpHeaders::WellKnownHeader::AIM};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // removeAll(QHttpHeaders::WellKnownHeader)
                cppSelf->removeAll(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpHeadersFunc_removeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.removeAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpHeaders::removeAt(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // removeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAt(qsizetype)
            cppSelf->removeAt(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpHeadersFunc_replace(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.replace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "replace", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpHeaders::replace(qsizetype,QAnyStringView,QAnyStringView)->bool
    // 1: QHttpHeaders::replace(qsizetype,QHttpHeaders::WellKnownHeader,QAnyStringView)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX])))->converter, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 1; // replace(qsizetype,QHttpHeaders::WellKnownHeader,QAnyStringView)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 0; // replace(qsizetype,QAnyStringView,QAnyStringView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // replace(qsizetype i, QAnyStringView name, QAnyStringView newValue)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(qsizetype,QAnyStringView,QAnyStringView)
                bool cppResult = cppSelf->replace(cppArg0, QAnyStringView(cppArg1), QAnyStringView(cppArg2));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // replace(qsizetype i, QHttpHeaders::WellKnownHeader name, QAnyStringView newValue)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QHttpHeaders::WellKnownHeader cppArg1{QHttpHeaders::WellKnownHeader::AIM};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(qsizetype,QHttpHeaders::WellKnownHeader,QAnyStringView)
                bool cppResult = cppSelf->replace(cppArg0, cppArg1, QAnyStringView(cppArg2));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_reserve(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.reserve";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpHeaders::reserve(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // reserve(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reserve(qsizetype)
            cppSelf->reserve(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpHeadersFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.size";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // size()const
            qsizetype cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->size();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpHeaders::swap(QHttpHeaders&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QHttpHeaders&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHttpHeaders cppArg0_local;
        ::QHttpHeaders *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QHttpHeaders&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QHttpHeadersFunc_toListOfPairs(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.toListOfPairs";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toListOfPairs()const
            QList<std::pair< QByteArray,QByteArray>> cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->toListOfPairs();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_std_pair_QByteArray_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_toMultiHash(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.toMultiHash";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toMultiHash()const
            QMultiHash<QByteArray,QByteArray> cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->toMultiHash();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiHash_QByteArray_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_toMultiMap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.toMultiMap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toMultiMap()const
            QMultiMap<QByteArray,QByteArray> cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->toMultiMap();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QMultiMap_QByteArray_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_value(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.value";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:value", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QHttpHeaders::value(QAnyStringView,QByteArrayView=)const->QByteArrayView
    // 1: QHttpHeaders::value(QHttpHeaders::WellKnownHeader,QByteArrayView=)const->QByteArrayView
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // value(QHttpHeaders::WellKnownHeader,QByteArrayView)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 1; // value(QHttpHeaders::WellKnownHeader,QByteArrayView)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // value(QAnyStringView,QByteArrayView)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 0; // value(QAnyStringView,QByteArrayView)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // value(QAnyStringView name, QByteArrayView defaultValue) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
                if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                    value = PyDict_GetItem(kwds, key_defaultValue);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_defaultValue);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_defaultValue);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1{};
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // value(QAnyStringView,QByteArrayView)const
                QByteArrayView cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->value(QAnyStringView(cppArg0), QByteArrayView(cppArg1));
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], &cppResult);
            }
            break;
        }
        case 1: // value(QHttpHeaders::WellKnownHeader name, QByteArrayView defaultValue) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
                if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                    value = PyDict_GetItem(kwds, key_defaultValue);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_defaultValue);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_defaultValue);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QHttpHeaders::WellKnownHeader cppArg0{QHttpHeaders::WellKnownHeader::AIM};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1{};
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // value(QHttpHeaders::WellKnownHeader,QByteArrayView)const
                QByteArrayView cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->value(cppArg0, QByteArrayView(cppArg1));
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_valueAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.valueAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpHeaders::valueAt(qsizetype)const->QByteArrayView
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // valueAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // valueAt(qsizetype)const
            QByteArrayView cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->valueAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_values(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.values";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QHttpHeaders::values(QAnyStringView)const->QList< QByteArray>
    // 1: QHttpHeaders::values(QHttpHeaders::WellKnownHeader)const->QList< QByteArray>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX])))->converter, (pyArg)))) {
        overloadId = 1; // values(QHttpHeaders::WellKnownHeader)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // values(QAnyStringView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // values(QAnyStringView name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // values(QAnyStringView)const
                QList<QByteArray> cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->values(QAnyStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QByteArray_IDX], &cppResult);
            }
            break;
        }
        case 1: // values(QHttpHeaders::WellKnownHeader name) const
        {
            ::QHttpHeaders::WellKnownHeader cppArg0{QHttpHeaders::WellKnownHeader::AIM};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // values(QHttpHeaders::WellKnownHeader)const
                QList<QByteArray> cppResult = const_cast<const ::QHttpHeaders *>(cppSelf)->values(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QByteArray_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeadersFunc_wellKnownHeaderName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QHttpHeaders.wellKnownHeaderName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QHttpHeaders::wellKnownHeaderName(QHttpHeaders::WellKnownHeader)->QByteArrayView
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // wellKnownHeaderName(QHttpHeaders::WellKnownHeader)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QHttpHeaders::WellKnownHeader cppArg0{QHttpHeaders::WellKnownHeader::AIM};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wellKnownHeaderName(QHttpHeaders::WellKnownHeader)
            QByteArrayView cppResult = ::QHttpHeaders::wellKnownHeaderName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QHttpHeaders__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QHttpHeaders_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QHttpHeaders_EnumFlagInfo[] = {
    "WellKnownHeader:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QHttpHeaders_methods[] = {
    {"append", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_append), METH_VARARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_clear), METH_NOARGS, nullptr},
    {"combinedValue", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_combinedValue), METH_O, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_contains), METH_O, nullptr},
    {"fromListOfPairs", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_fromListOfPairs), METH_O|METH_STATIC, nullptr},
    {"fromMultiHash", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_fromMultiHash), METH_O|METH_STATIC, nullptr},
    {"fromMultiMap", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_fromMultiMap), METH_O|METH_STATIC, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_insert), METH_VARARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_isEmpty), METH_NOARGS, nullptr},
    {"nameAt", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_nameAt), METH_O, nullptr},
    {"removeAll", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_removeAll), METH_O, nullptr},
    {"removeAt", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_removeAt), METH_O, nullptr},
    {"replace", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_replace), METH_VARARGS, nullptr},
    {"reserve", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_reserve), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_size), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_swap), METH_O, nullptr},
    {"toListOfPairs", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_toListOfPairs), METH_NOARGS, nullptr},
    {"toMultiHash", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_toMultiHash), METH_NOARGS, nullptr},
    {"toMultiMap", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_toMultiMap), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_value), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"valueAt", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_valueAt), METH_O, nullptr},
    {"values", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_values), METH_O, nullptr},
    {"wellKnownHeaderName", reinterpret_cast<PyCFunction>(Sbk_QHttpHeadersFunc_wellKnownHeaderName), METH_O|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QHttpHeaders__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QHttpHeaders_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QHttpHeaders_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QHttpHeaders_Type = nullptr;
static PyTypeObject *Sbk_QHttpHeaders_TypeF(void)
{
    return _Sbk_QHttpHeaders_Type;
}

static PyType_Slot Sbk_QHttpHeaders_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QHttpHeaders_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QHttpHeaders_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QHttpHeaders_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QHttpHeaders_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QHttpHeaders_spec = {
    "2:PySide6.QtNetwork.QHttpHeaders",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QHttpHeaders_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QHttpHeaders_WellKnownHeader(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QHttpHeaders::WellKnownHeader>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QHttpHeaders::WellKnownHeader *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QHttpHeaders_WellKnownHeader_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX])))
        return Enum_PythonToCpp_QHttpHeaders_WellKnownHeader;
    return {};
}
static PyObject *QHttpHeaders_WellKnownHeader_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QHttpHeaders::WellKnownHeader *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QHttpHeaders_PythonToCpp_QHttpHeaders_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QHttpHeaders_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QHttpHeaders_PythonToCpp_QHttpHeaders_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QHttpHeaders_TypeF()))
        return QHttpHeaders_PythonToCpp_QHttpHeaders_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QHttpHeaders_PTR_CppToPython_QHttpHeaders(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QHttpHeaders *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QHttpHeaders_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QHttpHeaders_COPY_CppToPython_QHttpHeaders(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QHttpHeaders *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QHttpHeaders_TypeF(), new ::QHttpHeaders(*source), true, true);
}

// Python to C++ copy conversion.
static void QHttpHeaders_PythonToCpp_QHttpHeaders_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QHttpHeaders *>(cppOut) = *reinterpret_cast< ::QHttpHeaders *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QHttpHeaders_PythonToCpp_QHttpHeaders_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QHttpHeaders_TypeF()))
        return QHttpHeaders_PythonToCpp_QHttpHeaders_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QHttpHeaders_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QHttpHeaders(self)",
    "0:PySide6.QtNetwork.QHttpHeaders(self,other:PySide6.QtNetwork.QHttpHeaders)",
    "1:PySide6.QtNetwork.QHttpHeaders.append(self,name:QString,value:QString)->bool",
    "0:PySide6.QtNetwork.QHttpHeaders.append(self,name:PySide6.QtNetwork.QHttpHeaders.WellKnownHeader,value:QString)->bool",
    "PySide6.QtNetwork.QHttpHeaders.clear(self)",
    "1:PySide6.QtNetwork.QHttpHeaders.combinedValue(self,name:QString)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtNetwork.QHttpHeaders.combinedValue(self,name:PySide6.QtNetwork.QHttpHeaders.WellKnownHeader)->PySide6.QtCore.QByteArray",
    "1:PySide6.QtNetwork.QHttpHeaders.contains(self,name:QString)->bool",
    "0:PySide6.QtNetwork.QHttpHeaders.contains(self,name:PySide6.QtNetwork.QHttpHeaders.WellKnownHeader)->bool",
    "PySide6.QtNetwork.QHttpHeaders.fromListOfPairs(headers:QList[std.pair[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]])->PySide6.QtNetwork.QHttpHeaders",
    "PySide6.QtNetwork.QHttpHeaders.fromMultiHash(headers:QMultiHash[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray])->PySide6.QtNetwork.QHttpHeaders",
    "PySide6.QtNetwork.QHttpHeaders.fromMultiMap(headers:QMultiMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray])->PySide6.QtNetwork.QHttpHeaders",
    "1:PySide6.QtNetwork.QHttpHeaders.insert(self,i:qsizetype,name:QString,value:QString)->bool",
    "0:PySide6.QtNetwork.QHttpHeaders.insert(self,i:qsizetype,name:PySide6.QtNetwork.QHttpHeaders.WellKnownHeader,value:QString)->bool",
    "PySide6.QtNetwork.QHttpHeaders.isEmpty(self)->bool",
    "PySide6.QtNetwork.QHttpHeaders.nameAt(self,i:qsizetype)->QLatin1String",
    "1:PySide6.QtNetwork.QHttpHeaders.removeAll(self,name:QString)",
    "0:PySide6.QtNetwork.QHttpHeaders.removeAll(self,name:PySide6.QtNetwork.QHttpHeaders.WellKnownHeader)",
    "PySide6.QtNetwork.QHttpHeaders.removeAt(self,i:qsizetype)",
    "1:PySide6.QtNetwork.QHttpHeaders.replace(self,i:qsizetype,name:QString,newValue:QString)->bool",
    "0:PySide6.QtNetwork.QHttpHeaders.replace(self,i:qsizetype,name:PySide6.QtNetwork.QHttpHeaders.WellKnownHeader,newValue:QString)->bool",
    "PySide6.QtNetwork.QHttpHeaders.reserve(self,size:qsizetype)",
    "PySide6.QtNetwork.QHttpHeaders.size(self)->qsizetype",
    "PySide6.QtNetwork.QHttpHeaders.swap(self,other:PySide6.QtNetwork.QHttpHeaders)",
    "PySide6.QtNetwork.QHttpHeaders.toListOfPairs(self)->QList[std.pair[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]]",
    "PySide6.QtNetwork.QHttpHeaders.toMultiHash(self)->QMultiHash[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]",
    "PySide6.QtNetwork.QHttpHeaders.toMultiMap(self)->QMultiMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]",
    "1:PySide6.QtNetwork.QHttpHeaders.value(self,name:QString,defaultValue:typing.Union[PySide6.QtCore.QByteArray, char*]={})->QByteArrayView",
    "0:PySide6.QtNetwork.QHttpHeaders.value(self,name:PySide6.QtNetwork.QHttpHeaders.WellKnownHeader,defaultValue:typing.Union[PySide6.QtCore.QByteArray, char*]={})->QByteArrayView",
    "PySide6.QtNetwork.QHttpHeaders.valueAt(self,i:qsizetype)->QByteArrayView",
    "1:PySide6.QtNetwork.QHttpHeaders.values(self,name:QString)->QList[PySide6.QtCore.QByteArray]",
    "0:PySide6.QtNetwork.QHttpHeaders.values(self,name:PySide6.QtNetwork.QHttpHeaders.WellKnownHeader)->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtNetwork.QHttpHeaders.wellKnownHeaderName(name:PySide6.QtNetwork.QHttpHeaders.WellKnownHeader)->QByteArrayView",
    "PySide6.QtNetwork.QHttpHeaders.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QHttpHeaders(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX].type;

    Shiboken::AutoDecRef Sbk_QHttpHeaders_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QHttpHeaders_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QHttpHeaders",
        "QHttpHeaders",
        &Sbk_QHttpHeaders_spec,
        &Shiboken::callCppDestructor< ::QHttpHeaders >,
        Sbk_QHttpHeaders_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QHttpHeaders_TypeF(); // references _Sbk_QHttpHeaders_Type
    InitSignatureStrings(pyType, QHttpHeaders_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QHttpHeaders_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QHttpHeaders_PythonToCpp_QHttpHeaders_PTR,
        is_QHttpHeaders_PythonToCpp_QHttpHeaders_PTR_Convertible,
        QHttpHeaders_PTR_CppToPython_QHttpHeaders,
        QHttpHeaders_COPY_CppToPython_QHttpHeaders);

    Shiboken::Conversions::registerConverterName(converter, "QHttpHeaders");
    Shiboken::Conversions::registerConverterName(converter, "QHttpHeaders*");
    Shiboken::Conversions::registerConverterName(converter, "QHttpHeaders&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QHttpHeaders).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QHttpHeaders_PythonToCpp_QHttpHeaders_COPY,
        is_QHttpHeaders_PythonToCpp_QHttpHeaders_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QHttpHeaders_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'WellKnownHeader'.
    const char *WellKnownHeader_Initializer[] = {
        "AIM",
        "Accept",
        "AcceptAdditions",
        "AcceptCH",
        "AcceptDatetime",
        "AcceptEncoding",
        "AcceptFeatures",
        "AcceptLanguage",
        "AcceptPatch",
        "AcceptPost",
        "AcceptRanges",
        "AcceptSignature",
        "AccessControlAllowCredentials",
        "AccessControlAllowHeaders",
        "AccessControlAllowMethods",
        "AccessControlAllowOrigin",
        "AccessControlExposeHeaders",
        "AccessControlMaxAge",
        "AccessControlRequestHeaders",
        "AccessControlRequestMethod",
        "Age",
        "Allow",
        "ALPN",
        "AltSvc",
        "AltUsed",
        "Alternates",
        "ApplyToRedirectRef",
        "AuthenticationControl",
        "AuthenticationInfo",
        "Authorization",
        "CacheControl",
        "CacheStatus",
        "CalManagedID",
        "CalDAVTimezones",
        "CapsuleProtocol",
        "CDNCacheControl",
        "CDNLoop",
        "CertNotAfter",
        "CertNotBefore",
        "ClearSiteData",
        "ClientCert",
        "ClientCertChain",
        "Close",
        "Connection",
        "ContentDigest",
        "ContentDisposition",
        "ContentEncoding",
        "ContentID",
        "ContentLanguage",
        "ContentLength",
        "ContentLocation",
        "ContentRange",
        "ContentSecurityPolicy",
        "ContentSecurityPolicyReportOnly",
        "ContentType",
        "Cookie",
        "CrossOriginEmbedderPolicy",
        "CrossOriginEmbedderPolicyReportOnly",
        "CrossOriginOpenerPolicy",
        "CrossOriginOpenerPolicyReportOnly",
        "CrossOriginResourcePolicy",
        "DASL",
        "Date",
        "DAV",
        "DeltaBase",
        "Depth",
        "Destination",
        "DifferentialID",
        "DPoP",
        "DPoPNonce",
        "EarlyData",
        "ETag",
        "Expect",
        "ExpectCT",
        "Expires",
        "Forwarded",
        "From",
        "Hobareg",
        "Host",
        "If",
        "IfMatch",
        "IfModifiedSince",
        "IfNoneMatch",
        "IfRange",
        "IfScheduleTagMatch",
        "IfUnmodifiedSince",
        "IM",
        "IncludeReferredTokenBindingID",
        "KeepAlive",
        "Label",
        "LastEventID",
        "LastModified",
        "Link",
        "Location",
        "LockToken",
        "MaxForwards",
        "MementoDatetime",
        "Meter",
        "MIMEVersion",
        "Negotiate",
        "NEL",
        "ODataEntityId",
        "ODataIsolation",
        "ODataMaxVersion",
        "ODataVersion",
        "OptionalWWWAuthenticate",
        "OrderingType",
        "Origin",
        "OriginAgentCluster",
        "OSCORE",
        "OSLCCoreVersion",
        "Overwrite",
        "PingFrom",
        "PingTo",
        "Position",
        "Prefer",
        "PreferenceApplied",
        "Priority",
        "ProxyAuthenticate",
        "ProxyAuthenticationInfo",
        "ProxyAuthorization",
        "ProxyStatus",
        "PublicKeyPins",
        "PublicKeyPinsReportOnly",
        "Range",
        "RedirectRef",
        "Referer",
        "Refresh",
        "ReplayNonce",
        "ReprDigest",
        "RetryAfter",
        "ScheduleReply",
        "ScheduleTag",
        "SecPurpose",
        "SecTokenBinding",
        "SecWebSocketAccept",
        "SecWebSocketExtensions",
        "SecWebSocketKey",
        "SecWebSocketProtocol",
        "SecWebSocketVersion",
        "Server",
        "ServerTiming",
        "SetCookie",
        "Signature",
        "SignatureInput",
        "SLUG",
        "SoapAction",
        "StatusURI",
        "StrictTransportSecurity",
        "Sunset",
        "SurrogateCapability",
        "SurrogateControl",
        "TCN",
        "TE",
        "Timeout",
        "Topic",
        "Traceparent",
        "Tracestate",
        "Trailer",
        "TransferEncoding",
        "TTL",
        "Upgrade",
        "Urgency",
        "UserAgent",
        "VariantVary",
        "Vary",
        "Via",
        "WantContentDigest",
        "WantReprDigest",
        "WWWAuthenticate",
        "XContentTypeOptions",
        "XFrameOptions",
        "AcceptCharset",
        "CPEPInfo",
        "Pragma",
        "ProtocolInfo",
        "ProtocolQuery",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t WellKnownHeader_InitializerValues[] = {
        int16_t(QHttpHeaders::WellKnownHeader::AIM),                                 //  0x0000  0
        int16_t(QHttpHeaders::WellKnownHeader::Accept),                              //  0x0001  1
        int16_t(QHttpHeaders::WellKnownHeader::AcceptAdditions),                     //  0x0002  2
        int16_t(QHttpHeaders::WellKnownHeader::AcceptCH),                            //  0x0003  3
        int16_t(QHttpHeaders::WellKnownHeader::AcceptDatetime),                      //  0x0004  4
        int16_t(QHttpHeaders::WellKnownHeader::AcceptEncoding),                      //  0x0005  5
        int16_t(QHttpHeaders::WellKnownHeader::AcceptFeatures),                      //  0x0006  6
        int16_t(QHttpHeaders::WellKnownHeader::AcceptLanguage),                      //  0x0007  7
        int16_t(QHttpHeaders::WellKnownHeader::AcceptPatch),                         //  0x0008  8
        int16_t(QHttpHeaders::WellKnownHeader::AcceptPost),                          //  0x0009  9
        int16_t(QHttpHeaders::WellKnownHeader::AcceptRanges),                        //  0x000a  10
        int16_t(QHttpHeaders::WellKnownHeader::AcceptSignature),                     //  0x000b  11
        int16_t(QHttpHeaders::WellKnownHeader::AccessControlAllowCredentials),       //  0x000c  12
        int16_t(QHttpHeaders::WellKnownHeader::AccessControlAllowHeaders),           //  0x000d  13
        int16_t(QHttpHeaders::WellKnownHeader::AccessControlAllowMethods),           //  0x000e  14
        int16_t(QHttpHeaders::WellKnownHeader::AccessControlAllowOrigin),            //  0x000f  15
        int16_t(QHttpHeaders::WellKnownHeader::AccessControlExposeHeaders),          //  0x0010  16
        int16_t(QHttpHeaders::WellKnownHeader::AccessControlMaxAge),                 //  0x0011  17
        int16_t(QHttpHeaders::WellKnownHeader::AccessControlRequestHeaders),         //  0x0012  18
        int16_t(QHttpHeaders::WellKnownHeader::AccessControlRequestMethod),          //  0x0013  19
        int16_t(QHttpHeaders::WellKnownHeader::Age),                                 //  0x0014  20
        int16_t(QHttpHeaders::WellKnownHeader::Allow),                               //  0x0015  21
        int16_t(QHttpHeaders::WellKnownHeader::ALPN),                                //  0x0016  22
        int16_t(QHttpHeaders::WellKnownHeader::AltSvc),                              //  0x0017  23
        int16_t(QHttpHeaders::WellKnownHeader::AltUsed),                             //  0x0018  24
        int16_t(QHttpHeaders::WellKnownHeader::Alternates),                          //  0x0019  25
        int16_t(QHttpHeaders::WellKnownHeader::ApplyToRedirectRef),                  //  0x001a  26
        int16_t(QHttpHeaders::WellKnownHeader::AuthenticationControl),               //  0x001b  27
        int16_t(QHttpHeaders::WellKnownHeader::AuthenticationInfo),                  //  0x001c  28
        int16_t(QHttpHeaders::WellKnownHeader::Authorization),                       //  0x001d  29
        int16_t(QHttpHeaders::WellKnownHeader::CacheControl),                        //  0x001e  30
        int16_t(QHttpHeaders::WellKnownHeader::CacheStatus),                         //  0x001f  31
        int16_t(QHttpHeaders::WellKnownHeader::CalManagedID),                        //  0x0020  32
        int16_t(QHttpHeaders::WellKnownHeader::CalDAVTimezones),                     //  0x0021  33
        int16_t(QHttpHeaders::WellKnownHeader::CapsuleProtocol),                     //  0x0022  34
        int16_t(QHttpHeaders::WellKnownHeader::CDNCacheControl),                     //  0x0023  35
        int16_t(QHttpHeaders::WellKnownHeader::CDNLoop),                             //  0x0024  36
        int16_t(QHttpHeaders::WellKnownHeader::CertNotAfter),                        //  0x0025  37
        int16_t(QHttpHeaders::WellKnownHeader::CertNotBefore),                       //  0x0026  38
        int16_t(QHttpHeaders::WellKnownHeader::ClearSiteData),                       //  0x0027  39
        int16_t(QHttpHeaders::WellKnownHeader::ClientCert),                          //  0x0028  40
        int16_t(QHttpHeaders::WellKnownHeader::ClientCertChain),                     //  0x0029  41
        int16_t(QHttpHeaders::WellKnownHeader::Close),                               //  0x002a  42
        int16_t(QHttpHeaders::WellKnownHeader::Connection),                          //  0x002b  43
        int16_t(QHttpHeaders::WellKnownHeader::ContentDigest),                       //  0x002c  44
        int16_t(QHttpHeaders::WellKnownHeader::ContentDisposition),                  //  0x002d  45
        int16_t(QHttpHeaders::WellKnownHeader::ContentEncoding),                     //  0x002e  46
        int16_t(QHttpHeaders::WellKnownHeader::ContentID),                           //  0x002f  47
        int16_t(QHttpHeaders::WellKnownHeader::ContentLanguage),                     //  0x0030  48
        int16_t(QHttpHeaders::WellKnownHeader::ContentLength),                       //  0x0031  49
        int16_t(QHttpHeaders::WellKnownHeader::ContentLocation),                     //  0x0032  50
        int16_t(QHttpHeaders::WellKnownHeader::ContentRange),                        //  0x0033  51
        int16_t(QHttpHeaders::WellKnownHeader::ContentSecurityPolicy),               //  0x0034  52
        int16_t(QHttpHeaders::WellKnownHeader::ContentSecurityPolicyReportOnly),     //  0x0035  53
        int16_t(QHttpHeaders::WellKnownHeader::ContentType),                         //  0x0036  54
        int16_t(QHttpHeaders::WellKnownHeader::Cookie),                              //  0x0037  55
        int16_t(QHttpHeaders::WellKnownHeader::CrossOriginEmbedderPolicy),           //  0x0038  56
        int16_t(QHttpHeaders::WellKnownHeader::CrossOriginEmbedderPolicyReportOnly), //  0x0039  57
        int16_t(QHttpHeaders::WellKnownHeader::CrossOriginOpenerPolicy),             //  0x003a  58
        int16_t(QHttpHeaders::WellKnownHeader::CrossOriginOpenerPolicyReportOnly),   //  0x003b  59
        int16_t(QHttpHeaders::WellKnownHeader::CrossOriginResourcePolicy),           //  0x003c  60
        int16_t(QHttpHeaders::WellKnownHeader::DASL),                                //  0x003d  61
        int16_t(QHttpHeaders::WellKnownHeader::Date),                                //  0x003e  62
        int16_t(QHttpHeaders::WellKnownHeader::DAV),                                 //  0x003f  63
        int16_t(QHttpHeaders::WellKnownHeader::DeltaBase),                           //  0x0040  64
        int16_t(QHttpHeaders::WellKnownHeader::Depth),                               //  0x0041  65
        int16_t(QHttpHeaders::WellKnownHeader::Destination),                         //  0x0042  66
        int16_t(QHttpHeaders::WellKnownHeader::DifferentialID),                      //  0x0043  67
        int16_t(QHttpHeaders::WellKnownHeader::DPoP),                                //  0x0044  68
        int16_t(QHttpHeaders::WellKnownHeader::DPoPNonce),                           //  0x0045  69
        int16_t(QHttpHeaders::WellKnownHeader::EarlyData),                           //  0x0046  70
        int16_t(QHttpHeaders::WellKnownHeader::ETag),                                //  0x0047  71
        int16_t(QHttpHeaders::WellKnownHeader::Expect),                              //  0x0048  72
        int16_t(QHttpHeaders::WellKnownHeader::ExpectCT),                            //  0x0049  73
        int16_t(QHttpHeaders::WellKnownHeader::Expires),                             //  0x004a  74
        int16_t(QHttpHeaders::WellKnownHeader::Forwarded),                           //  0x004b  75
        int16_t(QHttpHeaders::WellKnownHeader::From),                                //  0x004c  76
        int16_t(QHttpHeaders::WellKnownHeader::Hobareg),                             //  0x004d  77
        int16_t(QHttpHeaders::WellKnownHeader::Host),                                //  0x004e  78
        int16_t(QHttpHeaders::WellKnownHeader::If),                                  //  0x004f  79
        int16_t(QHttpHeaders::WellKnownHeader::IfMatch),                             //  0x0050  80
        int16_t(QHttpHeaders::WellKnownHeader::IfModifiedSince),                     //  0x0051  81
        int16_t(QHttpHeaders::WellKnownHeader::IfNoneMatch),                         //  0x0052  82
        int16_t(QHttpHeaders::WellKnownHeader::IfRange),                             //  0x0053  83
        int16_t(QHttpHeaders::WellKnownHeader::IfScheduleTagMatch),                  //  0x0054  84
        int16_t(QHttpHeaders::WellKnownHeader::IfUnmodifiedSince),                   //  0x0055  85
        int16_t(QHttpHeaders::WellKnownHeader::IM),                                  //  0x0056  86
        int16_t(QHttpHeaders::WellKnownHeader::IncludeReferredTokenBindingID),       //  0x0057  87
        int16_t(QHttpHeaders::WellKnownHeader::KeepAlive),                           //  0x0058  88
        int16_t(QHttpHeaders::WellKnownHeader::Label),                               //  0x0059  89
        int16_t(QHttpHeaders::WellKnownHeader::LastEventID),                         //  0x005a  90
        int16_t(QHttpHeaders::WellKnownHeader::LastModified),                        //  0x005b  91
        int16_t(QHttpHeaders::WellKnownHeader::Link),                                //  0x005c  92
        int16_t(QHttpHeaders::WellKnownHeader::Location),                            //  0x005d  93
        int16_t(QHttpHeaders::WellKnownHeader::LockToken),                           //  0x005e  94
        int16_t(QHttpHeaders::WellKnownHeader::MaxForwards),                         //  0x005f  95
        int16_t(QHttpHeaders::WellKnownHeader::MementoDatetime),                     //  0x0060  96
        int16_t(QHttpHeaders::WellKnownHeader::Meter),                               //  0x0061  97
        int16_t(QHttpHeaders::WellKnownHeader::MIMEVersion),                         //  0x0062  98
        int16_t(QHttpHeaders::WellKnownHeader::Negotiate),                           //  0x0063  99
        int16_t(QHttpHeaders::WellKnownHeader::NEL),                                 //  0x0064  100
        int16_t(QHttpHeaders::WellKnownHeader::ODataEntityId),                       //  0x0065  101
        int16_t(QHttpHeaders::WellKnownHeader::ODataIsolation),                      //  0x0066  102
        int16_t(QHttpHeaders::WellKnownHeader::ODataMaxVersion),                     //  0x0067  103
        int16_t(QHttpHeaders::WellKnownHeader::ODataVersion),                        //  0x0068  104
        int16_t(QHttpHeaders::WellKnownHeader::OptionalWWWAuthenticate),             //  0x0069  105
        int16_t(QHttpHeaders::WellKnownHeader::OrderingType),                        //  0x006a  106
        int16_t(QHttpHeaders::WellKnownHeader::Origin),                              //  0x006b  107
        int16_t(QHttpHeaders::WellKnownHeader::OriginAgentCluster),                  //  0x006c  108
        int16_t(QHttpHeaders::WellKnownHeader::OSCORE),                              //  0x006d  109
        int16_t(QHttpHeaders::WellKnownHeader::OSLCCoreVersion),                     //  0x006e  110
        int16_t(QHttpHeaders::WellKnownHeader::Overwrite),                           //  0x006f  111
        int16_t(QHttpHeaders::WellKnownHeader::PingFrom),                            //  0x0070  112
        int16_t(QHttpHeaders::WellKnownHeader::PingTo),                              //  0x0071  113
        int16_t(QHttpHeaders::WellKnownHeader::Position),                            //  0x0072  114
        int16_t(QHttpHeaders::WellKnownHeader::Prefer),                              //  0x0073  115
        int16_t(QHttpHeaders::WellKnownHeader::PreferenceApplied),                   //  0x0074  116
        int16_t(QHttpHeaders::WellKnownHeader::Priority),                            //  0x0075  117
        int16_t(QHttpHeaders::WellKnownHeader::ProxyAuthenticate),                   //  0x0076  118
        int16_t(QHttpHeaders::WellKnownHeader::ProxyAuthenticationInfo),             //  0x0077  119
        int16_t(QHttpHeaders::WellKnownHeader::ProxyAuthorization),                  //  0x0078  120
        int16_t(QHttpHeaders::WellKnownHeader::ProxyStatus),                         //  0x0079  121
        int16_t(QHttpHeaders::WellKnownHeader::PublicKeyPins),                       //  0x007a  122
        int16_t(QHttpHeaders::WellKnownHeader::PublicKeyPinsReportOnly),             //  0x007b  123
        int16_t(QHttpHeaders::WellKnownHeader::Range),                               //  0x007c  124
        int16_t(QHttpHeaders::WellKnownHeader::RedirectRef),                         //  0x007d  125
        int16_t(QHttpHeaders::WellKnownHeader::Referer),                             //  0x007e  126
        int16_t(QHttpHeaders::WellKnownHeader::Refresh),                             //  0x007f  127
        int16_t(QHttpHeaders::WellKnownHeader::ReplayNonce),                         //  0x0080  128
        int16_t(QHttpHeaders::WellKnownHeader::ReprDigest),                          //  0x0081  129
        int16_t(QHttpHeaders::WellKnownHeader::RetryAfter),                          //  0x0082  130
        int16_t(QHttpHeaders::WellKnownHeader::ScheduleReply),                       //  0x0083  131
        int16_t(QHttpHeaders::WellKnownHeader::ScheduleTag),                         //  0x0084  132
        int16_t(QHttpHeaders::WellKnownHeader::SecPurpose),                          //  0x0085  133
        int16_t(QHttpHeaders::WellKnownHeader::SecTokenBinding),                     //  0x0086  134
        int16_t(QHttpHeaders::WellKnownHeader::SecWebSocketAccept),                  //  0x0087  135
        int16_t(QHttpHeaders::WellKnownHeader::SecWebSocketExtensions),              //  0x0088  136
        int16_t(QHttpHeaders::WellKnownHeader::SecWebSocketKey),                     //  0x0089  137
        int16_t(QHttpHeaders::WellKnownHeader::SecWebSocketProtocol),                //  0x008a  138
        int16_t(QHttpHeaders::WellKnownHeader::SecWebSocketVersion),                 //  0x008b  139
        int16_t(QHttpHeaders::WellKnownHeader::Server),                              //  0x008c  140
        int16_t(QHttpHeaders::WellKnownHeader::ServerTiming),                        //  0x008d  141
        int16_t(QHttpHeaders::WellKnownHeader::SetCookie),                           //  0x008e  142
        int16_t(QHttpHeaders::WellKnownHeader::Signature),                           //  0x008f  143
        int16_t(QHttpHeaders::WellKnownHeader::SignatureInput),                      //  0x0090  144
        int16_t(QHttpHeaders::WellKnownHeader::SLUG),                                //  0x0091  145
        int16_t(QHttpHeaders::WellKnownHeader::SoapAction),                          //  0x0092  146
        int16_t(QHttpHeaders::WellKnownHeader::StatusURI),                           //  0x0093  147
        int16_t(QHttpHeaders::WellKnownHeader::StrictTransportSecurity),             //  0x0094  148
        int16_t(QHttpHeaders::WellKnownHeader::Sunset),                              //  0x0095  149
        int16_t(QHttpHeaders::WellKnownHeader::SurrogateCapability),                 //  0x0096  150
        int16_t(QHttpHeaders::WellKnownHeader::SurrogateControl),                    //  0x0097  151
        int16_t(QHttpHeaders::WellKnownHeader::TCN),                                 //  0x0098  152
        int16_t(QHttpHeaders::WellKnownHeader::TE),                                  //  0x0099  153
        int16_t(QHttpHeaders::WellKnownHeader::Timeout),                             //  0x009a  154
        int16_t(QHttpHeaders::WellKnownHeader::Topic),                               //  0x009b  155
        int16_t(QHttpHeaders::WellKnownHeader::Traceparent),                         //  0x009c  156
        int16_t(QHttpHeaders::WellKnownHeader::Tracestate),                          //  0x009d  157
        int16_t(QHttpHeaders::WellKnownHeader::Trailer),                             //  0x009e  158
        int16_t(QHttpHeaders::WellKnownHeader::TransferEncoding),                    //  0x009f  159
        int16_t(QHttpHeaders::WellKnownHeader::TTL),                                 //  0x00a0  160
        int16_t(QHttpHeaders::WellKnownHeader::Upgrade),                             //  0x00a1  161
        int16_t(QHttpHeaders::WellKnownHeader::Urgency),                             //  0x00a2  162
        int16_t(QHttpHeaders::WellKnownHeader::UserAgent),                           //  0x00a3  163
        int16_t(QHttpHeaders::WellKnownHeader::VariantVary),                         //  0x00a4  164
        int16_t(QHttpHeaders::WellKnownHeader::Vary),                                //  0x00a5  165
        int16_t(QHttpHeaders::WellKnownHeader::Via),                                 //  0x00a6  166
        int16_t(QHttpHeaders::WellKnownHeader::WantContentDigest),                   //  0x00a7  167
        int16_t(QHttpHeaders::WellKnownHeader::WantReprDigest),                      //  0x00a8  168
        int16_t(QHttpHeaders::WellKnownHeader::WWWAuthenticate),                     //  0x00a9  169
        int16_t(QHttpHeaders::WellKnownHeader::XContentTypeOptions),                 //  0x00aa  170
        int16_t(QHttpHeaders::WellKnownHeader::XFrameOptions),                       //  0x00ab  171
        int16_t(QHttpHeaders::WellKnownHeader::AcceptCharset),                       //  0x00ac  172
        int16_t(QHttpHeaders::WellKnownHeader::CPEPInfo),                            //  0x00ad  173
        int16_t(QHttpHeaders::WellKnownHeader::Pragma),                              //  0x00ae  174
        int16_t(QHttpHeaders::WellKnownHeader::ProtocolInfo),                        //  0x00af  175
        int16_t(QHttpHeaders::WellKnownHeader::ProtocolQuery)                        //  0x00b0  176
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QHttpHeaders_TypeF(),
        "2:PySide6.QtNetwork.QHttpHeaders.WellKnownHeader",
        WellKnownHeader_Initializer, WellKnownHeader_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QHttpHeaders_WellKnownHeader_IDX].type = EType;
    // Register converter for enum 'QHttpHeaders::WellKnownHeader'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QHttpHeaders_WellKnownHeader_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QHttpHeaders_WellKnownHeader,
            is_Enum_PythonToCpp_QHttpHeaders_WellKnownHeader_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QHttpHeaders::WellKnownHeader");
        Shiboken::Conversions::registerConverterName(converter, "WellKnownHeader");
    }
    // End of 'WellKnownHeader' enum.

    qRegisterMetaType< ::QHttpHeaders >("QHttpHeaders");
    qRegisterMetaType< ::QHttpHeaders::WellKnownHeader >("QHttpHeaders::WellKnownHeader");

    return pyType;
}
