// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkaddressentry_wrapper.h"

// Argument includes
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkinterface.h>
#include <qdeadlinetimer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkAddressEntry_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNetworkAddressEntry >()))
        return -1;

    ::QNetworkAddressEntry *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QNetworkAddressEntry", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNetworkAddressEntry::QNetworkAddressEntry()
    // 1: QNetworkAddressEntry::QNetworkAddressEntry(QNetworkAddressEntry)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkAddressEntry()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QNetworkAddressEntry(QNetworkAddressEntry)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNetworkAddressEntry()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkAddressEntry()
                cptr = new ::QNetworkAddressEntry();
            }
            break;
        }
        case 1: // QNetworkAddressEntry(const QNetworkAddressEntry &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkAddressEntry cppArg0_local;
            ::QNetworkAddressEntry *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkAddressEntry(QNetworkAddressEntry)
                cptr = new ::QNetworkAddressEntry(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNetworkAddressEntry >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_broadcast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.broadcast";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // broadcast()const
            QHostAddress cppResult = const_cast<const ::QNetworkAddressEntry *>(cppSelf)->broadcast();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_clearAddressLifetime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.clearAddressLifetime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearAddressLifetime()
            cppSelf->clearAddressLifetime();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_dnsEligibility(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.dnsEligibility";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // dnsEligibility()const
            QNetworkAddressEntry::DnsEligibilityStatus cppResult = const_cast<const ::QNetworkAddressEntry *>(cppSelf)->dnsEligibility();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_DnsEligibilityStatus_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_ip(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.ip";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // ip()const
            QHostAddress cppResult = const_cast<const ::QNetworkAddressEntry *>(cppSelf)->ip();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_isLifetimeKnown(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.isLifetimeKnown";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isLifetimeKnown()const
            bool cppResult = const_cast<const ::QNetworkAddressEntry *>(cppSelf)->isLifetimeKnown();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_isPermanent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.isPermanent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isPermanent()const
            bool cppResult = const_cast<const ::QNetworkAddressEntry *>(cppSelf)->isPermanent();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_isTemporary(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.isTemporary";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isTemporary()const
            bool cppResult = const_cast<const ::QNetworkAddressEntry *>(cppSelf)->isTemporary();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_netmask(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.netmask";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // netmask()const
            QHostAddress cppResult = const_cast<const ::QNetworkAddressEntry *>(cppSelf)->netmask();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_preferredLifetime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.preferredLifetime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // preferredLifetime()const
            QDeadlineTimer cppResult = const_cast<const ::QNetworkAddressEntry *>(cppSelf)->preferredLifetime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_prefixLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.prefixLength";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // prefixLength()const
            int cppResult = const_cast<const ::QNetworkAddressEntry *>(cppSelf)->prefixLength();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_setAddressLifetime(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.setAddressLifetime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setAddressLifetime", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNetworkAddressEntry::setAddressLifetime(QDeadlineTimer,QDeadlineTimer)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setAddressLifetime(QDeadlineTimer,QDeadlineTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDeadlineTimer cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDeadlineTimer cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAddressLifetime(QDeadlineTimer,QDeadlineTimer)
            cppSelf->setAddressLifetime(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_setBroadcast(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.setBroadcast";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkAddressEntry::setBroadcast(QHostAddress)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArg)))) {
        overloadId = 0; // setBroadcast(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHostAddress cppArg0_local;
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBroadcast(QHostAddress)
            cppSelf->setBroadcast(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_setDnsEligibility(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.setDnsEligibility";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkAddressEntry::setDnsEligibility(QNetworkAddressEntry::DnsEligibilityStatus)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_DnsEligibilityStatus_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDnsEligibility(QNetworkAddressEntry::DnsEligibilityStatus)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QNetworkAddressEntry::DnsEligibilityStatus cppArg0{QNetworkAddressEntry::DnsIneligible};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDnsEligibility(QNetworkAddressEntry::DnsEligibilityStatus)
            cppSelf->setDnsEligibility(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_setIp(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.setIp";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkAddressEntry::setIp(QHostAddress)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArg)))) {
        overloadId = 0; // setIp(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHostAddress cppArg0_local;
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setIp(QHostAddress)
            cppSelf->setIp(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_setNetmask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.setNetmask";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkAddressEntry::setNetmask(QHostAddress)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArg)))) {
        overloadId = 0; // setNetmask(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHostAddress cppArg0_local;
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setNetmask(QHostAddress)
            cppSelf->setNetmask(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_setPrefixLength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.setPrefixLength";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkAddressEntry::setPrefixLength(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPrefixLength(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPrefixLength(int)
            cppSelf->setPrefixLength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkAddressEntry::swap(QNetworkAddressEntry&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QNetworkAddressEntry&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkAddressEntry cppArg0_local;
        ::QNetworkAddressEntry *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QNetworkAddressEntry&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkAddressEntryFunc_validityLifetime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkAddressEntry.validityLifetime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // validityLifetime()const
            QDeadlineTimer cppResult = const_cast<const ::QNetworkAddressEntry *>(cppSelf)->validityLifetime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkAddressEntry__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkAddressEntry_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNetworkAddressEntry_EnumFlagInfo[] = {
    "DnsEligibilityStatus:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkAddressEntry_methods[] = {
    {"broadcast", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_broadcast), METH_NOARGS, nullptr},
    {"clearAddressLifetime", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_clearAddressLifetime), METH_NOARGS, nullptr},
    {"dnsEligibility", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_dnsEligibility), METH_NOARGS, nullptr},
    {"ip", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_ip), METH_NOARGS, nullptr},
    {"isLifetimeKnown", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_isLifetimeKnown), METH_NOARGS, nullptr},
    {"isPermanent", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_isPermanent), METH_NOARGS, nullptr},
    {"isTemporary", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_isTemporary), METH_NOARGS, nullptr},
    {"netmask", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_netmask), METH_NOARGS, nullptr},
    {"preferredLifetime", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_preferredLifetime), METH_NOARGS, nullptr},
    {"prefixLength", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_prefixLength), METH_NOARGS, nullptr},
    {"setAddressLifetime", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_setAddressLifetime), METH_VARARGS, nullptr},
    {"setBroadcast", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_setBroadcast), METH_O, nullptr},
    {"setDnsEligibility", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_setDnsEligibility), METH_O, nullptr},
    {"setIp", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_setIp), METH_O, nullptr},
    {"setNetmask", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_setNetmask), METH_O, nullptr},
    {"setPrefixLength", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_setPrefixLength), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_swap), METH_O, nullptr},
    {"validityLifetime", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntryFunc_validityLifetime), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNetworkAddressEntry__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QNetworkAddressEntry_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), (pyArg)))) {
                // operator!=(const QNetworkAddressEntry &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNetworkAddressEntry cppArg0_local;
                ::QNetworkAddressEntry *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), (pyArg)))) {
                // operator==(const QNetworkAddressEntry &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNetworkAddressEntry cppArg0_local;
                ::QNetworkAddressEntry *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QNetworkAddressEntry_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkAddressEntry_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QNetworkAddressEntry__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkAddressEntry_Type = nullptr;
static PyTypeObject *Sbk_QNetworkAddressEntry_TypeF(void)
{
    return _Sbk_QNetworkAddressEntry_Type;
}

static PyType_Slot Sbk_QNetworkAddressEntry_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QNetworkAddressEntry__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkAddressEntry_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkAddressEntry_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QNetworkAddressEntry_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkAddressEntry_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNetworkAddressEntry_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkAddressEntry_spec = {
    "2:PySide6.QtNetwork.QNetworkAddressEntry",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkAddressEntry_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QNetworkAddressEntry_DnsEligibilityStatus(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkAddressEntry::DnsEligibilityStatus>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkAddressEntry::DnsEligibilityStatus *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QNetworkAddressEntry_DnsEligibilityStatus_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_DnsEligibilityStatus_IDX])))
        return Enum_PythonToCpp_QNetworkAddressEntry_DnsEligibilityStatus;
    return {};
}
static PyObject *QNetworkAddressEntry_DnsEligibilityStatus_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNetworkAddressEntry::DnsEligibilityStatus *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_DnsEligibilityStatus_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkAddressEntry_PythonToCpp_QNetworkAddressEntry_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkAddressEntry_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkAddressEntry_PythonToCpp_QNetworkAddressEntry_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkAddressEntry_TypeF()))
        return QNetworkAddressEntry_PythonToCpp_QNetworkAddressEntry_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkAddressEntry_PTR_CppToPython_QNetworkAddressEntry(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QNetworkAddressEntry *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QNetworkAddressEntry_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QNetworkAddressEntry_COPY_CppToPython_QNetworkAddressEntry(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNetworkAddressEntry *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNetworkAddressEntry_TypeF(), new ::QNetworkAddressEntry(*source), true, true);
}

// Python to C++ copy conversion.
static void QNetworkAddressEntry_PythonToCpp_QNetworkAddressEntry_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNetworkAddressEntry *>(cppOut) = *reinterpret_cast< ::QNetworkAddressEntry *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNetworkAddressEntry_PythonToCpp_QNetworkAddressEntry_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkAddressEntry_TypeF()))
        return QNetworkAddressEntry_PythonToCpp_QNetworkAddressEntry_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QNetworkAddressEntry_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QNetworkAddressEntry(self)",
    "0:PySide6.QtNetwork.QNetworkAddressEntry(self,other:PySide6.QtNetwork.QNetworkAddressEntry)",
    "PySide6.QtNetwork.QNetworkAddressEntry.broadcast(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtNetwork.QNetworkAddressEntry.clearAddressLifetime(self)",
    "PySide6.QtNetwork.QNetworkAddressEntry.dnsEligibility(self)->PySide6.QtNetwork.QNetworkAddressEntry.DnsEligibilityStatus",
    "PySide6.QtNetwork.QNetworkAddressEntry.ip(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtNetwork.QNetworkAddressEntry.isLifetimeKnown(self)->bool",
    "PySide6.QtNetwork.QNetworkAddressEntry.isPermanent(self)->bool",
    "PySide6.QtNetwork.QNetworkAddressEntry.isTemporary(self)->bool",
    "PySide6.QtNetwork.QNetworkAddressEntry.netmask(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtNetwork.QNetworkAddressEntry.preferredLifetime(self)->PySide6.QtCore.QDeadlineTimer",
    "PySide6.QtNetwork.QNetworkAddressEntry.prefixLength(self)->int",
    "PySide6.QtNetwork.QNetworkAddressEntry.setAddressLifetime(self,preferred:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64],validity:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64])",
    "PySide6.QtNetwork.QNetworkAddressEntry.setBroadcast(self,newBroadcast:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress])",
    "PySide6.QtNetwork.QNetworkAddressEntry.setDnsEligibility(self,status:PySide6.QtNetwork.QNetworkAddressEntry.DnsEligibilityStatus)",
    "PySide6.QtNetwork.QNetworkAddressEntry.setIp(self,newIp:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress])",
    "PySide6.QtNetwork.QNetworkAddressEntry.setNetmask(self,newNetmask:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress])",
    "PySide6.QtNetwork.QNetworkAddressEntry.setPrefixLength(self,length:int)",
    "PySide6.QtNetwork.QNetworkAddressEntry.swap(self,other:PySide6.QtNetwork.QNetworkAddressEntry)",
    "PySide6.QtNetwork.QNetworkAddressEntry.validityLifetime(self)->PySide6.QtCore.QDeadlineTimer",
    "PySide6.QtNetwork.QNetworkAddressEntry.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QNetworkAddressEntry(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkAddressEntry_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNetworkAddressEntry_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkAddressEntry",
        "QNetworkAddressEntry",
        &Sbk_QNetworkAddressEntry_spec,
        &Shiboken::callCppDestructor< ::QNetworkAddressEntry >,
        Sbk_QNetworkAddressEntry_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNetworkAddressEntry_TypeF(); // references _Sbk_QNetworkAddressEntry_Type
    InitSignatureStrings(pyType, QNetworkAddressEntry_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkAddressEntry_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkAddressEntry_PythonToCpp_QNetworkAddressEntry_PTR,
        is_QNetworkAddressEntry_PythonToCpp_QNetworkAddressEntry_PTR_Convertible,
        QNetworkAddressEntry_PTR_CppToPython_QNetworkAddressEntry,
        QNetworkAddressEntry_COPY_CppToPython_QNetworkAddressEntry);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkAddressEntry");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkAddressEntry*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkAddressEntry&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkAddressEntry).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNetworkAddressEntry_PythonToCpp_QNetworkAddressEntry_COPY,
        is_QNetworkAddressEntry_PythonToCpp_QNetworkAddressEntry_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNetworkAddressEntry_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'DnsEligibilityStatus'.
    const char *DnsEligibilityStatus_Initializer[] = {
        "DnsEligibilityUnknown",
        "DnsIneligible",
        "DnsEligible",
        nullptr};
    // "int8_t" used instead of "signed char"
    constexpr int8_t DnsEligibilityStatus_InitializerValues[] = {
        int8_t(QNetworkAddressEntry::DnsEligibilityStatus::DnsEligibilityUnknown), // -0x01 -1
        int8_t(QNetworkAddressEntry::DnsEligibilityStatus::DnsIneligible),         //  0x00  0
        int8_t(QNetworkAddressEntry::DnsEligibilityStatus::DnsEligible)            //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkAddressEntry_TypeF(),
        "2:PySide6.QtNetwork.QNetworkAddressEntry.DnsEligibilityStatus",
        DnsEligibilityStatus_Initializer, DnsEligibilityStatus_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_DnsEligibilityStatus_IDX].type = EType;
    // Register converter for enum 'QNetworkAddressEntry::DnsEligibilityStatus'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkAddressEntry_DnsEligibilityStatus_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QNetworkAddressEntry_DnsEligibilityStatus,
            is_Enum_PythonToCpp_QNetworkAddressEntry_DnsEligibilityStatus_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkAddressEntry::DnsEligibilityStatus");
        Shiboken::Conversions::registerConverterName(converter, "DnsEligibilityStatus");
    }
    // End of 'DnsEligibilityStatus' enum.

    qRegisterMetaType< ::QNetworkAddressEntry >("QNetworkAddressEntry");
    qRegisterMetaType< ::QNetworkAddressEntry::DnsEligibilityStatus >("QNetworkAddressEntry::DnsEligibilityStatus");

    return pyType;
}
