// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnfc_python.h"

// main header
#include "qndefmessage_wrapper.h"

// Argument includes
#include <QList>
#include <QtNfc/qndefmessage.h>
#include <QtNfc/qndefrecord.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNdefMessage_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNdefMessage >()))
        return -1;

    ::QNdefMessage *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QNdefMessage", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNdefMessage::QNdefMessage()
    // 1: QNdefMessage::QNdefMessage(QList<QNdefRecord>)
    // 2: QNdefMessage::QNdefMessage(QNdefMessage)
    // 3: QNdefMessage::QNdefMessage(QNdefRecord)
    if (numArgs == 0) {
        overloadId = 0; // QNdefMessage()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QNdefMessage(QNdefRecord)
    } else if (numArgs == 1
        && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), pyArgs[0])
            && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], (pyArgs[0])))) {
        overloadId = 1; // QNdefMessage(QList<QNdefRecord>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QNdefMessage(QNdefMessage)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNdefMessage()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefMessage()
                cptr = new ::QNdefMessage();
            }
            break;
        }
        case 1: // QNdefMessage(const QList<QNdefRecord> &records)
        {
            ::QList<QNdefRecord> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefMessage(QList<QNdefRecord>)
                cptr = new ::QNdefMessage(cppArg0);
            }
            break;
        }
        case 2: // QNdefMessage(const QNdefMessage &message)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNdefMessage cppArg0_local;
            ::QNdefMessage *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefMessage(QNdefMessage)
                cptr = new ::QNdefMessage(*cppArg0);
            }
            break;
        }
        case 3: // QNdefMessage(const QNdefRecord &record)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNdefRecord cppArg0_local;
            ::QNdefRecord *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNdefMessage(QNdefRecord)
                cptr = new ::QNdefMessage(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNdefMessage >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNdefMessageFunc_append(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.append";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::append(QNdefRecord)
    // 1: QNdefMessage::append(QList<QNdefRecord>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArg)))) {
        overloadId = 0; // append(QNdefRecord)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], (pyArg)))) {
        overloadId = 1; // append(QList<QNdefRecord>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // append(QNdefRecord arg__1)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QNdefRecord cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QNdefRecord)
                cppSelf->append(cppArg0);
            }
            break;
        }
        case 1: // append(const QList<QNdefRecord> &l)
        {
            ::QList<QNdefRecord> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QList<QNdefRecord>)
                cppSelf->append(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_at(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.at";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::at(qsizetype)const->const QNdefRecord&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // at(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // at(qsizetype)const
            const QNdefRecord & cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->at(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_back(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.back";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // back()
            QNdefRecord & cppResult = cppSelf->back();
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_capacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.capacity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // capacity()const
            qsizetype cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->capacity();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.clear";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear()
            cppSelf->clear();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_constData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.constData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // constData()const
            const QNdefRecord * cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->constData();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_constFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.constFirst";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // constFirst()const
            const QNdefRecord & cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->constFirst();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_constLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.constLast";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // constLast()const
            const QNdefRecord & cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->constLast();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.count";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // count()const
            qsizetype cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->count();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.data";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // data()
            QNdefRecord * cppResult = cppSelf->data();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_empty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.empty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // empty()const
            bool cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->empty();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_first(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.first";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "first", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNdefMessage::first()->QNdefRecord&
    // 1: QNdefMessage::first(qsizetype)const->QList< QNdefRecord>
    if (numArgs == 0) {
        overloadId = 0; // first()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        overloadId = 1; // first(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // first()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // first()
                QNdefRecord & cppResult = cppSelf->first();
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &cppResult);
            }
            break;
        }
        case 1: // first(qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // first(qsizetype)const
                QList<QNdefRecord> cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->first(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_fromByteArray(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.fromByteArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNdefMessage::fromByteArray(QByteArray)->QNdefMessage
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // fromByteArray(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromByteArray(QByteArray)
            QNdefMessage cppResult = ::QNdefMessage::fromByteArray(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_fromList(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.fromList";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNdefMessage::fromList(QList<QNdefRecord>)->QList< QNdefRecord>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], (pyArg)))) {
        overloadId = 0; // fromList(QList<QNdefRecord>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QNdefRecord> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromList(QList<QNdefRecord>)
            QList<QNdefRecord> cppResult = ::QNdefMessage::fromList(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_fromVector(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.fromVector";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNdefMessage::fromVector(QList<QNdefRecord>)->QList< QNdefRecord>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], (pyArg)))) {
        overloadId = 0; // fromVector(QList<QNdefRecord>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QNdefRecord> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromVector(QList<QNdefRecord>)
            QList<QNdefRecord> cppResult = ::QNdefMessage::fromVector(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_front(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.front";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // front()
            QNdefRecord & cppResult = cppSelf->front();
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.insert";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNdefMessage::insert(qsizetype,QNdefRecord)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insert(qsizetype,QNdefRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QNdefRecord cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insert(qsizetype,QNdefRecord)
            cppSelf->insert(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.isEmpty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEmpty()const
            bool cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->isEmpty();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_isSharedWith(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.isSharedWith";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::isSharedWith(QList<QNdefRecord>)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], (pyArg)))) {
        overloadId = 0; // isSharedWith(QList<QNdefRecord>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QNdefRecord> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSharedWith(QList<QNdefRecord>)const
            bool cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->isSharedWith(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_last(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.last";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "last", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNdefMessage::last()->QNdefRecord&
    // 1: QNdefMessage::last(qsizetype)const->QList< QNdefRecord>
    if (numArgs == 0) {
        overloadId = 0; // last()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        overloadId = 1; // last(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // last()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // last()
                QNdefRecord & cppResult = cppSelf->last();
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &cppResult);
            }
            break;
        }
        case 1: // last(qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // last(qsizetype)const
                QList<QNdefRecord> cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->last(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.length";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // length()const
            qsizetype cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->length();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_mid(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.mid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:mid", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNdefMessage::mid(qsizetype,qsizetype=)const->QList< QNdefRecord>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // mid(qsizetype,qsizetype)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // mid(qsizetype,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_len = Shiboken::String::createStaticString("len");
            if (PyDict_Contains(kwds, key_len) != 0) {
                value = PyDict_GetItem(kwds, key_len);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_len);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_len);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = -1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mid(qsizetype,qsizetype)const
            QList<QNdefRecord> cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->mid(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_move(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.move";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "move", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNdefMessage::move(qsizetype,qsizetype)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // move(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // move(qsizetype,qsizetype)
            cppSelf->move(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_pop_back(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.pop_back";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pop_back()
            cppSelf->pop_back();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_pop_front(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.pop_front";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pop_front()
            cppSelf->pop_front();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_prepend(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.prepend";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::prepend(QNdefRecord)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArg)))) {
        overloadId = 0; // prepend(QNdefRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNdefRecord cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // prepend(QNdefRecord)
            cppSelf->prepend(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_push_back(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.push_back";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::push_back(QNdefRecord)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArg)))) {
        overloadId = 0; // push_back(QNdefRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNdefRecord cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // push_back(QNdefRecord)
            cppSelf->push_back(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_push_front(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.push_front";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::push_front(QNdefRecord)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArg)))) {
        overloadId = 0; // push_front(QNdefRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNdefRecord cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // push_front(QNdefRecord)
            cppSelf->push_front(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_remove(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.remove";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:remove", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNdefMessage::remove(qsizetype,qsizetype=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // remove(qsizetype,qsizetype)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // remove(qsizetype,qsizetype)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_n = Shiboken::String::createStaticString("n");
            if (PyDict_Contains(kwds, key_n) != 0) {
                value = PyDict_GetItem(kwds, key_n);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_n);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_n);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = 1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // remove(qsizetype,qsizetype)
            cppSelf->remove(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_removeAll(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.removeAll";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::removeAll(QNdefRecord)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArg)))) {
        overloadId = 0; // removeAll(QNdefRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNdefRecord cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAll(QNdefRecord)
            cppSelf->removeAll(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_removeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.removeAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::removeAt(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // removeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAt(qsizetype)
            cppSelf->removeAt(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_removeFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.removeFirst";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeFirst()
            cppSelf->removeFirst();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_removeLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.removeLast";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeLast()
            cppSelf->removeLast();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_removeOne(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.removeOne";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::removeOne(QNdefRecord)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArg)))) {
        overloadId = 0; // removeOne(QNdefRecord)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNdefRecord cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeOne(QNdefRecord)
            cppSelf->removeOne(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_reserve(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.reserve";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::reserve(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // reserve(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reserve(qsizetype)
            cppSelf->reserve(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_resize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.resize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::resize(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // resize(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resize(qsizetype)
            cppSelf->resize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_shrink_to_fit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.shrink_to_fit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // shrink_to_fit()
            cppSelf->shrink_to_fit();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.size";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // size()const
            qsizetype cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->size();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_sliced(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.sliced";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sliced", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNdefMessage::sliced(qsizetype)const->QList< QNdefRecord>
    // 1: QNdefMessage::sliced(qsizetype,qsizetype)const->QList< QNdefRecord>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sliced(qsizetype)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 1; // sliced(qsizetype,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // sliced(qsizetype pos) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sliced(qsizetype)const
                QList<QNdefRecord> cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->sliced(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
            }
            break;
        }
        case 1: // sliced(qsizetype pos, qsizetype n) const
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sliced(qsizetype,qsizetype)const
                QList<QNdefRecord> cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->sliced(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_squeeze(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.squeeze";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // squeeze()
            cppSelf->squeeze();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::swap(QList<QNdefRecord>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], (pyArg)))) {
        overloadId = 0; // swap(QList<QNdefRecord>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QNdefRecord> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QList<QNdefRecord>&)
            cppSelf->swap(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_swapItemsAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.swapItemsAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "swapItemsAt", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNdefMessage::swapItemsAt(qsizetype,qsizetype)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // swapItemsAt(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swapItemsAt(qsizetype,qsizetype)
            cppSelf->swapItemsAt(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNdefMessageFunc_takeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.takeAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::takeAt(qsizetype)->QNdefRecord
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // takeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // takeAt(qsizetype)
            QNdefRecord cppResult = cppSelf->takeAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_toByteArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.toByteArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toByteArray()const
            QByteArray cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->toByteArray();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_toList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.toList";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toList()const
            QList<QNdefRecord> cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->toList();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_toVector(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.toVector";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toVector()const
            QList<QNdefRecord> cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->toVector();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.value";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::value(qsizetype)const->QNdefRecord
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // value(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(qsizetype)const
            QNdefRecord cppResult = const_cast<const ::QNdefMessage *>(cppSelf)->value(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessage__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNdefMessage_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNdefMessage_methods[] = {
    {"append", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_append), METH_O, nullptr},
    {"at", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_at), METH_O, nullptr},
    {"back", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_back), METH_NOARGS, nullptr},
    {"capacity", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_capacity), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_clear), METH_NOARGS, nullptr},
    {"constData", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_constData), METH_NOARGS, nullptr},
    {"constFirst", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_constFirst), METH_NOARGS, nullptr},
    {"constLast", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_constLast), METH_NOARGS, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_count), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_data), METH_NOARGS, nullptr},
    {"empty", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_empty), METH_NOARGS, nullptr},
    {"first", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_first), METH_VARARGS, nullptr},
    {"fromByteArray", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_fromByteArray), METH_O|METH_STATIC, nullptr},
    {"fromList", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_fromList), METH_O|METH_STATIC, nullptr},
    {"fromVector", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_fromVector), METH_O|METH_STATIC, nullptr},
    {"front", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_front), METH_NOARGS, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_insert), METH_VARARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_isEmpty), METH_NOARGS, nullptr},
    {"isSharedWith", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_isSharedWith), METH_O, nullptr},
    {"last", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_last), METH_VARARGS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_length), METH_NOARGS, nullptr},
    {"mid", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_mid), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"move", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_move), METH_VARARGS, nullptr},
    {"pop_back", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_pop_back), METH_NOARGS, nullptr},
    {"pop_front", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_pop_front), METH_NOARGS, nullptr},
    {"prepend", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_prepend), METH_O, nullptr},
    {"push_back", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_push_back), METH_O, nullptr},
    {"push_front", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_push_front), METH_O, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_remove), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"removeAll", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_removeAll), METH_O, nullptr},
    {"removeAt", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_removeAt), METH_O, nullptr},
    {"removeFirst", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_removeFirst), METH_NOARGS, nullptr},
    {"removeLast", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_removeLast), METH_NOARGS, nullptr},
    {"removeOne", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_removeOne), METH_O, nullptr},
    {"reserve", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_reserve), METH_O, nullptr},
    {"resize", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_resize), METH_O, nullptr},
    {"shrink_to_fit", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_shrink_to_fit), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_size), METH_NOARGS, nullptr},
    {"sliced", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_sliced), METH_VARARGS, nullptr},
    {"squeeze", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_squeeze), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_swap), METH_O, nullptr},
    {"swapItemsAt", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_swapItemsAt), METH_VARARGS, nullptr},
    {"takeAt", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_takeAt), METH_O, nullptr},
    {"toByteArray", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_toByteArray), METH_NOARGS, nullptr},
    {"toList", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_toList), METH_NOARGS, nullptr},
    {"toVector", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_toVector), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QNdefMessageFunc_value), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNdefMessage__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QNdefMessageFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.__add__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::operator+(QList<QNdefRecord>)->QList< QNdefRecord>
    // 1: QNdefMessage::operator+(QList<QNdefRecord>)const->QList< QNdefRecord>
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], (pyArg)))) {
        overloadId = 1; // operator+(QList<QNdefRecord>)const
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], (pyArg)))) {
        overloadId = 0; // operator+(QList<QNdefRecord>)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // operator+(const QList<QNdefRecord> &l)
        {
            ::QList<QNdefRecord> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QList<QNdefRecord>)
                QList<QNdefRecord> cppResult = (*cppSelf) + cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
            }
            break;
        }
        case 1: // operator+(const QList<QNdefRecord> &l) const
        {
            ::QList<QNdefRecord> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QList<QNdefRecord>)const
                QList<QNdefRecord> cppResult = (*cppSelf) + cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNdefMessageFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.__iadd__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNdefMessage::operator+=(QList<QNdefRecord>)->QList< QNdefRecord>&
    if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], (pyArg)))) {
        overloadId = 0; // operator+=(QList<QNdefRecord>)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QNdefRecord> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator+=(QList<QNdefRecord>)
            (*cppSelf) += cppArg0;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

static PyObject *Sbk_QNdefMessageFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNdefMessage.__lshift__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QNdefMessage::operator<<(QList<QNdefRecord>)->QList< QNdefRecord>&
        if (!isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], (pyArg)))) {
            overloadId = 0; // operator<<(QList<QNdefRecord>)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

        // Call function/method
        {
            ::QList<QNdefRecord> cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QList<QNdefRecord>)
                QList<QNdefRecord> & cppResult = (*cppSelf) << cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

Py_ssize_t Sbk_QNdefMessage__len__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return cppSelf->size();
}
PyObject *Sbk_QNdefMessage__getitem__(PyObject *self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (_i < 0 || _i >= (Py_ssize_t) cppSelf->size()) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return 0;
    }
    QNdefMessage::const_iterator _item = cppSelf->begin();
    std::advance(_item, _i);
    return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), &*_item);
}
int Sbk_QNdefMessage__setitem__(PyObject *self, Py_ssize_t _i, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (_i < 0 || _i >= (Py_ssize_t) cppSelf->size()) {
        PyErr_SetString(PyExc_IndexError, "list assignment index out of range");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), (pyArg)))) {
        Shiboken::Errors::setSequenceTypeError("QNdefRecord");
        return -1;
    }
    if (!Shiboken::Object::isValid(pyArg))
        return -1;
    ::QNdefRecord cppValue;
    pythonToCpp(pyArg, &cppValue);
    QNdefMessage::iterator _item = cppSelf->begin();
    std::advance(_item, _i);
    *_item = cppValue;
    return {};
}
// Rich comparison
static PyObject * Sbk_QNdefMessage_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), (pyArg)))) {
                // operator==(const QNdefMessage &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNdefMessage cppArg0_local;
                ::QNdefMessage *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QNdefMessage_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNdefMessage_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNdefMessage_Type = nullptr;
static PyTypeObject *Sbk_QNdefMessage_TypeF(void)
{
    return _Sbk_QNdefMessage_Type;
}

static PyType_Slot Sbk_QNdefMessage_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNdefMessage_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNdefMessage_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QNdefMessage_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNdefMessage_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNdefMessage_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports sequence protocol
    {Py_sq_ass_item,    reinterpret_cast<void *>(Sbk_QNdefMessage__setitem__)},
    {Py_sq_length,      reinterpret_cast<void *>(Sbk_QNdefMessage__len__)},
    {Py_sq_item,        reinterpret_cast<void *>(Sbk_QNdefMessage__getitem__)},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QNdefMessageFunc___iadd__)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QNdefMessageFunc___lshift__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QNdefMessageFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNdefMessage_spec = {
    "2:PySide6.QtNfc.QNdefMessage",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNdefMessage_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNdefMessage_PythonToCpp_QNdefMessage_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNdefMessage_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNdefMessage_PythonToCpp_QNdefMessage_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNdefMessage_TypeF()))
        return QNdefMessage_PythonToCpp_QNdefMessage_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNdefMessage_PTR_CppToPython_QNdefMessage(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QNdefMessage *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QNdefMessage_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QNdefMessage_COPY_CppToPython_QNdefMessage(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNdefMessage *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNdefMessage_TypeF(), new ::QNdefMessage(*source), true, true);
}

// Python to C++ copy conversion.
static void QNdefMessage_PythonToCpp_QNdefMessage_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNdefMessage *>(cppOut) = *reinterpret_cast< ::QNdefMessage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNdefMessage_PythonToCpp_QNdefMessage_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNdefMessage_TypeF()))
        return QNdefMessage_PythonToCpp_QNdefMessage_COPY;
    return {};
}

// Implicit conversions.
static void _constQList_QNdefRecord_REF_PythonToCpp_QNdefMessage(PyObject *pyIn, void *cppOut)
{
    ::QList<QNdefRecord> cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefRecord_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QNdefMessage *>(cppOut) = ::QNdefMessage(cppIn);
}
static PythonToCppFunc is__constQList_QNdefRecord_REF_PythonToCpp_QNdefMessage_Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNdefRecord_IDX]), pyIn))
        return _constQList_QNdefRecord_REF_PythonToCpp_QNdefMessage;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QNdefMessage_SignatureStrings[] = {
    "3:PySide6.QtNfc.QNdefMessage(self)",
    "2:PySide6.QtNfc.QNdefMessage(self,records:QList[PySide6.QtNfc.QNdefRecord])",
    "1:PySide6.QtNfc.QNdefMessage(self,message:typing.Union[PySide6.QtNfc.QNdefMessage, QList[PySide6.QtNfc.QNdefRecord]])",
    "0:PySide6.QtNfc.QNdefMessage(self,record:PySide6.QtNfc.QNdefRecord)",
    "1:PySide6.QtNfc.QNdefMessage.append(self,arg__1:PySide6.QtNfc.QNdefRecord)",
    "0:PySide6.QtNfc.QNdefMessage.append(self,l:QList[PySide6.QtNfc.QNdefRecord])",
    "PySide6.QtNfc.QNdefMessage.at(self,i:qsizetype)->PySide6.QtNfc.QNdefRecord",
    "PySide6.QtNfc.QNdefMessage.back(self)->PySide6.QtNfc.QNdefRecord",
    "PySide6.QtNfc.QNdefMessage.capacity(self)->qsizetype",
    "PySide6.QtNfc.QNdefMessage.clear(self)",
    "PySide6.QtNfc.QNdefMessage.constData(self)->PySide6.QtNfc.QNdefRecord",
    "PySide6.QtNfc.QNdefMessage.constFirst(self)->PySide6.QtNfc.QNdefRecord",
    "PySide6.QtNfc.QNdefMessage.constLast(self)->PySide6.QtNfc.QNdefRecord",
    "PySide6.QtNfc.QNdefMessage.count(self)->qsizetype",
    "PySide6.QtNfc.QNdefMessage.data(self)->PySide6.QtNfc.QNdefRecord",
    "PySide6.QtNfc.QNdefMessage.empty(self)->bool",
    "1:PySide6.QtNfc.QNdefMessage.first(self)->PySide6.QtNfc.QNdefRecord",
    "0:PySide6.QtNfc.QNdefMessage.first(self,n:qsizetype)->QList[PySide6.QtNfc.QNdefRecord]",
    "PySide6.QtNfc.QNdefMessage.fromByteArray(message:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtNfc.QNdefMessage",
    "PySide6.QtNfc.QNdefMessage.fromList(list:QList[PySide6.QtNfc.QNdefRecord])->QList[PySide6.QtNfc.QNdefRecord]",
    "PySide6.QtNfc.QNdefMessage.fromVector(vector:QList[PySide6.QtNfc.QNdefRecord])->QList[PySide6.QtNfc.QNdefRecord]",
    "PySide6.QtNfc.QNdefMessage.front(self)->PySide6.QtNfc.QNdefRecord",
    "PySide6.QtNfc.QNdefMessage.insert(self,arg__1:qsizetype,arg__2:PySide6.QtNfc.QNdefRecord)",
    "PySide6.QtNfc.QNdefMessage.isEmpty(self)->bool",
    "PySide6.QtNfc.QNdefMessage.isSharedWith(self,other:QList[PySide6.QtNfc.QNdefRecord])->bool",
    "1:PySide6.QtNfc.QNdefMessage.last(self)->PySide6.QtNfc.QNdefRecord",
    "0:PySide6.QtNfc.QNdefMessage.last(self,n:qsizetype)->QList[PySide6.QtNfc.QNdefRecord]",
    "PySide6.QtNfc.QNdefMessage.length(self)->qsizetype",
    "PySide6.QtNfc.QNdefMessage.mid(self,pos:qsizetype,len:qsizetype=-1)->QList[PySide6.QtNfc.QNdefRecord]",
    "PySide6.QtNfc.QNdefMessage.move(self,from:qsizetype,to:qsizetype)",
    "PySide6.QtNfc.QNdefMessage.pop_back(self)",
    "PySide6.QtNfc.QNdefMessage.pop_front(self)",
    "PySide6.QtNfc.QNdefMessage.prepend(self,arg__1:PySide6.QtNfc.QNdefRecord)",
    "PySide6.QtNfc.QNdefMessage.push_back(self,arg__1:PySide6.QtNfc.QNdefRecord)",
    "PySide6.QtNfc.QNdefMessage.push_front(self,arg__1:PySide6.QtNfc.QNdefRecord)",
    "PySide6.QtNfc.QNdefMessage.remove(self,i:qsizetype,n:qsizetype=1)",
    "PySide6.QtNfc.QNdefMessage.removeAll(self,arg__1:PySide6.QtNfc.QNdefRecord)",
    "PySide6.QtNfc.QNdefMessage.removeAt(self,i:qsizetype)",
    "PySide6.QtNfc.QNdefMessage.removeFirst(self)",
    "PySide6.QtNfc.QNdefMessage.removeLast(self)",
    "PySide6.QtNfc.QNdefMessage.removeOne(self,arg__1:PySide6.QtNfc.QNdefRecord)",
    "PySide6.QtNfc.QNdefMessage.reserve(self,size:qsizetype)",
    "PySide6.QtNfc.QNdefMessage.resize(self,size:qsizetype)",
    "PySide6.QtNfc.QNdefMessage.shrink_to_fit(self)",
    "PySide6.QtNfc.QNdefMessage.size(self)->qsizetype",
    "1:PySide6.QtNfc.QNdefMessage.sliced(self,pos:qsizetype)->QList[PySide6.QtNfc.QNdefRecord]",
    "0:PySide6.QtNfc.QNdefMessage.sliced(self,pos:qsizetype,n:qsizetype)->QList[PySide6.QtNfc.QNdefRecord]",
    "PySide6.QtNfc.QNdefMessage.squeeze(self)",
    "PySide6.QtNfc.QNdefMessage.swap(self,other:QList[PySide6.QtNfc.QNdefRecord])",
    "PySide6.QtNfc.QNdefMessage.swapItemsAt(self,i:qsizetype,j:qsizetype)",
    "PySide6.QtNfc.QNdefMessage.takeAt(self,i:qsizetype)->PySide6.QtNfc.QNdefRecord",
    "PySide6.QtNfc.QNdefMessage.toByteArray(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNfc.QNdefMessage.toList(self)->QList[PySide6.QtNfc.QNdefRecord]",
    "PySide6.QtNfc.QNdefMessage.toVector(self)->QList[PySide6.QtNfc.QNdefRecord]",
    "PySide6.QtNfc.QNdefMessage.value(self,i:qsizetype)->PySide6.QtNfc.QNdefRecord",
    "PySide6.QtNfc.QNdefMessage.__copy__()",
    "1:PySide6.QtNfc.QNdefMessage.__add__(self,l:QList[PySide6.QtNfc.QNdefRecord])->QList[PySide6.QtNfc.QNdefRecord]",
    "0:PySide6.QtNfc.QNdefMessage.__add__(self,l:QList[PySide6.QtNfc.QNdefRecord])->QList[PySide6.QtNfc.QNdefRecord]",
    "PySide6.QtNfc.QNdefMessage.__iadd__(self,l:QList[PySide6.QtNfc.QNdefRecord])->QList[PySide6.QtNfc.QNdefRecord]",
    "PySide6.QtNfc.QNdefMessage.__lshift__(self,l:QList[PySide6.QtNfc.QNdefRecord])->QList[PySide6.QtNfc.QNdefRecord]",
    nullptr}; // Sentinel

PyTypeObject *init_QNdefMessage(PyObject *module)
{
    if (SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX].type != nullptr)
        return SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX].type;

    Shiboken::AutoDecRef Sbk_QNdefMessage_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNdefMessage_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNdefMessage",
        "QNdefMessage",
        &Sbk_QNdefMessage_spec,
        &Shiboken::callCppDestructor< ::QNdefMessage >,
        Sbk_QNdefMessage_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNdefMessage_TypeF(); // references _Sbk_QNdefMessage_Type
    InitSignatureStrings(pyType, QNdefMessage_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNdefMessage_PropertyStrings);
    SbkPySide6_QtNfcTypeStructs[SBK_QNdefMessage_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNdefMessage_PythonToCpp_QNdefMessage_PTR,
        is_QNdefMessage_PythonToCpp_QNdefMessage_PTR_Convertible,
        QNdefMessage_PTR_CppToPython_QNdefMessage,
        QNdefMessage_COPY_CppToPython_QNdefMessage);

    Shiboken::Conversions::registerConverterName(converter, "QNdefMessage");
    Shiboken::Conversions::registerConverterName(converter, "QNdefMessage*");
    Shiboken::Conversions::registerConverterName(converter, "QNdefMessage&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNdefMessage).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNdefMessage_PythonToCpp_QNdefMessage_COPY,
        is_QNdefMessage_PythonToCpp_QNdefMessage_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        _constQList_QNdefRecord_REF_PythonToCpp_QNdefMessage,
        is__constQList_QNdefRecord_REF_PythonToCpp_QNdefMessage_Convertible);

    qRegisterMetaType< ::QNdefMessage >("QNdefMessage");

    return pyType;
}
