// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopenglpixeltransferoptions_wrapper.h"

// Argument includes
#include <QtOpenGL/qopenglpixeltransferoptions.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLPixelTransferOptions_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLPixelTransferOptions >()))
        return -1;

    ::QOpenGLPixelTransferOptions *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QOpenGLPixelTransferOptions", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOpenGLPixelTransferOptions::QOpenGLPixelTransferOptions()
    // 1: QOpenGLPixelTransferOptions::QOpenGLPixelTransferOptions(QOpenGLPixelTransferOptions)
    if (numArgs == 0) {
        overloadId = 0; // QOpenGLPixelTransferOptions()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QOpenGLPixelTransferOptions(QOpenGLPixelTransferOptions)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOpenGLPixelTransferOptions()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLPixelTransferOptions()
                cptr = new ::QOpenGLPixelTransferOptions();
            }
            break;
        }
        case 1: // QOpenGLPixelTransferOptions(const QOpenGLPixelTransferOptions &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QOpenGLPixelTransferOptions cppArg0_local;
            ::QOpenGLPixelTransferOptions *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLPixelTransferOptions(QOpenGLPixelTransferOptions)
                cptr = new ::QOpenGLPixelTransferOptions(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLPixelTransferOptions >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_alignment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.alignment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // alignment()const
            int cppResult = const_cast<const ::QOpenGLPixelTransferOptions *>(cppSelf)->alignment();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_imageHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.imageHeight";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // imageHeight()const
            int cppResult = const_cast<const ::QOpenGLPixelTransferOptions *>(cppSelf)->imageHeight();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_isLeastSignificantBitFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.isLeastSignificantBitFirst";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isLeastSignificantBitFirst()const
            bool cppResult = const_cast<const ::QOpenGLPixelTransferOptions *>(cppSelf)->isLeastSignificantBitFirst();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_isSwapBytesEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.isSwapBytesEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSwapBytesEnabled()const
            bool cppResult = const_cast<const ::QOpenGLPixelTransferOptions *>(cppSelf)->isSwapBytesEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_rowLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.rowLength";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rowLength()const
            int cppResult = const_cast<const ::QOpenGLPixelTransferOptions *>(cppSelf)->rowLength();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_setAlignment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setAlignment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLPixelTransferOptions::setAlignment(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAlignment(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlignment(int)
            cppSelf->setAlignment(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_setImageHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setImageHeight";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLPixelTransferOptions::setImageHeight(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setImageHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setImageHeight(int)
            cppSelf->setImageHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_setLeastSignificantByteFirst(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setLeastSignificantByteFirst";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLPixelTransferOptions::setLeastSignificantByteFirst(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLeastSignificantByteFirst(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLeastSignificantByteFirst(bool)
            cppSelf->setLeastSignificantByteFirst(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_setRowLength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setRowLength";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLPixelTransferOptions::setRowLength(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setRowLength(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRowLength(int)
            cppSelf->setRowLength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_setSkipImages(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setSkipImages";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLPixelTransferOptions::setSkipImages(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSkipImages(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSkipImages(int)
            cppSelf->setSkipImages(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_setSkipPixels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setSkipPixels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLPixelTransferOptions::setSkipPixels(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSkipPixels(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSkipPixels(int)
            cppSelf->setSkipPixels(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_setSkipRows(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setSkipRows";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLPixelTransferOptions::setSkipRows(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSkipRows(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSkipRows(int)
            cppSelf->setSkipRows(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_setSwapBytesEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setSwapBytesEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLPixelTransferOptions::setSwapBytesEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSwapBytesEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSwapBytesEnabled(bool)
            cppSelf->setSwapBytesEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_skipImages(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.skipImages";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // skipImages()const
            int cppResult = const_cast<const ::QOpenGLPixelTransferOptions *>(cppSelf)->skipImages();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_skipPixels(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.skipPixels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // skipPixels()const
            int cppResult = const_cast<const ::QOpenGLPixelTransferOptions *>(cppSelf)->skipPixels();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_skipRows(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.skipRows";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // skipRows()const
            int cppResult = const_cast<const ::QOpenGLPixelTransferOptions *>(cppSelf)->skipRows();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLPixelTransferOptionsFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLPixelTransferOptions::swap(QOpenGLPixelTransferOptions&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QOpenGLPixelTransferOptions&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QOpenGLPixelTransferOptions cppArg0_local;
        ::QOpenGLPixelTransferOptions *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QOpenGLPixelTransferOptions&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLPixelTransferOptions__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLPixelTransferOptions_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLPixelTransferOptions_methods[] = {
    {"alignment", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_alignment), METH_NOARGS, nullptr},
    {"imageHeight", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_imageHeight), METH_NOARGS, nullptr},
    {"isLeastSignificantBitFirst", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_isLeastSignificantBitFirst), METH_NOARGS, nullptr},
    {"isSwapBytesEnabled", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_isSwapBytesEnabled), METH_NOARGS, nullptr},
    {"rowLength", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_rowLength), METH_NOARGS, nullptr},
    {"setAlignment", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_setAlignment), METH_O, nullptr},
    {"setImageHeight", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_setImageHeight), METH_O, nullptr},
    {"setLeastSignificantByteFirst", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_setLeastSignificantByteFirst), METH_O, nullptr},
    {"setRowLength", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_setRowLength), METH_O, nullptr},
    {"setSkipImages", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_setSkipImages), METH_O, nullptr},
    {"setSkipPixels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_setSkipPixels), METH_O, nullptr},
    {"setSkipRows", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_setSkipRows), METH_O, nullptr},
    {"setSwapBytesEnabled", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_setSwapBytesEnabled), METH_O, nullptr},
    {"skipImages", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_skipImages), METH_NOARGS, nullptr},
    {"skipPixels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_skipPixels), METH_NOARGS, nullptr},
    {"skipRows", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_skipRows), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptionsFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QOpenGLPixelTransferOptions__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QOpenGLPixelTransferOptions_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLPixelTransferOptions_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLPixelTransferOptions_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLPixelTransferOptions_TypeF(void)
{
    return _Sbk_QOpenGLPixelTransferOptions_Type;
}

static PyType_Slot Sbk_QOpenGLPixelTransferOptions_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLPixelTransferOptions_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLPixelTransferOptions_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLPixelTransferOptions_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLPixelTransferOptions_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLPixelTransferOptions_spec = {
    "2:PySide6.QtOpenGL.QOpenGLPixelTransferOptions",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLPixelTransferOptions_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLPixelTransferOptions_PythonToCpp_QOpenGLPixelTransferOptions_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLPixelTransferOptions_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLPixelTransferOptions_PythonToCpp_QOpenGLPixelTransferOptions_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLPixelTransferOptions_TypeF()))
        return QOpenGLPixelTransferOptions_PythonToCpp_QOpenGLPixelTransferOptions_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLPixelTransferOptions_PTR_CppToPython_QOpenGLPixelTransferOptions(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QOpenGLPixelTransferOptions *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QOpenGLPixelTransferOptions_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QOpenGLPixelTransferOptions_COPY_CppToPython_QOpenGLPixelTransferOptions(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QOpenGLPixelTransferOptions *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QOpenGLPixelTransferOptions_TypeF(), new ::QOpenGLPixelTransferOptions(*source), true, true);
}

// Python to C++ copy conversion.
static void QOpenGLPixelTransferOptions_PythonToCpp_QOpenGLPixelTransferOptions_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QOpenGLPixelTransferOptions *>(cppOut) = *reinterpret_cast< ::QOpenGLPixelTransferOptions *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QOpenGLPixelTransferOptions_PythonToCpp_QOpenGLPixelTransferOptions_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLPixelTransferOptions_TypeF()))
        return QOpenGLPixelTransferOptions_PythonToCpp_QOpenGLPixelTransferOptions_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QOpenGLPixelTransferOptions_SignatureStrings[] = {
    "1:PySide6.QtOpenGL.QOpenGLPixelTransferOptions(self)",
    "0:PySide6.QtOpenGL.QOpenGLPixelTransferOptions(self,arg__1:PySide6.QtOpenGL.QOpenGLPixelTransferOptions)",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.alignment(self)->int",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.imageHeight(self)->int",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.isLeastSignificantBitFirst(self)->bool",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.isSwapBytesEnabled(self)->bool",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.rowLength(self)->int",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setAlignment(self,alignment:int)",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setImageHeight(self,imageHeight:int)",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setLeastSignificantByteFirst(self,lsbFirst:bool)",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setRowLength(self,rowLength:int)",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setSkipImages(self,skipImages:int)",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setSkipPixels(self,skipPixels:int)",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setSkipRows(self,skipRows:int)",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.setSwapBytesEnabled(self,swapBytes:bool)",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.skipImages(self)->int",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.skipPixels(self)->int",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.skipRows(self)->int",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.swap(self,other:PySide6.QtOpenGL.QOpenGLPixelTransferOptions)",
    "PySide6.QtOpenGL.QOpenGLPixelTransferOptions.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QOpenGLPixelTransferOptions(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLPixelTransferOptions_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLPixelTransferOptions_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLPixelTransferOptions",
        "QOpenGLPixelTransferOptions",
        &Sbk_QOpenGLPixelTransferOptions_spec,
        &Shiboken::callCppDestructor< ::QOpenGLPixelTransferOptions >,
        Sbk_QOpenGLPixelTransferOptions_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QOpenGLPixelTransferOptions_TypeF(); // references _Sbk_QOpenGLPixelTransferOptions_Type
    InitSignatureStrings(pyType, QOpenGLPixelTransferOptions_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLPixelTransferOptions_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLPixelTransferOptions_PythonToCpp_QOpenGLPixelTransferOptions_PTR,
        is_QOpenGLPixelTransferOptions_PythonToCpp_QOpenGLPixelTransferOptions_PTR_Convertible,
        QOpenGLPixelTransferOptions_PTR_CppToPython_QOpenGLPixelTransferOptions,
        QOpenGLPixelTransferOptions_COPY_CppToPython_QOpenGLPixelTransferOptions);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLPixelTransferOptions");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLPixelTransferOptions*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLPixelTransferOptions&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLPixelTransferOptions).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QOpenGLPixelTransferOptions_PythonToCpp_QOpenGLPixelTransferOptions_COPY,
        is_QOpenGLPixelTransferOptions_PythonToCpp_QOpenGLPixelTransferOptions_COPY_Convertible);

    qRegisterMetaType< ::QOpenGLPixelTransferOptions >("QOpenGLPixelTransferOptions");

    return pyType;
}
