// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopenglversionfunctionsfactory_wrapper.h"

// Extra includes
#include <QtOpenGL/qopenglfunctions_1_0.h>
#include <QtOpenGL/qopenglfunctions_1_1.h>
#include <QtOpenGL/qopenglfunctions_1_2.h>
#include <QtOpenGL/qopenglfunctions_1_3.h>
#include <QtOpenGL/qopenglfunctions_1_4.h>
#include <QtOpenGL/qopenglfunctions_1_5.h>
#include <QtOpenGL/qopenglfunctions_2_0.h>
#include <QtOpenGL/qopenglfunctions_2_1.h>
#include <QtOpenGL/qopenglfunctions_3_0.h>
#include <QtOpenGL/qopenglfunctions_3_1.h>
#include <QtOpenGL/qopenglfunctions_3_2_compatibility.h>
#include <QtOpenGL/qopenglfunctions_3_2_core.h>
#include <QtOpenGL/qopenglfunctions_3_3_compatibility.h>
#include <QtOpenGL/qopenglfunctions_3_3_core.h>
#include <QtOpenGL/qopenglfunctions_4_0_compatibility.h>
#include <QtOpenGL/qopenglfunctions_4_0_core.h>
#include <QtOpenGL/qopenglfunctions_4_1_compatibility.h>
#include <QtOpenGL/qopenglfunctions_4_1_core.h>
#include <QtOpenGL/qopenglfunctions_4_2_compatibility.h>
#include <QtOpenGL/qopenglfunctions_4_2_core.h>
#include <QtOpenGL/qopenglfunctions_4_3_compatibility.h>
#include <QtOpenGL/qopenglfunctions_4_3_core.h>
#include <QtOpenGL/qopenglfunctions_4_4_compatibility.h>
#include <QtOpenGL/qopenglfunctions_4_4_core.h>
#include <QtOpenGL/qopenglfunctions_4_5_compatibility.h>
#include <QtOpenGL/qopenglfunctions_4_5_core.h>

// Argument includes
#include <QtGui/qopenglcontext.h>
#include <QtOpenGL/qopenglversionfunctions.h>
#include <QtOpenGL/qopenglversionprofile.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLVersionFunctionsFactory_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLVersionFunctionsFactory >()))
        return -1;

    ::QOpenGLVersionFunctionsFactory *cptr{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLVersionFunctionsFactory.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QOpenGLVersionFunctionsFactory()
            cptr = new ::QOpenGLVersionFunctionsFactory();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLVersionFunctionsFactory >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLVersionFunctionsFactoryFunc_get(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLVersionFunctionsFactory.get";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:get", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOpenGLVersionFunctionsFactory::get(const QOpenGLVersionProfile&=,QOpenGLContext*=)->QAbstractOpenGLFunctions*
    if (numArgs == 0) {
        overloadId = 0; // get(QOpenGLVersionProfile,QOpenGLContext*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // get(QOpenGLVersionProfile,QOpenGLContext*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), (pyArgs[1])))) {
            overloadId = 0; // get(QOpenGLVersionProfile,QOpenGLContext*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_versionProfile = Shiboken::String::createStaticString("versionProfile");
            if (PyDict_Contains(kwds, key_versionProfile) != 0) {
                value = PyDict_GetItem(kwds, key_versionProfile);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_versionProfile);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionProfile_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_versionProfile);
            }
            static PyObject *const key_context = Shiboken::String::createStaticString("context");
            if (PyDict_Contains(kwds, key_context) != 0) {
                value = PyDict_GetItem(kwds, key_context);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_context);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_context);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QOpenGLVersionProfile cppArg0_local = QOpenGLVersionProfile();
        ::QOpenGLVersionProfile *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QOpenGLContext *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // get(QOpenGLVersionProfile,QOpenGLContext*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtopengl.cpp (qopenglversionfunctionsfactory-get)]
            QAbstractOpenGLFunctions *af = QOpenGLVersionFunctionsFactory::get((*cppArg0), cppArg1);
            if (auto *f = dynamic_cast<QOpenGLFunctions_4_5_Core *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_4_5_Core_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_4_5_Compatibility *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_4_5_Compatibility_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_4_4_Core *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_4_4_Core_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_4_4_Compatibility *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_4_4_Compatibility_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_4_3_Core *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_4_3_Core_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_4_2_Core *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_4_2_Core_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_4_1_Core *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_4_1_Core_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_4_0_Core *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_4_0_Core_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_4_0_Compatibility *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_4_0_Compatibility_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_3_3_Core *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_3_3_Core_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_3_3_Compatibility *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_3_3_Compatibility_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_3_2_Core *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_3_2_Core_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_3_2_Compatibility *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_3_2_Compatibility_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_3_1 *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_3_1_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_3_0 *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_3_0_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_2_1 *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_2_1_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_2_0 *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_2_0_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_1_5 *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_5_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_1_4 *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_4_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_1_3 *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_3_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_1_2 *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_1_1 *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_1_IDX]), f);
            } else if (auto *f = dynamic_cast<QOpenGLFunctions_1_0 *>(af)) {
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_0_IDX]), f);
            } else {
                QString message;
                QDebug(&message) << "No OpenGL functions could be obtained for" << (*cppArg0);
                PyErr_SetString(PyExc_RuntimeError, message.toUtf8().constData());
                pyResult = Py_None;
            }
            // END of custom code block [file: ../glue/qtopengl.cpp (qopenglversionfunctionsfactory-get)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLVersionFunctionsFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLVersionFunctionsFactory_methods[] = {
    {"get", reinterpret_cast<PyCFunction>(Sbk_QOpenGLVersionFunctionsFactoryFunc_get), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QOpenGLVersionFunctionsFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLVersionFunctionsFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLVersionFunctionsFactory_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLVersionFunctionsFactory_TypeF(void)
{
    return _Sbk_QOpenGLVersionFunctionsFactory_Type;
}

static PyType_Slot Sbk_QOpenGLVersionFunctionsFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLVersionFunctionsFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLVersionFunctionsFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLVersionFunctionsFactory_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLVersionFunctionsFactory_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLVersionFunctionsFactory_spec = {
    "2:PySide6.QtOpenGL.QOpenGLVersionFunctionsFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLVersionFunctionsFactory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLVersionFunctionsFactory_PythonToCpp_QOpenGLVersionFunctionsFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLVersionFunctionsFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLVersionFunctionsFactory_PythonToCpp_QOpenGLVersionFunctionsFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLVersionFunctionsFactory_TypeF()))
        return QOpenGLVersionFunctionsFactory_PythonToCpp_QOpenGLVersionFunctionsFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLVersionFunctionsFactory_PTR_CppToPython_QOpenGLVersionFunctionsFactory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QOpenGLVersionFunctionsFactory *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QOpenGLVersionFunctionsFactory_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QOpenGLVersionFunctionsFactory_SignatureStrings[] = {
    "PySide6.QtOpenGL.QOpenGLVersionFunctionsFactory(self)",
    "PySide6.QtOpenGL.QOpenGLVersionFunctionsFactory.get(versionProfile:PySide6.QtOpenGL.QOpenGLVersionProfile=QOpenGLVersionProfile(),context:PySide6.QtGui.QOpenGLContext=nullptr)->PySide6.QtOpenGL.QAbstractOpenGLFunctions",
    nullptr}; // Sentinel

PyTypeObject *init_QOpenGLVersionFunctionsFactory(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionFunctionsFactory_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionFunctionsFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLVersionFunctionsFactory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLVersionFunctionsFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLVersionFunctionsFactory",
        "QOpenGLVersionFunctionsFactory*",
        &Sbk_QOpenGLVersionFunctionsFactory_spec,
        &Shiboken::callCppDestructor< ::QOpenGLVersionFunctionsFactory >,
        Sbk_QOpenGLVersionFunctionsFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOpenGLVersionFunctionsFactory_TypeF(); // references _Sbk_QOpenGLVersionFunctionsFactory_Type
    InitSignatureStrings(pyType, QOpenGLVersionFunctionsFactory_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLVersionFunctionsFactory_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLVersionFunctionsFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLVersionFunctionsFactory_PythonToCpp_QOpenGLVersionFunctionsFactory_PTR,
        is_QOpenGLVersionFunctionsFactory_PythonToCpp_QOpenGLVersionFunctionsFactory_PTR_Convertible,
        QOpenGLVersionFunctionsFactory_PTR_CppToPython_QOpenGLVersionFunctionsFactory);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLVersionFunctionsFactory");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLVersionFunctionsFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLVersionFunctionsFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLVersionFunctionsFactory).name());

    qRegisterMetaType< ::QOpenGLVersionFunctionsFactory *>();

    return pyType;
}
