// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtprintsupport_python.h"

// main header
#include "qprintengine_wrapper.h"

// Argument includes
#include <QtGui/qpaintdevice.h>
#include <QtPrintSupport/qprintengine.h>
#include <QtPrintSupport/qprinter.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPrintEngineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPrintEngineWrapper::QPrintEngineWrapper() : QPrintEngine()
{
    resetPyMethodCache();
    // ... middle
}

bool QPrintEngineWrapper::abort()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.abort");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "abort";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.abort");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrintEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QPrintEngineWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.metric");
        return 0;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "metric";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.metric");
        return 0;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrintEngine", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QPrintEngineWrapper::newPage()
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.newPage");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "newPage";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.newPage");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrintEngine", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPrinter::PrinterState QPrintEngineWrapper::printerState() const
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.printerState");
        return QPrinter::Idle;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QPrinter::Idle;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "printerState";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.printerState");
        return QPrinter::Idle;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QPrinter::Idle;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterState_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrintEngine", funcName, Shiboken::SbkType< QPrinter::PrinterState >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QPrinter::Idle;
    }
    ::QPrinter::PrinterState cppResult{QPrinter::Idle};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QVariant QPrintEngineWrapper::property(::QPrintEngine::PrintEnginePropertyKey key) const
{
    if (m_PyMethodCache[4]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.property");
        return ::QVariant();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "property";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.property");
        return ::QVariant();
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_PrintEnginePropertyKey_IDX])))->converter, &key)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_PrintEnginePropertyKey_IDX])))->converter, &key)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrintEngine", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPrintEngineWrapper::setProperty(::QPrintEngine::PrintEnginePropertyKey key, const ::QVariant & value)
{
    if (m_PyMethodCache[5]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.setProperty");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setProperty";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.setProperty");
        return;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_PrintEnginePropertyKey_IDX])))->converter, &key),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_PrintEnginePropertyKey_IDX])))->converter, &key),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QPrintEngineWrapper::~QPrintEngineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPrintEngine_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QPrintEngine");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPrintEngine >()))
        return -1;

    QPrintEngineWrapper *cptr{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrintEngine.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPrintEngine()
            cptr = new QPrintEngineWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPrintEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPrintEngineFunc_abort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrintEngine.abort";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // abort()
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.abort");
                return {};
            }
            bool cppResult = cppSelf->abort();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrintEngineFunc_metric(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrintEngine.metric";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrintEngine::metric(QPaintDevice::PaintDeviceMetric)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPaintDevice::PaintDeviceMetric cppArg0 = static_cast< ::QPaintDevice::PaintDeviceMetric>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // metric(QPaintDevice::PaintDeviceMetric)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.metric");
                return {};
            }
            int cppResult = const_cast<const ::QPrintEngine *>(cppSelf)->metric(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrintEngineFunc_newPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrintEngine.newPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // newPage()
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.newPage");
                return {};
            }
            bool cppResult = cppSelf->newPage();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrintEngineFunc_printerState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrintEngine.printerState";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // printerState()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.printerState");
                return {};
            }
            QPrinter::PrinterState cppResult = const_cast<const ::QPrintEngine *>(cppSelf)->printerState();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterState_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrintEngineFunc_property(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrintEngine.property";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrintEngine::property(QPrintEngine::PrintEnginePropertyKey)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_PrintEnginePropertyKey_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // property(QPrintEngine::PrintEnginePropertyKey)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPrintEngine::PrintEnginePropertyKey cppArg0{QPrintEngine::PPK_CollateCopies};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // property(QPrintEngine::PrintEnginePropertyKey)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.property");
                return {};
            }
            QVariant cppResult = const_cast<const ::QPrintEngine *>(cppSelf)->property(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrintEngineFunc_setProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrintEngine.setProperty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPrintEngine::setProperty(QPrintEngine::PrintEnginePropertyKey,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_PrintEnginePropertyKey_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setProperty(QPrintEngine::PrintEnginePropertyKey,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QPrintEngine::PrintEnginePropertyKey cppArg0{QPrintEngine::PPK_CollateCopies};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProperty(QPrintEngine::PrintEnginePropertyKey,QVariant)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QPrintEngine.setProperty");
                return {};
            }
            cppSelf->setProperty(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QPrintEngine_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPrintEngine_EnumFlagInfo[] = {
    "PrintEnginePropertyKey:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPrintEngine_methods[] = {
    {"abort", reinterpret_cast<PyCFunction>(Sbk_QPrintEngineFunc_abort), METH_NOARGS, nullptr},
    {"metric", reinterpret_cast<PyCFunction>(Sbk_QPrintEngineFunc_metric), METH_O, nullptr},
    {"newPage", reinterpret_cast<PyCFunction>(Sbk_QPrintEngineFunc_newPage), METH_NOARGS, nullptr},
    {"printerState", reinterpret_cast<PyCFunction>(Sbk_QPrintEngineFunc_printerState), METH_NOARGS, nullptr},
    {"property", reinterpret_cast<PyCFunction>(Sbk_QPrintEngineFunc_property), METH_O, nullptr},
    {"setProperty", reinterpret_cast<PyCFunction>(Sbk_QPrintEngineFunc_setProperty), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPrintEngine_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPrintEngine *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPrintEngineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPrintEngine_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPrintEngine_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPrintEngine_Type = nullptr;
static PyTypeObject *Sbk_QPrintEngine_TypeF(void)
{
    return _Sbk_QPrintEngine_Type;
}

static PyType_Slot Sbk_QPrintEngine_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPrintEngine_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPrintEngine_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPrintEngine_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPrintEngine_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPrintEngine_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPrintEngine_spec = {
    "2:PySide6.QtPrintSupport.QPrintEngine",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPrintEngine_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPrintEngine_PrintEnginePropertyKey(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPrintEngine::PrintEnginePropertyKey>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPrintEngine::PrintEnginePropertyKey *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPrintEngine_PrintEnginePropertyKey_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_PrintEnginePropertyKey_IDX])))
        return Enum_PythonToCpp_QPrintEngine_PrintEnginePropertyKey;
    return {};
}
static PyObject *QPrintEngine_PrintEnginePropertyKey_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPrintEngine::PrintEnginePropertyKey *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_PrintEnginePropertyKey_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPrintEngine_PythonToCpp_QPrintEngine_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPrintEngine_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPrintEngine_PythonToCpp_QPrintEngine_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPrintEngine_TypeF()))
        return QPrintEngine_PythonToCpp_QPrintEngine_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPrintEngine_PTR_CppToPython_QPrintEngine(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QPrintEngine *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QPrintEngine_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPrintEngine_SignatureStrings[] = {
    "PySide6.QtPrintSupport.QPrintEngine(self)",
    "PySide6.QtPrintSupport.QPrintEngine.abort(self)->bool",
    "PySide6.QtPrintSupport.QPrintEngine.metric(self,arg__1:PySide6.QtGui.QPaintDevice.PaintDeviceMetric)->int",
    "PySide6.QtPrintSupport.QPrintEngine.newPage(self)->bool",
    "PySide6.QtPrintSupport.QPrintEngine.printerState(self)->PySide6.QtPrintSupport.QPrinter.PrinterState",
    "PySide6.QtPrintSupport.QPrintEngine.property(self,key:PySide6.QtPrintSupport.QPrintEngine.PrintEnginePropertyKey)->QVariant",
    "PySide6.QtPrintSupport.QPrintEngine.setProperty(self,key:PySide6.QtPrintSupport.QPrintEngine.PrintEnginePropertyKey,value:QVariant)",
    nullptr}; // Sentinel

PyTypeObject *init_QPrintEngine(PyObject *module)
{
    if (SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX].type != nullptr)
        return SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX].type;

    Shiboken::AutoDecRef Sbk_QPrintEngine_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPrintEngine_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPrintEngine",
        "QPrintEngine*",
        &Sbk_QPrintEngine_spec,
        &Shiboken::callCppDestructor< QPrintEngine >,
        Sbk_QPrintEngine_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPrintEngine_TypeF(); // references _Sbk_QPrintEngine_Type
    InitSignatureStrings(pyType, QPrintEngine_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPrintEngine_PropertyStrings);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPrintEngine_PythonToCpp_QPrintEngine_PTR,
        is_QPrintEngine_PythonToCpp_QPrintEngine_PTR_Convertible,
        QPrintEngine_PTR_CppToPython_QPrintEngine);

    Shiboken::Conversions::registerConverterName(converter, "QPrintEngine");
    Shiboken::Conversions::registerConverterName(converter, "QPrintEngine*");
    Shiboken::Conversions::registerConverterName(converter, "QPrintEngine&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPrintEngine).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPrintEngineWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPrintEngine_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PrintEnginePropertyKey'.
    const char *PrintEnginePropertyKey_Initializer[] = {
        "PPK_CollateCopies",
        "PPK_ColorMode",
        "PPK_Creator",
        "PPK_DocumentName",
        "PPK_FullPage",
        "PPK_NumberOfCopies",
        "PPK_Orientation",
        "PPK_OutputFileName",
        "PPK_PageOrder",
        "PPK_PageRect",
        "PPK_PageSize",
        "PPK_PaperRect",
        "PPK_PaperSource",
        "PPK_PrinterName",
        "PPK_PrinterProgram",
        "PPK_Resolution",
        "PPK_SelectionOption",
        "PPK_SupportedResolutions",
        "PPK_WindowsPageSize",
        "PPK_FontEmbedding",
        "PPK_Duplex",
        "PPK_PaperSources",
        "PPK_CustomPaperSize",
        "PPK_PageMargins",
        "PPK_CopyCount",
        "PPK_SupportsMultipleCopies",
        "PPK_PaperName",
        "PPK_QPageSize",
        "PPK_QPageMargins",
        "PPK_QPageLayout",
        "PPK_PaperSize",
        "PPK_CustomBase",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t PrintEnginePropertyKey_InitializerValues[] = {
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_CollateCopies),          //  0x0000  0
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_ColorMode),              //  0x0001  1
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_Creator),                //  0x0002  2
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_DocumentName),           //  0x0003  3
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_FullPage),               //  0x0004  4
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_NumberOfCopies),         //  0x0005  5
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_Orientation),            //  0x0006  6
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_OutputFileName),         //  0x0007  7
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PageOrder),              //  0x0008  8
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PageRect),               //  0x0009  9
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PageSize),               //  0x000a  10
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PaperRect),              //  0x000b  11
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PaperSource),            //  0x000c  12
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PrinterName),            //  0x000d  13
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PrinterProgram),         //  0x000e  14
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_Resolution),             //  0x000f  15
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_SelectionOption),        //  0x0010  16
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_SupportedResolutions),   //  0x0011  17
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_WindowsPageSize),        //  0x0012  18
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_FontEmbedding),          //  0x0013  19
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_Duplex),                 //  0x0014  20
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PaperSources),           //  0x0015  21
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_CustomPaperSize),        //  0x0016  22
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PageMargins),            //  0x0017  23
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_CopyCount),              //  0x0018  24
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_SupportsMultipleCopies), //  0x0019  25
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PaperName),              //  0x001a  26
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_QPageSize),              //  0x001b  27
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_QPageMargins),           //  0x001c  28
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_QPageLayout),            //  0x001d  29
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_PaperSize),              //  0x000a  10
        uint16_t(QPrintEngine::PrintEnginePropertyKey::PPK_CustomBase)              //  0xff00  65280
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPrintEngine_TypeF(),
        "2:PySide6.QtPrintSupport.QPrintEngine.PrintEnginePropertyKey",
        PrintEnginePropertyKey_Initializer, PrintEnginePropertyKey_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_PrintEnginePropertyKey_IDX].type = EType;
    // Register converter for enum 'QPrintEngine::PrintEnginePropertyKey'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPrintEngine_PrintEnginePropertyKey_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPrintEngine_PrintEnginePropertyKey,
            is_Enum_PythonToCpp_QPrintEngine_PrintEnginePropertyKey_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPrintEngine::PrintEnginePropertyKey");
        Shiboken::Conversions::registerConverterName(converter, "PrintEnginePropertyKey");
    }
    // End of 'PrintEnginePropertyKey' enum.

    qRegisterMetaType< ::QPrintEngine *>();
    qRegisterMetaType< ::QPrintEngine::PrintEnginePropertyKey >("QPrintEngine::PrintEnginePropertyKey");

    return pyType;
}
