// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtprintsupport_python.h"

// main header
#include "qprinter_wrapper.h"

// Extra includes
#include <QPrinterInfo>

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpagelayout.h>
#include <QtGui/qpageranges.h>
#include <QtGui/qpagesize.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtPrintSupport/qprintengine.h>
#include <QtPrintSupport/qprinter.h>
#include <QtPrintSupport/qprinterinfo.h>
#include <qmargins.h>
#include <qpoint.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPrinterWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPrinterWrapper::QPrinterWrapper(::QPrinter::PrinterMode mode) : QPrinter(mode)
{
    resetPyMethodCache();
    // ... middle
}

QPrinterWrapper::QPrinterWrapper(const ::QPrinterInfo & printer, ::QPrinter::PrinterMode mode) : QPrinter(printer, mode)
{
    resetPyMethodCache();
    // ... middle
}

int QPrinterWrapper::devType() const
{
    if (m_PyMethodCache[0])
        return this->::QPrinter::devType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "devType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QPrinter::devType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrinter", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPrinterWrapper::initPainter(::QPainter * painter) const
{
    if (m_PyMethodCache[1]) {
        return this->::QPaintDevice::initPainter(painter);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QPaintDevice::initPainter(painter);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

int QPrinterWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    if (m_PyMethodCache[2])
        return this->::QPrinter::metric(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "metric";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QPrinter::metric(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrinter", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QPrinterWrapper::newPage()
{
    if (m_PyMethodCache[3])
        return this->::QPrinter::newPage();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "newPage";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QPrinter::newPage();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrinter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPaintEngine * QPrinterWrapper::paintEngine() const
{
    if (m_PyMethodCache[4])
        return this->::QPrinter::paintEngine();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintEngine";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QPrinter::paintEngine();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrinter", funcName, Shiboken::SbkType< QPaintEngine >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintEngine *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPaintDevice * QPrinterWrapper::redirected(::QPoint * offset) const
{
    if (m_PyMethodCache[5])
        return this->::QPaintDevice::redirected(offset);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "redirected";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QPaintDevice::redirected(offset);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrinter", funcName, Shiboken::SbkType< QPaintDevice >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintDevice *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QPrinterWrapper::setPageLayout(const ::QPageLayout & pageLayout)
{
    if (m_PyMethodCache[6])
        return this->::QPagedPaintDevice::setPageLayout(pageLayout);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setPageLayout";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QPagedPaintDevice::setPageLayout(pageLayout);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageLayout_IDX]), &pageLayout)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageLayout_IDX]), &pageLayout)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrinter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QPrinterWrapper::setPageMargins(const ::QMarginsF & margins, ::QPageLayout::Unit units)
{
    if (m_PyMethodCache[7])
        return this->::QPagedPaintDevice::setPageMargins(margins, units);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setPageMargins";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QPagedPaintDevice::setPageMargins(margins, units);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMarginsF_IDX]), &margins),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageLayout_Unit_IDX])))->converter, &units)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMarginsF_IDX]), &margins),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageLayout_Unit_IDX])))->converter, &units)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrinter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QPrinterWrapper::setPageOrientation(::QPageLayout::Orientation orientation)
{
    if (m_PyMethodCache[8])
        return this->::QPagedPaintDevice::setPageOrientation(orientation);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setPageOrientation";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QPagedPaintDevice::setPageOrientation(orientation);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageLayout_Orientation_IDX])))->converter, &orientation)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageLayout_Orientation_IDX])))->converter, &orientation)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrinter", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPrinterWrapper::setPageRanges(const ::QPageRanges & ranges)
{
    if (m_PyMethodCache[9]) {
        return this->::QPagedPaintDevice::setPageRanges(ranges);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setPageRanges";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QPagedPaintDevice::setPageRanges(ranges);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_IDX]), &ranges)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_IDX]), &ranges)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QPainter * QPrinterWrapper::sharedPainter() const
{
    if (m_PyMethodCache[10])
        return this->::QPaintDevice::sharedPainter();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sharedPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QPaintDevice::sharedPainter();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPrinter", funcName, Shiboken::SbkType< QPainter >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPainter *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QPrinterWrapper::~QPrinterWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPrinter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPrinter >()))
        return -1;

    QPrinterWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QPrinter", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPrinter::QPrinter(QPrinter::PrinterMode=)
    // 1: QPrinter::QPrinter(QPrinterInfo,QPrinter::PrinterMode=)
    if (numArgs == 0) {
        overloadId = 0; // QPrinter(QPrinter::PrinterMode)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QPrinter(QPrinterInfo,QPrinter::PrinterMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // QPrinter(QPrinterInfo,QPrinter::PrinterMode)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterMode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QPrinter(QPrinter::PrinterMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPrinter(QPrinter::PrinterMode mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterMode_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QPrinter::PrinterMode cppArg0(QPrinter::PrinterMode::ScreenResolution);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPrinter(QPrinter::PrinterMode)
                cptr = new QPrinterWrapper(cppArg0);
            }
            break;
        }
        case 1: // QPrinter(const QPrinterInfo &printer, QPrinter::PrinterMode mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterMode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPrinterInfo cppArg0_local;
            ::QPrinterInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QPrinter::PrinterMode cppArg1(QPrinter::PrinterMode::ScreenResolution);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPrinter(QPrinterInfo,QPrinter::PrinterMode)
                cptr = new QPrinterWrapper(*cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPrinter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPrinterFunc_abort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.abort";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // abort()
            bool cppResult = cppSelf->abort();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_collateCopies(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.collateCopies";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // collateCopies()const
            bool cppResult = const_cast<const ::QPrinter *>(cppSelf)->collateCopies();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_colorMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.colorMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // colorMode()const
            QPrinter::ColorMode cppResult = const_cast<const ::QPrinter *>(cppSelf)->colorMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_ColorMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_copyCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.copyCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // copyCount()const
            int cppResult = const_cast<const ::QPrinter *>(cppSelf)->copyCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_creator(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.creator";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // creator()const
            QString cppResult = const_cast<const ::QPrinter *>(cppSelf)->creator();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_devType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.devType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // devType()const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPrinter *>(cppSelf)->::QPrinter::devType()
                : const_cast<const ::QPrinter *>(cppSelf)->devType();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_docName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.docName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // docName()const
            QString cppResult = const_cast<const ::QPrinter *>(cppSelf)->docName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_duplex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.duplex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // duplex()const
            QPrinter::DuplexMode cppResult = const_cast<const ::QPrinter *>(cppSelf)->duplex();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_DuplexMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_fontEmbeddingEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.fontEmbeddingEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fontEmbeddingEnabled()const
            bool cppResult = const_cast<const ::QPrinter *>(cppSelf)->fontEmbeddingEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_fromPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.fromPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromPage()const
            int cppResult = const_cast<const ::QPrinter *>(cppSelf)->fromPage();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_fullPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.fullPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fullPage()const
            bool cppResult = const_cast<const ::QPrinter *>(cppSelf)->fullPage();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QPrinter *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_metric(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.metric";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPaintDevice::metric(QPaintDevice::PaintDeviceMetric)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPaintDevice::PaintDeviceMetric cppArg0 = static_cast< ::QPaintDevice::PaintDeviceMetric>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // metric(QPaintDevice::PaintDeviceMetric)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPrinter *>(cppSelf)->::QPrinter::metric(cppArg0)
                : const_cast<const ::QPrinter *>(cppSelf)->metric(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_newPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.newPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // newPage()
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPrinter::newPage()
                : cppSelf->newPage();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_outputFileName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.outputFileName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // outputFileName()const
            QString cppResult = const_cast<const ::QPrinter *>(cppSelf)->outputFileName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_outputFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.outputFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // outputFormat()const
            QPrinter::OutputFormat cppResult = const_cast<const ::QPrinter *>(cppSelf)->outputFormat();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_OutputFormat_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_pageOrder(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.pageOrder";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pageOrder()const
            QPrinter::PageOrder cppResult = const_cast<const ::QPrinter *>(cppSelf)->pageOrder();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PageOrder_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_pageRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.pageRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::pageRect(QPrinter::Unit)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_Unit_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // pageRect(QPrinter::Unit)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPrinter::Unit cppArg0{QPrinter::Millimeter};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // pageRect(QPrinter::Unit)const
            QRectF cppResult = const_cast<const ::QPrinter *>(cppSelf)->pageRect(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_paintEngine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.paintEngine";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintEngine()const
            QPaintEngine * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPrinter *>(cppSelf)->::QPrinter::paintEngine()
                : const_cast<const ::QPrinter *>(cppSelf)->paintEngine();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_paperRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.paperRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::paperRect(QPrinter::Unit)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_Unit_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // paperRect(QPrinter::Unit)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPrinter::Unit cppArg0{QPrinter::Millimeter};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paperRect(QPrinter::Unit)const
            QRectF cppResult = const_cast<const ::QPrinter *>(cppSelf)->paperRect(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_paperSource(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.paperSource";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // paperSource()const
            QPrinter::PaperSource cppResult = const_cast<const ::QPrinter *>(cppSelf)->paperSource();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PaperSource_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_pdfVersion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.pdfVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pdfVersion()const
            QPagedPaintDevice::PdfVersion cppResult = const_cast<const ::QPrinter *>(cppSelf)->pdfVersion();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPagedPaintDevice_PdfVersion_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_printEngine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.printEngine";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // printEngine()const
            QPrintEngine * cppResult = const_cast<const ::QPrinter *>(cppSelf)->printEngine();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_printProgram(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.printProgram";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // printProgram()const
            QString cppResult = const_cast<const ::QPrinter *>(cppSelf)->printProgram();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_printRange(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.printRange";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // printRange()const
            QPrinter::PrintRange cppResult = const_cast<const ::QPrinter *>(cppSelf)->printRange();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrintRange_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_printerName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.printerName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // printerName()const
            QString cppResult = const_cast<const ::QPrinter *>(cppSelf)->printerName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_printerState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.printerState";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // printerState()const
            QPrinter::PrinterState cppResult = const_cast<const ::QPrinter *>(cppSelf)->printerState();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterState_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_resolution(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.resolution";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // resolution()const
            int cppResult = const_cast<const ::QPrinter *>(cppSelf)->resolution();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_setCollateCopies(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setCollateCopies";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setCollateCopies(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setCollateCopies(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCollateCopies(bool)
            cppSelf->setCollateCopies(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setColorMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setColorMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setColorMode(QPrinter::ColorMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_ColorMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setColorMode(QPrinter::ColorMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPrinter::ColorMode cppArg0{QPrinter::GrayScale};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorMode(QPrinter::ColorMode)
            cppSelf->setColorMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setCopyCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setCopyCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setCopyCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCopyCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCopyCount(int)
            cppSelf->setCopyCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setCreator(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setCreator";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setCreator(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCreator(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCreator(QString)
            cppSelf->setCreator(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setDocName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setDocName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setDocName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDocName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocName(QString)
            cppSelf->setDocName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setDuplex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setDuplex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setDuplex(QPrinter::DuplexMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_DuplexMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDuplex(QPrinter::DuplexMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPrinter::DuplexMode cppArg0{QPrinter::DuplexNone};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDuplex(QPrinter::DuplexMode)
            cppSelf->setDuplex(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setEngines(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setEngines";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setEngines", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPrinter::setEngines(QPrintEngine*,QPaintEngine*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrintEngine_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setEngines(QPrintEngine*,QPaintEngine*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPrintEngine *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPaintEngine *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEngines(QPrintEngine*,QPaintEngine*)
            cppSelf->setEngines(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[0]);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[1]);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setFontEmbeddingEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setFontEmbeddingEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setFontEmbeddingEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFontEmbeddingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFontEmbeddingEnabled(bool)
            cppSelf->setFontEmbeddingEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setFromTo(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setFromTo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFromTo", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPrinter::setFromTo(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setFromTo(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFromTo(int,int)
            cppSelf->setFromTo(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setFullPage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setFullPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setFullPage(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFullPage(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFullPage(bool)
            cppSelf->setFullPage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setOutputFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setOutputFileName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setOutputFileName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setOutputFileName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputFileName(QString)
            cppSelf->setOutputFileName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setOutputFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setOutputFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setOutputFormat(QPrinter::OutputFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_OutputFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setOutputFormat(QPrinter::OutputFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPrinter::OutputFormat cppArg0{QPrinter::NativeFormat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOutputFormat(QPrinter::OutputFormat)
            cppSelf->setOutputFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setPageOrder(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setPageOrder";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setPageOrder(QPrinter::PageOrder)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PageOrder_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPageOrder(QPrinter::PageOrder)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPrinter::PageOrder cppArg0{QPrinter::FirstPageFirst};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPageOrder(QPrinter::PageOrder)
            cppSelf->setPageOrder(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setPageSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setPageSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPagedPaintDevice::setPageSize(QPageSize)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), (pyArg)))) {
        overloadId = 0; // setPageSize(QPageSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPageSize cppArg0_local;
        ::QPageSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);

        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPageSize(QPageSize)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtprintsupport.cpp (setpagesize)]
            bool out = cppSelf->setPageSize((*cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &out);
            // END of custom code block [file: ../glue/qtprintsupport.cpp (setpagesize)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_setPaperSource(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setPaperSource";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setPaperSource(QPrinter::PaperSource)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PaperSource_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPaperSource(QPrinter::PaperSource)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPrinter::PaperSource cppArg0{QPrinter::Upper};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPaperSource(QPrinter::PaperSource)
            cppSelf->setPaperSource(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setPdfVersion(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setPdfVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setPdfVersion(QPagedPaintDevice::PdfVersion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPagedPaintDevice_PdfVersion_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPdfVersion(QPagedPaintDevice::PdfVersion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPagedPaintDevice::PdfVersion cppArg0{QPagedPaintDevice::PdfVersion_1_4};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPdfVersion(QPagedPaintDevice::PdfVersion)
            cppSelf->setPdfVersion(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setPrintProgram(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setPrintProgram";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setPrintProgram(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPrintProgram(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPrintProgram(QString)
            cppSelf->setPrintProgram(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setPrintRange(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setPrintRange";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setPrintRange(QPrinter::PrintRange)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrintRange_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPrintRange(QPrinter::PrintRange)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPrinter::PrintRange cppArg0{QPrinter::AllPages};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPrintRange(QPrinter::PrintRange)
            cppSelf->setPrintRange(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setPrinterName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setPrinterName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setPrinterName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPrinterName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPrinterName(QString)
            cppSelf->setPrinterName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_setResolution(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.setResolution";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPrinter::setResolution(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setResolution(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setResolution(int)
            cppSelf->setResolution(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPrinterFunc_supportedResolutions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.supportedResolutions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedResolutions()const
            QList<int> cppResult = const_cast<const ::QPrinter *>(cppSelf)->supportedResolutions();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_int_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_supportsMultipleCopies(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.supportsMultipleCopies";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportsMultipleCopies()const
            bool cppResult = const_cast<const ::QPrinter *>(cppSelf)->supportsMultipleCopies();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterFunc_toPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinter.toPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toPage()const
            int cppResult = const_cast<const ::QPrinter *>(cppSelf)->toPage();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPrinter_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPrinter_EnumFlagInfo[] = {
    "ColorMode:Enum",
    "DuplexMode:Enum",
    "OutputFormat:Enum",
    "PageOrder:Enum",
    "PaperSource:Enum",
    "PrintRange:Enum",
    "PrinterMode:Enum",
    "PrinterState:Enum",
    "Unit:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPrinter_methods[] = {
    {"abort", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_abort), METH_NOARGS, nullptr},
    {"collateCopies", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_collateCopies), METH_NOARGS, nullptr},
    {"colorMode", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_colorMode), METH_NOARGS, nullptr},
    {"copyCount", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_copyCount), METH_NOARGS, nullptr},
    {"creator", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_creator), METH_NOARGS, nullptr},
    {"devType", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_devType), METH_NOARGS, nullptr},
    {"docName", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_docName), METH_NOARGS, nullptr},
    {"duplex", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_duplex), METH_NOARGS, nullptr},
    {"fontEmbeddingEnabled", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_fontEmbeddingEnabled), METH_NOARGS, nullptr},
    {"fromPage", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_fromPage), METH_NOARGS, nullptr},
    {"fullPage", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_fullPage), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_isValid), METH_NOARGS, nullptr},
    {"metric", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_metric), METH_O, nullptr},
    {"newPage", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_newPage), METH_NOARGS, nullptr},
    {"outputFileName", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_outputFileName), METH_NOARGS, nullptr},
    {"outputFormat", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_outputFormat), METH_NOARGS, nullptr},
    {"pageOrder", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_pageOrder), METH_NOARGS, nullptr},
    {"pageRect", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_pageRect), METH_O, nullptr},
    {"paintEngine", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_paintEngine), METH_NOARGS, nullptr},
    {"paperRect", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_paperRect), METH_O, nullptr},
    {"paperSource", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_paperSource), METH_NOARGS, nullptr},
    {"pdfVersion", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_pdfVersion), METH_NOARGS, nullptr},
    {"printEngine", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_printEngine), METH_NOARGS, nullptr},
    {"printProgram", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_printProgram), METH_NOARGS, nullptr},
    {"printRange", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_printRange), METH_NOARGS, nullptr},
    {"printerName", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_printerName), METH_NOARGS, nullptr},
    {"printerState", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_printerState), METH_NOARGS, nullptr},
    {"resolution", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_resolution), METH_NOARGS, nullptr},
    {"setCollateCopies", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setCollateCopies), METH_O, nullptr},
    {"setColorMode", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setColorMode), METH_O, nullptr},
    {"setCopyCount", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setCopyCount), METH_O, nullptr},
    {"setCreator", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setCreator), METH_O, nullptr},
    {"setDocName", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setDocName), METH_O, nullptr},
    {"setDuplex", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setDuplex), METH_O, nullptr},
    {"setEngines", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setEngines), METH_VARARGS, nullptr},
    {"setFontEmbeddingEnabled", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setFontEmbeddingEnabled), METH_O, nullptr},
    {"setFromTo", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setFromTo), METH_VARARGS, nullptr},
    {"setFullPage", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setFullPage), METH_O, nullptr},
    {"setOutputFileName", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setOutputFileName), METH_O, nullptr},
    {"setOutputFormat", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setOutputFormat), METH_O, nullptr},
    {"setPageOrder", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setPageOrder), METH_O, nullptr},
    {"setPageSize", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setPageSize), METH_O, nullptr},
    {"setPaperSource", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setPaperSource), METH_O, nullptr},
    {"setPdfVersion", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setPdfVersion), METH_O, nullptr},
    {"setPrintProgram", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setPrintProgram), METH_O, nullptr},
    {"setPrintRange", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setPrintRange), METH_O, nullptr},
    {"setPrinterName", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setPrinterName), METH_O, nullptr},
    {"setResolution", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_setResolution), METH_O, nullptr},
    {"supportedResolutions", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_supportedResolutions), METH_NOARGS, nullptr},
    {"supportsMultipleCopies", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_supportsMultipleCopies), METH_NOARGS, nullptr},
    {"toPage", reinterpret_cast<PyCFunction>(Sbk_QPrinterFunc_toPage), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPrinter_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPrinter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPrinterWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPrinter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPrinter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPrinter_Type = nullptr;
static PyTypeObject *Sbk_QPrinter_TypeF(void)
{
    return _Sbk_QPrinter_Type;
}

static PyType_Slot Sbk_QPrinter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPrinter_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPrinter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPrinter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPrinter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPrinter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPrinter_spec = {
    "2:PySide6.QtPrintSupport.QPrinter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPrinter_slots
};

} //extern "C"

static void *Sbk_QPrinter_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QPrinter *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPrinter_PrinterMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPrinter::PrinterMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPrinter::PrinterMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPrinter_PrinterMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterMode_IDX])))
        return Enum_PythonToCpp_QPrinter_PrinterMode;
    return {};
}
static PyObject *QPrinter_PrinterMode_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPrinter::PrinterMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPrinter_PageOrder(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPrinter::PageOrder>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPrinter::PageOrder *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPrinter_PageOrder_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PageOrder_IDX])))
        return Enum_PythonToCpp_QPrinter_PageOrder;
    return {};
}
static PyObject *QPrinter_PageOrder_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPrinter::PageOrder *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PageOrder_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPrinter_ColorMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPrinter::ColorMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPrinter::ColorMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPrinter_ColorMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_ColorMode_IDX])))
        return Enum_PythonToCpp_QPrinter_ColorMode;
    return {};
}
static PyObject *QPrinter_ColorMode_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPrinter::ColorMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_ColorMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPrinter_PaperSource(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPrinter::PaperSource>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPrinter::PaperSource *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPrinter_PaperSource_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PaperSource_IDX])))
        return Enum_PythonToCpp_QPrinter_PaperSource;
    return {};
}
static PyObject *QPrinter_PaperSource_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPrinter::PaperSource *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PaperSource_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPrinter_PrinterState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPrinter::PrinterState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPrinter::PrinterState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPrinter_PrinterState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterState_IDX])))
        return Enum_PythonToCpp_QPrinter_PrinterState;
    return {};
}
static PyObject *QPrinter_PrinterState_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPrinter::PrinterState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterState_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPrinter_OutputFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPrinter::OutputFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPrinter::OutputFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPrinter_OutputFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_OutputFormat_IDX])))
        return Enum_PythonToCpp_QPrinter_OutputFormat;
    return {};
}
static PyObject *QPrinter_OutputFormat_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPrinter::OutputFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_OutputFormat_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPrinter_PrintRange(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPrinter::PrintRange>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPrinter::PrintRange *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPrinter_PrintRange_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrintRange_IDX])))
        return Enum_PythonToCpp_QPrinter_PrintRange;
    return {};
}
static PyObject *QPrinter_PrintRange_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPrinter::PrintRange *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrintRange_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPrinter_Unit(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPrinter::Unit>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPrinter::Unit *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPrinter_Unit_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_Unit_IDX])))
        return Enum_PythonToCpp_QPrinter_Unit;
    return {};
}
static PyObject *QPrinter_Unit_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPrinter::Unit *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_Unit_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QPrinter_DuplexMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPrinter::DuplexMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPrinter::DuplexMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPrinter_DuplexMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_DuplexMode_IDX])))
        return Enum_PythonToCpp_QPrinter_DuplexMode;
    return {};
}
static PyObject *QPrinter_DuplexMode_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPrinter::DuplexMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_DuplexMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPrinter_PythonToCpp_QPrinter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPrinter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPrinter_PythonToCpp_QPrinter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPrinter_TypeF()))
        return QPrinter_PythonToCpp_QPrinter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPrinter_PTR_CppToPython_QPrinter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QPrinter *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QPrinter_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPrinter_SignatureStrings[] = {
    "1:PySide6.QtPrintSupport.QPrinter(self,mode:PySide6.QtPrintSupport.QPrinter.PrinterMode=QPrinter.PrinterMode.ScreenResolution)",
    "0:PySide6.QtPrintSupport.QPrinter(self,printer:PySide6.QtPrintSupport.QPrinterInfo,mode:PySide6.QtPrintSupport.QPrinter.PrinterMode=QPrinter.PrinterMode.ScreenResolution)",
    "PySide6.QtPrintSupport.QPrinter.abort(self)->bool",
    "PySide6.QtPrintSupport.QPrinter.collateCopies(self)->bool",
    "PySide6.QtPrintSupport.QPrinter.colorMode(self)->PySide6.QtPrintSupport.QPrinter.ColorMode",
    "PySide6.QtPrintSupport.QPrinter.copyCount(self)->int",
    "PySide6.QtPrintSupport.QPrinter.creator(self)->QString",
    "PySide6.QtPrintSupport.QPrinter.devType(self)->int",
    "PySide6.QtPrintSupport.QPrinter.docName(self)->QString",
    "PySide6.QtPrintSupport.QPrinter.duplex(self)->PySide6.QtPrintSupport.QPrinter.DuplexMode",
    "PySide6.QtPrintSupport.QPrinter.fontEmbeddingEnabled(self)->bool",
    "PySide6.QtPrintSupport.QPrinter.fromPage(self)->int",
    "PySide6.QtPrintSupport.QPrinter.fullPage(self)->bool",
    "PySide6.QtPrintSupport.QPrinter.isValid(self)->bool",
    "PySide6.QtPrintSupport.QPrinter.metric(self,arg__1:PySide6.QtGui.QPaintDevice.PaintDeviceMetric)->int",
    "PySide6.QtPrintSupport.QPrinter.newPage(self)->bool",
    "PySide6.QtPrintSupport.QPrinter.outputFileName(self)->QString",
    "PySide6.QtPrintSupport.QPrinter.outputFormat(self)->PySide6.QtPrintSupport.QPrinter.OutputFormat",
    "PySide6.QtPrintSupport.QPrinter.pageOrder(self)->PySide6.QtPrintSupport.QPrinter.PageOrder",
    "PySide6.QtPrintSupport.QPrinter.pageRect(self,arg__1:PySide6.QtPrintSupport.QPrinter.Unit)->PySide6.QtCore.QRectF",
    "PySide6.QtPrintSupport.QPrinter.paintEngine(self)->PySide6.QtGui.QPaintEngine",
    "PySide6.QtPrintSupport.QPrinter.paperRect(self,arg__1:PySide6.QtPrintSupport.QPrinter.Unit)->PySide6.QtCore.QRectF",
    "PySide6.QtPrintSupport.QPrinter.paperSource(self)->PySide6.QtPrintSupport.QPrinter.PaperSource",
    "PySide6.QtPrintSupport.QPrinter.pdfVersion(self)->PySide6.QtGui.QPagedPaintDevice.PdfVersion",
    "PySide6.QtPrintSupport.QPrinter.printEngine(self)->PySide6.QtPrintSupport.QPrintEngine",
    "PySide6.QtPrintSupport.QPrinter.printProgram(self)->QString",
    "PySide6.QtPrintSupport.QPrinter.printRange(self)->PySide6.QtPrintSupport.QPrinter.PrintRange",
    "PySide6.QtPrintSupport.QPrinter.printerName(self)->QString",
    "PySide6.QtPrintSupport.QPrinter.printerState(self)->PySide6.QtPrintSupport.QPrinter.PrinterState",
    "PySide6.QtPrintSupport.QPrinter.resolution(self)->int",
    "PySide6.QtPrintSupport.QPrinter.setCollateCopies(self,collate:bool)",
    "PySide6.QtPrintSupport.QPrinter.setColorMode(self,arg__1:PySide6.QtPrintSupport.QPrinter.ColorMode)",
    "PySide6.QtPrintSupport.QPrinter.setCopyCount(self,arg__1:int)",
    "PySide6.QtPrintSupport.QPrinter.setCreator(self,arg__1:QString)",
    "PySide6.QtPrintSupport.QPrinter.setDocName(self,arg__1:QString)",
    "PySide6.QtPrintSupport.QPrinter.setDuplex(self,duplex:PySide6.QtPrintSupport.QPrinter.DuplexMode)",
    "PySide6.QtPrintSupport.QPrinter.setEngines(self,printEngine:PySide6.QtPrintSupport.QPrintEngine,paintEngine:PySide6.QtGui.QPaintEngine)",
    "PySide6.QtPrintSupport.QPrinter.setFontEmbeddingEnabled(self,enable:bool)",
    "PySide6.QtPrintSupport.QPrinter.setFromTo(self,fromPage:int,toPage:int)",
    "PySide6.QtPrintSupport.QPrinter.setFullPage(self,arg__1:bool)",
    "PySide6.QtPrintSupport.QPrinter.setOutputFileName(self,arg__1:QString)",
    "PySide6.QtPrintSupport.QPrinter.setOutputFormat(self,format:PySide6.QtPrintSupport.QPrinter.OutputFormat)",
    "PySide6.QtPrintSupport.QPrinter.setPageOrder(self,arg__1:PySide6.QtPrintSupport.QPrinter.PageOrder)",
    "PySide6.QtPrintSupport.QPrinter.setPageSize(self,arg__1:typing.Union[PySide6.QtGui.QPageSize, PySide6.QtGui.QPageSize.PageSizeId, PySide6.QtCore.QSize])->bool",
    "PySide6.QtPrintSupport.QPrinter.setPaperSource(self,arg__1:PySide6.QtPrintSupport.QPrinter.PaperSource)",
    "PySide6.QtPrintSupport.QPrinter.setPdfVersion(self,version:PySide6.QtGui.QPagedPaintDevice.PdfVersion)",
    "PySide6.QtPrintSupport.QPrinter.setPrintProgram(self,arg__1:QString)",
    "PySide6.QtPrintSupport.QPrinter.setPrintRange(self,range:PySide6.QtPrintSupport.QPrinter.PrintRange)",
    "PySide6.QtPrintSupport.QPrinter.setPrinterName(self,arg__1:QString)",
    "PySide6.QtPrintSupport.QPrinter.setResolution(self,arg__1:int)",
    "PySide6.QtPrintSupport.QPrinter.supportedResolutions(self)->QList[int]",
    "PySide6.QtPrintSupport.QPrinter.supportsMultipleCopies(self)->bool",
    "PySide6.QtPrintSupport.QPrinter.toPage(self)->int",
    nullptr}; // Sentinel

PyTypeObject *init_QPrinter(PyObject *module)
{
    if (SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX].type != nullptr)
        return SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX].type;

    Shiboken::AutoDecRef Sbk_QPrinter_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPagedPaintDevice_IDX]))));

    _Sbk_QPrinter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPrinter",
        "QPrinter*",
        &Sbk_QPrinter_spec,
        &Shiboken::callCppDestructor< QPrinter >,
        Sbk_QPrinter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPrinter_TypeF(); // references _Sbk_QPrinter_Type
    InitSignatureStrings(pyType, QPrinter_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPrinter_PropertyStrings);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPrinter_PythonToCpp_QPrinter_PTR,
        is_QPrinter_PythonToCpp_QPrinter_PTR_Convertible,
        QPrinter_PTR_CppToPython_QPrinter);

    Shiboken::Conversions::registerConverterName(converter, "QPrinter");
    Shiboken::Conversions::registerConverterName(converter, "QPrinter*");
    Shiboken::Conversions::registerConverterName(converter, "QPrinter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPrinter).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPrinterWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPrinter_TypeF(), &Sbk_QPrinter_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPrinter_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PrinterMode'.
    const char *PrinterMode_Initializer[] = {
        "ScreenResolution",
        "PrinterResolution",
        "HighResolution",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PrinterMode_InitializerValues[] = {
        uint8_t(QPrinter::PrinterMode::ScreenResolution),  //  0x00  0
        uint8_t(QPrinter::PrinterMode::PrinterResolution), //  0x01  1
        uint8_t(QPrinter::PrinterMode::HighResolution)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPrinter_TypeF(),
        "2:PySide6.QtPrintSupport.QPrinter.PrinterMode",
        PrinterMode_Initializer, PrinterMode_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterMode_IDX].type = EType;
    // Register converter for enum 'QPrinter::PrinterMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPrinter_PrinterMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPrinter_PrinterMode,
            is_Enum_PythonToCpp_QPrinter_PrinterMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPrinter::PrinterMode");
        Shiboken::Conversions::registerConverterName(converter, "PrinterMode");
    }
    // End of 'PrinterMode' enum.

    // Initialization of enum 'PageOrder'.
    const char *PageOrder_Initializer[] = {
        "FirstPageFirst",
        "LastPageFirst",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PageOrder_InitializerValues[] = {
        uint8_t(QPrinter::PageOrder::FirstPageFirst), //  0x00  0
        uint8_t(QPrinter::PageOrder::LastPageFirst)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPrinter_TypeF(),
        "2:PySide6.QtPrintSupport.QPrinter.PageOrder",
        PageOrder_Initializer, PageOrder_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PageOrder_IDX].type = EType;
    // Register converter for enum 'QPrinter::PageOrder'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPrinter_PageOrder_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPrinter_PageOrder,
            is_Enum_PythonToCpp_QPrinter_PageOrder_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPrinter::PageOrder");
        Shiboken::Conversions::registerConverterName(converter, "PageOrder");
    }
    // End of 'PageOrder' enum.

    // Initialization of enum 'ColorMode'.
    const char *ColorMode_Initializer[] = {
        "GrayScale",
        "Color",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ColorMode_InitializerValues[] = {
        uint8_t(QPrinter::ColorMode::GrayScale), //  0x00  0
        uint8_t(QPrinter::ColorMode::Color)      //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPrinter_TypeF(),
        "2:PySide6.QtPrintSupport.QPrinter.ColorMode",
        ColorMode_Initializer, ColorMode_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_ColorMode_IDX].type = EType;
    // Register converter for enum 'QPrinter::ColorMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPrinter_ColorMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPrinter_ColorMode,
            is_Enum_PythonToCpp_QPrinter_ColorMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPrinter::ColorMode");
        Shiboken::Conversions::registerConverterName(converter, "ColorMode");
    }
    // End of 'ColorMode' enum.

    // Initialization of enum 'PaperSource'.
    const char *PaperSource_Initializer[] = {
        "OnlyOne",
        "Lower",
        "Middle",
        "Manual",
        "Envelope",
        "EnvelopeManual",
        "Auto",
        "Tractor",
        "SmallFormat",
        "LargeFormat",
        "LargeCapacity",
        "Cassette",
        "FormSource",
        "MaxPageSource",
        "CustomSource",
        "LastPaperSource",
        "Upper",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PaperSource_InitializerValues[] = {
        uint8_t(QPrinter::PaperSource::OnlyOne),         //  0x00  0
        uint8_t(QPrinter::PaperSource::Lower),           //  0x01  1
        uint8_t(QPrinter::PaperSource::Middle),          //  0x02  2
        uint8_t(QPrinter::PaperSource::Manual),          //  0x03  3
        uint8_t(QPrinter::PaperSource::Envelope),        //  0x04  4
        uint8_t(QPrinter::PaperSource::EnvelopeManual),  //  0x05  5
        uint8_t(QPrinter::PaperSource::Auto),            //  0x06  6
        uint8_t(QPrinter::PaperSource::Tractor),         //  0x07  7
        uint8_t(QPrinter::PaperSource::SmallFormat),     //  0x08  8
        uint8_t(QPrinter::PaperSource::LargeFormat),     //  0x09  9
        uint8_t(QPrinter::PaperSource::LargeCapacity),   //  0x0a  10
        uint8_t(QPrinter::PaperSource::Cassette),        //  0x0b  11
        uint8_t(QPrinter::PaperSource::FormSource),      //  0x0c  12
        uint8_t(QPrinter::PaperSource::MaxPageSource),   //  0x0d  13
        uint8_t(QPrinter::PaperSource::CustomSource),    //  0x0e  14
        uint8_t(QPrinter::PaperSource::LastPaperSource), //  0x0e  14
        uint8_t(QPrinter::PaperSource::Upper)            //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPrinter_TypeF(),
        "2:PySide6.QtPrintSupport.QPrinter.PaperSource",
        PaperSource_Initializer, PaperSource_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PaperSource_IDX].type = EType;
    // Register converter for enum 'QPrinter::PaperSource'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPrinter_PaperSource_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPrinter_PaperSource,
            is_Enum_PythonToCpp_QPrinter_PaperSource_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPrinter::PaperSource");
        Shiboken::Conversions::registerConverterName(converter, "PaperSource");
    }
    // End of 'PaperSource' enum.

    // Initialization of enum 'PrinterState'.
    const char *PrinterState_Initializer[] = {
        "Idle",
        "Active",
        "Aborted",
        "Error",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PrinterState_InitializerValues[] = {
        uint8_t(QPrinter::PrinterState::Idle),    //  0x00  0
        uint8_t(QPrinter::PrinterState::Active),  //  0x01  1
        uint8_t(QPrinter::PrinterState::Aborted), //  0x02  2
        uint8_t(QPrinter::PrinterState::Error)    //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPrinter_TypeF(),
        "2:PySide6.QtPrintSupport.QPrinter.PrinterState",
        PrinterState_Initializer, PrinterState_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterState_IDX].type = EType;
    // Register converter for enum 'QPrinter::PrinterState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPrinter_PrinterState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPrinter_PrinterState,
            is_Enum_PythonToCpp_QPrinter_PrinterState_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPrinter::PrinterState");
        Shiboken::Conversions::registerConverterName(converter, "PrinterState");
    }
    // End of 'PrinterState' enum.

    // Initialization of enum 'OutputFormat'.
    const char *OutputFormat_Initializer[] = {
        "NativeFormat",
        "PdfFormat",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OutputFormat_InitializerValues[] = {
        uint8_t(QPrinter::OutputFormat::NativeFormat), //  0x00  0
        uint8_t(QPrinter::OutputFormat::PdfFormat)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPrinter_TypeF(),
        "2:PySide6.QtPrintSupport.QPrinter.OutputFormat",
        OutputFormat_Initializer, OutputFormat_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_OutputFormat_IDX].type = EType;
    // Register converter for enum 'QPrinter::OutputFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPrinter_OutputFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPrinter_OutputFormat,
            is_Enum_PythonToCpp_QPrinter_OutputFormat_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPrinter::OutputFormat");
        Shiboken::Conversions::registerConverterName(converter, "OutputFormat");
    }
    // End of 'OutputFormat' enum.

    // Initialization of enum 'PrintRange'.
    const char *PrintRange_Initializer[] = {
        "AllPages",
        "Selection",
        "PageRange",
        "CurrentPage",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PrintRange_InitializerValues[] = {
        uint8_t(QPrinter::PrintRange::AllPages),   //  0x00  0
        uint8_t(QPrinter::PrintRange::Selection),  //  0x01  1
        uint8_t(QPrinter::PrintRange::PageRange),  //  0x02  2
        uint8_t(QPrinter::PrintRange::CurrentPage) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPrinter_TypeF(),
        "2:PySide6.QtPrintSupport.QPrinter.PrintRange",
        PrintRange_Initializer, PrintRange_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrintRange_IDX].type = EType;
    // Register converter for enum 'QPrinter::PrintRange'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPrinter_PrintRange_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPrinter_PrintRange,
            is_Enum_PythonToCpp_QPrinter_PrintRange_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPrinter::PrintRange");
        Shiboken::Conversions::registerConverterName(converter, "PrintRange");
    }
    // End of 'PrintRange' enum.

    // Initialization of enum 'Unit'.
    const char *Unit_Initializer[] = {
        "Millimeter",
        "Point",
        "Inch",
        "Pica",
        "Didot",
        "Cicero",
        "DevicePixel",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Unit_InitializerValues[] = {
        uint8_t(QPrinter::Unit::Millimeter), //  0x00  0
        uint8_t(QPrinter::Unit::Point),      //  0x01  1
        uint8_t(QPrinter::Unit::Inch),       //  0x02  2
        uint8_t(QPrinter::Unit::Pica),       //  0x03  3
        uint8_t(QPrinter::Unit::Didot),      //  0x04  4
        uint8_t(QPrinter::Unit::Cicero),     //  0x05  5
        uint8_t(QPrinter::Unit::DevicePixel) //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPrinter_TypeF(),
        "2:PySide6.QtPrintSupport.QPrinter.Unit",
        Unit_Initializer, Unit_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_Unit_IDX].type = EType;
    // Register converter for enum 'QPrinter::Unit'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPrinter_Unit_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPrinter_Unit,
            is_Enum_PythonToCpp_QPrinter_Unit_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPrinter::Unit");
        Shiboken::Conversions::registerConverterName(converter, "Unit");
    }
    // End of 'Unit' enum.

    // Initialization of enum 'DuplexMode'.
    const char *DuplexMode_Initializer[] = {
        "DuplexNone",
        "DuplexAuto",
        "DuplexLongSide",
        "DuplexShortSide",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DuplexMode_InitializerValues[] = {
        uint8_t(QPrinter::DuplexMode::DuplexNone),     //  0x00  0
        uint8_t(QPrinter::DuplexMode::DuplexAuto),     //  0x01  1
        uint8_t(QPrinter::DuplexMode::DuplexLongSide), //  0x02  2
        uint8_t(QPrinter::DuplexMode::DuplexShortSide) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPrinter_TypeF(),
        "2:PySide6.QtPrintSupport.QPrinter.DuplexMode",
        DuplexMode_Initializer, DuplexMode_InitializerValues);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_DuplexMode_IDX].type = EType;
    // Register converter for enum 'QPrinter::DuplexMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPrinter_DuplexMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPrinter_DuplexMode,
            is_Enum_PythonToCpp_QPrinter_DuplexMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPrinter::DuplexMode");
        Shiboken::Conversions::registerConverterName(converter, "DuplexMode");
    }
    // End of 'DuplexMode' enum.

    qRegisterMetaType< ::QPrinter *>();
    qRegisterMetaType< ::QPrinter::PrinterMode >("QPrinter::PrinterMode");
    qRegisterMetaType< ::QPrinter::PageOrder >("QPrinter::PageOrder");
    qRegisterMetaType< ::QPrinter::ColorMode >("QPrinter::ColorMode");
    qRegisterMetaType< ::QPrinter::PaperSource >("QPrinter::PaperSource");
    qRegisterMetaType< ::QPrinter::PrinterState >("QPrinter::PrinterState");
    qRegisterMetaType< ::QPrinter::OutputFormat >("QPrinter::OutputFormat");
    qRegisterMetaType< ::QPrinter::PrintRange >("QPrinter::PrintRange");
    qRegisterMetaType< ::QPrinter::Unit >("QPrinter::Unit");
    qRegisterMetaType< ::QPrinter::DuplexMode >("QPrinter::DuplexMode");

    return pyType;
}
