// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qjsvalue_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtCore/qlatin1stringview.h>
#include <QtQml/qjsmanagedvalue.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QJSValue_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QJSValue >()))
        return -1;

    ::QJSValue *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:QJSValue", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QJSValue::QJSValue(QJSValue::SpecialValue=)
    // 1: QJSValue::QJSValue(bool)
    // 2: QJSValue::QJSValue(QJSValue)
    // 3: QJSValue::QJSValue(QLatin1String)
    // 4: QJSValue::QJSValue(QString)
    // 5: QJSValue::QJSValue(const char*)
    // 6: QJSValue::QJSValue(double)
    // 7: QJSValue::QJSValue(int)
    // 8: QJSValue::QJSValue(uint)
    if (numArgs == 0) {
        overloadId = 0; // QJSValue(QJSValue::SpecialValue)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArgs[0])))) {
        overloadId = 3; // QJSValue(QLatin1String)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_SpecialValue_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QJSValue(QJSValue::SpecialValue)
    } else if (numArgs == 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        overloadId = 6; // QJSValue(double)
    } else if (numArgs == 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 5; // QJSValue(const char*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 4; // QJSValue(QString)
    } else if (numArgs == 1
        && PyBool_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 1; // QJSValue(bool)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))) {
        overloadId = 8; // QJSValue(uint)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 7; // QJSValue(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QJSValue(QJSValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QJSValue(QJSValue::SpecialValue value)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_value = Shiboken::String::createStaticString("value");
                if (PyDict_Contains(kwds, key_value) != 0) {
                    value = PyDict_GetItem(kwds, key_value);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_value);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_SpecialValue_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_value);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QJSValue::SpecialValue cppArg0(QJSValue::SpecialValue::UndefinedValue);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSValue(QJSValue::SpecialValue)
                cptr = new ::QJSValue(cppArg0);
            }
            break;
        }
        case 1: // QJSValue(bool value)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            bool cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSValue(bool)
                cptr = new ::QJSValue(cppArg0);
            }
            break;
        }
        case 2: // QJSValue(const QJSValue &other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QJSValue cppArg0_local;
            ::QJSValue *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSValue(QJSValue)
                cptr = new ::QJSValue(*cppArg0);
            }
            break;
        }
        case 3: // QJSValue(const QLatin1String &value)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QLatin1String cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSValue(QLatin1String)
                cptr = new ::QJSValue(cppArg0);
            }
            break;
        }
        case 4: // QJSValue(const QString &value)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSValue(QString)
                cptr = new ::QJSValue(cppArg0);
            }
            break;
        }
        case 5: // QJSValue(const char *str)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSValue(const char*)
                cptr = new ::QJSValue(cppArg0);
            }
            break;
        }
        case 6: // QJSValue(double value)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSValue(double)
                cptr = new ::QJSValue(cppArg0);
            }
            break;
        }
        case 7: // QJSValue(int value)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSValue(int)
                cptr = new ::QJSValue(cppArg0);
            }
            break;
        }
        case 8: // QJSValue(uint value)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QJSValue(uint)
                cptr = new ::QJSValue(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QJSValue >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QJSValueFunc_call(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.call";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:call", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSValue::call(const QList<QJSValue>&=)const->QJSValue
    if (numArgs == 0) {
        overloadId = 0; // call(QList<QJSValue>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[0])))) {
        overloadId = 0; // call(QList<QJSValue>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_args = Shiboken::String::createStaticString("args");
            if (PyDict_Contains(kwds, key_args) != 0) {
                value = PyDict_GetItem(kwds, key_args);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_args);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_args);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QList<QJSValue> cppArg0 = QJSValueList();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // call(QList<QJSValue>)const
            QJSValue cppResult = const_cast<const ::QJSValue *>(cppSelf)->call(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_callAsConstructor(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.callAsConstructor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:callAsConstructor", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSValue::callAsConstructor(const QList<QJSValue>&=)const->QJSValue
    if (numArgs == 0) {
        overloadId = 0; // callAsConstructor(QList<QJSValue>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[0])))) {
        overloadId = 0; // callAsConstructor(QList<QJSValue>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_args = Shiboken::String::createStaticString("args");
            if (PyDict_Contains(kwds, key_args) != 0) {
                value = PyDict_GetItem(kwds, key_args);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_args);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_args);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QList<QJSValue> cppArg0 = QJSValueList();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // callAsConstructor(QList<QJSValue>)const
            QJSValue cppResult = const_cast<const ::QJSValue *>(cppSelf)->callAsConstructor(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_callWithInstance(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.callWithInstance";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:callWithInstance", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSValue::callWithInstance(QJSValue,const QList<QJSValue>&=)const->QJSValue
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // callWithInstance(QJSValue,QList<QJSValue>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[1])))) {
            overloadId = 0; // callWithInstance(QJSValue,QList<QJSValue>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_args = Shiboken::String::createStaticString("args");
            if (PyDict_Contains(kwds, key_args) != 0) {
                value = PyDict_GetItem(kwds, key_args);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_args);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQmlTypeConverters[SBK_QtQml_QList_QJSValue_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_args);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QJSValue cppArg0_local;
        ::QJSValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QList<QJSValue> cppArg1 = QJSValueList();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // callWithInstance(QJSValue,QList<QJSValue>)const
            QJSValue cppResult = const_cast<const ::QJSValue *>(cppSelf)->callWithInstance(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_deleteProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.deleteProperty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSValue::deleteProperty(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // deleteProperty(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // deleteProperty(QString)
            bool cppResult = cppSelf->deleteProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_equals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.equals";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSValue::equals(QJSValue)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArg)))) {
        overloadId = 0; // equals(QJSValue)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSValue cppArg0_local;
        ::QJSValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // equals(QJSValue)const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->equals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_errorType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.errorType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorType()const
            QJSValue::ErrorType cppResult = const_cast<const ::QJSValue *>(cppSelf)->errorType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_ErrorType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_hasOwnProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.hasOwnProperty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSValue::hasOwnProperty(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // hasOwnProperty(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasOwnProperty(QString)const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->hasOwnProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_hasProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.hasProperty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSValue::hasProperty(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // hasProperty(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasProperty(QString)const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->hasProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isArray(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isArray()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isArray();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isBool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isBool";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isBool()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isBool();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isCallable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isCallable";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isCallable()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isCallable();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDate()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isDate();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isError()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isError();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNull()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isNull();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isNumber";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNumber()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isNumber();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isObject()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isObject();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isQMetaObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isQMetaObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isQMetaObject()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isQMetaObject();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isQObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isQObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isQObject()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isQObject();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isRegExp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isRegExp";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isRegExp()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isRegExp();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isString()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isString();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isUndefined(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isUndefined";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isUndefined()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isUndefined();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isUrl()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isUrl();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_isVariant(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.isVariant";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isVariant()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->isVariant();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_property(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.property";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSValue::property(QString)const->QJSValue
    // 1: QJSValue::property(quint32)const->QJSValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 1; // property(quint32)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // property(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // property(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // property(QString)const
                QJSValue cppResult = const_cast<const ::QJSValue *>(cppSelf)->property(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
            }
            break;
        }
        case 1: // property(quint32 arrayIndex) const
        {
            quint32 cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // property(quint32)const
                QJSValue cppResult = const_cast<const ::QJSValue *>(cppSelf)->property(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_prototype(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.prototype";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // prototype()const
            QJSValue cppResult = const_cast<const ::QJSValue *>(cppSelf)->prototype();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_setProperty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.setProperty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSValue::setProperty(QString,QJSValue)
    // 1: QJSValue::setProperty(quint32,QJSValue)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[1])))) {
        overloadId = 1; // setProperty(quint32,QJSValue)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setProperty(QString,QJSValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setProperty(const QString &name, const QJSValue &value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJSValue cppArg1_local;
            ::QJSValue *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setProperty(QString,QJSValue)
                cppSelf->setProperty(cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // setProperty(quint32 arrayIndex, const QJSValue &value)
        {
            quint32 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QJSValue cppArg1_local;
            ::QJSValue *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setProperty(quint32,QJSValue)
                cppSelf->setProperty(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJSValueFunc_setPrototype(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.setPrototype";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSValue::setPrototype(QJSValue)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArg)))) {
        overloadId = 0; // setPrototype(QJSValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSValue cppArg0_local;
        ::QJSValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPrototype(QJSValue)
            cppSelf->setPrototype(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QJSValueFunc_strictlyEquals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.strictlyEquals";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QJSValue::strictlyEquals(QJSValue)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArg)))) {
        overloadId = 0; // strictlyEquals(QJSValue)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QJSValue cppArg0_local;
        ::QJSValue *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // strictlyEquals(QJSValue)const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->strictlyEquals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_toBool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.toBool";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toBool()const
            bool cppResult = const_cast<const ::QJSValue *>(cppSelf)->toBool();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_toDateTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.toDateTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toDateTime()const
            QDateTime cppResult = const_cast<const ::QJSValue *>(cppSelf)->toDateTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_toInt(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.toInt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toInt()const
            qint32 cppResult = const_cast<const ::QJSValue *>(cppSelf)->toInt();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_toNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.toNumber";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toNumber()const
            double cppResult = const_cast<const ::QJSValue *>(cppSelf)->toNumber();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_toPrimitive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.toPrimitive";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toPrimitive()const
            QJSPrimitiveValue cppResult = const_cast<const ::QJSValue *>(cppSelf)->toPrimitive();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSPrimitiveValue_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_toQMetaObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.toQMetaObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toQMetaObject()const
            const QMetaObject * cppResult = const_cast<const ::QJSValue *>(cppSelf)->toQMetaObject();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_toQObject(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.toQObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toQObject()const
            QObject * cppResult = const_cast<const ::QJSValue *>(cppSelf)->toQObject();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.toString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString()const
            QString cppResult = const_cast<const ::QJSValue *>(cppSelf)->toString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_toUInt(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.toUInt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUInt()const
            quint32 cppResult = const_cast<const ::QJSValue *>(cppSelf)->toUInt();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc_toVariant(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.toVariant";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toVariant", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QJSValue::toVariant()const->QVariant
    // 1: QJSValue::toVariant(QJSValue::ObjectConversionBehavior)const->QVariant
    if (numArgs == 0) {
        overloadId = 0; // toVariant()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_ObjectConversionBehavior_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // toVariant(QJSValue::ObjectConversionBehavior)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toVariant() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // toVariant()const
                QVariant cppResult = const_cast<const ::QJSValue *>(cppSelf)->toVariant();
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
        case 1: // toVariant(QJSValue::ObjectConversionBehavior behavior) const
        {
            ::QJSValue::ObjectConversionBehavior cppArg0{QJSValue::ConvertJSObjects};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toVariant(QJSValue::ObjectConversionBehavior)const
                QVariant cppResult = const_cast<const ::QJSValue *>(cppSelf)->toVariant(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValue__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QJSValue_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QJSValue_EnumFlagInfo[] = {
    "ErrorType:Enum",
    "ObjectConversionBehavior:Enum",
    "SpecialValue:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QJSValue_methods[] = {
    {"call", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_call), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"callAsConstructor", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_callAsConstructor), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"callWithInstance", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_callWithInstance), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"deleteProperty", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_deleteProperty), METH_O, nullptr},
    {"equals", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_equals), METH_O, nullptr},
    {"errorType", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_errorType), METH_NOARGS, nullptr},
    {"hasOwnProperty", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_hasOwnProperty), METH_O, nullptr},
    {"hasProperty", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_hasProperty), METH_O, nullptr},
    {"isArray", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isArray), METH_NOARGS, nullptr},
    {"isBool", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isBool), METH_NOARGS, nullptr},
    {"isCallable", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isCallable), METH_NOARGS, nullptr},
    {"isDate", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isDate), METH_NOARGS, nullptr},
    {"isError", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isError), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isNull), METH_NOARGS, nullptr},
    {"isNumber", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isNumber), METH_NOARGS, nullptr},
    {"isObject", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isObject), METH_NOARGS, nullptr},
    {"isQMetaObject", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isQMetaObject), METH_NOARGS, nullptr},
    {"isQObject", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isQObject), METH_NOARGS, nullptr},
    {"isRegExp", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isRegExp), METH_NOARGS, nullptr},
    {"isString", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isString), METH_NOARGS, nullptr},
    {"isUndefined", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isUndefined), METH_NOARGS, nullptr},
    {"isUrl", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isUrl), METH_NOARGS, nullptr},
    {"isVariant", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_isVariant), METH_NOARGS, nullptr},
    {"property", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_property), METH_O, nullptr},
    {"prototype", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_prototype), METH_NOARGS, nullptr},
    {"setProperty", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_setProperty), METH_VARARGS, nullptr},
    {"setPrototype", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_setPrototype), METH_O, nullptr},
    {"strictlyEquals", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_strictlyEquals), METH_O, nullptr},
    {"toBool", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_toBool), METH_NOARGS, nullptr},
    {"toDateTime", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_toDateTime), METH_NOARGS, nullptr},
    {"toInt", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_toInt), METH_NOARGS, nullptr},
    {"toNumber", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_toNumber), METH_NOARGS, nullptr},
    {"toPrimitive", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_toPrimitive), METH_NOARGS, nullptr},
    {"toQMetaObject", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_toQMetaObject), METH_NOARGS, nullptr},
    {"toQObject", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_toQObject), METH_NOARGS, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_toString), METH_NOARGS, nullptr},
    {"toUInt", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_toUInt), METH_NOARGS, nullptr},
    {"toVariant", reinterpret_cast<PyCFunction>(Sbk_QJSValueFunc_toVariant), METH_VARARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QJSValue__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QJSValue___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

static PyObject *Sbk_QJSValueFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.__lshift__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QJSValue::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QJSValue)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QJSValue) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QJSValueFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QJSValue.__rshift__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QJSValue::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QJSValue&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QJSValue&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

} // extern "C"

static int Sbk_QJSValue_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QJSValue_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QJSValue_Type = nullptr;
static PyTypeObject *Sbk_QJSValue_TypeF(void)
{
    return _Sbk_QJSValue_Type;
}

static PyType_Slot Sbk_QJSValue_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QJSValue_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QJSValue_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QJSValue_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QJSValue_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QJSValue___nb_bool)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QJSValueFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QJSValueFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QJSValue_spec = {
    "2:PySide6.QtQml.QJSValue",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QJSValue_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QJSValue_SpecialValue(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJSValue::SpecialValue>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJSValue::SpecialValue *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QJSValue_SpecialValue_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_SpecialValue_IDX])))
        return Enum_PythonToCpp_QJSValue_SpecialValue;
    return {};
}
static PyObject *QJSValue_SpecialValue_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QJSValue::SpecialValue *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_SpecialValue_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QJSValue_ErrorType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJSValue::ErrorType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJSValue::ErrorType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QJSValue_ErrorType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_ErrorType_IDX])))
        return Enum_PythonToCpp_QJSValue_ErrorType;
    return {};
}
static PyObject *QJSValue_ErrorType_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QJSValue::ErrorType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_ErrorType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QJSValue_ObjectConversionBehavior(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QJSValue::ObjectConversionBehavior>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QJSValue::ObjectConversionBehavior *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QJSValue_ObjectConversionBehavior_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_ObjectConversionBehavior_IDX])))
        return Enum_PythonToCpp_QJSValue_ObjectConversionBehavior;
    return {};
}
static PyObject *QJSValue_ObjectConversionBehavior_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QJSValue::ObjectConversionBehavior *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_ObjectConversionBehavior_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QJSValue_PythonToCpp_QJSValue_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QJSValue_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QJSValue_PythonToCpp_QJSValue_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QJSValue_TypeF()))
        return QJSValue_PythonToCpp_QJSValue_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QJSValue_PTR_CppToPython_QJSValue(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QJSValue *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QJSValue_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QJSValue_COPY_CppToPython_QJSValue(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QJSValue *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QJSValue_TypeF(), new ::QJSValue(*source), true, true);
}

// Python to C++ copy conversion.
static void QJSValue_PythonToCpp_QJSValue_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QJSValue *>(cppOut) = *reinterpret_cast< ::QJSValue *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QJSValue_PythonToCpp_QJSValue_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QJSValue_TypeF()))
        return QJSValue_PythonToCpp_QJSValue_COPY;
    return {};
}

// Implicit conversions.
static void QJSValue_SpecialValue_PythonToCpp_QJSValue(PyObject *pyIn, void *cppOut)
{
    ::QJSValue::SpecialValue cppIn{QJSValue::NullValue};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_SpecialValue_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QJSValue *>(cppOut) = ::QJSValue(cppIn);
}
static PythonToCppFunc is_QJSValue_SpecialValue_PythonToCpp_QJSValue_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_SpecialValue_IDX]), pyIn))
        return QJSValue_SpecialValue_PythonToCpp_QJSValue;
    return {};
}

static void bool_PythonToCpp_QJSValue(PyObject *pyIn, void *cppOut)
{
    bool cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyIn, &cppIn);
    *reinterpret_cast<::QJSValue *>(cppOut) = ::QJSValue(cppIn);
}
static PythonToCppFunc is_bool_PythonToCpp_QJSValue_Convertible(PyObject *pyIn)
{
    if (PyBool_Check(pyIn))
        return bool_PythonToCpp_QJSValue;
    return {};
}

static void PySide6_QtCore_constQLatin1StringREF_PythonToCpp_QJSValue(PyObject *pyIn, void *cppOut)
{
    ::QLatin1String cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QJSValue *>(cppOut) = ::QJSValue(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_constQLatin1StringREF_PythonToCpp_QJSValue_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return PySide6_QtCore_constQLatin1StringREF_PythonToCpp_QJSValue;
    return {};
}

static void PySide6_QtCore_constQStringREF_PythonToCpp_QJSValue(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QJSValue *>(cppOut) = ::QJSValue(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_constQStringREF_PythonToCpp_QJSValue_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return PySide6_QtCore_constQStringREF_PythonToCpp_QJSValue;
    return {};
}

static void constcharPTR_PythonToCpp_QJSValue(PyObject *pyIn, void *cppOut)
{
    const char* cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), pyIn, &cppIn);
    *reinterpret_cast<::QJSValue *>(cppOut) = ::QJSValue(cppIn);
}
static PythonToCppFunc is_constcharPTR_PythonToCpp_QJSValue_Convertible(PyObject *pyIn)
{
    if (Shiboken::String::check(pyIn))
        return constcharPTR_PythonToCpp_QJSValue;
    return {};
}

static void double_PythonToCpp_QJSValue(PyObject *pyIn, void *cppOut)
{
    double cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<double>(), pyIn, &cppIn);
    *reinterpret_cast<::QJSValue *>(cppOut) = ::QJSValue(cppIn);
}
static PythonToCppFunc is_double_PythonToCpp_QJSValue_Convertible(PyObject *pyIn)
{
    if (PyFloat_Check(pyIn))
        return double_PythonToCpp_QJSValue;
    return {};
}

static void int_PythonToCpp_QJSValue(PyObject *pyIn, void *cppOut)
{
    int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn, &cppIn);
    *reinterpret_cast<::QJSValue *>(cppOut) = ::QJSValue(cppIn);
}
static PythonToCppFunc is_int_PythonToCpp_QJSValue_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return int_PythonToCpp_QJSValue;
    return {};
}

static void PySide6_QtCore_uint_PythonToCpp_QJSValue(PyObject *pyIn, void *cppOut)
{
    uint cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), pyIn, &cppIn);
    *reinterpret_cast<::QJSValue *>(cppOut) = ::QJSValue(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_uint_PythonToCpp_QJSValue_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return PySide6_QtCore_uint_PythonToCpp_QJSValue;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QJSValue_SignatureStrings[] = {
    "8:PySide6.QtQml.QJSValue(self,value:PySide6.QtQml.QJSValue.SpecialValue=QJSValue.SpecialValue.UndefinedValue)",
    "7:PySide6.QtQml.QJSValue(self,value:bool)",
    "6:PySide6.QtQml.QJSValue(self,other:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])",
    "5:PySide6.QtQml.QJSValue(self,value:QLatin1String)",
    "4:PySide6.QtQml.QJSValue(self,value:QString)",
    "3:PySide6.QtQml.QJSValue(self,str:char*)",
    "2:PySide6.QtQml.QJSValue(self,value:double)",
    "1:PySide6.QtQml.QJSValue(self,value:int)",
    "0:PySide6.QtQml.QJSValue(self,value:uint)",
    "PySide6.QtQml.QJSValue.call(self,args:QList[PySide6.QtQml.QJSValue]=QJSValueList())->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSValue.callAsConstructor(self,args:QList[PySide6.QtQml.QJSValue]=QJSValueList())->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSValue.callWithInstance(self,instance:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint],args:QList[PySide6.QtQml.QJSValue]=QJSValueList())->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSValue.deleteProperty(self,name:QString)->bool",
    "PySide6.QtQml.QJSValue.equals(self,other:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])->bool",
    "PySide6.QtQml.QJSValue.errorType(self)->PySide6.QtQml.QJSValue.ErrorType",
    "PySide6.QtQml.QJSValue.hasOwnProperty(self,name:QString)->bool",
    "PySide6.QtQml.QJSValue.hasProperty(self,name:QString)->bool",
    "PySide6.QtQml.QJSValue.isArray(self)->bool",
    "PySide6.QtQml.QJSValue.isBool(self)->bool",
    "PySide6.QtQml.QJSValue.isCallable(self)->bool",
    "PySide6.QtQml.QJSValue.isDate(self)->bool",
    "PySide6.QtQml.QJSValue.isError(self)->bool",
    "PySide6.QtQml.QJSValue.isNull(self)->bool",
    "PySide6.QtQml.QJSValue.isNumber(self)->bool",
    "PySide6.QtQml.QJSValue.isObject(self)->bool",
    "PySide6.QtQml.QJSValue.isQMetaObject(self)->bool",
    "PySide6.QtQml.QJSValue.isQObject(self)->bool",
    "PySide6.QtQml.QJSValue.isRegExp(self)->bool",
    "PySide6.QtQml.QJSValue.isString(self)->bool",
    "PySide6.QtQml.QJSValue.isUndefined(self)->bool",
    "PySide6.QtQml.QJSValue.isUrl(self)->bool",
    "PySide6.QtQml.QJSValue.isVariant(self)->bool",
    "1:PySide6.QtQml.QJSValue.property(self,name:QString)->PySide6.QtQml.QJSValue",
    "0:PySide6.QtQml.QJSValue.property(self,arrayIndex:quint32)->PySide6.QtQml.QJSValue",
    "PySide6.QtQml.QJSValue.prototype(self)->PySide6.QtQml.QJSValue",
    "1:PySide6.QtQml.QJSValue.setProperty(self,name:QString,value:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])",
    "0:PySide6.QtQml.QJSValue.setProperty(self,arrayIndex:quint32,value:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])",
    "PySide6.QtQml.QJSValue.setPrototype(self,prototype:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])",
    "PySide6.QtQml.QJSValue.strictlyEquals(self,other:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint])->bool",
    "PySide6.QtQml.QJSValue.toBool(self)->bool",
    "PySide6.QtQml.QJSValue.toDateTime(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtQml.QJSValue.toInt(self)->qint32",
    "PySide6.QtQml.QJSValue.toNumber(self)->double",
    "PySide6.QtQml.QJSValue.toPrimitive(self)->PySide6.QtQml.QJSPrimitiveValue",
    "PySide6.QtQml.QJSValue.toQMetaObject(self)->PySide6.QtCore.QMetaObject",
    "PySide6.QtQml.QJSValue.toQObject(self)->PySide6.QtCore.QObject",
    "PySide6.QtQml.QJSValue.toString(self)->QString",
    "PySide6.QtQml.QJSValue.toUInt(self)->quint32",
    "1:PySide6.QtQml.QJSValue.toVariant(self)->QVariant",
    "0:PySide6.QtQml.QJSValue.toVariant(self,behavior:PySide6.QtQml.QJSValue.ObjectConversionBehavior)->QVariant",
    "PySide6.QtQml.QJSValue.__copy__()",
    "PySide6.QtQml.QJSValue.__lshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtQml.QJSValue.__rshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    nullptr}; // Sentinel

PyTypeObject *init_QJSValue(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX].type;

    Shiboken::AutoDecRef Sbk_QJSValue_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QJSValue_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QJSValue",
        "QJSValue",
        &Sbk_QJSValue_spec,
        &Shiboken::callCppDestructor< ::QJSValue >,
        Sbk_QJSValue_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QJSValue_TypeF(); // references _Sbk_QJSValue_Type
    InitSignatureStrings(pyType, QJSValue_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QJSValue_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QJSValue_PythonToCpp_QJSValue_PTR,
        is_QJSValue_PythonToCpp_QJSValue_PTR_Convertible,
        QJSValue_PTR_CppToPython_QJSValue,
        QJSValue_COPY_CppToPython_QJSValue);

    Shiboken::Conversions::registerConverterName(converter, "QJSValue");
    Shiboken::Conversions::registerConverterName(converter, "QJSValue*");
    Shiboken::Conversions::registerConverterName(converter, "QJSValue&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QJSValue).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QJSValue_PythonToCpp_QJSValue_COPY,
        is_QJSValue_PythonToCpp_QJSValue_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QJSValue_SpecialValue_PythonToCpp_QJSValue,
        is_QJSValue_SpecialValue_PythonToCpp_QJSValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        bool_PythonToCpp_QJSValue,
        is_bool_PythonToCpp_QJSValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQLatin1StringREF_PythonToCpp_QJSValue,
        is_PySide6_QtCore_constQLatin1StringREF_PythonToCpp_QJSValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQStringREF_PythonToCpp_QJSValue,
        is_PySide6_QtCore_constQStringREF_PythonToCpp_QJSValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constcharPTR_PythonToCpp_QJSValue,
        is_constcharPTR_PythonToCpp_QJSValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        double_PythonToCpp_QJSValue,
        is_double_PythonToCpp_QJSValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        int_PythonToCpp_QJSValue,
        is_int_PythonToCpp_QJSValue_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_uint_PythonToCpp_QJSValue,
        is_PySide6_QtCore_uint_PythonToCpp_QJSValue_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QJSValue_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SpecialValue'.
    const char *SpecialValue_Initializer[] = {
        "NullValue",
        "UndefinedValue",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SpecialValue_InitializerValues[] = {
        uint8_t(QJSValue::SpecialValue::NullValue),     //  0x00  0
        uint8_t(QJSValue::SpecialValue::UndefinedValue) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJSValue_TypeF(),
        "2:PySide6.QtQml.QJSValue.SpecialValue",
        SpecialValue_Initializer, SpecialValue_InitializerValues);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_SpecialValue_IDX].type = EType;
    // Register converter for enum 'QJSValue::SpecialValue'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJSValue_SpecialValue_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QJSValue_SpecialValue,
            is_Enum_PythonToCpp_QJSValue_SpecialValue_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QJSValue::SpecialValue");
        Shiboken::Conversions::registerConverterName(converter, "SpecialValue");
    }
    // End of 'SpecialValue' enum.

    // Initialization of enum 'ErrorType'.
    const char *ErrorType_Initializer[] = {
        "NoError",
        "GenericError",
        "EvalError",
        "RangeError",
        "ReferenceError",
        "SyntaxError",
        "TypeError",
        "URIError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ErrorType_InitializerValues[] = {
        uint8_t(QJSValue::ErrorType::NoError),        //  0x00  0
        uint8_t(QJSValue::ErrorType::GenericError),   //  0x01  1
        uint8_t(QJSValue::ErrorType::EvalError),      //  0x02  2
        uint8_t(QJSValue::ErrorType::RangeError),     //  0x03  3
        uint8_t(QJSValue::ErrorType::ReferenceError), //  0x04  4
        uint8_t(QJSValue::ErrorType::SyntaxError),    //  0x05  5
        uint8_t(QJSValue::ErrorType::TypeError),      //  0x06  6
        uint8_t(QJSValue::ErrorType::URIError)        //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJSValue_TypeF(),
        "2:PySide6.QtQml.QJSValue.ErrorType",
        ErrorType_Initializer, ErrorType_InitializerValues);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_ErrorType_IDX].type = EType;
    // Register converter for enum 'QJSValue::ErrorType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJSValue_ErrorType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QJSValue_ErrorType,
            is_Enum_PythonToCpp_QJSValue_ErrorType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QJSValue::ErrorType");
        Shiboken::Conversions::registerConverterName(converter, "ErrorType");
    }
    // End of 'ErrorType' enum.

    // Initialization of enum 'ObjectConversionBehavior'.
    const char *ObjectConversionBehavior_Initializer[] = {
        "ConvertJSObjects",
        "RetainJSObjects",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ObjectConversionBehavior_InitializerValues[] = {
        uint8_t(QJSValue::ObjectConversionBehavior::ConvertJSObjects), //  0x00  0
        uint8_t(QJSValue::ObjectConversionBehavior::RetainJSObjects)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QJSValue_TypeF(),
        "2:PySide6.QtQml.QJSValue.ObjectConversionBehavior",
        ObjectConversionBehavior_Initializer, ObjectConversionBehavior_InitializerValues);
    SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_ObjectConversionBehavior_IDX].type = EType;
    // Register converter for enum 'QJSValue::ObjectConversionBehavior'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QJSValue_ObjectConversionBehavior_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QJSValue_ObjectConversionBehavior,
            is_Enum_PythonToCpp_QJSValue_ObjectConversionBehavior_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QJSValue::ObjectConversionBehavior");
        Shiboken::Conversions::registerConverterName(converter, "ObjectConversionBehavior");
    }
    // End of 'ObjectConversionBehavior' enum.

    qRegisterMetaType< ::QJSValue >("QJSValue");
    qRegisterMetaType< ::QJSValue::SpecialValue >("QJSValue::SpecialValue");
    qRegisterMetaType< ::QJSValue::ErrorType >("QJSValue::ErrorType");
    qRegisterMetaType< ::QJSValue::ObjectConversionBehavior >("QJSValue::ObjectConversionBehavior");

    return pyType;
}
