// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtsensors_python.h"

// main header
#include "qsensorplugininterface_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSensorPluginInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSensorPluginInterfaceWrapper::QSensorPluginInterfaceWrapper() : QSensorPluginInterface()
{
    resetPyMethodCache();
    // ... middle
}

void QSensorPluginInterfaceWrapper::registerSensors()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSensorPluginInterface.registerSensors");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "registerSensors";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSensorPluginInterface.registerSensors");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QSensorPluginInterfaceWrapper::~QSensorPluginInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSensorPluginInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorPluginInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSensorPluginInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSensorPluginInterface >()))
        return -1;

    QSensorPluginInterfaceWrapper *cptr{};
    static const char fullName[] = "PySide6.QtSensors.QSensorPluginInterface.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSensorPluginInterface()
            cptr = new QSensorPluginInterfaceWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSensorPluginInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSensorPluginInterfaceFunc_registerSensors(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSensorPluginInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorPluginInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtSensors.QSensorPluginInterface.registerSensors";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // registerSensors()
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSensorPluginInterface.registerSensors");
                return {};
            }
            cppSelf->registerSensors();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QSensorPluginInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSensorPluginInterface_methods[] = {
    {"registerSensors", reinterpret_cast<PyCFunction>(Sbk_QSensorPluginInterfaceFunc_registerSensors), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSensorPluginInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSensorPluginInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSensorsTypeStructs[SBK_QSensorPluginInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSensorPluginInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSensorPluginInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSensorPluginInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSensorPluginInterface_Type = nullptr;
static PyTypeObject *Sbk_QSensorPluginInterface_TypeF(void)
{
    return _Sbk_QSensorPluginInterface_Type;
}

static PyType_Slot Sbk_QSensorPluginInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSensorPluginInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSensorPluginInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSensorPluginInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSensorPluginInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSensorPluginInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSensorPluginInterface_spec = {
    "2:PySide6.QtSensors.QSensorPluginInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSensorPluginInterface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSensorPluginInterface_PythonToCpp_QSensorPluginInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSensorPluginInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSensorPluginInterface_PythonToCpp_QSensorPluginInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSensorPluginInterface_TypeF()))
        return QSensorPluginInterface_PythonToCpp_QSensorPluginInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSensorPluginInterface_PTR_CppToPython_QSensorPluginInterface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QSensorPluginInterface *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QSensorPluginInterface_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSensorPluginInterface_SignatureStrings[] = {
    "PySide6.QtSensors.QSensorPluginInterface(self)",
    "PySide6.QtSensors.QSensorPluginInterface.registerSensors(self)",
    nullptr}; // Sentinel

PyTypeObject *init_QSensorPluginInterface(PyObject *module)
{
    if (SbkPySide6_QtSensorsTypeStructs[SBK_QSensorPluginInterface_IDX].type != nullptr)
        return SbkPySide6_QtSensorsTypeStructs[SBK_QSensorPluginInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QSensorPluginInterface_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSensorPluginInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSensorPluginInterface",
        "QSensorPluginInterface*",
        &Sbk_QSensorPluginInterface_spec,
        &Shiboken::callCppDestructor< QSensorPluginInterface >,
        Sbk_QSensorPluginInterface_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSensorPluginInterface_TypeF(); // references _Sbk_QSensorPluginInterface_Type
    InitSignatureStrings(pyType, QSensorPluginInterface_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSensorPluginInterface_PropertyStrings);
    SbkPySide6_QtSensorsTypeStructs[SBK_QSensorPluginInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSensorPluginInterface_PythonToCpp_QSensorPluginInterface_PTR,
        is_QSensorPluginInterface_PythonToCpp_QSensorPluginInterface_PTR_Convertible,
        QSensorPluginInterface_PTR_CppToPython_QSensorPluginInterface);

    Shiboken::Conversions::registerConverterName(converter, "QSensorPluginInterface");
    Shiboken::Conversions::registerConverterName(converter, "QSensorPluginInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QSensorPluginInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSensorPluginInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSensorPluginInterfaceWrapper).name());

    qRegisterMetaType< ::QSensorPluginInterface *>();

    return pyType;
}
