// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qmodbusexceptionresponse_wrapper.h"

// Argument includes
#include <QtSerialBus/qmodbuspdu.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QModbusExceptionResponseWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QModbusExceptionResponseWrapper::QModbusExceptionResponseWrapper() : QModbusExceptionResponse()
{
    resetPyMethodCache();
    // ... middle
}

QModbusExceptionResponseWrapper::QModbusExceptionResponseWrapper(::QModbusPdu::FunctionCode fc, ::QModbusPdu::ExceptionCode ec) : QModbusExceptionResponse(fc, ec)
{
    resetPyMethodCache();
    // ... middle
}

QModbusExceptionResponseWrapper::QModbusExceptionResponseWrapper(const ::QModbusPdu & pdu) : QModbusExceptionResponse(pdu)
{
    resetPyMethodCache();
    // ... middle
}

void QModbusExceptionResponseWrapper::setFunctionCode(::QModbusPdu::FunctionCode c)
{
    if (m_PyMethodCache[0]) {
        return this->::QModbusExceptionResponse::setFunctionCode(c);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setFunctionCode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QModbusExceptionResponse::setFunctionCode(c);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, &c)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, &c)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QModbusExceptionResponseWrapper::~QModbusExceptionResponseWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModbusExceptionResponse_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModbusExceptionResponse >()))
        return -1;

    QModbusExceptionResponseWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QModbusExceptionResponse.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QModbusExceptionResponse", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModbusExceptionResponse::QModbusExceptionResponse()
    // 1: QModbusExceptionResponse::QModbusExceptionResponse(QModbusPdu::FunctionCode,QModbusPdu::ExceptionCode)
    // 2: QModbusExceptionResponse::QModbusExceptionResponse(QModbusPdu)
    if (numArgs == 0) {
        overloadId = 0; // QModbusExceptionResponse()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QModbusExceptionResponse(QModbusPdu)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_ExceptionCode_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 1; // QModbusExceptionResponse(QModbusPdu::FunctionCode,QModbusPdu::ExceptionCode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QModbusExceptionResponse()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusExceptionResponse()
                cptr = new QModbusExceptionResponseWrapper();
            }
            break;
        }
        case 1: // QModbusExceptionResponse(QModbusPdu::FunctionCode fc, QModbusPdu::ExceptionCode ec)
        {
            ::QModbusPdu::FunctionCode cppArg0{QModbusPdu::Invalid};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QModbusPdu::ExceptionCode cppArg1 = static_cast< ::QModbusPdu::ExceptionCode>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusExceptionResponse(QModbusPdu::FunctionCode,QModbusPdu::ExceptionCode)
                cptr = new QModbusExceptionResponseWrapper(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QModbusExceptionResponse(const QModbusPdu &pdu)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModbusPdu *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusExceptionResponse(QModbusPdu)
                cptr = new QModbusExceptionResponseWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QModbusExceptionResponse >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QModbusExceptionResponseFunc_setExceptionCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusExceptionResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusExceptionResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QModbusExceptionResponse.setExceptionCode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusExceptionResponse::setExceptionCode(QModbusPdu::ExceptionCode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_ExceptionCode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setExceptionCode(QModbusPdu::ExceptionCode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QModbusPdu::ExceptionCode cppArg0 = static_cast< ::QModbusPdu::ExceptionCode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExceptionCode(QModbusPdu::ExceptionCode)
            cppSelf->setExceptionCode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QModbusExceptionResponseFunc_setFunctionCode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusExceptionResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusExceptionResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QModbusExceptionResponse.setFunctionCode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QModbusPdu::setFunctionCode(QModbusPdu::FunctionCode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFunctionCode(QModbusPdu::FunctionCode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QModbusPdu::FunctionCode cppArg0{QModbusPdu::Invalid};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFunctionCode(QModbusPdu::FunctionCode)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QModbusExceptionResponse::setFunctionCode(cppArg0)
                : cppSelf->setFunctionCode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QModbusExceptionResponse_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModbusExceptionResponse_methods[] = {
    {"setExceptionCode", reinterpret_cast<PyCFunction>(Sbk_QModbusExceptionResponseFunc_setExceptionCode), METH_O, nullptr},
    {"setFunctionCode", reinterpret_cast<PyCFunction>(Sbk_QModbusExceptionResponseFunc_setFunctionCode), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QModbusExceptionResponse_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QModbusExceptionResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusExceptionResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QModbusExceptionResponseWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QModbusExceptionResponse_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModbusExceptionResponse_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModbusExceptionResponse_Type = nullptr;
static PyTypeObject *Sbk_QModbusExceptionResponse_TypeF(void)
{
    return _Sbk_QModbusExceptionResponse_Type;
}

static PyType_Slot Sbk_QModbusExceptionResponse_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QModbusExceptionResponse_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModbusExceptionResponse_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModbusExceptionResponse_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModbusExceptionResponse_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModbusExceptionResponse_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModbusExceptionResponse_spec = {
    "2:PySide6.QtSerialBus.QModbusExceptionResponse",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModbusExceptionResponse_slots
};

} //extern "C"

static void *Sbk_QModbusExceptionResponse_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QModbusPdu >())
        return dynamic_cast< ::QModbusExceptionResponse *>(reinterpret_cast< ::QModbusPdu *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModbusExceptionResponse_PythonToCpp_QModbusExceptionResponse_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModbusExceptionResponse_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModbusExceptionResponse_PythonToCpp_QModbusExceptionResponse_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusExceptionResponse_TypeF()))
        return QModbusExceptionResponse_PythonToCpp_QModbusExceptionResponse_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModbusExceptionResponse_PTR_CppToPython_QModbusExceptionResponse(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QModbusExceptionResponse *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QModbusExceptionResponse_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QModbusExceptionResponse_SignatureStrings[] = {
    "2:PySide6.QtSerialBus.QModbusExceptionResponse(self)",
    "1:PySide6.QtSerialBus.QModbusExceptionResponse(self,fc:PySide6.QtSerialBus.QModbusPdu.FunctionCode,ec:PySide6.QtSerialBus.QModbusPdu.ExceptionCode)",
    "0:PySide6.QtSerialBus.QModbusExceptionResponse(self,pdu:PySide6.QtSerialBus.QModbusPdu)",
    "PySide6.QtSerialBus.QModbusExceptionResponse.setExceptionCode(self,ec:PySide6.QtSerialBus.QModbusPdu.ExceptionCode)",
    "PySide6.QtSerialBus.QModbusExceptionResponse.setFunctionCode(self,c:PySide6.QtSerialBus.QModbusPdu.FunctionCode)",
    nullptr}; // Sentinel

PyTypeObject *init_QModbusExceptionResponse(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusExceptionResponse_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusExceptionResponse_IDX].type;

    Shiboken::AutoDecRef Sbk_QModbusExceptionResponse_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]))));

    _Sbk_QModbusExceptionResponse_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModbusExceptionResponse",
        "QModbusExceptionResponse*",
        &Sbk_QModbusExceptionResponse_spec,
        &Shiboken::callCppDestructor< QModbusExceptionResponse >,
        Sbk_QModbusExceptionResponse_Type_bases.object(),
        0);
    auto *pyType = Sbk_QModbusExceptionResponse_TypeF(); // references _Sbk_QModbusExceptionResponse_Type
    InitSignatureStrings(pyType, QModbusExceptionResponse_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModbusExceptionResponse_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusExceptionResponse_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModbusExceptionResponse_PythonToCpp_QModbusExceptionResponse_PTR,
        is_QModbusExceptionResponse_PythonToCpp_QModbusExceptionResponse_PTR_Convertible,
        QModbusExceptionResponse_PTR_CppToPython_QModbusExceptionResponse);

    Shiboken::Conversions::registerConverterName(converter, "QModbusExceptionResponse");
    Shiboken::Conversions::registerConverterName(converter, "QModbusExceptionResponse*");
    Shiboken::Conversions::registerConverterName(converter, "QModbusExceptionResponse&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusExceptionResponse).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QModbusExceptionResponseWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QModbusExceptionResponse_TypeF(), &Sbk_QModbusExceptionResponse_typeDiscovery);

    qRegisterMetaType< ::QModbusExceptionResponse *>();

    return pyType;
}
