// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qmodbusresponse_wrapper.h"

// Argument includes
#include <QtSerialBus/qmodbuspdu.h>
#include <qbytearray.h>
#include <qdatastream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QModbusResponseWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QModbusResponseWrapper::QModbusResponseWrapper() : QModbusResponse()
{
    resetPyMethodCache();
    // ... middle
}

QModbusResponseWrapper::QModbusResponseWrapper(::QModbusPdu::FunctionCode code, const ::QByteArray & newData) : QModbusResponse(code, newData)
{
    resetPyMethodCache();
    // ... middle
}

QModbusResponseWrapper::QModbusResponseWrapper(const ::QModbusPdu & pdu) : QModbusResponse(pdu)
{
    resetPyMethodCache();
    // ... middle
}

void QModbusResponseWrapper::setFunctionCode(::QModbusPdu::FunctionCode code)
{
    if (m_PyMethodCache[0]) {
        return this->::QModbusPdu::setFunctionCode(code);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setFunctionCode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QModbusPdu::setFunctionCode(code);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, &code)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, &code)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QModbusResponseWrapper::~QModbusResponseWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QModbusResponse_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QModbusResponse >()))
        return -1;

    QModbusResponseWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QModbusResponse.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QModbusResponse", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QModbusResponse::QModbusResponse()
    // 1: QModbusResponse::QModbusResponse(QModbusPdu::FunctionCode,const QByteArray&=)
    // 2: QModbusResponse::QModbusResponse(QModbusPdu)
    if (numArgs == 0) {
        overloadId = 0; // QModbusResponse()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QModbusResponse(QModbusPdu)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_FunctionCode_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QModbusResponse(QModbusPdu::FunctionCode,QByteArray)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QModbusResponse(QModbusPdu::FunctionCode,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QModbusResponse()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusResponse()
                cptr = new QModbusResponseWrapper();
            }
            break;
        }
        case 1: // QModbusResponse(QModbusPdu::FunctionCode code, const QByteArray &newData)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_newData = Shiboken::String::createStaticString("newData");
                if (PyDict_Contains(kwds, key_newData) != 0) {
                    value = PyDict_GetItem(kwds, key_newData);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_newData);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_newData);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QModbusPdu::FunctionCode cppArg0{QModbusPdu::Invalid};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QByteArray cppArg1_local = QByteArray();
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusResponse(QModbusPdu::FunctionCode,QByteArray)
                cptr = new QModbusResponseWrapper(cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // QModbusResponse(const QModbusPdu &pdu)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QModbusPdu *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QModbusResponse(QModbusPdu)
                cptr = new QModbusResponseWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QModbusResponse >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QModbusResponseFunc_calculateDataSize(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QModbusResponse.calculateDataSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QModbusResponse::calculateDataSize(QModbusResponse)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), (pyArg)))) {
        overloadId = 0; // calculateDataSize(QModbusResponse)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModbusResponse *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // calculateDataSize(QModbusResponse)
            int cppResult = ::QModbusResponse::calculateDataSize(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusResponseFunc_minimumDataSize(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QModbusResponse.minimumDataSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QModbusResponse::minimumDataSize(QModbusResponse)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), (pyArg)))) {
        overloadId = 0; // minimumDataSize(QModbusResponse)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModbusResponse *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumDataSize(QModbusResponse)
            int cppResult = ::QModbusResponse::minimumDataSize(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QModbusResponse_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QModbusResponse_methods[] = {
    {"calculateDataSize", reinterpret_cast<PyCFunction>(Sbk_QModbusResponseFunc_calculateDataSize), METH_O|METH_STATIC, nullptr},
    {"minimumDataSize", reinterpret_cast<PyCFunction>(Sbk_QModbusResponseFunc_minimumDataSize), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QModbusResponse_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QModbusResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QModbusResponseWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QModbusResponseFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QModbusResponse.__lshift__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QModbusResponse::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QModbusResponse)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QModbusResponse) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QModbusResponseFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QModbusResponse *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QModbusResponse.__rshift__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QModbusResponse::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QModbusResponse&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QModbusResponse&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

} // extern "C"

static int Sbk_QModbusResponse_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QModbusResponse_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QModbusResponse_Type = nullptr;
static PyTypeObject *Sbk_QModbusResponse_TypeF(void)
{
    return _Sbk_QModbusResponse_Type;
}

static PyType_Slot Sbk_QModbusResponse_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QModbusResponse_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QModbusResponse_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QModbusResponse_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QModbusResponse_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QModbusResponse_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QModbusResponseFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QModbusResponseFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QModbusResponse_spec = {
    "2:PySide6.QtSerialBus.QModbusResponse",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QModbusResponse_slots
};

} //extern "C"

static void *Sbk_QModbusResponse_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QModbusPdu >())
        return dynamic_cast< ::QModbusResponse *>(reinterpret_cast< ::QModbusPdu *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QModbusResponse_PythonToCpp_QModbusResponse_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QModbusResponse_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QModbusResponse_PythonToCpp_QModbusResponse_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QModbusResponse_TypeF()))
        return QModbusResponse_PythonToCpp_QModbusResponse_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QModbusResponse_PTR_CppToPython_QModbusResponse(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QModbusResponse *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QModbusResponse_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QModbusResponse_SignatureStrings[] = {
    "2:PySide6.QtSerialBus.QModbusResponse(self)",
    "1:PySide6.QtSerialBus.QModbusResponse(self,code:PySide6.QtSerialBus.QModbusPdu.FunctionCode,newData:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())",
    "0:PySide6.QtSerialBus.QModbusResponse(self,pdu:PySide6.QtSerialBus.QModbusPdu)",
    "PySide6.QtSerialBus.QModbusResponse.calculateDataSize(pdu:PySide6.QtSerialBus.QModbusResponse)->int",
    "PySide6.QtSerialBus.QModbusResponse.minimumDataSize(pdu:PySide6.QtSerialBus.QModbusResponse)->int",
    "PySide6.QtSerialBus.QModbusResponse.__lshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtSerialBus.QModbusResponse.__rshift__(self,stream:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    nullptr}; // Sentinel

PyTypeObject *init_QModbusResponse(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX].type;

    Shiboken::AutoDecRef Sbk_QModbusResponse_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX]))));

    _Sbk_QModbusResponse_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QModbusResponse",
        "QModbusResponse*",
        &Sbk_QModbusResponse_spec,
        &Shiboken::callCppDestructor< QModbusResponse >,
        Sbk_QModbusResponse_Type_bases.object(),
        0);
    auto *pyType = Sbk_QModbusResponse_TypeF(); // references _Sbk_QModbusResponse_Type
    InitSignatureStrings(pyType, QModbusResponse_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QModbusResponse_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QModbusResponse_PythonToCpp_QModbusResponse_PTR,
        is_QModbusResponse_PythonToCpp_QModbusResponse_PTR_Convertible,
        QModbusResponse_PTR_CppToPython_QModbusResponse);

    Shiboken::Conversions::registerConverterName(converter, "QModbusResponse");
    Shiboken::Conversions::registerConverterName(converter, "QModbusResponse*");
    Shiboken::Conversions::registerConverterName(converter, "QModbusResponse&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QModbusResponse).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QModbusResponseWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QModbusResponse_TypeF(), &Sbk_QModbusResponse_typeDiscovery);

    qRegisterMetaType< ::QModbusResponse *>();

    return pyType;
}
