// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <signature.h>
#include <sbkcontainer.h>
#include <sbkstaticstrings.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysidecleanup.h>
#include <pysideqenum.h>
#include <feature_select.h>
#include <pysidestaticstrings.h>
#include "pyside6_qtserialbus_python.h"

#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QtSerialBus/qcanbusdevice.h>
#include <QtSerialBus/qcanbusdeviceinfo.h>
#include <QtSerialBus/qcanbusframe.h>
#include <QtSerialBus/qcancommondefinitions.h>
#include <QtSerialBus/qcanmessagedescription.h>
#include <QtSerialBus/qcansignaldescription.h>
#include <QtSerialBus/qmodbusdataunit.h>
#include <QtSerialBus/qmodbusdevice.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qvariant.h>


// Current module's type array.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtSerialBusTypeStructs = nullptr;
// Backwards compatible structure with identical indexing.
PyTypeObject **SbkPySide6_QtSerialBusTypes = nullptr;
// Current module's PyObject pointer.
PyObject *SbkPySide6_QtSerialBusModuleObject = nullptr;
// Current module's converter array.
SbkConverter **SbkPySide6_QtSerialBusTypeConverters = nullptr;

void cleanTypesAttributes() {
    static PyObject *attrName = Shiboken::PyName::qtStaticMetaObject();
    const int imax = SBK_QtSerialBus_IDX_COUNT;
    for (int i = 0; i < imax && SbkPySide6_QtSerialBusTypeStructs[i].fullName != nullptr; ++i) {
        auto *pyType = reinterpret_cast<PyObject *>(SbkPySide6_QtSerialBusTypeStructs[i].type);
        if (pyType != nullptr && PyObject_HasAttr(pyType, attrName))
            PyObject_SetAttr(pyType, attrName, Py_None);
    }
}

// Global functions ------------------------------------------------------------

static PyMethodDef QtSerialBus_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
PyTypeObject *init_QtSerialBusQtCanBus(PyObject *module);
PyTypeObject *init_QModbusTcpConnectionObserver(PyObject *module);
PyTypeObject *init_QModbusPdu(PyObject *module);
PyTypeObject *init_QModbusDeviceIdentification(PyObject *module);
PyTypeObject *init_QModbusDataUnit(PyObject *module);
PyTypeObject *init_QCanUniqueIdDescription(PyObject *module);
PyTypeObject *init_QCanSignalDescription(PyObject *module);
PyTypeObject *init_QCanSignalDescription_MultiplexValueRange(PyObject *enclosingClass);
PyTypeObject *init_QCanMessageDescription(PyObject *module);
PyTypeObject *init_QCanFrameProcessor(PyObject *module);
PyTypeObject *init_QCanFrameProcessor_ParseResult(PyObject *enclosingClass);
PyTypeObject *init_QCanDbcFileParser(PyObject *module);
PyTypeObject *init_QCanBusFrame(PyObject *module);
PyTypeObject *init_QCanBusFrame_TimeStamp(PyObject *enclosingClass);
PyTypeObject *init_QCanBusFactory(PyObject *module);
PyTypeObject *init_QCanBusDeviceInfo(PyObject *module);
PyTypeObject *init_QModbusReply(PyObject *module);
PyTypeObject *init_QModbusDevice(PyObject *module);
PyTypeObject *init_QModbusServer(PyObject *module);
PyTypeObject *init_QModbusTcpServer(PyObject *module);
PyTypeObject *init_QModbusRtuSerialServer(PyObject *module);
PyTypeObject *init_QModbusClient(PyObject *module);
PyTypeObject *init_QModbusTcpClient(PyObject *module);
PyTypeObject *init_QModbusRtuSerialClient(PyObject *module);
PyTypeObject *init_QCanBusDevice(PyObject *module);
PyTypeObject *init_QCanBusDevice_Filter(PyObject *enclosingClass);
PyTypeObject *init_QCanBus(PyObject *module);
PyTypeObject *init_QModbusResponse(PyObject *module);
PyTypeObject *init_QModbusExceptionResponse(PyObject *module);
PyTypeObject *init_QModbusRequest(PyObject *module);

// Required modules' type and converter arrays.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtCoreTypeStructs;
SbkConverter **SbkPySide6_QtCoreTypeConverters;
Shiboken::Module::TypeInitStruct *SbkPySide6_QtNetworkTypeStructs;
SbkConverter **SbkPySide6_QtNetworkTypeConverters;
Shiboken::Module::TypeInitStruct *SbkPySide6_QtSerialPortTypeStructs;
SbkConverter **SbkPySide6_QtSerialPortTypeConverters;

// Module initialization ------------------------------------------------------------
// Container Type converters.

// C++ to Python conversion for container type 'QList<int>'.
static PyObject *_QList_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp__QList_int_;
    return {};
}


// Binding for QList<int>

template <>
struct ShibokenContainerValueConverter<int>
{
    static bool checkValue(PyObject *pyArg)
    {
        return PyLong_Check(pyArg);
    }

    static PyObject *convertValueToPython(int cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg);
    }

    static std::optional<int> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!(PyLong_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        int cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QIntList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QIntList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QIntList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QIntList_spec = {
    "2:PySide6.QtSerialBus.QIntList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QIntList_slots
};

static inline PyTypeObject *createQIntListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QIntList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QIntList_TypeF()
{
    static PyTypeObject *type = createQIntListType();
    return type;
}

extern "C" PyObject *createQIntList(QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQIntList(const QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = const_cast<QList<int> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QIntList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QIntList_TypeF();
}

extern "C" void PythonToCppQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QList<int>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQIntListPythonToCppConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToCppQIntList;
    return {};
}

// C++ to Python conversion for container type 'QList<quint16>'.
static PyObject *_QList_quint16__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<quint16> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_quint16_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<quint16> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        quint16 cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_quint16__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), pyIn))
        return PySequence_PythonToCpp__QList_quint16_;
    return {};
}

// C++ to Python conversion for container type 'QList<QCanSignalDescription::MultiplexValueRange>'.
static PyObject *_QList_QCanSignalDescription_MultiplexValueRange__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QCanSignalDescription::MultiplexValueRange> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanSignalDescription_MultiplexValueRange_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QCanSignalDescription_MultiplexValueRange_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QCanSignalDescription::MultiplexValueRange> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QCanSignalDescription::MultiplexValueRange cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanSignalDescription_MultiplexValueRange_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QCanSignalDescription_MultiplexValueRange__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanSignalDescription_MultiplexValueRange_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QCanSignalDescription_MultiplexValueRange_;
    return {};
}

// C++ to Python conversion for container type 'QHash<QString,QList< QCanSignalDescription::MultiplexValueRange>>'.
static PyObject *_QHash_QString_QList_QCanSignalDescription_MultiplexValueRange___CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<QString,QList< QCanSignalDescription::MultiplexValueRange>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_MultiplexValueRange_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QHash_QString_QList_QCanSignalDescription_MultiplexValueRange__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<QString,QList< QCanSignalDescription::MultiplexValueRange>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QList<QCanSignalDescription::MultiplexValueRange> cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_MultiplexValueRange_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QHash_QString_QList_QCanSignalDescription_MultiplexValueRange___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_MultiplexValueRange_IDX], false, pyIn))
        return PyDict_PythonToCpp__QHash_QString_QList_QCanSignalDescription_MultiplexValueRange__;
    return {};
}

// C++ to Python conversion for container type 'QList<QCanSignalDescription>'.
static PyObject *_QList_QCanSignalDescription__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QCanSignalDescription> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanSignalDescription_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QCanSignalDescription_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QCanSignalDescription> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QCanSignalDescription cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanSignalDescription_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QCanSignalDescription__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanSignalDescription_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QCanSignalDescription_;
    return {};
}

// C++ to Python conversion for container type 'QList<QCanMessageDescription>'.
static PyObject *_QList_QCanMessageDescription__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QCanMessageDescription> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QCanMessageDescription_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QCanMessageDescription> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QCanMessageDescription cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QCanMessageDescription__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanMessageDescription_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QCanMessageDescription_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QString,QVariant>'.
static PyObject *_QMap_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_QString_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QHash<unsigned int,QString>'.
static PyObject *_QHash_unsignedint_QString__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<unsigned int,QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QHash_unsignedint_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<unsigned int,QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        unsigned int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), key, &(cppKey));
        ::QString cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QHash_unsignedint_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), false, SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, pyIn))
        return PyDict_PythonToCpp__QHash_unsignedint_QString_;
    return {};
}

// C++ to Python conversion for container type 'QHash<QString,QHash< unsigned int,QString>>'.
static PyObject *_QHash_QString_QHash_unsignedint_QString___CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<QString,QHash< unsigned int,QString>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_unsignedint_QString_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QHash_QString_QHash_unsignedint_QString__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<QString,QHash< unsigned int,QString>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QHash<unsigned int,QString> cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_unsignedint_QString_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QHash_QString_QHash_unsignedint_QString___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_unsignedint_QString_IDX], false, pyIn))
        return PyDict_PythonToCpp__QHash_QString_QHash_unsignedint_QString__;
    return {};
}

// C++ to Python conversion for container type 'QHash<QtCanBus::UniqueId,QHash< QString,QHash< unsigned int,QString>>>'.
static PyObject *_QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString____CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<QtCanBus::UniqueId,QHash< QString,QHash< unsigned int,QString>>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QtCanBus_UniqueId_IDX])))->converter, &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QString_QHash_unsignedint_QString_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString___(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<QtCanBus::UniqueId,QHash< QString,QHash< unsigned int,QString>>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QtCanBus::UniqueId cppKey = static_cast< ::QtCanBus::UniqueId>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QtCanBus_UniqueId_IDX])))->converter, key, &(cppKey));
        ::QHash<QString,QHash< unsigned int,QString>> cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QString_QHash_unsignedint_QString_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString____Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QtCanBus_UniqueId_IDX])))->converter, false, SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QString_QHash_unsignedint_QString_IDX], false, pyIn))
        return PyDict_PythonToCpp__QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString___;
    return {};
}

// C++ to Python conversion for container type 'QList<QCanBusDeviceInfo>'.
static PyObject *_QList_QCanBusDeviceInfo__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QCanBusDeviceInfo> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QCanBusDeviceInfo_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QCanBusDeviceInfo> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QCanBusDeviceInfo* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(*cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QCanBusDeviceInfo__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDeviceInfo_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QCanBusDeviceInfo_;
    return {};
}

// C++ to Python conversion for container type 'QList<QObject*>'.
static PyObject *_QList_QObjectPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QObject*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QObjectPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QObject*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QObject* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QObjectPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QByteArray>'.
static PyObject *_QList_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QModbusDevice::IntermediateError>'.
static PyObject *_QList_QModbusDevice_IntermediateError__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QModbusDevice::IntermediateError> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IntermediateError_IDX])))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QModbusDevice_IntermediateError_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QModbusDevice::IntermediateError> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QModbusDevice::IntermediateError cppItem{QModbusDevice::ResponseCrcError};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IntermediateError_IDX])))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QModbusDevice_IntermediateError__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IntermediateError_IDX])))->converter, pyIn))
        return PySequence_PythonToCpp__QList_QModbusDevice_IntermediateError_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QModbusDataUnit::RegisterType,QModbusDataUnit>'.
static PyObject *_QMap_QModbusDataUnit_RegisterType_QModbusDataUnit__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QModbusDataUnit::RegisterType,QModbusDataUnit> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_RegisterType_IDX])))->converter, &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QModbusDataUnit_RegisterType_QModbusDataUnit_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QModbusDataUnit::RegisterType,QModbusDataUnit> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QModbusDataUnit::RegisterType cppKey{QModbusDataUnit::Invalid};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_RegisterType_IDX])))->converter, key, &(cppKey));
        ::QModbusDataUnit cppValue;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX]), value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QModbusDataUnit_RegisterType_QModbusDataUnit__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_RegisterType_IDX])))->converter, false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDataUnit_IDX])))->converter, false, pyIn))
        return PyDict_PythonToCpp__QMap_QModbusDataUnit_RegisterType_QModbusDataUnit_;
    return {};
}

// C++ to Python conversion for container type 'QList<QCanBusDevice::ConfigurationKey>'.
static PyObject *_QList_QCanBusDevice_ConfigurationKey__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QCanBusDevice::ConfigurationKey> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_ConfigurationKey_IDX])))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QCanBusDevice_ConfigurationKey_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QCanBusDevice::ConfigurationKey> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QCanBusDevice::ConfigurationKey cppItem{QCanBusDevice::RawFilterKey};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_ConfigurationKey_IDX])))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QCanBusDevice_ConfigurationKey__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_ConfigurationKey_IDX])))->converter, pyIn))
        return PySequence_PythonToCpp__QList_QCanBusDevice_ConfigurationKey_;
    return {};
}

// C++ to Python conversion for container type 'QList<QCanBusFrame>'.
static PyObject *_QList_QCanBusFrame__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QCanBusFrame> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QCanBusFrame_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QCanBusFrame> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QCanBusFrame cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QCanBusFrame__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QCanBusFrame_;
    return {};
}

// C++ to Python conversion for container type 'QList<QVariant>'.
static PyObject *_QList_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVariant cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QString>'.
static PyObject *_QList_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QString_;
    return {};
}


static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtSerialBus",
    /* m_doc      */ nullptr,
    /* m_size     */ -1,
    /* m_methods  */ QtSerialBus_methods,
    /* m_reload   */ nullptr,
    /* m_traverse */ nullptr,
    /* m_clear    */ nullptr,
    /* m_free     */ nullptr
};

// The signatures string for the global functions.
// Multiple signatures have their index "n:" in front.
static const char *QtSerialBus_SignatureStrings[] = {
    nullptr}; // Sentinel

static void initInheritance()
{
    auto &bm = Shiboken::BindingManager::instance();
    SBK_UNUSED(bm)
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusReply_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusServer_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusServer_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpServer_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusServer_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialServer_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusDevice_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusTcpClient_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusClient_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRtuSerialClient_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBus_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusResponse_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusExceptionResponse_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusPdu_IDX],
                           &SbkPySide6_QtSerialBusTypeStructs[SBK_QModbusRequest_IDX]);
}

extern "C" LIBSHIBOKEN_EXPORT PyObject *PyInit_QtSerialBus()
{
    if (SbkPySide6_QtSerialBusModuleObject != nullptr)
        return SbkPySide6_QtSerialBusModuleObject;
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtCoreTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtNetwork"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtNetworkTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtNetworkTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtSerialPort"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtSerialPortTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtSerialPortTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    // Create an array of wrapper types/names for the current module.
    static Shiboken::Module::TypeInitStruct cppApi[] = {
        {nullptr, "PySide6.QtSerialBus.QCanBus"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDevice"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDevice.CanBusDeviceState"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDevice.CanBusError"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDevice.CanBusStatus"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDevice.ConfigurationKey"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDevice.Direction"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDevice.Filter"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDevice.Filter.FormatFilter"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDeviceInfo"},
        {nullptr, "PySide6.QtSerialBus.QCanBusFactory"},
        {nullptr, "PySide6.QtSerialBus.QCanBusFrame"},
        {nullptr, "PySide6.QtSerialBus.QCanBusFrame.FrameError"},
        {nullptr, "PySide6.QtSerialBus.QCanBusFrame.FrameType"},
        {nullptr, "PySide6.QtSerialBus.QCanBusFrame.TimeStamp"},
        {nullptr, "PySide6.QtSerialBus.QCanDbcFileParser"},
        {nullptr, "PySide6.QtSerialBus.QCanDbcFileParser.Error"},
        {nullptr, "PySide6.QtSerialBus.QCanFrameProcessor"},
        {nullptr, "PySide6.QtSerialBus.QCanFrameProcessor.Error"},
        {nullptr, "PySide6.QtSerialBus.QCanFrameProcessor.ParseResult"},
        {nullptr, "PySide6.QtSerialBus.QCanMessageDescription"},
        {nullptr, "PySide6.QtSerialBus.QCanSignalDescription"},
        {nullptr, "PySide6.QtSerialBus.QCanSignalDescription.MultiplexValueRange"},
        {nullptr, "PySide6.QtSerialBus.QCanUniqueIdDescription"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDevice.Directions"},
        {nullptr, "PySide6.QtSerialBus.QCanBusDevice.Filter.FormatFilters"},
        {nullptr, "PySide6.QtSerialBus.QCanBusFrame.FrameErrors"},
        {nullptr, "PySide6.QtSerialBus.QModbusClient"},
        {nullptr, "PySide6.QtSerialBus.QModbusDataUnit"},
        {nullptr, "PySide6.QtSerialBus.QModbusDataUnit.RegisterType"},
        {nullptr, "PySide6.QtSerialBus.QModbusDevice"},
        {nullptr, "PySide6.QtSerialBus.QModbusDevice.ConnectionParameter"},
        {nullptr, "PySide6.QtSerialBus.QModbusDevice.Error"},
        {nullptr, "PySide6.QtSerialBus.QModbusDevice.IntermediateError"},
        {nullptr, "PySide6.QtSerialBus.QModbusDevice.State"},
        {nullptr, "PySide6.QtSerialBus.QModbusDeviceIdentification"},
        {nullptr, "PySide6.QtSerialBus.QModbusDeviceIdentification.ConformityLevel"},
        {nullptr, "PySide6.QtSerialBus.QModbusDeviceIdentification.ObjectId"},
        {nullptr, "PySide6.QtSerialBus.QModbusDeviceIdentification.ReadDeviceIdCode"},
        {nullptr, "PySide6.QtSerialBus.QModbusExceptionResponse"},
        {nullptr, "PySide6.QtSerialBus.QModbusPdu"},
        {nullptr, "PySide6.QtSerialBus.QModbusPdu.ExceptionCode"},
        {nullptr, "PySide6.QtSerialBus.QModbusPdu.FunctionCode"},
        {nullptr, "PySide6.QtSerialBus.QModbusReply"},
        {nullptr, "PySide6.QtSerialBus.QModbusReply.ReplyType"},
        {nullptr, "PySide6.QtSerialBus.QModbusRequest"},
        {nullptr, "PySide6.QtSerialBus.QModbusResponse"},
        {nullptr, "PySide6.QtSerialBus.QModbusRtuSerialClient"},
        {nullptr, "PySide6.QtSerialBus.QModbusRtuSerialServer"},
        {nullptr, "PySide6.QtSerialBus.QModbusServer"},
        {nullptr, "PySide6.QtSerialBus.QModbusServer.Option"},
        {nullptr, "PySide6.QtSerialBus.QModbusTcpClient"},
        {nullptr, "PySide6.QtSerialBus.QModbusTcpConnectionObserver"},
        {nullptr, "PySide6.QtSerialBus.QModbusTcpServer"},
        {nullptr, "PySide6.QtSerialBus.QtCanBus"},
        {nullptr, "PySide6.QtSerialBus.QtCanBus.DataFormat"},
        {nullptr, "PySide6.QtSerialBus.QtCanBus.DataSource"},
        {nullptr, "PySide6.QtSerialBus.QtCanBus.MultiplexState"},
        {nullptr, "PySide6.QtSerialBus.QtCanBus.UniqueId"},
        {nullptr, nullptr}
    };
    // The new global structure consisting of (type, name) pairs.
    SbkPySide6_QtSerialBusTypeStructs = cppApi;
    QT_WARNING_PUSH
    QT_WARNING_DISABLE_DEPRECATED
    // The backward compatible alias with upper case indexes.
    SbkPySide6_QtSerialBusTypes = reinterpret_cast<PyTypeObject **>(cppApi);
    QT_WARNING_POP

    // Create an array of primitive type converters for the current module.
    static SbkConverter *sbkConverters[SBK_QtSerialBus_CONVERTERS_IDX_COUNT];
    SbkPySide6_QtSerialBusTypeConverters = sbkConverters;

    PyObject *module = Shiboken::Module::create("QtSerialBus", &moduledef);

    // Make module available from global scope
    SbkPySide6_QtSerialBusModuleObject = module;

    // Initialize classes in the type system
    Shiboken::Module::AddTypeCreationFunction(module, "QtCanBus", init_QtSerialBusQtCanBus);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusTcpConnectionObserver", init_QModbusTcpConnectionObserver);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusPdu", init_QModbusPdu);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusDeviceIdentification", init_QModbusDeviceIdentification);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusDataUnit", init_QModbusDataUnit);
    Shiboken::Module::AddTypeCreationFunction(module, "QCanUniqueIdDescription", init_QCanUniqueIdDescription);
    Shiboken::Module::AddTypeCreationFunction(module, "QCanSignalDescription", init_QCanSignalDescription);
    Shiboken::Module::AddTypeCreationFunction(module, "MultiplexValueRange", init_QCanSignalDescription_MultiplexValueRange, "QCanSignalDescription");
    Shiboken::Module::AddTypeCreationFunction(module, "QCanMessageDescription", init_QCanMessageDescription);
    Shiboken::Module::AddTypeCreationFunction(module, "QCanFrameProcessor", init_QCanFrameProcessor);
    Shiboken::Module::AddTypeCreationFunction(module, "ParseResult", init_QCanFrameProcessor_ParseResult, "QCanFrameProcessor");
    Shiboken::Module::AddTypeCreationFunction(module, "QCanDbcFileParser", init_QCanDbcFileParser);
    Shiboken::Module::AddTypeCreationFunction(module, "QCanBusFrame", init_QCanBusFrame);
    Shiboken::Module::AddTypeCreationFunction(module, "TimeStamp", init_QCanBusFrame_TimeStamp, "QCanBusFrame");
    Shiboken::Module::AddTypeCreationFunction(module, "QCanBusFactory", init_QCanBusFactory);
    Shiboken::Module::AddTypeCreationFunction(module, "QCanBusDeviceInfo", init_QCanBusDeviceInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusReply", init_QModbusReply);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusDevice", init_QModbusDevice);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusServer", init_QModbusServer);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusTcpServer", init_QModbusTcpServer);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusRtuSerialServer", init_QModbusRtuSerialServer);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusClient", init_QModbusClient);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusTcpClient", init_QModbusTcpClient);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusRtuSerialClient", init_QModbusRtuSerialClient);
    Shiboken::Module::AddTypeCreationFunction(module, "QCanBusDevice", init_QCanBusDevice);
    Shiboken::Module::AddTypeCreationFunction(module, "Filter", init_QCanBusDevice_Filter, "QCanBusDevice");
    Shiboken::Module::AddTypeCreationFunction(module, "QCanBus", init_QCanBus);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusResponse", init_QModbusResponse);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusExceptionResponse", init_QModbusExceptionResponse);
    Shiboken::Module::AddTypeCreationFunction(module, "QModbusRequest", init_QModbusRequest);

    // Register converter for type 'QList<int>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_int_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_int_IDX], "QList<int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_int_IDX],
        PySequence_PythonToCpp__QList_int_,
        is_PySequence_PythonToCpp__QList_int__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_int_IDX],
        PythonToCppQIntList,
        isQIntListPythonToCppConvertible);

    // Register converter for type 'QList<quint16>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_quint16_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_quint16__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_quint16_IDX], "QList<quint16>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_quint16_IDX],
        PySequence_PythonToCpp__QList_quint16_,
        is_PySequence_PythonToCpp__QList_quint16__Convertible);

    // Register converter for type 'QList<QCanSignalDescription::MultiplexValueRange>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_MultiplexValueRange_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QCanSignalDescription_MultiplexValueRange__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_MultiplexValueRange_IDX], "QList<QCanSignalDescription::MultiplexValueRange>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_MultiplexValueRange_IDX],
        PySequence_PythonToCpp__QList_QCanSignalDescription_MultiplexValueRange_,
        is_PySequence_PythonToCpp__QList_QCanSignalDescription_MultiplexValueRange__Convertible);
    // Register converters for type aliases of QList<QCanSignalDescription::MultiplexValueRange>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_MultiplexValueRange_IDX], "QCanSignalDescription::MultiplexValues");

    // Register converter for type 'QHash<QString,QList<QCanSignalDescription::MultiplexValueRange>>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QString_QList_QCanSignalDescription_MultiplexValueRange_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QHash_QString_QList_QCanSignalDescription_MultiplexValueRange___CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QString_QList_QCanSignalDescription_MultiplexValueRange_IDX], "QHash<QString,QList<QCanSignalDescription::MultiplexValueRange>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QString_QList_QCanSignalDescription_MultiplexValueRange_IDX],
        PyDict_PythonToCpp__QHash_QString_QList_QCanSignalDescription_MultiplexValueRange__,
        is_PyDict_PythonToCpp__QHash_QString_QList_QCanSignalDescription_MultiplexValueRange___Convertible);

    // Register converter for type 'QList<QCanSignalDescription>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QCanSignalDescription__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_IDX], "QList<QCanSignalDescription>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanSignalDescription_IDX],
        PySequence_PythonToCpp__QList_QCanSignalDescription_,
        is_PySequence_PythonToCpp__QList_QCanSignalDescription__Convertible);

    // Register converter for type 'QList<QCanMessageDescription>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanMessageDescription_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QCanMessageDescription__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanMessageDescription_IDX], "QList<QCanMessageDescription>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanMessageDescription_IDX],
        PySequence_PythonToCpp__QList_QCanMessageDescription_,
        is_PySequence_PythonToCpp__QList_QCanMessageDescription__Convertible);

    // Register converter for type 'QMap<QString,QVariant>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QMap_QString_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QMap_QString_QVariant_IDX], "QMap<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QMap_QString_QVariant_IDX],
        PyDict_PythonToCpp__QMap_QString_QVariant_,
        is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible);
    // Register converters for type aliases of QMap<QString,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QMap_QString_QVariant_IDX], "QVariantMap");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QMap_QString_QVariant_IDX], "QSettings::SettingsMap");

    // Register converter for type 'QHash<unsigned int,QString>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_unsignedint_QString_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QHash_unsignedint_QString__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_unsignedint_QString_IDX], "QHash<unsigned int,QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_unsignedint_QString_IDX],
        PyDict_PythonToCpp__QHash_unsignedint_QString_,
        is_PyDict_PythonToCpp__QHash_unsignedint_QString__Convertible);

    // Register converter for type 'QHash<QString,QHash<unsigned int,QString>>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QString_QHash_unsignedint_QString_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QHash_QString_QHash_unsignedint_QString___CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QString_QHash_unsignedint_QString_IDX], "QHash<QString,QHash<unsigned int,QString>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QString_QHash_unsignedint_QString_IDX],
        PyDict_PythonToCpp__QHash_QString_QHash_unsignedint_QString__,
        is_PyDict_PythonToCpp__QHash_QString_QHash_unsignedint_QString___Convertible);

    // Register converter for type 'QHash<QtCanBus::UniqueId,QHash<QString,QHash<unsigned int,QString>>>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString____CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString_IDX], "QHash<QtCanBus::UniqueId,QHash<QString,QHash<unsigned int,QString>>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString_IDX],
        PyDict_PythonToCpp__QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString___,
        is_PyDict_PythonToCpp__QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString____Convertible);

    // Register converter for type 'QList<QCanBusDeviceInfo>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusDeviceInfo_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QCanBusDeviceInfo__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusDeviceInfo_IDX], "QList<QCanBusDeviceInfo>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusDeviceInfo_IDX],
        PySequence_PythonToCpp__QList_QCanBusDeviceInfo_,
        is_PySequence_PythonToCpp__QList_QCanBusDeviceInfo__Convertible);

    // Register converter for type 'QList<QObject*>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QObjectPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QObjectPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QObjectPTR_IDX], "QList<QObject*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QObjectPTR_IDX],
        PySequence_PythonToCpp__QList_QObjectPTR_,
        is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible);
    // Register converters for type aliases of QList<QObject*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QObjectPTR_IDX], "QObjectList");

    // Register converter for type 'QList<QByteArray>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QByteArray_IDX], "QList<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QByteArray_IDX],
        PySequence_PythonToCpp__QList_QByteArray_,
        is_PySequence_PythonToCpp__QList_QByteArray__Convertible);
    // Register converters for type aliases of QList<QByteArray>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QByteArray_IDX], "QByteArrayList");

    // Register converter for type 'QList<QModbusDevice::IntermediateError>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QModbusDevice_IntermediateError_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QModbusDevice_IntermediateError__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QModbusDevice_IntermediateError_IDX], "QList<QModbusDevice::IntermediateError>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QModbusDevice_IntermediateError_IDX],
        PySequence_PythonToCpp__QList_QModbusDevice_IntermediateError_,
        is_PySequence_PythonToCpp__QList_QModbusDevice_IntermediateError__Convertible);

    // Register converter for type 'QMap<QModbusDataUnit::RegisterType,QModbusDataUnit>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QMap_QModbusDataUnit_RegisterType_QModbusDataUnit_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QModbusDataUnit_RegisterType_QModbusDataUnit__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QMap_QModbusDataUnit_RegisterType_QModbusDataUnit_IDX], "QMap<QModbusDataUnit::RegisterType,QModbusDataUnit>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QMap_QModbusDataUnit_RegisterType_QModbusDataUnit_IDX],
        PyDict_PythonToCpp__QMap_QModbusDataUnit_RegisterType_QModbusDataUnit_,
        is_PyDict_PythonToCpp__QMap_QModbusDataUnit_RegisterType_QModbusDataUnit__Convertible);
    // Register converters for type aliases of QMap<QModbusDataUnit::RegisterType,QModbusDataUnit>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QMap_QModbusDataUnit_RegisterType_QModbusDataUnit_IDX], "QModbusDataUnitMap");

    // Register converter for type 'QList<QCanBusDevice::ConfigurationKey>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusDevice_ConfigurationKey_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QCanBusDevice_ConfigurationKey__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusDevice_ConfigurationKey_IDX], "QList<QCanBusDevice::ConfigurationKey>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusDevice_ConfigurationKey_IDX],
        PySequence_PythonToCpp__QList_QCanBusDevice_ConfigurationKey_,
        is_PySequence_PythonToCpp__QList_QCanBusDevice_ConfigurationKey__Convertible);

    // Register converter for type 'QList<QCanBusFrame>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusFrame_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QCanBusFrame__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusFrame_IDX], "QList<QCanBusFrame>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanBusFrame_IDX],
        PySequence_PythonToCpp__QList_QCanBusFrame_,
        is_PySequence_PythonToCpp__QList_QCanBusFrame__Convertible);

    // Register converter for type 'QList<QVariant>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QVariant_IDX], "QList<QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QVariant_IDX],
        PySequence_PythonToCpp__QList_QVariant_,
        is_PySequence_PythonToCpp__QList_QVariant__Convertible);
    // Register converters for type aliases of QList<QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QVariant_IDX], "QVariantList");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QVariant_IDX], "QVariantList");

    // Register converter for type 'QList<QString>'.
    SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QString_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QString_IDX], "QList<QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QString_IDX],
        PySequence_PythonToCpp__QList_QString_,
        is_PySequence_PythonToCpp__QList_QString__Convertible);
    // Register converters for type aliases of QList<QString>'.


    // Opaque container type registration
    PyObject *ob_type{};
    ob_type = reinterpret_cast<PyObject *>(QIntList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QIntList", ob_type);

    // Register primitive types converters.
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "__caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__clock_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__clockid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_d_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__fsword_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__sig_atomic_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__socklen_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__syscall_slong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__syscall_ulong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__time_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__useconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "comparison_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), "qInternalCallback");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "register_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "useconds_t");

    Shiboken::Module::registerTypes(module, SbkPySide6_QtSerialBusTypeStructs);
    Shiboken::Module::registerTypeConverters(module, SbkPySide6_QtSerialBusTypeConverters);

    initInheritance();

    if (Shiboken::Errors::occurred() != nullptr) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtSerialBus");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);

    FinishSignatureInitialization(module, QtSerialBus_SignatureStrings);

    return module;
}
