// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialport_python.h"

// main header
#include "qserialportinfo_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtSerialPort/qserialport.h>
#include <QtSerialPort/qserialportinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSerialPortInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSerialPortInfo >()))
        return -1;

    ::QSerialPortInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSerialPortInfo", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSerialPortInfo::QSerialPortInfo()
    // 1: QSerialPortInfo::QSerialPortInfo(QSerialPort)
    // 2: QSerialPortInfo::QSerialPortInfo(QSerialPortInfo)
    // 3: QSerialPortInfo::QSerialPortInfo(QString)
    if (numArgs == 0) {
        overloadId = 0; // QSerialPortInfo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 3; // QSerialPortInfo(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QSerialPortInfo(QSerialPortInfo)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPort_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QSerialPortInfo(QSerialPort)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSerialPortInfo()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSerialPortInfo()
                cptr = new ::QSerialPortInfo();
            }
            break;
        }
        case 1: // QSerialPortInfo(const QSerialPort &port)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSerialPort *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSerialPortInfo(QSerialPort)
                cptr = new ::QSerialPortInfo(*cppArg0);
            }
            break;
        }
        case 2: // QSerialPortInfo(const QSerialPortInfo &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSerialPortInfo cppArg0_local;
            ::QSerialPortInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QSerialPortInfo(QSerialPortInfo)
                cptr = new ::QSerialPortInfo(*cppArg0);
            }
            break;
        }
        case 3: // QSerialPortInfo(const QString &name)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSerialPortInfo(QString)
                cptr = new ::QSerialPortInfo(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSerialPortInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSerialPortInfoFunc_availablePorts(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.availablePorts";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // availablePorts()
            QList<QSerialPortInfo> cppResult = ::QSerialPortInfo::availablePorts();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialPortTypeConverters[SBK_QtSerialPort_QList_QSerialPortInfo_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.description";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // description()const
            QString cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->description();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_hasProductIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.hasProductIdentifier";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasProductIdentifier()const
            bool cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->hasProductIdentifier();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_hasVendorIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.hasVendorIdentifier";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasVendorIdentifier()const
            bool cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->hasVendorIdentifier();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.isNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNull()const
            bool cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->isNull();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_manufacturer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.manufacturer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // manufacturer()const
            QString cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->manufacturer();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_portName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.portName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // portName()const
            QString cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->portName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_productIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.productIdentifier";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // productIdentifier()const
            quint16 cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->productIdentifier();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_serialNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.serialNumber";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // serialNumber()const
            QString cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->serialNumber();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_standardBaudRates(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.standardBaudRates";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // standardBaudRates()
            QList<qint32> cppResult = ::QSerialPortInfo::standardBaudRates();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialPortTypeConverters[SBK_QtSerialPort_QList_qint32_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSerialPortInfo::swap(QSerialPortInfo&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QSerialPortInfo&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSerialPortInfo cppArg0_local;
        ::QSerialPortInfo *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QSerialPortInfo&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSerialPortInfoFunc_systemLocation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.systemLocation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // systemLocation()const
            QString cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->systemLocation();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfoFunc_vendorIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialPort.QSerialPortInfo.vendorIdentifier";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // vendorIdentifier()const
            quint16 cppResult = const_cast<const ::QSerialPortInfo *>(cppSelf)->vendorIdentifier();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSerialPortInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSerialPortInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSerialPortInfo_methods[] = {
    {"availablePorts", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_availablePorts), METH_NOARGS|METH_STATIC, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_description), METH_NOARGS, nullptr},
    {"hasProductIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_hasProductIdentifier), METH_NOARGS, nullptr},
    {"hasVendorIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_hasVendorIdentifier), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_isNull), METH_NOARGS, nullptr},
    {"manufacturer", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_manufacturer), METH_NOARGS, nullptr},
    {"portName", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_portName), METH_NOARGS, nullptr},
    {"productIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_productIdentifier), METH_NOARGS, nullptr},
    {"serialNumber", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_serialNumber), METH_NOARGS, nullptr},
    {"standardBaudRates", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_standardBaudRates), METH_NOARGS|METH_STATIC, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_swap), METH_O, nullptr},
    {"systemLocation", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_systemLocation), METH_NOARGS, nullptr},
    {"vendorIdentifier", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfoFunc_vendorIdentifier), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QSerialPortInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSerialPortInfo___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QSerialPortInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSerialPortInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSerialPortInfo_Type = nullptr;
static PyTypeObject *Sbk_QSerialPortInfo_TypeF(void)
{
    return _Sbk_QSerialPortInfo_Type;
}

static PyType_Slot Sbk_QSerialPortInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSerialPortInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSerialPortInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSerialPortInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSerialPortInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QSerialPortInfo___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSerialPortInfo_spec = {
    "2:PySide6.QtSerialPort.QSerialPortInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSerialPortInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSerialPortInfo_PythonToCpp_QSerialPortInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSerialPortInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSerialPortInfo_PythonToCpp_QSerialPortInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSerialPortInfo_TypeF()))
        return QSerialPortInfo_PythonToCpp_QSerialPortInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSerialPortInfo_PTR_CppToPython_QSerialPortInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QSerialPortInfo *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QSerialPortInfo_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QSerialPortInfo_COPY_CppToPython_QSerialPortInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QSerialPortInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QSerialPortInfo_TypeF(), new ::QSerialPortInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QSerialPortInfo_PythonToCpp_QSerialPortInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QSerialPortInfo *>(cppOut) = *reinterpret_cast< ::QSerialPortInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QSerialPortInfo_PythonToCpp_QSerialPortInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QSerialPortInfo_TypeF()))
        return QSerialPortInfo_PythonToCpp_QSerialPortInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSerialPortInfo_SignatureStrings[] = {
    "3:PySide6.QtSerialPort.QSerialPortInfo(self)",
    "2:PySide6.QtSerialPort.QSerialPortInfo(self,port:PySide6.QtSerialPort.QSerialPort)",
    "1:PySide6.QtSerialPort.QSerialPortInfo(self,other:PySide6.QtSerialPort.QSerialPortInfo)",
    "0:PySide6.QtSerialPort.QSerialPortInfo(self,name:QString)",
    "PySide6.QtSerialPort.QSerialPortInfo.availablePorts()->QList[PySide6.QtSerialPort.QSerialPortInfo]",
    "PySide6.QtSerialPort.QSerialPortInfo.description(self)->QString",
    "PySide6.QtSerialPort.QSerialPortInfo.hasProductIdentifier(self)->bool",
    "PySide6.QtSerialPort.QSerialPortInfo.hasVendorIdentifier(self)->bool",
    "PySide6.QtSerialPort.QSerialPortInfo.isNull(self)->bool",
    "PySide6.QtSerialPort.QSerialPortInfo.manufacturer(self)->QString",
    "PySide6.QtSerialPort.QSerialPortInfo.portName(self)->QString",
    "PySide6.QtSerialPort.QSerialPortInfo.productIdentifier(self)->quint16",
    "PySide6.QtSerialPort.QSerialPortInfo.serialNumber(self)->QString",
    "PySide6.QtSerialPort.QSerialPortInfo.standardBaudRates()->QList[qint32]",
    "PySide6.QtSerialPort.QSerialPortInfo.swap(self,other:PySide6.QtSerialPort.QSerialPortInfo)",
    "PySide6.QtSerialPort.QSerialPortInfo.systemLocation(self)->QString",
    "PySide6.QtSerialPort.QSerialPortInfo.vendorIdentifier(self)->quint16",
    "PySide6.QtSerialPort.QSerialPortInfo.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QSerialPortInfo(PyObject *module)
{
    if (SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX].type != nullptr)
        return SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QSerialPortInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSerialPortInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSerialPortInfo",
        "QSerialPortInfo",
        &Sbk_QSerialPortInfo_spec,
        &Shiboken::callCppDestructor< ::QSerialPortInfo >,
        Sbk_QSerialPortInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QSerialPortInfo_TypeF(); // references _Sbk_QSerialPortInfo_Type
    InitSignatureStrings(pyType, QSerialPortInfo_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSerialPortInfo_PropertyStrings);
    SbkPySide6_QtSerialPortTypeStructs[SBK_QSerialPortInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSerialPortInfo_PythonToCpp_QSerialPortInfo_PTR,
        is_QSerialPortInfo_PythonToCpp_QSerialPortInfo_PTR_Convertible,
        QSerialPortInfo_PTR_CppToPython_QSerialPortInfo,
        QSerialPortInfo_COPY_CppToPython_QSerialPortInfo);

    Shiboken::Conversions::registerConverterName(converter, "QSerialPortInfo");
    Shiboken::Conversions::registerConverterName(converter, "QSerialPortInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QSerialPortInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSerialPortInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QSerialPortInfo_PythonToCpp_QSerialPortInfo_COPY,
        is_QSerialPortInfo_PythonToCpp_QSerialPortInfo_COPY_Convertible);

    qRegisterMetaType< ::QSerialPortInfo >("QSerialPortInfo");

    return pyType;
}
