// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgraphicsscenecontextmenuevent_wrapper.h"

// Argument includes
#include <QtWidgets/qgraphicssceneevent.h>
#include <QtWidgets/qwidget.h>
#include <qcoreevent.h>
#include <qpoint.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphicsSceneContextMenuEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphicsSceneContextMenuEventWrapper::QGraphicsSceneContextMenuEventWrapper(::QEvent::Type type) : QGraphicsSceneContextMenuEvent(type)
{
    resetPyMethodCache();
    // ... middle
}

::QEvent * QGraphicsSceneContextMenuEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphicsSceneContextMenuEvent", funcName, Shiboken::SbkType< QEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphicsSceneContextMenuEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QGraphicsSceneContextMenuEventWrapper::~QGraphicsSceneContextMenuEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsSceneContextMenuEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphicsSceneContextMenuEvent >()))
        return -1;

    QGraphicsSceneContextMenuEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:QGraphicsSceneContextMenuEvent", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphicsSceneContextMenuEvent::QGraphicsSceneContextMenuEvent(QEvent::Type=)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsSceneContextMenuEvent(QEvent::Type)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QGraphicsSceneContextMenuEvent(QEvent::Type)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_type = Shiboken::String::createStaticString("type");
            if (PyDict_Contains(kwds, key_type) != 0) {
                value = PyDict_GetItem(kwds, key_type);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_type);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_Type_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_type);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
        }
        ::QEvent::Type cppArg0(QEvent::Type::None);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGraphicsSceneContextMenuEvent(QEvent::Type)
            cptr = new QGraphicsSceneContextMenuEventWrapper(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGraphicsSceneContextMenuEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGraphicsSceneContextMenuEventFunc_modifiers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.modifiers";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // modifiers()const
            QFlags<Qt::KeyboardModifier> cppResult = const_cast<const ::QGraphicsSceneContextMenuEvent *>(cppSelf)->modifiers();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneContextMenuEventFunc_pos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.pos";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pos()const
            QPointF cppResult = const_cast<const ::QGraphicsSceneContextMenuEvent *>(cppSelf)->pos();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneContextMenuEventFunc_reason(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.reason";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // reason()const
            QGraphicsSceneContextMenuEvent::Reason cppResult = const_cast<const ::QGraphicsSceneContextMenuEvent *>(cppSelf)->reason();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_Reason_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneContextMenuEventFunc_scenePos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.scenePos";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // scenePos()const
            QPointF cppResult = const_cast<const ::QGraphicsSceneContextMenuEvent *>(cppSelf)->scenePos();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneContextMenuEventFunc_screenPos(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.screenPos";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // screenPos()const
            QPoint cppResult = const_cast<const ::QGraphicsSceneContextMenuEvent *>(cppSelf)->screenPos();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneContextMenuEventFunc_setModifiers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.setModifiers";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsSceneContextMenuEvent::setModifiers(QFlags<Qt::KeyboardModifier>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setModifiers(QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<Qt::KeyboardModifier> cppArg0 = QFlags<Qt::KeyboardModifier>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setModifiers(QFlags<Qt::KeyboardModifier>)
            cppSelf->setModifiers(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneContextMenuEventFunc_setPos(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.setPos";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsSceneContextMenuEvent::setPos(QPointF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // setPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPos(QPointF)
            cppSelf->setPos(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneContextMenuEventFunc_setReason(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.setReason";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsSceneContextMenuEvent::setReason(QGraphicsSceneContextMenuEvent::Reason)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_Reason_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setReason(QGraphicsSceneContextMenuEvent::Reason)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QGraphicsSceneContextMenuEvent::Reason cppArg0{QGraphicsSceneContextMenuEvent::Mouse};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReason(QGraphicsSceneContextMenuEvent::Reason)
            cppSelf->setReason(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneContextMenuEventFunc_setScenePos(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.setScenePos";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsSceneContextMenuEvent::setScenePos(QPointF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // setScenePos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setScenePos(QPointF)
            cppSelf->setScenePos(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneContextMenuEventFunc_setScreenPos(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.setScreenPos";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsSceneContextMenuEvent::setScreenPos(QPoint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // setScreenPos(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setScreenPos(QPoint)
            cppSelf->setScreenPos(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QGraphicsSceneContextMenuEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QGraphicsSceneContextMenuEvent_EnumFlagInfo[] = {
    "Reason:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphicsSceneContextMenuEvent_methods[] = {
    {"modifiers", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneContextMenuEventFunc_modifiers), METH_NOARGS, nullptr},
    {"pos", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneContextMenuEventFunc_pos), METH_NOARGS, nullptr},
    {"reason", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneContextMenuEventFunc_reason), METH_NOARGS, nullptr},
    {"scenePos", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneContextMenuEventFunc_scenePos), METH_NOARGS, nullptr},
    {"screenPos", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneContextMenuEventFunc_screenPos), METH_NOARGS, nullptr},
    {"setModifiers", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneContextMenuEventFunc_setModifiers), METH_O, nullptr},
    {"setPos", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneContextMenuEventFunc_setPos), METH_O, nullptr},
    {"setReason", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneContextMenuEventFunc_setReason), METH_O, nullptr},
    {"setScenePos", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneContextMenuEventFunc_setScenePos), METH_O, nullptr},
    {"setScreenPos", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneContextMenuEventFunc_setScreenPos), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphicsSceneContextMenuEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphicsSceneContextMenuEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsSceneContextMenuEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphicsSceneContextMenuEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphicsSceneContextMenuEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphicsSceneContextMenuEvent_Type = nullptr;
static PyTypeObject *Sbk_QGraphicsSceneContextMenuEvent_TypeF(void)
{
    return _Sbk_QGraphicsSceneContextMenuEvent_Type;
}

static PyType_Slot Sbk_QGraphicsSceneContextMenuEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphicsSceneContextMenuEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphicsSceneContextMenuEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphicsSceneContextMenuEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphicsSceneContextMenuEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphicsSceneContextMenuEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphicsSceneContextMenuEvent_spec = {
    "2:PySide6.QtWidgets.QGraphicsSceneContextMenuEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphicsSceneContextMenuEvent_slots
};

} //extern "C"

static void *Sbk_QGraphicsSceneContextMenuEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::GraphicsSceneContextMenu)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QGraphicsSceneContextMenuEvent_Reason(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGraphicsSceneContextMenuEvent::Reason>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGraphicsSceneContextMenuEvent::Reason *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGraphicsSceneContextMenuEvent_Reason_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_Reason_IDX])))
        return Enum_PythonToCpp_QGraphicsSceneContextMenuEvent_Reason;
    return {};
}
static PyObject *QGraphicsSceneContextMenuEvent_Reason_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGraphicsSceneContextMenuEvent::Reason *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_Reason_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsSceneContextMenuEvent_PythonToCpp_QGraphicsSceneContextMenuEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphicsSceneContextMenuEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsSceneContextMenuEvent_PythonToCpp_QGraphicsSceneContextMenuEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphicsSceneContextMenuEvent_TypeF()))
        return QGraphicsSceneContextMenuEvent_PythonToCpp_QGraphicsSceneContextMenuEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsSceneContextMenuEvent_PTR_CppToPython_QGraphicsSceneContextMenuEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QGraphicsSceneContextMenuEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QGraphicsSceneContextMenuEvent_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QGraphicsSceneContextMenuEvent_SignatureStrings[] = {
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent(self,type:PySide6.QtCore.QEvent.Type=QEvent.Type.None)",
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.modifiers(self)->PySide6.QtCore.Qt.KeyboardModifier",
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.pos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.reason(self)->PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.Reason",
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.scenePos(self)->PySide6.QtCore.QPointF",
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.screenPos(self)->PySide6.QtCore.QPoint",
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.setModifiers(self,modifiers:PySide6.QtCore.Qt.KeyboardModifier)",
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.setPos(self,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.setReason(self,reason:PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.Reason)",
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.setScenePos(self,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.setScreenPos(self,pos:PySide6.QtCore.QPoint)",
    nullptr}; // Sentinel

PyTypeObject *init_QGraphicsSceneContextMenuEvent(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphicsSceneContextMenuEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX]))));

    _Sbk_QGraphicsSceneContextMenuEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphicsSceneContextMenuEvent",
        "QGraphicsSceneContextMenuEvent*",
        &Sbk_QGraphicsSceneContextMenuEvent_spec,
        &Shiboken::callCppDestructor< QGraphicsSceneContextMenuEvent >,
        Sbk_QGraphicsSceneContextMenuEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphicsSceneContextMenuEvent_TypeF(); // references _Sbk_QGraphicsSceneContextMenuEvent_Type
    InitSignatureStrings(pyType, QGraphicsSceneContextMenuEvent_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphicsSceneContextMenuEvent_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsSceneContextMenuEvent_PythonToCpp_QGraphicsSceneContextMenuEvent_PTR,
        is_QGraphicsSceneContextMenuEvent_PythonToCpp_QGraphicsSceneContextMenuEvent_PTR_Convertible,
        QGraphicsSceneContextMenuEvent_PTR_CppToPython_QGraphicsSceneContextMenuEvent);

    Shiboken::Conversions::registerConverterName(converter, "QGraphicsSceneContextMenuEvent");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsSceneContextMenuEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsSceneContextMenuEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphicsSceneContextMenuEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsSceneContextMenuEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGraphicsSceneContextMenuEvent_TypeF(), &Sbk_QGraphicsSceneContextMenuEvent_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGraphicsSceneContextMenuEvent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Reason'.
    const char *Reason_Initializer[] = {
        "Mouse",
        "Keyboard",
        "Other",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Reason_InitializerValues[] = {
        uint8_t(QGraphicsSceneContextMenuEvent::Reason::Mouse),    //  0x00  0
        uint8_t(QGraphicsSceneContextMenuEvent::Reason::Keyboard), //  0x01  1
        uint8_t(QGraphicsSceneContextMenuEvent::Reason::Other)     //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGraphicsSceneContextMenuEvent_TypeF(),
        "2:PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.Reason",
        Reason_Initializer, Reason_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_Reason_IDX].type = EType;
    // Register converter for enum 'QGraphicsSceneContextMenuEvent::Reason'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGraphicsSceneContextMenuEvent_Reason_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGraphicsSceneContextMenuEvent_Reason,
            is_Enum_PythonToCpp_QGraphicsSceneContextMenuEvent_Reason_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGraphicsSceneContextMenuEvent::Reason");
        Shiboken::Conversions::registerConverterName(converter, "Reason");
    }
    // End of 'Reason' enum.

    qRegisterMetaType< ::QGraphicsSceneContextMenuEvent::Reason >("QGraphicsSceneContextMenuEvent::Reason");

    return pyType;
}
