// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qscrollerproperties_wrapper.h"

// Argument includes
#include <QtWidgets/qscrollerproperties.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QScrollerPropertiesWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QScrollerPropertiesWrapper::QScrollerPropertiesWrapper() : QScrollerProperties()
{
    resetPyMethodCache();
    // ... middle
}

QScrollerPropertiesWrapper::~QScrollerPropertiesWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScrollerProperties_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QScrollerProperties >()))
        return -1;

    QScrollerPropertiesWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QScrollerProperties.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QScrollerProperties", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QScrollerProperties::QScrollerProperties()
    // 1: QScrollerProperties::QScrollerProperties(QScrollerProperties)
    if (numArgs == 0) {
        overloadId = 0; // QScrollerProperties()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QScrollerProperties(QScrollerProperties)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QScrollerProperties()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QScrollerProperties()
                cptr = new QScrollerPropertiesWrapper();
            }
            break;
        }
        case 1: // QScrollerProperties(const QScrollerProperties &sp)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QScrollerProperties cppArg0_local;
            ::QScrollerProperties *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QScrollerProperties(QScrollerProperties)
                cptr = new QScrollerPropertiesWrapper(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QScrollerProperties >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QScrollerPropertiesFunc_scrollMetric(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollerProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QScrollerProperties.scrollMetric";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QScrollerProperties::scrollMetric(QScrollerProperties::ScrollMetric)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_ScrollMetric_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // scrollMetric(QScrollerProperties::ScrollMetric)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QScrollerProperties::ScrollMetric cppArg0{QScrollerProperties::MousePressEventDelay};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scrollMetric(QScrollerProperties::ScrollMetric)const
            QVariant cppResult = const_cast<const ::QScrollerProperties *>(cppSelf)->scrollMetric(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QScrollerPropertiesFunc_setDefaultScrollerProperties(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QScrollerProperties.setDefaultScrollerProperties";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QScrollerProperties::setDefaultScrollerProperties(QScrollerProperties)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), (pyArg)))) {
        overloadId = 0; // setDefaultScrollerProperties(QScrollerProperties)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QScrollerProperties cppArg0_local;
        ::QScrollerProperties *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultScrollerProperties(QScrollerProperties)
            ::QScrollerProperties::setDefaultScrollerProperties(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerPropertiesFunc_setScrollMetric(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QScrollerProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QScrollerProperties.setScrollMetric";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setScrollMetric", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QScrollerProperties::setScrollMetric(QScrollerProperties::ScrollMetric,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_ScrollMetric_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setScrollMetric(QScrollerProperties::ScrollMetric,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QScrollerProperties::ScrollMetric cppArg0{QScrollerProperties::MousePressEventDelay};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setScrollMetric(QScrollerProperties::ScrollMetric,QVariant)
            cppSelf->setScrollMetric(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerPropertiesFunc_unsetDefaultScrollerProperties(PyObject *self)
{
    SBK_UNUSED(self)
    static const char fullName[] = "PySide6.QtWidgets.QScrollerProperties.unsetDefaultScrollerProperties";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // unsetDefaultScrollerProperties()
            ::QScrollerProperties::unsetDefaultScrollerProperties();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QScrollerProperties__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QScrollerProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QScrollerProperties_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QScrollerProperties_EnumFlagInfo[] = {
    "FrameRates:Enum",
    "OvershootPolicy:Enum",
    "ScrollMetric:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QScrollerProperties_methods[] = {
    {"scrollMetric", reinterpret_cast<PyCFunction>(Sbk_QScrollerPropertiesFunc_scrollMetric), METH_O, nullptr},
    {"setDefaultScrollerProperties", reinterpret_cast<PyCFunction>(Sbk_QScrollerPropertiesFunc_setDefaultScrollerProperties), METH_O|METH_STATIC, nullptr},
    {"setScrollMetric", reinterpret_cast<PyCFunction>(Sbk_QScrollerPropertiesFunc_setScrollMetric), METH_VARARGS, nullptr},
    {"unsetDefaultScrollerProperties", reinterpret_cast<PyCFunction>(Sbk_QScrollerPropertiesFunc_unsetDefaultScrollerProperties), METH_NOARGS|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QScrollerProperties__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QScrollerProperties_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QScrollerProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QScrollerPropertiesWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

// Rich comparison
static PyObject * Sbk_QScrollerProperties_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QScrollerProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), (pyArg)))) {
                // operator!=(const QScrollerProperties &sp) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QScrollerProperties cppArg0_local;
                ::QScrollerProperties *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), (pyArg)))) {
                // operator==(const QScrollerProperties &sp) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QScrollerProperties cppArg0_local;
                ::QScrollerProperties *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QScrollerProperties_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QScrollerProperties_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QScrollerProperties_Type = nullptr;
static PyTypeObject *Sbk_QScrollerProperties_TypeF(void)
{
    return _Sbk_QScrollerProperties_Type;
}

static PyType_Slot Sbk_QScrollerProperties_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QScrollerProperties_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QScrollerProperties_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QScrollerProperties_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QScrollerProperties_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QScrollerProperties_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QScrollerProperties_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QScrollerProperties_spec = {
    "2:PySide6.QtWidgets.QScrollerProperties",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QScrollerProperties_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QScrollerProperties_OvershootPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QScrollerProperties::OvershootPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QScrollerProperties::OvershootPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QScrollerProperties_OvershootPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_OvershootPolicy_IDX])))
        return Enum_PythonToCpp_QScrollerProperties_OvershootPolicy;
    return {};
}
static PyObject *QScrollerProperties_OvershootPolicy_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QScrollerProperties::OvershootPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_OvershootPolicy_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QScrollerProperties_FrameRates(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QScrollerProperties::FrameRates>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QScrollerProperties::FrameRates *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QScrollerProperties_FrameRates_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_FrameRates_IDX])))
        return Enum_PythonToCpp_QScrollerProperties_FrameRates;
    return {};
}
static PyObject *QScrollerProperties_FrameRates_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QScrollerProperties::FrameRates *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_FrameRates_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QScrollerProperties_ScrollMetric(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QScrollerProperties::ScrollMetric>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QScrollerProperties::ScrollMetric *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QScrollerProperties_ScrollMetric_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_ScrollMetric_IDX])))
        return Enum_PythonToCpp_QScrollerProperties_ScrollMetric;
    return {};
}
static PyObject *QScrollerProperties_ScrollMetric_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QScrollerProperties::ScrollMetric *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_ScrollMetric_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QScrollerProperties_PythonToCpp_QScrollerProperties_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QScrollerProperties_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QScrollerProperties_PythonToCpp_QScrollerProperties_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QScrollerProperties_TypeF()))
        return QScrollerProperties_PythonToCpp_QScrollerProperties_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QScrollerProperties_PTR_CppToPython_QScrollerProperties(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QScrollerProperties *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QScrollerProperties_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QScrollerProperties_COPY_CppToPython_QScrollerProperties(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QScrollerProperties *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QScrollerProperties_TypeF(), new QScrollerPropertiesWrapper(*source), true, true);
}

// Python to C++ copy conversion.
static void QScrollerProperties_PythonToCpp_QScrollerProperties_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QScrollerProperties *>(cppOut) = *reinterpret_cast< ::QScrollerProperties *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QScrollerProperties_PythonToCpp_QScrollerProperties_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QScrollerProperties_TypeF()))
        return QScrollerProperties_PythonToCpp_QScrollerProperties_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QScrollerProperties_SignatureStrings[] = {
    "1:PySide6.QtWidgets.QScrollerProperties(self)",
    "0:PySide6.QtWidgets.QScrollerProperties(self,sp:PySide6.QtWidgets.QScrollerProperties)",
    "PySide6.QtWidgets.QScrollerProperties.scrollMetric(self,metric:PySide6.QtWidgets.QScrollerProperties.ScrollMetric)->QVariant",
    "PySide6.QtWidgets.QScrollerProperties.setDefaultScrollerProperties(sp:PySide6.QtWidgets.QScrollerProperties)",
    "PySide6.QtWidgets.QScrollerProperties.setScrollMetric(self,metric:PySide6.QtWidgets.QScrollerProperties.ScrollMetric,value:QVariant)",
    "PySide6.QtWidgets.QScrollerProperties.unsetDefaultScrollerProperties()",
    "PySide6.QtWidgets.QScrollerProperties.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QScrollerProperties(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX].type;

    Shiboken::AutoDecRef Sbk_QScrollerProperties_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QScrollerProperties_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QScrollerProperties",
        "QScrollerProperties",
        &Sbk_QScrollerProperties_spec,
        &Shiboken::callCppDestructor< QScrollerPropertiesWrapper >,
        Sbk_QScrollerProperties_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QScrollerProperties_TypeF(); // references _Sbk_QScrollerProperties_Type
    InitSignatureStrings(pyType, QScrollerProperties_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QScrollerProperties_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QScrollerProperties_PythonToCpp_QScrollerProperties_PTR,
        is_QScrollerProperties_PythonToCpp_QScrollerProperties_PTR_Convertible,
        QScrollerProperties_PTR_CppToPython_QScrollerProperties,
        QScrollerProperties_COPY_CppToPython_QScrollerProperties);

    Shiboken::Conversions::registerConverterName(converter, "QScrollerProperties");
    Shiboken::Conversions::registerConverterName(converter, "QScrollerProperties*");
    Shiboken::Conversions::registerConverterName(converter, "QScrollerProperties&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QScrollerProperties).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QScrollerPropertiesWrapper).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QScrollerProperties_PythonToCpp_QScrollerProperties_COPY,
        is_QScrollerProperties_PythonToCpp_QScrollerProperties_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QScrollerProperties_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'OvershootPolicy'.
    const char *OvershootPolicy_Initializer[] = {
        "OvershootWhenScrollable",
        "OvershootAlwaysOff",
        "OvershootAlwaysOn",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t OvershootPolicy_InitializerValues[] = {
        uint8_t(QScrollerProperties::OvershootPolicy::OvershootWhenScrollable), //  0x00  0
        uint8_t(QScrollerProperties::OvershootPolicy::OvershootAlwaysOff),      //  0x01  1
        uint8_t(QScrollerProperties::OvershootPolicy::OvershootAlwaysOn)        //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QScrollerProperties_TypeF(),
        "2:PySide6.QtWidgets.QScrollerProperties.OvershootPolicy",
        OvershootPolicy_Initializer, OvershootPolicy_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_OvershootPolicy_IDX].type = EType;
    // Register converter for enum 'QScrollerProperties::OvershootPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QScrollerProperties_OvershootPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QScrollerProperties_OvershootPolicy,
            is_Enum_PythonToCpp_QScrollerProperties_OvershootPolicy_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QScrollerProperties::OvershootPolicy");
        Shiboken::Conversions::registerConverterName(converter, "OvershootPolicy");
    }
    // End of 'OvershootPolicy' enum.

    // Initialization of enum 'FrameRates'.
    const char *FrameRates_Initializer[] = {
        "Standard",
        "Fps60",
        "Fps30",
        "Fps20",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FrameRates_InitializerValues[] = {
        uint8_t(QScrollerProperties::FrameRates::Standard), //  0x00  0
        uint8_t(QScrollerProperties::FrameRates::Fps60),    //  0x01  1
        uint8_t(QScrollerProperties::FrameRates::Fps30),    //  0x02  2
        uint8_t(QScrollerProperties::FrameRates::Fps20)     //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QScrollerProperties_TypeF(),
        "2:PySide6.QtWidgets.QScrollerProperties.FrameRates",
        FrameRates_Initializer, FrameRates_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_FrameRates_IDX].type = EType;
    // Register converter for enum 'QScrollerProperties::FrameRates'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QScrollerProperties_FrameRates_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QScrollerProperties_FrameRates,
            is_Enum_PythonToCpp_QScrollerProperties_FrameRates_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QScrollerProperties::FrameRates");
        Shiboken::Conversions::registerConverterName(converter, "FrameRates");
    }
    // End of 'FrameRates' enum.

    // Initialization of enum 'ScrollMetric'.
    const char *ScrollMetric_Initializer[] = {
        "MousePressEventDelay",
        "DragStartDistance",
        "DragVelocitySmoothingFactor",
        "AxisLockThreshold",
        "ScrollingCurve",
        "DecelerationFactor",
        "MinimumVelocity",
        "MaximumVelocity",
        "MaximumClickThroughVelocity",
        "AcceleratingFlickMaximumTime",
        "AcceleratingFlickSpeedupFactor",
        "SnapPositionRatio",
        "SnapTime",
        "OvershootDragResistanceFactor",
        "OvershootDragDistanceFactor",
        "OvershootScrollDistanceFactor",
        "OvershootScrollTime",
        "HorizontalOvershootPolicy",
        "VerticalOvershootPolicy",
        "FrameRate",
        "ScrollMetricCount",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ScrollMetric_InitializerValues[] = {
        uint8_t(QScrollerProperties::ScrollMetric::MousePressEventDelay),           //  0x00  0
        uint8_t(QScrollerProperties::ScrollMetric::DragStartDistance),              //  0x01  1
        uint8_t(QScrollerProperties::ScrollMetric::DragVelocitySmoothingFactor),    //  0x02  2
        uint8_t(QScrollerProperties::ScrollMetric::AxisLockThreshold),              //  0x03  3
        uint8_t(QScrollerProperties::ScrollMetric::ScrollingCurve),                 //  0x04  4
        uint8_t(QScrollerProperties::ScrollMetric::DecelerationFactor),             //  0x05  5
        uint8_t(QScrollerProperties::ScrollMetric::MinimumVelocity),                //  0x06  6
        uint8_t(QScrollerProperties::ScrollMetric::MaximumVelocity),                //  0x07  7
        uint8_t(QScrollerProperties::ScrollMetric::MaximumClickThroughVelocity),    //  0x08  8
        uint8_t(QScrollerProperties::ScrollMetric::AcceleratingFlickMaximumTime),   //  0x09  9
        uint8_t(QScrollerProperties::ScrollMetric::AcceleratingFlickSpeedupFactor), //  0x0a  10
        uint8_t(QScrollerProperties::ScrollMetric::SnapPositionRatio),              //  0x0b  11
        uint8_t(QScrollerProperties::ScrollMetric::SnapTime),                       //  0x0c  12
        uint8_t(QScrollerProperties::ScrollMetric::OvershootDragResistanceFactor),  //  0x0d  13
        uint8_t(QScrollerProperties::ScrollMetric::OvershootDragDistanceFactor),    //  0x0e  14
        uint8_t(QScrollerProperties::ScrollMetric::OvershootScrollDistanceFactor),  //  0x0f  15
        uint8_t(QScrollerProperties::ScrollMetric::OvershootScrollTime),            //  0x10  16
        uint8_t(QScrollerProperties::ScrollMetric::HorizontalOvershootPolicy),      //  0x11  17
        uint8_t(QScrollerProperties::ScrollMetric::VerticalOvershootPolicy),        //  0x12  18
        uint8_t(QScrollerProperties::ScrollMetric::FrameRate),                      //  0x13  19
        uint8_t(QScrollerProperties::ScrollMetric::ScrollMetricCount)               //  0x14  20
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QScrollerProperties_TypeF(),
        "2:PySide6.QtWidgets.QScrollerProperties.ScrollMetric",
        ScrollMetric_Initializer, ScrollMetric_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollerProperties_ScrollMetric_IDX].type = EType;
    // Register converter for enum 'QScrollerProperties::ScrollMetric'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QScrollerProperties_ScrollMetric_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QScrollerProperties_ScrollMetric,
            is_Enum_PythonToCpp_QScrollerProperties_ScrollMetric_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QScrollerProperties::ScrollMetric");
        Shiboken::Conversions::registerConverterName(converter, "ScrollMetric");
    }
    // End of 'ScrollMetric' enum.

    qRegisterMetaType< ::QScrollerProperties >("QScrollerProperties");
    qRegisterMetaType< ::QScrollerProperties::OvershootPolicy >("QScrollerProperties::OvershootPolicy");
    qRegisterMetaType< ::QScrollerProperties::FrameRates >("QScrollerProperties::FrameRates");
    qRegisterMetaType< ::QScrollerProperties::ScrollMetric >("QScrollerProperties::ScrollMetric");

    return pyType;
}
