// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qbytearray_wrapper.h"

// inner classes
#include "qbytearray_frombase64result_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qnamespace.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qbytearray-bufferprotocol)]
extern "C" {
// QByteArray buffer protocol functions
// see: http://www.python.org/dev/peps/pep-3118/

static int SbkQByteArray_getbufferproc(PyObject *obj, Py_buffer *view, int flags)
{
    if (!view || !Shiboken::Object::isValid(obj))
        return -1;

    ::QByteArray* cppSelf{nullptr};
Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), obj, &(cppSelf));
    //XXX      /|\ omitting this space crashes shiboken!
#ifdef Py_LIMITED_API
    view->obj = obj;
    view->buf = reinterpret_cast<void *>(cppSelf->data());
    view->len = cppSelf->size();
    view->readonly = 0;
    view->itemsize = 1;
    view->format = (flags & PyBUF_FORMAT) == PyBUF_FORMAT ? const_cast<char *>("B") : nullptr;
    view->ndim = 1;
    view->shape = (flags & PyBUF_ND) == PyBUF_ND ? &(view->len) : nullptr;
    view->strides = (flags & PyBUF_STRIDES) == PyBUF_STRIDES ? &(view->itemsize) : nullptr;
    view->suboffsets = nullptr;
    view->internal = nullptr;

    Py_XINCREF(obj);
    return 0;
#else // Py_LIMITED_API
    const int result = PyBuffer_FillInfo(view, obj, reinterpret_cast<void *>(cppSelf->data()),
                                         cppSelf->size(), 0, flags);
    if (result == 0)
        Py_XINCREF(obj);
    return result;
#endif
}

static PyBufferProcs SbkQByteArrayBufferProc = {
    /*bf_getbuffer*/  (getbufferproc)SbkQByteArray_getbufferproc,
    /*bf_releasebuffer*/ (releasebufferproc)0,
};

}
// END of custom code block [file: ../glue/qtcore.cpp (qbytearray-bufferprotocol)]
// ========================================================================
// End of code injection



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QByteArray_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QByteArray >()))
        return -1;

    ::QByteArray *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QByteArray", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QByteArray::QByteArray()
    // 1: QByteArray::QByteArray(PyByteArray)
    // 2: QByteArray::QByteArray(PyBytes)
    // 3: QByteArray::QByteArray(QByteArray)
    // 4: QByteArray::QByteArray(const char*,qsizetype=)
    // 5: QByteArray::QByteArray(qsizetype,char)
    if (numArgs == 0) {
        overloadId = 0; // QByteArray()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
        overloadId = 5; // QByteArray(qsizetype,char)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // QByteArray(const char*,qsizetype)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 4; // QByteArray(const char*,qsizetype)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QByteArray(QByteArray)
    } else if (numArgs == 1
        && PyBytes_Check(pyArgs[0])) {
        overloadId = 2; // QByteArray(PyBytes)
    } else if (numArgs == 1
        && PyByteArray_Check(pyArgs[0])) {
        overloadId = 1; // QByteArray(PyByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QByteArray()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArray()
                cptr = new ::QByteArray();
            }
            break;
        }
        case 1: // QByteArray(PyByteArray arg__1)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArray(PyByteArray)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-2)]
                cptr = new QByteArray(PyByteArray_AsString(pyArgs[1-1]), PyByteArray_Size(pyArgs[1-1]));
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-2)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 2: // QByteArray(PyBytes arg__1)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArray(PyBytes)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-3)]
                cptr = new QByteArray(PyBytes_AS_STRING(pyArgs[1-1]), PyBytes_GET_SIZE(pyArgs[1-1]));
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-3)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 3: // QByteArray(const QByteArray &arg__1)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArray(QByteArray)
                cptr = new ::QByteArray(*cppArg0);
            }
            break;
        }
        case 4: // QByteArray(const char *arg__1, qsizetype size)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_size = Shiboken::String::createStaticString("size");
                if (PyDict_Contains(kwds, key_size) != 0) {
                    value = PyDict_GetItem(kwds, key_size);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_size);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_size);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArray(const char*,qsizetype)
                cptr = new ::QByteArray(cppArg0, cppArg1);
            }
            break;
        }
        case 5: // QByteArray(qsizetype size, char c)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArray(qsizetype,char)
                cptr = new ::QByteArray(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QByteArray >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QByteArrayFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.__reduce__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __reduce__()
            // Begin code injection
            // TEMPLATE - reduce_code - START
            pyResult = Py_BuildValue("(N(N))", PyObject_Type(self), PyBytes_FromStringAndSize(cppSelf->constData(), cppSelf->size()));
            // TEMPLATE - reduce_code - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.__repr__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __repr__()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-repr)]
            PyObject *aux = PyBytes_FromStringAndSize(cppSelf->constData(), cppSelf->size());
            if (aux == nullptr) {
                return nullptr;
            }
            QByteArray b(Py_TYPE(self)->tp_name);
            pyResult = PyUnicode_FromFormat("%s(%R)", b.constData(), aux);
            Py_DECREF(aux);
            // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-repr)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc___str__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.__str__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __str__()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-str)]
            PyObject *aux = PyBytes_FromStringAndSize(cppSelf->constData(), cppSelf->size());
            if (aux == nullptr) {
                return nullptr;
            }
            pyResult = PyObject_Repr(aux);
            Py_DECREF(aux);
            // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-str)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_append(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.append";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "append", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::append(QByteArrayView)->QByteArray&
    // 1: QByteArray::append(char)->QByteArray&
    // 2: QByteArray::append(QByteArray)->QByteArray&
    // 3: QByteArray::append(const char*,qsizetype)->QByteArray&
    // 4: QByteArray::append(qsizetype,char)->QByteArray&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
        overloadId = 4; // append(qsizetype,char)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 3; // append(const char*,qsizetype)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0])))) {
        overloadId = 1; // append(char)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 2; // append(QByteArray)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 0; // append(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // append(QByteArrayView a)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QByteArrayView)
                QByteArray & cppResult = cppSelf->append(QByteArrayView(cppArg0));
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // append(char c)
        {
            char cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(char)
                QByteArray & cppResult = cppSelf->append(cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 2: // append(const QByteArray &a)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // append(QByteArray)
                QByteArray & cppResult = cppSelf->append(*cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 3: // append(const char *s, qsizetype len)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(const char*,qsizetype)
                QByteArray & cppResult = cppSelf->append(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 4: // append(qsizetype count, char c)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // append(qsizetype,char)
                QByteArray & cppResult = cppSelf->append(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_assign(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.assign";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "assign", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::assign(QByteArrayView)->QByteArray&
    // 1: QByteArray::assign(qsizetype,char)->QByteArray&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
        overloadId = 1; // assign(qsizetype,char)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 0; // assign(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // assign(QByteArrayView v)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // assign(QByteArrayView)
                QByteArray & cppResult = cppSelf->assign(QByteArrayView(cppArg0));
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // assign(qsizetype n, char c)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // assign(qsizetype,char)
                QByteArray & cppResult = cppSelf->assign(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_at(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.at";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::at(qsizetype)const->char
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // at(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // at(qsizetype)const
            char cppResult = const_cast<const ::QByteArray *>(cppSelf)->at(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<char>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_back(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.back";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // back()
            char & cppResult = cppSelf->back();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<char>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_capacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.capacity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // capacity()const
            qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->capacity();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_cbegin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.cbegin";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cbegin()const
            const char * cppResult = const_cast<const ::QByteArray *>(cppSelf)->cbegin();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_cend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.cend";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cend()const
            const char * cppResult = const_cast<const ::QByteArray *>(cppSelf)->cend();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_chop(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.chop";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::chop(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // chop(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // chop(qsizetype)
            cppSelf->chop(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArrayFunc_chopped(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.chopped";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::chopped(qsizetype)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // chopped(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // chopped(qsizetype)
            QByteArray cppResult = cppSelf->chopped(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QByteArray.clear";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear()
            cppSelf->clear();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArrayFunc_compare(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.compare";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:compare", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::compare(QByteArrayView,Qt::CaseSensitivity=)const->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // compare(QByteArrayView,Qt::CaseSensitivity)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // compare(QByteArrayView,Qt::CaseSensitivity)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_cs = Shiboken::String::createStaticString("cs");
            if (PyDict_Contains(kwds, key_cs) != 0) {
                value = PyDict_GetItem(kwds, key_cs);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_cs);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CaseSensitivity_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_cs);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::CaseSensitivity cppArg1(Qt::CaseSensitive);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // compare(QByteArrayView,Qt::CaseSensitivity)const
            int cppResult = const_cast<const ::QByteArray *>(cppSelf)->compare(QByteArrayView(cppArg0), cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.contains";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::contains(QByteArrayView)const->bool
    // 1: QByteArray::contains(char)const->bool
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
        overloadId = 1; // contains(char)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // contains(QByteArrayView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // contains(QByteArrayView bv) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // contains(QByteArrayView)const
                bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->contains(QByteArrayView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // contains(char c) const
        {
            char cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // contains(char)const
                bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->contains(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_count(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.count";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "count", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::count()const->qsizetype
    // 1: QByteArray::count(QByteArrayView)const->qsizetype
    // 2: QByteArray::count(char)const->qsizetype
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (numArgs == 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0])))) {
        overloadId = 2; // count(char)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // count(QByteArrayView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // count() const
        {
            Shiboken::Warnings::warnDeprecated("QByteArray", "count() const");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};

            if (Shiboken::Errors::occurred() == nullptr) {
                // count()const
                qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->count();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
        case 1: // count(QByteArrayView bv) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // count(QByteArrayView)const
                qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->count(QByteArrayView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
        case 2: // count(char c) const
        {
            char cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // count(char)const
                qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->count(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.data";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // data()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-data)]
            pyResult = PyBytes_FromStringAndSize(cppSelf->data(), cppSelf->size());
            // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-data)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_endsWith(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.endsWith";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::endsWith(QByteArrayView)const->bool
    // 1: QByteArray::endsWith(char)const->bool
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
        overloadId = 1; // endsWith(char)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // endsWith(QByteArrayView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // endsWith(QByteArrayView bv) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // endsWith(QByteArrayView)const
                bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->endsWith(QByteArrayView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // endsWith(char c) const
        {
            char cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // endsWith(char)const
                bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->endsWith(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_erase(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.erase";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "erase", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::erase(const char*,const char*)->char*
    // 1: QByteArray::erase(const char*)->char*
    if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // erase(const char*)
        } else if (numArgs == 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 0; // erase(const char*,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // erase(const char *first, const char *last)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // erase(const char*,const char*)
                char * cppResult = cppSelf->erase(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
            }
            break;
        }
        case 1: // erase(const char *it)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // erase(const char*)
                char * cppResult = cppSelf->erase(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_fill(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.fill";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:fill", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::fill(char,qsizetype=)->QByteArray&
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fill(char,qsizetype)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // fill(char,qsizetype)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_size = Shiboken::String::createStaticString("size");
            if (PyDict_Contains(kwds, key_size) != 0) {
                value = PyDict_GetItem(kwds, key_size);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_size);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_size);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        char cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = -1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fill(char,qsizetype)
            QByteArray & cppResult = cppSelf->fill(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_first(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.first";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::first(qsizetype)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // first(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // first(qsizetype)
            QByteArray cppResult = cppSelf->first(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_fromBase64(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.fromBase64";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:fromBase64", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QByteArray::fromBase64(QByteArray,QFlags<QByteArray::Base64Option>=)->QByteArray
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromBase64(QByteArray,QFlags<QByteArray::Base64Option>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QByteArray_Base64Option_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // fromBase64(QByteArray,QFlags<QByteArray::Base64Option>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QByteArray_Base64Option_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFlags<QByteArray::Base64Option> cppArg1(QByteArray::Base64Option::Base64Encoding);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromBase64(QByteArray,QFlags<QByteArray::Base64Option>)
            QByteArray cppResult = ::QByteArray::fromBase64(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_fromBase64Encoding(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.fromBase64Encoding";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:fromBase64Encoding", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QByteArray::fromBase64Encoding(QByteArray,QFlags<QByteArray::Base64Option>=)->QByteArray::FromBase64Result
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromBase64Encoding(QByteArray,QFlags<QByteArray::Base64Option>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QByteArray_Base64Option_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // fromBase64Encoding(QByteArray,QFlags<QByteArray::Base64Option>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QByteArray_Base64Option_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFlags<QByteArray::Base64Option> cppArg1(QByteArray::Base64Option::Base64Encoding);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromBase64Encoding(QByteArray,QFlags<QByteArray::Base64Option>)
            QByteArray::FromBase64Result cppResult = ::QByteArray::fromBase64Encoding(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_FromBase64Result_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_fromHex(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.fromHex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QByteArray::fromHex(QByteArray)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // fromHex(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromHex(QByteArray)
            QByteArray cppResult = ::QByteArray::fromHex(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_fromPercentEncoding(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.fromPercentEncoding";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:fromPercentEncoding", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QByteArray::fromPercentEncoding(QByteArray,char=)->QByteArray
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromPercentEncoding(QByteArray,char)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            overloadId = 0; // fromPercentEncoding(QByteArray,char)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_percent = Shiboken::String::createStaticString("percent");
            if (PyDict_Contains(kwds, key_percent) != 0) {
                value = PyDict_GetItem(kwds, key_percent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_percent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_percent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        char cppArg1 = '%';
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromPercentEncoding(QByteArray,char)
            QByteArray cppResult = ::QByteArray::fromPercentEncoding(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_fromRawData(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.fromRawData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fromRawData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QByteArray::fromRawData(const char*,qsizetype)->QByteArray
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // fromRawData(const char*,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromRawData(const char*,qsizetype)
            QByteArray cppResult = ::QByteArray::fromRawData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_fromStdString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.fromStdString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QByteArray::fromStdString(std::string)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<std::string>(), (pyArg)))) {
        overloadId = 0; // fromStdString(std::string)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        std::string cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromStdString(std::string)
            QByteArray cppResult = ::QByteArray::fromStdString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_front(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.front";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // front()
            char & cppResult = cppSelf->front();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<char>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_indexOf(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.indexOf";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:indexOf", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::indexOf(QByteArrayView,qsizetype=)const->qsizetype
    // 1: QByteArray::indexOf(char,qsizetype=)const->qsizetype
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // indexOf(char,qsizetype)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 1; // indexOf(char,qsizetype)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // indexOf(QByteArrayView,qsizetype)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // indexOf(QByteArrayView,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // indexOf(QByteArrayView bv, qsizetype from) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_from = Shiboken::String::createStaticString("from");
                if (PyDict_Contains(kwds, key_from) != 0) {
                    value = PyDict_GetItem(kwds, key_from);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_from);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_from);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // indexOf(QByteArrayView,qsizetype)const
                qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->indexOf(QByteArrayView(cppArg0), cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
        case 1: // indexOf(char c, qsizetype from) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_from = Shiboken::String::createStaticString("from");
                if (PyDict_Contains(kwds, key_from) != 0) {
                    value = PyDict_GetItem(kwds, key_from);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_from);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_from);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            char cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // indexOf(char,qsizetype)const
                qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->indexOf(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.insert";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::insert(qsizetype,QByteArrayView)->QByteArray&
    // 1: QByteArray::insert(qsizetype,char)->QByteArray&
    // 2: QByteArray::insert(qsizetype,QByteArray)->QByteArray&
    // 3: QByteArray::insert(qsizetype,const char*)->QByteArray&
    // 4: QByteArray::insert(qsizetype,const char*,qsizetype)->QByteArray&
    // 5: QByteArray::insert(qsizetype,qsizetype,char)->QByteArray&
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))
            && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[2])))) {
            overloadId = 5; // insert(qsizetype,qsizetype,char)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // insert(qsizetype,const char*)
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[2])))) {
                overloadId = 4; // insert(qsizetype,const char*,qsizetype)
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            overloadId = 1; // insert(qsizetype,char)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 2; // insert(qsizetype,QByteArray)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 0; // insert(qsizetype,QByteArrayView)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // insert(qsizetype i, QByteArrayView data)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(qsizetype,QByteArrayView)
                QByteArray & cppResult = cppSelf->insert(cppArg0, QByteArrayView(cppArg1));
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // insert(qsizetype i, char c)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(qsizetype,char)
                QByteArray & cppResult = cppSelf->insert(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 2: // insert(qsizetype i, const QByteArray &data)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(qsizetype,QByteArray)
                QByteArray & cppResult = cppSelf->insert(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 3: // insert(qsizetype i, const char *s)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(qsizetype,const char*)
                QByteArray & cppResult = cppSelf->insert(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 4: // insert(qsizetype i, const char *s, qsizetype len)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qsizetype cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(qsizetype,const char*,qsizetype)
                QByteArray & cppResult = cppSelf->insert(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 5: // insert(qsizetype i, qsizetype count, char c)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            char cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(qsizetype,qsizetype,char)
                QByteArray & cppResult = cppSelf->insert(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.isEmpty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEmpty()const
            bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->isEmpty();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_isLower(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.isLower";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isLower()const
            bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->isLower();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.isNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNull()const
            bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->isNull();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_isSharedWith(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.isSharedWith";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::isSharedWith(QByteArray)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // isSharedWith(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isSharedWith(QByteArray)const
            bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->isSharedWith(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_isUpper(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.isUpper";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isUpper()const
            bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->isUpper();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_isValidUtf8(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.isValidUtf8";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValidUtf8()const
            bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->isValidUtf8();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_last(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.last";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::last(qsizetype)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // last(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // last(qsizetype)
            QByteArray cppResult = cppSelf->last(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_lastIndexOf(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.lastIndexOf";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:lastIndexOf", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::lastIndexOf(QByteArrayView)const->qsizetype
    // 1: QByteArray::lastIndexOf(QByteArrayView,qsizetype)const->qsizetype
    // 2: QByteArray::lastIndexOf(char,qsizetype=)const->qsizetype
    if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // lastIndexOf(char,qsizetype)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 2; // lastIndexOf(char,qsizetype)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexOf(QByteArrayView)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 1; // lastIndexOf(QByteArrayView,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // lastIndexOf(QByteArrayView bv) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // lastIndexOf(QByteArrayView)const
                qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->lastIndexOf(QByteArrayView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
        case 1: // lastIndexOf(QByteArrayView bv, qsizetype from) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // lastIndexOf(QByteArrayView,qsizetype)const
                qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->lastIndexOf(QByteArrayView(cppArg0), cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
        case 2: // lastIndexOf(char c, qsizetype from) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_from = Shiboken::String::createStaticString("from");
                if (PyDict_Contains(kwds, key_from) != 0) {
                    value = PyDict_GetItem(kwds, key_from);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_from);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_from);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            char cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // lastIndexOf(char,qsizetype)const
                qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->lastIndexOf(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_left(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.left";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::left(qsizetype)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // left(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // left(qsizetype)
            QByteArray cppResult = cppSelf->left(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_leftJustified(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.leftJustified";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:leftJustified", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::leftJustified(qsizetype,char=,bool=)const->QByteArray
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // leftJustified(qsizetype,char,bool)const
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // leftJustified(qsizetype,char,bool)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))) {
                overloadId = 0; // leftJustified(qsizetype,char,bool)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
            if (PyDict_Contains(kwds, key_fill) != 0) {
                value = PyDict_GetItem(kwds, key_fill);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_fill);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_fill);
            }
            static PyObject *const key_truncate = Shiboken::String::createStaticString("truncate");
            if (PyDict_Contains(kwds, key_truncate) != 0) {
                value = PyDict_GetItem(kwds, key_truncate);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_truncate);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_truncate);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        char cppArg1 = ' ';
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        bool cppArg2 = false;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // leftJustified(qsizetype,char,bool)const
            QByteArray cppResult = const_cast<const ::QByteArray *>(cppSelf)->leftJustified(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.length";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // length()const
            qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->length();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_mid(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.mid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:mid", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::mid(qsizetype,qsizetype=)->QByteArray
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // mid(qsizetype,qsizetype)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // mid(qsizetype,qsizetype)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_len = Shiboken::String::createStaticString("len");
            if (PyDict_Contains(kwds, key_len) != 0) {
                value = PyDict_GetItem(kwds, key_len);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_len);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_len);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1 = -1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mid(qsizetype,qsizetype)
            QByteArray cppResult = cppSelf->mid(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_number(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.number";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:number", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QByteArray::number(double,char=,int=)->QByteArray
    // 1: static QByteArray::number(int,int=)->QByteArray
    // 2: static QByteArray::number(qlonglong,int=)->QByteArray
    if (numArgs >= 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // number(double,char,int)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // number(double,char,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // number(double,char,int)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // number(qlonglong,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 2; // number(qlonglong,int)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // number(int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // number(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // number(double arg__1, char format, int precision)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                static PyObject *const key_precision = Shiboken::String::createStaticString("precision");
                if (PyDict_Contains(kwds, key_precision) != 0) {
                    value = PyDict_GetItem(kwds, key_precision);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_precision);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_precision);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1 = 'g';
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 6;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // number(double,char,int)
                QByteArray cppResult = ::QByteArray::number(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // number(int arg__1, int base)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_base = Shiboken::String::createStaticString("base");
                if (PyDict_Contains(kwds, key_base) != 0) {
                    value = PyDict_GetItem(kwds, key_base);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_base);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_base);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 10;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // number(int,int)
                QByteArray cppResult = ::QByteArray::number(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 2: // number(qlonglong arg__1, int base)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_base = Shiboken::String::createStaticString("base");
                if (PyDict_Contains(kwds, key_base) != 0) {
                    value = PyDict_GetItem(kwds, key_base);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_base);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_base);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            qlonglong cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 10;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // number(qlonglong,int)
                QByteArray cppResult = ::QByteArray::number(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_percentDecoded(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.percentDecoded";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:percentDecoded", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::percentDecoded(char=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // percentDecoded(char)const
    } else if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0])))) {
        overloadId = 0; // percentDecoded(char)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_percent = Shiboken::String::createStaticString("percent");
            if (PyDict_Contains(kwds, key_percent) != 0) {
                value = PyDict_GetItem(kwds, key_percent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_percent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_percent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        char cppArg0 = '%';
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // percentDecoded(char)const
            QByteArray cppResult = const_cast<const ::QByteArray *>(cppSelf)->percentDecoded(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_prepend(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.prepend";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "prepend", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::prepend(QByteArrayView)->QByteArray&
    // 1: QByteArray::prepend(char)->QByteArray&
    // 2: QByteArray::prepend(QByteArray)->QByteArray&
    // 3: QByteArray::prepend(const char*,qsizetype)->QByteArray&
    // 4: QByteArray::prepend(qsizetype,char)->QByteArray&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
        overloadId = 4; // prepend(qsizetype,char)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 3; // prepend(const char*,qsizetype)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0])))) {
        overloadId = 1; // prepend(char)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 2; // prepend(QByteArray)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 0; // prepend(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // prepend(QByteArrayView a)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // prepend(QByteArrayView)
                QByteArray & cppResult = cppSelf->prepend(QByteArrayView(cppArg0));
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // prepend(char c)
        {
            char cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // prepend(char)
                QByteArray & cppResult = cppSelf->prepend(cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 2: // prepend(const QByteArray &a)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // prepend(QByteArray)
                QByteArray & cppResult = cppSelf->prepend(*cppArg0);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 3: // prepend(const char *s, qsizetype len)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // prepend(const char*,qsizetype)
                QByteArray & cppResult = cppSelf->prepend(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 4: // prepend(qsizetype count, char c)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // prepend(qsizetype,char)
                QByteArray & cppResult = cppSelf->prepend(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_push_back(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.push_back";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::push_back(QByteArrayView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // push_back(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // push_back(QByteArrayView)
            cppSelf->push_back(QByteArrayView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArrayFunc_push_front(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.push_front";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::push_front(QByteArrayView)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // push_front(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // push_front(QByteArrayView)
            cppSelf->push_front(QByteArrayView(cppArg0));
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArrayFunc_remove(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.remove";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "remove", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::remove(qsizetype,qsizetype)->QByteArray&
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // remove(qsizetype,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // remove(qsizetype,qsizetype)
            QByteArray & cppResult = cppSelf->remove(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_removeAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.removeAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::removeAt(qsizetype)->QByteArray&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // removeAt(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAt(qsizetype)
            QByteArray & cppResult = cppSelf->removeAt(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_removeFirst(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.removeFirst";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeFirst()
            QByteArray & cppResult = cppSelf->removeFirst();
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_removeLast(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.removeLast";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeLast()
            QByteArray & cppResult = cppSelf->removeLast();
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_repeated(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.repeated";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::repeated(qsizetype)const->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // repeated(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // repeated(qsizetype)const
            QByteArray cppResult = const_cast<const ::QByteArray *>(cppSelf)->repeated(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_replace(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.replace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "replace", 2, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::replace(QByteArrayView,QByteArrayView)->QByteArray&
    // 1: QByteArray::replace(char,QByteArrayView)->QByteArray&
    // 2: QByteArray::replace(char,char)->QByteArray&
    // 3: QByteArray::replace(const char*,qsizetype,const char*,qsizetype)->QByteArray&
    // 4: QByteArray::replace(qsizetype,qsizetype,QByteArrayView)->QByteArray&
    // 5: QByteArray::replace(qsizetype,qsizetype,const char*,qsizetype)->QByteArray&
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        if (numArgs == 4
            && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[3])))) {
            overloadId = 5; // replace(qsizetype,qsizetype,const char*,qsizetype)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))) {
            overloadId = 4; // replace(qsizetype,qsizetype,QByteArrayView)
        }
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))
        && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[3])))) {
        overloadId = 3; // replace(const char*,qsizetype,const char*,qsizetype)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0])))) {
        if (numArgs == 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            overloadId = 2; // replace(char,char)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 1; // replace(char,QByteArrayView)
        }
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // replace(QByteArrayView,QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // replace(QByteArrayView before, QByteArrayView after)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(QByteArrayView,QByteArrayView)
                QByteArray & cppResult = cppSelf->replace(QByteArrayView(cppArg0), QByteArrayView(cppArg1));
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // replace(char before, QByteArrayView after)
        {
            char cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(char,QByteArrayView)
                QByteArray & cppResult = cppSelf->replace(cppArg0, QByteArrayView(cppArg1));
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 2: // replace(char before, char after)
        {
            char cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(char,char)
                QByteArray & cppResult = cppSelf->replace(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 3: // replace(const char *before, qsizetype bsize, const char *after, qsizetype asize)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qsizetype cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(const char*,qsizetype,const char*,qsizetype)
                QByteArray & cppResult = cppSelf->replace(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 4: // replace(qsizetype index, qsizetype len, QByteArrayView s)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QByteArray cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(qsizetype,qsizetype,QByteArrayView)
                QByteArray & cppResult = cppSelf->replace(cppArg0, cppArg1, QByteArrayView(cppArg2));
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 5: // replace(qsizetype index, qsizetype len, const char *s, qsizetype alen)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qsizetype cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // replace(qsizetype,qsizetype,const char*,qsizetype)
                QByteArray & cppResult = cppSelf->replace(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_reserve(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.reserve";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::reserve(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // reserve(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reserve(qsizetype)
            cppSelf->reserve(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArrayFunc_resize(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.resize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resize", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::resize(qsizetype)
    // 1: QByteArray::resize(qsizetype,char)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // resize(qsizetype)
        } else if (numArgs == 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            overloadId = 1; // resize(qsizetype,char)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // resize(qsizetype size)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // resize(qsizetype)
                cppSelf->resize(cppArg0);
            }
            break;
        }
        case 1: // resize(qsizetype size, char c)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // resize(qsizetype,char)
                cppSelf->resize(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArrayFunc_right(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.right";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::right(qsizetype)->QByteArray
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // right(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // right(qsizetype)
            QByteArray cppResult = cppSelf->right(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_rightJustified(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.rightJustified";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:rightJustified", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::rightJustified(qsizetype,char=,bool=)const->QByteArray
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // rightJustified(qsizetype,char,bool)const
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // rightJustified(qsizetype,char,bool)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))) {
                overloadId = 0; // rightJustified(qsizetype,char,bool)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
            if (PyDict_Contains(kwds, key_fill) != 0) {
                value = PyDict_GetItem(kwds, key_fill);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_fill);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_fill);
            }
            static PyObject *const key_truncate = Shiboken::String::createStaticString("truncate");
            if (PyDict_Contains(kwds, key_truncate) != 0) {
                value = PyDict_GetItem(kwds, key_truncate);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_truncate);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_truncate);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        qsizetype cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        char cppArg1 = ' ';
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        bool cppArg2 = false;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rightJustified(qsizetype,char,bool)const
            QByteArray cppResult = const_cast<const ::QByteArray *>(cppSelf)->rightJustified(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_setNum(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.setNum";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:setNum", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::setNum(double,char=,int=)->QByteArray&
    // 1: QByteArray::setNum(int,int=)->QByteArray&
    // 2: QByteArray::setNum(qlonglong,int=)->QByteArray&
    if (numArgs >= 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setNum(double,char,int)
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setNum(double,char,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // setNum(double,char,int)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // setNum(qlonglong,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 2; // setNum(qlonglong,int)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // setNum(int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // setNum(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setNum(double arg__1, char format, int precision)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                static PyObject *const key_precision = Shiboken::String::createStaticString("precision");
                if (PyDict_Contains(kwds, key_precision) != 0) {
                    value = PyDict_GetItem(kwds, key_precision);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_precision);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_precision);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1 = 'g';
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 6;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setNum(double,char,int)
                QByteArray & cppResult = cppSelf->setNum(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // setNum(int arg__1, int base)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_base = Shiboken::String::createStaticString("base");
                if (PyDict_Contains(kwds, key_base) != 0) {
                    value = PyDict_GetItem(kwds, key_base);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_base);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_base);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 10;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setNum(int,int)
                QByteArray & cppResult = cppSelf->setNum(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 2: // setNum(qlonglong arg__1, int base)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_base = Shiboken::String::createStaticString("base");
                if (PyDict_Contains(kwds, key_base) != 0) {
                    value = PyDict_GetItem(kwds, key_base);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_base);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_base);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            qlonglong cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 10;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setNum(qlonglong,int)
                QByteArray & cppResult = cppSelf->setNum(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_setRawData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.setRawData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setRawData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::setRawData(const char*,qsizetype)->QByteArray&
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // setRawData(const char*,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRawData(const char*,qsizetype)
            QByteArray & cppResult = cppSelf->setRawData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_shrink_to_fit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QByteArray.shrink_to_fit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // shrink_to_fit()
            cppSelf->shrink_to_fit();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArrayFunc_simplified(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.simplified";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // simplified()
            QByteArray cppResult = cppSelf->simplified();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.size";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // size()const
            qsizetype cppResult = const_cast<const ::QByteArray *>(cppSelf)->size();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_sliced(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.sliced";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sliced", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::sliced(qsizetype)->QByteArray
    // 1: QByteArray::sliced(qsizetype,qsizetype)->QByteArray
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // sliced(qsizetype)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 1; // sliced(qsizetype,qsizetype)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // sliced(qsizetype pos)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sliced(qsizetype)
                QByteArray cppResult = cppSelf->sliced(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // sliced(qsizetype pos, qsizetype n)
        {
            qsizetype cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sliced(qsizetype,qsizetype)
                QByteArray cppResult = cppSelf->sliced(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_split(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.split";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::split(char)const->QList< QByteArray>
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
        overloadId = 0; // split(char)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        char cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // split(char)const
            QList<QByteArray> cppResult = const_cast<const ::QByteArray *>(cppSelf)->split(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_squeeze(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QByteArray.squeeze";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // squeeze()
            cppSelf->squeeze();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArrayFunc_startsWith(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.startsWith";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::startsWith(QByteArrayView)const->bool
    // 1: QByteArray::startsWith(char)const->bool
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
        overloadId = 1; // startsWith(char)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // startsWith(QByteArrayView)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // startsWith(QByteArrayView bv) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // startsWith(QByteArrayView)const
                bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->startsWith(QByteArrayView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // startsWith(char c) const
        {
            char cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // startsWith(char)const
                bool cppResult = const_cast<const ::QByteArray *>(cppSelf)->startsWith(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::swap(QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QByteArray&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArrayFunc_toBase64(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toBase64";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toBase64", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toBase64(QFlags<QByteArray::Base64Option>=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // toBase64(QFlags<QByteArray::Base64Option>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QByteArray_Base64Option_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // toBase64(QFlags<QByteArray::Base64Option>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QByteArray_Base64Option_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QFlags<QByteArray::Base64Option> cppArg0(QByteArray::Base64Option::Base64Encoding);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toBase64(QFlags<QByteArray::Base64Option>)const
            QByteArray cppResult = const_cast<const ::QByteArray *>(cppSelf)->toBase64(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toDouble(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toDouble";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // toDouble(bool*)const
            // Begin code injection
            // TEMPLATE - fix_bool* - START
            bool ok_;
            double retval_ = cppSelf->toDouble(&ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toFloat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toFloat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // toFloat(bool*)const
            // Begin code injection
            // TEMPLATE - fix_bool* - START
            bool ok_;
            float retval_ = cppSelf->toFloat(&ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toHex(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toHex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toHex", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toHex(char=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // toHex(char)const
    } else if (numArgs >= 1
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0])))) {
        overloadId = 0; // toHex(char)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_separator = Shiboken::String::createStaticString("separator");
            if (PyDict_Contains(kwds, key_separator) != 0) {
                value = PyDict_GetItem(kwds, key_separator);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_separator);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_separator);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        char cppArg0 = '\0';
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toHex(char)const
            QByteArray cppResult = const_cast<const ::QByteArray *>(cppSelf)->toHex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toInt(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toInt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toInt", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toInt(bool*=,int=)const->int
    if (numArgs == 0) {
        overloadId = 0; // toInt(bool*,int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toInt(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_base = Shiboken::String::createStaticString("base");
            if (PyDict_Contains(kwds, key_base) != 0) {
                value = PyDict_GetItem(kwds, key_base);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_base);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_base);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)
        int cppArg0 = 10;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toInt(bool*,int)const
            // Begin code injection
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            int retval_ = cppSelf->toInt(&ok_, cppArg0);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool*,arg - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toLong(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toLong";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toLong", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toLong(bool*=,int=)const->long
    if (numArgs == 0) {
        overloadId = 0; // toLong(bool*,int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toLong(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_base = Shiboken::String::createStaticString("base");
            if (PyDict_Contains(kwds, key_base) != 0) {
                value = PyDict_GetItem(kwds, key_base);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_base);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_base);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)
        int cppArg0 = 10;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toLong(bool*,int)const
            // Begin code injection
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            long retval_ = cppSelf->toLong(&ok_, cppArg0);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<long>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool*,arg - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toLongLong(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toLongLong";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toLongLong", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toLongLong(bool*=,int=)const->qlonglong
    if (numArgs == 0) {
        overloadId = 0; // toLongLong(bool*,int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toLongLong(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_base = Shiboken::String::createStaticString("base");
            if (PyDict_Contains(kwds, key_base) != 0) {
                value = PyDict_GetItem(kwds, key_base);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_base);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_base);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)
        int cppArg0 = 10;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toLongLong(bool*,int)const
            // Begin code injection
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            qlonglong retval_ = cppSelf->toLongLong(&ok_, cppArg0);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool*,arg - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toLower(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toLower";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toLower()
            QByteArray cppResult = cppSelf->toLower();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toPercentEncoding(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toPercentEncoding";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:toPercentEncoding", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toPercentEncoding(const QByteArray&=,const QByteArray&=,char=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // toPercentEncoding(QByteArray,QByteArray,char)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toPercentEncoding(QByteArray,QByteArray,char)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // toPercentEncoding(QByteArray,QByteArray,char)const
            } else if (numArgs >= 3
                && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[2])))) {
                overloadId = 0; // toPercentEncoding(QByteArray,QByteArray,char)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_exclude = Shiboken::String::createStaticString("exclude");
            if (PyDict_Contains(kwds, key_exclude) != 0) {
                value = PyDict_GetItem(kwds, key_exclude);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_exclude);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_exclude);
            }
            static PyObject *const key_include = Shiboken::String::createStaticString("include");
            if (PyDict_Contains(kwds, key_include) != 0) {
                value = PyDict_GetItem(kwds, key_include);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_include);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_include);
            }
            static PyObject *const key_percent = Shiboken::String::createStaticString("percent");
            if (PyDict_Contains(kwds, key_percent) != 0) {
                value = PyDict_GetItem(kwds, key_percent);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_percent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_percent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local = QByteArray();
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local = QByteArray();
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }
        char cppArg2 = '%';
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toPercentEncoding(QByteArray,QByteArray,char)const
            QByteArray cppResult = const_cast<const ::QByteArray *>(cppSelf)->toPercentEncoding(*cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toShort(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toShort";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toShort", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toShort(bool*=,int=)const->short
    if (numArgs == 0) {
        overloadId = 0; // toShort(bool*,int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toShort(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_base = Shiboken::String::createStaticString("base");
            if (PyDict_Contains(kwds, key_base) != 0) {
                value = PyDict_GetItem(kwds, key_base);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_base);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_base);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)
        int cppArg0 = 10;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toShort(bool*,int)const
            // Begin code injection
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            short retval_ = cppSelf->toShort(&ok_, cppArg0);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<short>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool*,arg - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toStdString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toStdString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toStdString()const
            std::string cppResult = const_cast<const ::QByteArray *>(cppSelf)->toStdString();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<std::string>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toUInt(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toUInt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toUInt", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toUInt(bool*=,int=)const->uint
    if (numArgs == 0) {
        overloadId = 0; // toUInt(bool*,int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toUInt(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_base = Shiboken::String::createStaticString("base");
            if (PyDict_Contains(kwds, key_base) != 0) {
                value = PyDict_GetItem(kwds, key_base);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_base);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_base);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)
        int cppArg0 = 10;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUInt(bool*,int)const
            // Begin code injection
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            uint retval_ = cppSelf->toUInt(&ok_, cppArg0);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool*,arg - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toULong(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toULong";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toULong", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toULong(bool*=,int=)const->ulong
    if (numArgs == 0) {
        overloadId = 0; // toULong(bool*,int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toULong(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_base = Shiboken::String::createStaticString("base");
            if (PyDict_Contains(kwds, key_base) != 0) {
                value = PyDict_GetItem(kwds, key_base);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_base);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_base);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)
        int cppArg0 = 10;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toULong(bool*,int)const
            // Begin code injection
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            ulong retval_ = cppSelf->toULong(&ok_, cppArg0);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<ulong>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool*,arg - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toULongLong(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toULongLong";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toULongLong", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toULongLong(bool*=,int=)const->qulonglong
    if (numArgs == 0) {
        overloadId = 0; // toULongLong(bool*,int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toULongLong(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_base = Shiboken::String::createStaticString("base");
            if (PyDict_Contains(kwds, key_base) != 0) {
                value = PyDict_GetItem(kwds, key_base);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_base);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_base);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)
        int cppArg0 = 10;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toULongLong(bool*,int)const
            // Begin code injection
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            qulonglong retval_ = cppSelf->toULongLong(&ok_, cppArg0);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qulonglong>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool*,arg - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toUShort(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toUShort";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toUShort", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArray::toUShort(bool*=,int=)const->ushort
    if (numArgs == 0) {
        overloadId = 0; // toUShort(bool*,int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // toUShort(bool*,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_base = Shiboken::String::createStaticString("base");
            if (PyDict_Contains(kwds, key_base) != 0) {
                value = PyDict_GetItem(kwds, key_base);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_base);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_base);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        bool* removed_cppArg0 = nullptr;
        SBK_UNUSED(removed_cppArg0)
        int cppArg0 = 10;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUShort(bool*,int)const
            // Begin code injection
            // TEMPLATE - fix_bool*,arg - START
            bool ok_;
            ushort retval_ = cppSelf->toUShort(&ok_, cppArg0);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_bool*,arg - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_toUpper(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.toUpper";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUpper()
            QByteArray cppResult = cppSelf->toUpper();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_trimmed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.trimmed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // trimmed()
            QByteArray cppResult = cppSelf->trimmed();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc_truncate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.truncate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::truncate(qsizetype)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // truncate(qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // truncate(qsizetype)
            cppSelf->truncate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArray__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QByteArray_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QByteArray_EnumFlagInfo[] = {
    "Base64DecodingStatus:Enum",
    "Base64Option:Flag:Base64Options",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QByteArray_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc___reduce__), METH_NOARGS, nullptr},
    {"append", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_append), METH_VARARGS, nullptr},
    {"assign", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_assign), METH_VARARGS, nullptr},
    {"at", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_at), METH_O, nullptr},
    {"back", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_back), METH_NOARGS, nullptr},
    {"capacity", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_capacity), METH_NOARGS, nullptr},
    {"cbegin", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_cbegin), METH_NOARGS, nullptr},
    {"cend", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_cend), METH_NOARGS, nullptr},
    {"chop", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_chop), METH_O, nullptr},
    {"chopped", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_chopped), METH_O, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_clear), METH_NOARGS, nullptr},
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_compare), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_contains), METH_O, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_count), METH_VARARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_data), METH_NOARGS, nullptr},
    {"endsWith", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_endsWith), METH_O, nullptr},
    {"erase", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_erase), METH_VARARGS, nullptr},
    {"fill", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_fill), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"first", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_first), METH_O, nullptr},
    {"fromBase64", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_fromBase64), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromBase64Encoding", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_fromBase64Encoding), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromHex", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_fromHex), METH_O|METH_STATIC, nullptr},
    {"fromPercentEncoding", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_fromPercentEncoding), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromRawData", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_fromRawData), METH_VARARGS|METH_STATIC, nullptr},
    {"fromStdString", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_fromStdString), METH_O|METH_STATIC, nullptr},
    {"front", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_front), METH_NOARGS, nullptr},
    {"indexOf", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_indexOf), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_insert), METH_VARARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_isEmpty), METH_NOARGS, nullptr},
    {"isLower", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_isLower), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_isNull), METH_NOARGS, nullptr},
    {"isSharedWith", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_isSharedWith), METH_O, nullptr},
    {"isUpper", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_isUpper), METH_NOARGS, nullptr},
    {"isValidUtf8", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_isValidUtf8), METH_NOARGS, nullptr},
    {"last", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_last), METH_O, nullptr},
    {"lastIndexOf", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_lastIndexOf), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"left", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_left), METH_O, nullptr},
    {"leftJustified", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_leftJustified), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_length), METH_NOARGS, nullptr},
    {"mid", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_mid), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"number", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_number), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"percentDecoded", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_percentDecoded), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"prepend", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_prepend), METH_VARARGS, nullptr},
    {"push_back", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_push_back), METH_O, nullptr},
    {"push_front", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_push_front), METH_O, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_remove), METH_VARARGS, nullptr},
    {"removeAt", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_removeAt), METH_O, nullptr},
    {"removeFirst", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_removeFirst), METH_NOARGS, nullptr},
    {"removeLast", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_removeLast), METH_NOARGS, nullptr},
    {"repeated", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_repeated), METH_O, nullptr},
    {"replace", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_replace), METH_VARARGS, nullptr},
    {"reserve", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_reserve), METH_O, nullptr},
    {"resize", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_resize), METH_VARARGS, nullptr},
    {"right", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_right), METH_O, nullptr},
    {"rightJustified", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_rightJustified), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setNum", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_setNum), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setRawData", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_setRawData), METH_VARARGS, nullptr},
    {"shrink_to_fit", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_shrink_to_fit), METH_NOARGS, nullptr},
    {"simplified", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_simplified), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_size), METH_NOARGS, nullptr},
    {"sliced", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_sliced), METH_VARARGS, nullptr},
    {"split", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_split), METH_O, nullptr},
    {"squeeze", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_squeeze), METH_NOARGS, nullptr},
    {"startsWith", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_startsWith), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_swap), METH_O, nullptr},
    {"toBase64", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toBase64), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toDouble", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toDouble), METH_NOARGS, nullptr},
    {"toFloat", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toFloat), METH_NOARGS, nullptr},
    {"toHex", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toHex), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toInt", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toInt), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toLong", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toLong), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toLongLong", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toLongLong), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toLower", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toLower), METH_NOARGS, nullptr},
    {"toPercentEncoding", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toPercentEncoding), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toShort", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toShort), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toStdString", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toStdString), METH_NOARGS, nullptr},
    {"toUInt", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toUInt), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toULong", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toULong), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toULongLong", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toULongLong), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toUShort", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toUShort), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toUpper", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_toUpper), METH_NOARGS, nullptr},
    {"trimmed", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_trimmed), METH_NOARGS, nullptr},
    {"truncate", reinterpret_cast<PyCFunction>(Sbk_QByteArrayFunc_truncate), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QByteArray__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QByteArrayFunc___add__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.__add__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::operator+(PyByteArray)->QByteArray
    // 1: QByteArray::operator+(PyByteArray)->QByteArray
    // 2: QByteArray::operator+(PyBytes)
    // 3: QByteArray::operator+(char)->QByteArray
    // 4: QByteArray::operator+(char)->QByteArray
    // 5: QByteArray::operator+(QByteArray)->QByteArray
    // 6: QByteArray::operator+(QByteArray)->QByteArray
    // 7: QByteArray::operator+(QString)->QString
    // 8: QByteArray::operator+(QString)->QString
    // 9: QByteArray::operator+(const char*)->QByteArray
    if (!isReverse
        && Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 9; // operator+(QByteArray&&,const char*)
    } else if (!isReverse
        && SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
        overloadId = 4; // operator+(QByteArray&&,char)
    } else if (!isReverse
        && SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
        overloadId = 3; // operator+(QByteArray,char)
    } else if (isReverse
        && PyBytes_Check(pyArg)) {
        overloadId = 2; // operator+(PyBytes,QByteArray)
    } else if (!isReverse
        && PyByteArray_Check(pyArg)) {
        overloadId = 1; // operator+(PyByteArray)
    } else if (isReverse
        && PyByteArray_Check(pyArg)) {
        overloadId = 0; // operator+(PyByteArray,QByteArray)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 8; // operator+(QByteArray,QString)
    } else if (isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 7; // operator+(QString,QByteArray)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 6; // operator+(QByteArray&&,QByteArray)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 5; // operator+(QByteArray,QByteArray)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // operator+(PyByteArray , QByteArray )
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(PyByteArray,QByteArray) [reverse operator]
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorplus-2)]
                QByteArray ba = QByteArray(PyByteArray_AsString(pyArg), PyByteArray_Size(pyArg)) + *cppSelf;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &ba);
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorplus-2)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // operator+(PyByteArray arg__1)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(PyByteArray)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorplus-3)]
                QByteArray ba = *cppSelf + QByteArray(PyByteArray_AsString(pyArg), PyByteArray_Size(pyArg));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &ba);
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorplus-3)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 2: // operator+(PyBytes , QByteArray )
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(PyBytes,QByteArray) [reverse operator]
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorplus-1)]
                QByteArray ba = QByteArray(PyBytes_AS_STRING(pyArg), PyBytes_GET_SIZE(pyArg)) + *cppSelf;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &ba);
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorplus-1)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 3: // operator+(char a2)
        {
            char cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QByteArray,char)
                QByteArray cppResult = (*cppSelf) + cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 4: // operator+(char rhs)
        {
            char cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QByteArray&&,char)
                QByteArray cppResult = (*cppSelf) + cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 5: // operator+(const QByteArray &a2)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QByteArray,QByteArray)
                QByteArray cppResult = (*cppSelf) + (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 6: // operator+(const QByteArray &rhs)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QByteArray&&,QByteArray)
                QByteArray cppResult = (*cppSelf) + (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 7: // operator+(const QString &s)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QString,QByteArray) [reverse operator]
                QString cppResult = cppArg0 + (*cppSelf);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 8: // operator+(const QString &s)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QByteArray,QString)
                QString cppResult = (*cppSelf) + cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 9: // operator+(const char *rhs)
        {
            const char* cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+(QByteArray&&,const char*)
                QByteArray cppResult = (*cppSelf) + cppArg0;
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayFunc___iadd__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArray.__iadd__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArray::operator+=(PyByteArray)->QByteArray
    // 1: QByteArray::operator+=(QByteArrayView)->QByteArray&
    // 2: QByteArray::operator+=(char)->QByteArray&
    // 3: QByteArray::operator+=(QByteArray)->QByteArray&
    if (!isReverse
        && SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
        overloadId = 2; // operator+=(char)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 3; // operator+=(QByteArray)
    } else if (!isReverse
        && (pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 1; // operator+=(QByteArrayView)
    } else if (!isReverse
        && PyByteArray_Check(pyArg)) {
        overloadId = 0; // operator+=(PyByteArray)
    }

    if (isReverse && overloadId == -1) {
        Shiboken::Errors::setReverseOperatorNotImplemented();
        return {};
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // operator+=(PyByteArray arg__1)
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+=(PyByteArray)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorplusequal)]
                *cppSelf += QByteArray(PyByteArray_AsString(pyArg), PyByteArray_Size(pyArg));
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorplusequal)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // operator+=(QByteArrayView a)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+=(QByteArrayView)
                (*cppSelf) += cppArg0;
            }
            break;
        }
        case 2: // operator+=(char c)
        {
            char cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+=(char)
                (*cppSelf) += cppArg0;
            }
            break;
        }
        case 3: // operator+=(const QByteArray &a)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // operator+=(QByteArray)
                (*cppSelf) += (*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_INCREF(self);
    return self;
}

Py_ssize_t Sbk_QByteArrayFunc___len__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-len)]
    return cppSelf->size();
    // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-len)]
    // ========================================================================
    // End of code injection

}

PyObject* Sbk_QByteArrayFunc___getitem__(PyObject *self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-getitem)]
    if (_i < 0 || _i >= cppSelf->size()) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return 0;
    } else {
        char res[2];
        res[0] = cppSelf->at(_i);
        res[1] = 0;
        return PyBytes_FromStringAndSize(res, 1);
    }
    // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-getitem)]
    // ========================================================================
    // End of code injection

}

int Sbk_QByteArrayFunc___setitem__(PyObject *self, Py_ssize_t _i, PyObject *_value)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-setitem)]
    cppSelf->remove(_i, 1);
    PyObject *args = Py_BuildValue("(nO)", _i, _value);
    PyObject *result = Sbk_QByteArrayFunc_insert(self, args);
    Py_DECREF(args);
    Py_XDECREF(result);
    return !result ? -1 : 0;
    // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-setitem)]
    // ========================================================================
    // End of code injection

}

PyObject* Sbk_QByteArrayFunc___mgetitem__(PyObject *self, PyObject *_key)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-mgetitem)]
    if (PyIndex_Check(_key)) {
        const Py_ssize_t _i = PyNumber_AsSsize_t(_key, PyExc_IndexError);
        if (_i < 0 || _i >= cppSelf->size())
            return PyErr_Format(PyExc_IndexError, "index out of bounds");
        char res[2] = {cppSelf->at(_i), '\0'};
        return PyBytes_FromStringAndSize(res, 1);
    }

    if (PySlice_Check(_key) == 0)
        return PyErr_Format(PyExc_TypeError,
                     "list indices must be integers or slices, not %.200s",
                     Py_TYPE(_key)->tp_name);

    Py_ssize_t start, stop, step, slicelength;
    if (PySlice_GetIndicesEx(_key, cppSelf->size(), &start, &stop, &step, &slicelength) < 0)
        return nullptr;

    QByteArray ba;
    if (slicelength <= 0)
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &ba);

    if (step == 1) {
        Py_ssize_t max = cppSelf->size();
        start = qBound(Py_ssize_t(0), start, max);
        stop = qBound(Py_ssize_t(0), stop, max);
        if (start < stop)
            ba = cppSelf->mid(start, stop - start);
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &ba);
    }

    for (Py_ssize_t cur = start; slicelength > 0; cur += step, --slicelength)
        ba.append(cppSelf->at(cur));

    return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &ba);
    // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-mgetitem)]
    // ========================================================================
    // End of code injection

}

int Sbk_QByteArrayFunc___msetitem__(PyObject *self, PyObject *_key, PyObject *_value)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-msetitem)]
    // PYSIDE-2404: Usage of the `get()` function not necessary, the type exists.
    if (PyIndex_Check(_key)) {
        Py_ssize_t _i = PyNumber_AsSsize_t(_key, PyExc_IndexError);
        if (_i == -1 && PyErr_Occurred())
            return -1;

        if (_i < 0)
            _i += cppSelf->size();

        if (_i < 0 || _i >= cppSelf->size()) {
            PyErr_SetString(PyExc_IndexError, "QByteArray index out of range");
            return -1;
        }

        // Provide more specific error message for bytes/str, bytearray, QByteArray respectively
        if (PyBytes_Check(_value)) {
            if (Py_SIZE(_value) != 1) {
                PyErr_SetString(PyExc_ValueError, "bytes must be of size 1");
                return -1;
            }
        } else if (PyByteArray_Check(_value)) {
            if (Py_SIZE(_value) != 1) {
                PyErr_SetString(PyExc_ValueError, "bytearray must be of size 1");
                return -1;
            }
        } else if (Py_TYPE(_value) == reinterpret_cast<PyTypeObject *>(
                SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX].type)) {
            if (PyObject_Length(_value) != 1) {
                PyErr_SetString(PyExc_ValueError, "QByteArray must be of size 1");
                return -1;
            }
        } else {
            PyErr_SetString(PyExc_ValueError, "a bytes, bytearray, QByteArray of size 1 is required");
            return -1;
        }

        // Not support int or long.
        cppSelf->remove(_i, 1);
        PyObject *args = Py_BuildValue("(nO)", _i, _value);
        PyObject *result = Sbk_QByteArrayFunc_insert(self, args);
        Py_DECREF(args);
        Py_XDECREF(result);
        return result != nullptr ? 0: -1;
    }

    if (PySlice_Check(_key) == 0) {
        PyErr_Format(PyExc_TypeError, "QBytearray indices must be integers or slices, not %.200s",
                     Py_TYPE(_key)->tp_name);
        return -1;
    }

    Py_ssize_t start, stop, step, slicelength;
    if (PySlice_GetIndicesEx(_key, cppSelf->size(), &start, &stop, &step, &slicelength) < 0)
        return -1;

    // The parameter candidates are: bytes/str, bytearray, QByteArray itself.
    // Not supported are iterables containing ints between 0~255
    // case 1: value is nullpre, means delete the items within the range
    // case 2: step is 1, means shrink or expand
    // case 3: step is not 1, then the number of slots have to equal the number of items in _value
    Py_ssize_t value_length = 0;
    if (_value != nullptr && _value != Py_None) {
        if (!(PyBytes_Check(_value) || PyByteArray_Check(_value)
              || Py_TYPE(_value) == SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX].type)) {
               PyErr_Format(PyExc_TypeError, "bytes, bytearray or QByteArray is required, not %.200s",
                            Py_TYPE(_value)->tp_name);
               return -1;
        }
        value_length = PyObject_Length(_value);
    }

    if (step != 1 && value_length != slicelength) {
        PyErr_Format(PyExc_ValueError, "attempt to assign %s of size %d to extended slice of size %d",
                     Py_TYPE(_value)->tp_name, int(value_length), int(slicelength));
        return -1;
    }

    if (step != 1) {
        Py_ssize_t i = start;
        for (Py_ssize_t j = 0; j < slicelength; ++j) {
            PyObject *item = PyObject_GetItem(_value, PyLong_FromSsize_t(j));
            QByteArray temp;
            if (PyLong_Check(item)) {
                int overflow;
                const long ival = PyLong_AsLongAndOverflow(item, &overflow);
                // Not supposed to be bigger than 255 because only bytes,
                // bytearray, QByteArray were accepted
                temp.append(char(ival));
            } else {
                Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), item, &(temp));
            }
            cppSelf->replace(i, 1, temp);
            i += step;
        }
        return 0;
    }

    ::QByteArray ba;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), _value, &(ba));
    cppSelf->replace(start, slicelength, ba);
    return 0;
    // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-msetitem)]
    // ========================================================================
    // End of code injection

}

// Rich comparison
static PyObject * Sbk_QByteArray_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if (PyUnicode_Check(pyArg)) {
                // operator!=(PyUnicode arg__1)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatornotequal)]
                if (PyUnicode_CheckExact(pyArg)) {
                    Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(pyArg));
                    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
                    bool cppResult = cppSelf != ba;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                }
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatornotequal)]
                // ========================================================================
                // End of code injection

            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
                // operator!=(const QString &s2) const
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
                // operator!=(const QByteArray &a2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
                // operator<(const char *a2)
                const char* cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf < (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if (PyUnicode_Check(pyArg)) {
                // operator<(PyUnicode arg__1)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorlower)]
                if (PyUnicode_CheckExact(pyArg)) {
                    Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(pyArg));
                    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
                    bool cppResult = cppSelf < ba;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                }
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorlower)]
                // ========================================================================
                // End of code injection

            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
                // operator<(const QString &s2) const
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf < (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
                // operator<(const QByteArray &a2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if (PyUnicode_Check(pyArg)) {
                // operator<=(PyUnicode arg__1)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorlowerequal)]
                if (PyUnicode_CheckExact(pyArg)) {
                    Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(pyArg));
                    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
                    bool cppResult = cppSelf <= ba;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                }
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorlowerequal)]
                // ========================================================================
                // End of code injection

            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
                // operator<=(const QString &s2) const
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf <= (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
                // operator<=(const QByteArray &a2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if (PyUnicode_Check(pyArg)) {
                // operator==(PyUnicode arg__1)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorequalequal)]
                if (PyUnicode_CheckExact(pyArg)) {
                    Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(pyArg));
                    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
                    bool cppResult = cppSelf == ba;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                }
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorequalequal)]
                // ========================================================================
                // End of code injection

            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
                // operator==(const QString &s2) const
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
                // operator==(const QByteArray &a2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if (PyUnicode_Check(pyArg)) {
                // operator>(PyUnicode arg__1)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorgreater)]
                if (PyUnicode_CheckExact(pyArg)) {
                    Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(pyArg));
                    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
                    bool cppResult = cppSelf > ba;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                }
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorgreater)]
                // ========================================================================
                // End of code injection

            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
                // operator>(const QString &s2) const
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf > (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
                // operator>(const QByteArray &a2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if (PyUnicode_Check(pyArg)) {
                // operator>=(PyUnicode arg__1)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorgreaterequal)]
                if (PyUnicode_CheckExact(pyArg)) {
                    Shiboken::AutoDecRef data(PyUnicode_AsASCIIString(pyArg));
                    QByteArray ba = QByteArray(PyBytes_AsString(data.object()), PyBytes_GET_SIZE(data.object()));
                    bool cppResult = cppSelf >= ba;
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
                }
                // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-operatorgreaterequal)]
                // ========================================================================
                // End of code injection

            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
                // operator>=(const QString &s2) const
                ::QString cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf >= (cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
                // operator>=(const QByteArray &a2)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QByteArray cppArg0_local;
                ::QByteArray *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QByteArray_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QByteArray_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QByteArray_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QByteArray_Type = nullptr;
static PyTypeObject *Sbk_QByteArray_TypeF(void)
{
    return _Sbk_QByteArray_Type;
}

static PyType_Slot Sbk_QByteArray_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QByteArrayFunc___repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QByteArray_HashFunc)},
    {Py_tp_str,         reinterpret_cast<void *>(Sbk_QByteArrayFunc___str__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QByteArray_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QByteArray_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QByteArray_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QByteArray_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QByteArray_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports sequence protocol
    {Py_sq_ass_item,    reinterpret_cast<void *>(&Sbk_QByteArrayFunc___setitem__)},
    {Py_sq_length,      reinterpret_cast<void *>(&Sbk_QByteArrayFunc___len__)},
    {Py_sq_item,        reinterpret_cast<void *>(&Sbk_QByteArrayFunc___getitem__)},
    // type supports mapping protocol
    {Py_mp_subscript,   reinterpret_cast<void *>(reinterpret_cast<void *>(&Sbk_QByteArrayFunc___mgetitem__))},
    {Py_mp_ass_subscript,reinterpret_cast<void *>(reinterpret_cast<void *>(&Sbk_QByteArrayFunc___msetitem__))},
    // type supports number protocol
    {Py_nb_inplace_add, reinterpret_cast<void *>(Sbk_QByteArrayFunc___iadd__)},
    {Py_nb_add,         reinterpret_cast<void *>(Sbk_QByteArrayFunc___add__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QByteArray_spec = {
    "2:PySide6.QtCore.QByteArray",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QByteArray_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QByteArray_Base64Option(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QByteArray::Base64Option>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QByteArray::Base64Option *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QByteArray_Base64Option_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_Base64Option_IDX])))
        return Enum_PythonToCpp_QByteArray_Base64Option;
    return {};
}
static PyObject *QByteArray_Base64Option_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QByteArray::Base64Option *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_Base64Option_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QByteArray_Base64DecodingStatus(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QByteArray::Base64DecodingStatus>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QByteArray::Base64DecodingStatus *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QByteArray_Base64DecodingStatus_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_Base64DecodingStatus_IDX])))
        return Enum_PythonToCpp_QByteArray_Base64DecodingStatus;
    return {};
}
static PyObject *QByteArray_Base64DecodingStatus_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QByteArray::Base64DecodingStatus *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_Base64DecodingStatus_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QByteArray_PythonToCpp_QByteArray_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QByteArray_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QByteArray_PythonToCpp_QByteArray_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QByteArray_TypeF()))
        return QByteArray_PythonToCpp_QByteArray_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QByteArray_PTR_CppToPython_QByteArray(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QByteArray *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QByteArray_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QByteArray_COPY_CppToPython_QByteArray(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QByteArray *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QByteArray_TypeF(), new ::QByteArray(*source), true, true);
}

// Python to C++ copy conversion.
static void QByteArray_PythonToCpp_QByteArray_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QByteArray *>(cppOut) = *reinterpret_cast< ::QByteArray *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QByteArray_PythonToCpp_QByteArray_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QByteArray_TypeF()))
        return QByteArray_PythonToCpp_QByteArray_COPY;
    return {};
}

// Python to C++ conversions for type 'QByteArray'.
static void Py_None_PythonToCpp_QByteArray(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    SBK_UNUSED(pyIn)
    *reinterpret_cast<::QByteArray *>(cppOut) = QByteArray();
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-pynone)]
    // ========================================================================

}
static PythonToCppFunc is_Py_None_PythonToCpp_QByteArray_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Py_None_PythonToCpp_QByteArray;
    return {};
}
static void PyBytes_PythonToCpp_QByteArray(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-qbytearray-pybytes)]
    *reinterpret_cast<::QByteArray *>(cppOut) = QByteArray(PyBytes_AS_STRING(pyIn), PyBytes_GET_SIZE(pyIn));
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-qbytearray-pybytes)]
    // ========================================================================

}
static PythonToCppFunc is_PyBytes_PythonToCpp_QByteArray_Convertible(PyObject *pyIn)
{
    if (PyBytes_Check(pyIn))
        return PyBytes_PythonToCpp_QByteArray;
    return {};
}
static void PyByteArray_PythonToCpp_QByteArray(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-qbytearray-pybytearray)]
    *reinterpret_cast<::QByteArray *>(cppOut) = QByteArray(PyByteArray_AsString(pyIn), PyByteArray_Size(pyIn));
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-qbytearray-pybytearray)]
    // ========================================================================

}
static PythonToCppFunc is_PyByteArray_PythonToCpp_QByteArray_Convertible(PyObject *pyIn)
{
    if (PyByteArray_Check(pyIn))
        return PyByteArray_PythonToCpp_QByteArray;
    return {};
}
static void PyString_PythonToCpp_QByteArray(PyObject *pyIn, void *cppOut)
{
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (conversion-qbytearray-pystring)]
    *reinterpret_cast<::QByteArray *>(cppOut) = QByteArray(Shiboken::String::toCString(pyIn), Shiboken::String::len(pyIn));
    // END of custom code block [file: ../glue/qtcore.cpp (conversion-qbytearray-pystring)]
    // ========================================================================

}
static PythonToCppFunc is_PyString_PythonToCpp_QByteArray_Convertible(PyObject *pyIn)
{
    if (Shiboken::String::check(pyIn) && !PyUnicode_Check(pyIn))
        return PyString_PythonToCpp_QByteArray;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QByteArray_SignatureStrings[] = {
    "5:PySide6.QtCore.QByteArray(self)",
    "4:PySide6.QtCore.QByteArray(self,arg__1:PyByteArray)",
    "3:PySide6.QtCore.QByteArray(self,arg__1:PyBytes)",
    "2:PySide6.QtCore.QByteArray(self,arg__1:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "1:PySide6.QtCore.QByteArray(self,arg__1:char*,size:qsizetype=-1)",
    "0:PySide6.QtCore.QByteArray(self,size:qsizetype,c:char)",
    "PySide6.QtCore.QByteArray.__reduce__(self)->PyObject",
    "PySide6.QtCore.QByteArray.__repr__(self)->PyObject",
    "PySide6.QtCore.QByteArray.__str__(self)->PyObject",
    "4:PySide6.QtCore.QByteArray.append(self,a:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "3:PySide6.QtCore.QByteArray.append(self,c:char)->PySide6.QtCore.QByteArray",
    "2:PySide6.QtCore.QByteArray.append(self,a:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QByteArray.append(self,s:char*,len:qsizetype)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.QByteArray.append(self,count:qsizetype,c:char)->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QByteArray.assign(self,v:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.QByteArray.assign(self,n:qsizetype,c:char)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.at(self,i:qsizetype)->char",
    "PySide6.QtCore.QByteArray.back(self)->char",
    "PySide6.QtCore.QByteArray.capacity(self)->qsizetype",
    "PySide6.QtCore.QByteArray.cbegin(self)->char*",
    "PySide6.QtCore.QByteArray.cend(self)->char*",
    "PySide6.QtCore.QByteArray.chop(self,n:qsizetype)",
    "PySide6.QtCore.QByteArray.chopped(self,len:qsizetype)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.clear(self)",
    "PySide6.QtCore.QByteArray.compare(self,a:typing.Union[PySide6.QtCore.QByteArray, char*],cs:PySide6.QtCore.Qt.CaseSensitivity=Qt.CaseSensitive)->int",
    "1:PySide6.QtCore.QByteArray.contains(self,bv:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "0:PySide6.QtCore.QByteArray.contains(self,c:char)->bool",
    "2:PySide6.QtCore.QByteArray.count(self)->qsizetype",
    "1:PySide6.QtCore.QByteArray.count(self,bv:typing.Union[PySide6.QtCore.QByteArray, char*])->qsizetype",
    "0:PySide6.QtCore.QByteArray.count(self,c:char)->qsizetype",
    "PySide6.QtCore.QByteArray.data(self)->char*",
    "1:PySide6.QtCore.QByteArray.endsWith(self,bv:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "0:PySide6.QtCore.QByteArray.endsWith(self,c:char)->bool",
    "1:PySide6.QtCore.QByteArray.erase(self,first:char*,last:char*)->char*",
    "0:PySide6.QtCore.QByteArray.erase(self,it:char*)->char*",
    "PySide6.QtCore.QByteArray.fill(self,c:char,size:qsizetype=-1)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.first(self,n:qsizetype)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.fromBase64(base64:typing.Union[PySide6.QtCore.QByteArray, char*],options:PySide6.QtCore.QByteArray.Base64Option=QByteArray.Base64Option.Base64Encoding)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.fromBase64Encoding(base64:typing.Union[PySide6.QtCore.QByteArray, char*],options:PySide6.QtCore.QByteArray.Base64Option=QByteArray.Base64Option.Base64Encoding)->PySide6.QtCore.QByteArray.FromBase64Result",
    "PySide6.QtCore.QByteArray.fromHex(hexEncoded:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.fromPercentEncoding(pctEncoded:typing.Union[PySide6.QtCore.QByteArray, char*],percent:char='%')->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.fromRawData(data:str,size:qsizetype)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.fromStdString(s:std.string)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.front(self)->char",
    "1:PySide6.QtCore.QByteArray.indexOf(self,bv:typing.Union[PySide6.QtCore.QByteArray, char*],from:qsizetype=0)->qsizetype",
    "0:PySide6.QtCore.QByteArray.indexOf(self,c:char,from:qsizetype=0)->qsizetype",
    "5:PySide6.QtCore.QByteArray.insert(self,i:qsizetype,data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "4:PySide6.QtCore.QByteArray.insert(self,i:qsizetype,c:char)->PySide6.QtCore.QByteArray",
    "3:PySide6.QtCore.QByteArray.insert(self,i:qsizetype,data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "2:PySide6.QtCore.QByteArray.insert(self,i:qsizetype,s:char*)->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QByteArray.insert(self,i:qsizetype,s:char*,len:qsizetype)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.QByteArray.insert(self,i:qsizetype,count:qsizetype,c:char)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.isEmpty(self)->bool",
    "PySide6.QtCore.QByteArray.isLower(self)->bool",
    "PySide6.QtCore.QByteArray.isNull(self)->bool",
    "PySide6.QtCore.QByteArray.isSharedWith(self,other:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "PySide6.QtCore.QByteArray.isUpper(self)->bool",
    "PySide6.QtCore.QByteArray.isValidUtf8(self)->bool",
    "PySide6.QtCore.QByteArray.last(self,n:qsizetype)->PySide6.QtCore.QByteArray",
    "2:PySide6.QtCore.QByteArray.lastIndexOf(self,bv:typing.Union[PySide6.QtCore.QByteArray, char*])->qsizetype",
    "1:PySide6.QtCore.QByteArray.lastIndexOf(self,bv:typing.Union[PySide6.QtCore.QByteArray, char*],from:qsizetype)->qsizetype",
    "0:PySide6.QtCore.QByteArray.lastIndexOf(self,c:char,from:qsizetype=-1)->qsizetype",
    "PySide6.QtCore.QByteArray.left(self,n:qsizetype)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.leftJustified(self,width:qsizetype,fill:char=' ',truncate:bool=false)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.length(self)->qsizetype",
    "PySide6.QtCore.QByteArray.mid(self,index:qsizetype,len:qsizetype=-1)->PySide6.QtCore.QByteArray",
    "2:PySide6.QtCore.QByteArray.number(arg__1:double,format:char='g',precision:int=6)->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QByteArray.number(arg__1:int,base:int=10)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.QByteArray.number(arg__1:qlonglong,base:int=10)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.percentDecoded(self,percent:char='%')->PySide6.QtCore.QByteArray",
    "4:PySide6.QtCore.QByteArray.prepend(self,a:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "3:PySide6.QtCore.QByteArray.prepend(self,c:char)->PySide6.QtCore.QByteArray",
    "2:PySide6.QtCore.QByteArray.prepend(self,a:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QByteArray.prepend(self,s:char*,len:qsizetype)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.QByteArray.prepend(self,count:qsizetype,c:char)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.push_back(self,a:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtCore.QByteArray.push_front(self,a:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtCore.QByteArray.remove(self,index:qsizetype,len:qsizetype)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.removeAt(self,pos:qsizetype)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.removeFirst(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.removeLast(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.repeated(self,times:qsizetype)->PySide6.QtCore.QByteArray",
    "5:PySide6.QtCore.QByteArray.replace(self,before:typing.Union[PySide6.QtCore.QByteArray, char*],after:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "4:PySide6.QtCore.QByteArray.replace(self,before:char,after:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "3:PySide6.QtCore.QByteArray.replace(self,before:char,after:char)->PySide6.QtCore.QByteArray",
    "2:PySide6.QtCore.QByteArray.replace(self,before:char*,bsize:qsizetype,after:char*,asize:qsizetype)->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QByteArray.replace(self,index:qsizetype,len:qsizetype,s:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.QByteArray.replace(self,index:qsizetype,len:qsizetype,s:char*,alen:qsizetype)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.reserve(self,size:qsizetype)",
    "1:PySide6.QtCore.QByteArray.resize(self,size:qsizetype)",
    "0:PySide6.QtCore.QByteArray.resize(self,size:qsizetype,c:char)",
    "PySide6.QtCore.QByteArray.right(self,n:qsizetype)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.rightJustified(self,width:qsizetype,fill:char=' ',truncate:bool=false)->PySide6.QtCore.QByteArray",
    "2:PySide6.QtCore.QByteArray.setNum(self,arg__1:double,format:char='g',precision:int=6)->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QByteArray.setNum(self,arg__1:int,base:int=10)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.QByteArray.setNum(self,arg__1:qlonglong,base:int=10)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.setRawData(self,a:char*,n:qsizetype)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.shrink_to_fit(self)",
    "PySide6.QtCore.QByteArray.simplified(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.size(self)->qsizetype",
    "1:PySide6.QtCore.QByteArray.sliced(self,pos:qsizetype)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.QByteArray.sliced(self,pos:qsizetype,n:qsizetype)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.split(self,sep:char)->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtCore.QByteArray.squeeze(self)",
    "1:PySide6.QtCore.QByteArray.startsWith(self,bv:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "0:PySide6.QtCore.QByteArray.startsWith(self,c:char)->bool",
    "PySide6.QtCore.QByteArray.swap(self,other:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtCore.QByteArray.toBase64(self,options:PySide6.QtCore.QByteArray.Base64Option=QByteArray.Base64Option.Base64Encoding)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.toDouble(self)->double",
    "PySide6.QtCore.QByteArray.toFloat(self)->float",
    R"CPP(PySide6.QtCore.QByteArray.toHex(self,separator:char='\0')->PySide6.QtCore.QByteArray)CPP",
    "PySide6.QtCore.QByteArray.toInt(self,base:int=10)->int",
    "PySide6.QtCore.QByteArray.toLong(self,base:int=10)->long",
    "PySide6.QtCore.QByteArray.toLongLong(self,base:int=10)->qlonglong",
    "PySide6.QtCore.QByteArray.toLower(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.toPercentEncoding(self,exclude:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray(),include:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray(),percent:char='%')->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.toShort(self,base:int=10)->short",
    "PySide6.QtCore.QByteArray.toStdString(self)->std.string",
    "PySide6.QtCore.QByteArray.toUInt(self,base:int=10)->uint",
    "PySide6.QtCore.QByteArray.toULong(self,base:int=10)->ulong",
    "PySide6.QtCore.QByteArray.toULongLong(self,base:int=10)->qulonglong",
    "PySide6.QtCore.QByteArray.toUShort(self,base:int=10)->ushort",
    "PySide6.QtCore.QByteArray.toUpper(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.trimmed(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArray.truncate(self,pos:qsizetype)",
    "PySide6.QtCore.QByteArray.__copy__()",
    "9:PySide6.QtCore.QByteArray.__add__(self,arg__1:PyByteArray)->PySide6.QtCore.QByteArray",
    "8:PySide6.QtCore.QByteArray.__add__(self,arg__1:PyByteArray)->PySide6.QtCore.QByteArray",
    "7:PySide6.QtCore.QByteArray.__add__(self,arg__1:PyBytes)",
    "6:PySide6.QtCore.QByteArray.__add__(self,a2:char)->PySide6.QtCore.QByteArray",
    "5:PySide6.QtCore.QByteArray.__add__(self,rhs:char)->PySide6.QtCore.QByteArray",
    "4:PySide6.QtCore.QByteArray.__add__(self,a2:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "3:PySide6.QtCore.QByteArray.__add__(self,rhs:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "2:PySide6.QtCore.QByteArray.__add__(self,s:QString)->QString",
    "1:PySide6.QtCore.QByteArray.__add__(self,s:QString)->QString",
    "0:PySide6.QtCore.QByteArray.__add__(self,rhs:char*)->PySide6.QtCore.QByteArray",
    "3:PySide6.QtCore.QByteArray.__iadd__(self,arg__1:PyByteArray)->PySide6.QtCore.QByteArray",
    "2:PySide6.QtCore.QByteArray.__iadd__(self,a:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    "1:PySide6.QtCore.QByteArray.__iadd__(self,c:char)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtCore.QByteArray.__iadd__(self,a:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel

PyTypeObject *init_QByteArray(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX].type;

    Shiboken::AutoDecRef Sbk_QByteArray_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QByteArray_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QByteArray",
        "QByteArray",
        &Sbk_QByteArray_spec,
        &Shiboken::callCppDestructor< ::QByteArray >,
        Sbk_QByteArray_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QByteArray_TypeF(); // references _Sbk_QByteArray_Type
    InitSignatureStrings(pyType, QByteArray_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QByteArray_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QByteArray_PythonToCpp_QByteArray_PTR,
        is_QByteArray_PythonToCpp_QByteArray_PTR_Convertible,
        QByteArray_PTR_CppToPython_QByteArray,
        QByteArray_COPY_CppToPython_QByteArray);

    Shiboken::Conversions::registerConverterName(converter, "QByteArray");
    Shiboken::Conversions::registerConverterName(converter, "QByteArray*");
    Shiboken::Conversions::registerConverterName(converter, "QByteArray&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QByteArray).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QByteArray_PythonToCpp_QByteArray_COPY,
        is_QByteArray_PythonToCpp_QByteArray_COPY_Convertible);
    // Add user defined implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Py_None_PythonToCpp_QByteArray,
        is_Py_None_PythonToCpp_QByteArray_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PyBytes_PythonToCpp_QByteArray,
        is_PyBytes_PythonToCpp_QByteArray_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PyByteArray_PythonToCpp_QByteArray,
        is_PyByteArray_PythonToCpp_QByteArray_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PyString_PythonToCpp_QByteArray,
        is_PyString_PythonToCpp_QByteArray_Convertible);


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QByteArray_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Base64Option'.
    const char *Base64Option_Initializer[] = {
        "Base64Encoding",
        "Base64UrlEncoding",
        "KeepTrailingEquals",
        "OmitTrailingEquals",
        "IgnoreBase64DecodingErrors",
        "AbortOnBase64DecodingErrors",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Base64Option_InitializerValues[] = {
        uint8_t(QByteArray::Base64Option::Base64Encoding),             //  0x00  0
        uint8_t(QByteArray::Base64Option::Base64UrlEncoding),          //  0x01  1
        uint8_t(QByteArray::Base64Option::KeepTrailingEquals),         //  0x00  0
        uint8_t(QByteArray::Base64Option::OmitTrailingEquals),         //  0x02  2
        uint8_t(QByteArray::Base64Option::IgnoreBase64DecodingErrors), //  0x00  0
        uint8_t(QByteArray::Base64Option::AbortOnBase64DecodingErrors) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QByteArray_TypeF(),
        "2:PySide6.QtCore.QByteArray.Base64Option",
        Base64Option_Initializer, Base64Option_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_Base64Option_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QByteArray_Base64Option_IDX].type =
        EType;
    // Register converter for enum 'QByteArray::Base64Option'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QByteArray_Base64Option_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QByteArray_Base64Option,
            is_Enum_PythonToCpp_QByteArray_Base64Option_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QByteArray::Base64Option");
        Shiboken::Conversions::registerConverterName(converter, "Base64Option");
        // Register converter for flag 'QFlags<QByteArray::Base64Option>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QByteArray::Base64Option>");
        Shiboken::Conversions::registerConverterName(converter, "QByteArray::Base64Options");
    }
    // End of 'Base64Option' enum/flags.

    // Initialization of enum 'Base64DecodingStatus'.
    const char *Base64DecodingStatus_Initializer[] = {
        "Ok",
        "IllegalInputLength",
        "IllegalCharacter",
        "IllegalPadding",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Base64DecodingStatus_InitializerValues[] = {
        int8_t(QByteArray::Base64DecodingStatus::Ok),                 //  0x00  0
        int8_t(QByteArray::Base64DecodingStatus::IllegalInputLength), //  0x01  1
        int8_t(QByteArray::Base64DecodingStatus::IllegalCharacter),   //  0x02  2
        int8_t(QByteArray::Base64DecodingStatus::IllegalPadding)      //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QByteArray_TypeF(),
        "2:PySide6.QtCore.QByteArray.Base64DecodingStatus",
        Base64DecodingStatus_Initializer, Base64DecodingStatus_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_Base64DecodingStatus_IDX].type = EType;
    // Register converter for enum 'QByteArray::Base64DecodingStatus'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QByteArray_Base64DecodingStatus_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QByteArray_Base64DecodingStatus,
            is_Enum_PythonToCpp_QByteArray_Base64DecodingStatus_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QByteArray::Base64DecodingStatus");
        Shiboken::Conversions::registerConverterName(converter, "Base64DecodingStatus");
    }
    // End of 'Base64DecodingStatus' enum.


    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (qbytearray-py3)]
    PepType_AS_BUFFER(Shiboken::SbkType<QByteArray>()) = &SbkQByteArrayBufferProc;
    // END of custom code block [file: ../glue/qtcore.cpp (qbytearray-py3)]
    // ========================================================================
    // End of code injection

    qRegisterMetaType< ::QByteArray >("QByteArray");
    qRegisterMetaType< ::QByteArray::Base64Option >("QByteArray::Base64Option");
    qRegisterMetaType< ::QByteArray::Base64DecodingStatus >("QByteArray::Base64DecodingStatus");

    return pyType;
}

