// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphs_python.h"

// main header
#include "qabstract3dgraph_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGraphs/q3dscene.h>
#include <QtGraphs/q3dtheme.h>
#include <QtGraphs/qabstract3daxis.h>
#include <QtGraphs/qabstract3dgraph.h>
#include <QtGraphs/qabstract3dinputhandler.h>
#include <QtGraphs/qabstract3dseries.h>
#include <QtGraphs/qcustom3ditem.h>
#include <QtGui/qcolor.h>
#include <QtGui/qevent.h>
#include <QtGui/qimage.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qvectornd.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmlerror.h>
#include <QtQuick/qquickitem.h>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuickWidgets/qquickwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qlocale.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsharedpointer.h>
#include <qsize.h>
#include <qurl.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstract3DGraphWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstract3DGraphWrapper::QAbstract3DGraphWrapper(const ::QString & graphType) : QAbstract3DGraph(graphType)
{
    resetPyMethodCache();
    // ... middle
}

void QAbstract3DGraphWrapper::actionEvent(::QActionEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QWidget::actionEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "actionEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QActionEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QActionEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::changeEvent(::QEvent * event)
{
    if (m_PyMethodCache[1]) {
        return this->::QWidget::changeEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "changeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QWidget::changeEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::closeEvent(::QCloseEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QWidget::closeEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "closeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    if (m_PyMethodCache[5]) {
        return this->::QWidget::contextMenuEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "contextMenuEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QWidget::contextMenuEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

int QAbstract3DGraphWrapper::devType() const
{
    if (m_PyMethodCache[7])
        return this->::QWidget::devType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "devType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QWidget::devType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DGraphWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[8]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::dragEnterEvent(::QDragEnterEvent * arg__1)
{
    if (m_PyMethodCache[9]) {
        return this->::QQuickWidget::dragEnterEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragEnterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QQuickWidget::dragEnterEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::dragLeaveEvent(::QDragLeaveEvent * arg__1)
{
    if (m_PyMethodCache[10]) {
        return this->::QQuickWidget::dragLeaveEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragLeaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QQuickWidget::dragLeaveEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::dragMoveEvent(::QDragMoveEvent * arg__1)
{
    if (m_PyMethodCache[11]) {
        return this->::QQuickWidget::dragMoveEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QQuickWidget::dragMoveEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::dropEvent(::QDropEvent * arg__1)
{
    if (m_PyMethodCache[12]) {
        return this->::QQuickWidget::dropEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dropEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QQuickWidget::dropEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::enterEvent(::QEnterEvent * event)
{
    if (m_PyMethodCache[13]) {
        return this->::QWidget::enterEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "enterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEnterEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEnterEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QAbstract3DGraphWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[14])
        return this->::QAbstract3DGraph::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QAbstract3DGraph::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstract3DGraphWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[15])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DGraphWrapper::focusInEvent(::QFocusEvent * event)
{
    if (m_PyMethodCache[16]) {
        return this->::QQuickWidget::focusInEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusInEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        gil.release();
        return this->::QQuickWidget::focusInEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QAbstract3DGraphWrapper::focusNextPrevChild(bool next)
{
    if (m_PyMethodCache[17])
        return this->::QQuickWidget::focusNextPrevChild(next);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusNextPrevChild";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QQuickWidget::focusNextPrevChild(next);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &next)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &next)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DGraphWrapper::focusOutEvent(::QFocusEvent * event)
{
    if (m_PyMethodCache[18]) {
        return this->::QQuickWidget::focusOutEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusOutEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        gil.release();
        return this->::QQuickWidget::focusOutEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QAbstract3DGraphWrapper::hasHeightForWidth() const
{
    if (m_PyMethodCache[19])
        return this->::QWidget::hasHeightForWidth();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hasHeightForWidth";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        gil.release();
        return this->::QWidget::hasHeightForWidth();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QAbstract3DGraphWrapper::heightForWidth(int arg__1) const
{
    if (m_PyMethodCache[20])
        return this->::QWidget::heightForWidth(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "heightForWidth";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        arg__1
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DGraphWrapper::hideEvent(::QHideEvent * arg__1)
{
    if (m_PyMethodCache[21]) {
        return this->::QQuickWidget::hideEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hideEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        gil.release();
        return this->::QQuickWidget::hideEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::initPainter(::QPainter * painter) const
{
    if (m_PyMethodCache[22]) {
        return this->::QWidget::initPainter(painter);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[22] = true;
        gil.release();
        return this->::QWidget::initPainter(painter);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    if (m_PyMethodCache[23]) {
        return this->::QWidget::inputMethodEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[23] = true;
        gil.release();
        return this->::QWidget::inputMethodEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QVariant QAbstract3DGraphWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    if (m_PyMethodCache[24])
        return this->::QWidget::inputMethodQuery(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodQuery";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[24] = true;
        gil.release();
        return this->::QWidget::inputMethodQuery(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DGraphWrapper::keyPressEvent(::QKeyEvent * arg__1)
{
    if (m_PyMethodCache[25]) {
        return this->::QQuickWidget::keyPressEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyPressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[25] = true;
        gil.release();
        return this->::QQuickWidget::keyPressEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::keyReleaseEvent(::QKeyEvent * arg__1)
{
    if (m_PyMethodCache[26]) {
        return this->::QQuickWidget::keyReleaseEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[26] = true;
        gil.release();
        return this->::QQuickWidget::keyReleaseEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::leaveEvent(::QEvent * event)
{
    if (m_PyMethodCache[27]) {
        return this->::QWidget::leaveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "leaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[27] = true;
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

int QAbstract3DGraphWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    if (m_PyMethodCache[28])
        return this->::QWidget::metric(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "metric";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[28] = true;
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSize QAbstract3DGraphWrapper::minimumSizeHint() const
{
    if (m_PyMethodCache[29])
        return this->::QWidget::minimumSizeHint();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[29] = true;
        gil.release();
        return this->::QWidget::minimumSizeHint();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DGraphWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[30]) {
        return this->::QAbstract3DGraph::mouseDoubleClickEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseDoubleClickEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[30] = true;
        gil.release();
        return this->::QAbstract3DGraph::mouseDoubleClickEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[31]) {
        return this->::QAbstract3DGraph::mouseMoveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[31] = true;
        gil.release();
        return this->::QAbstract3DGraph::mouseMoveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::mousePressEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[32]) {
        return this->::QAbstract3DGraph::mousePressEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mousePressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[32] = true;
        gil.release();
        return this->::QAbstract3DGraph::mousePressEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[33]) {
        return this->::QAbstract3DGraph::mouseReleaseEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[33] = true;
        gil.release();
        return this->::QAbstract3DGraph::mouseReleaseEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::moveEvent(::QMoveEvent * event)
{
    if (m_PyMethodCache[34]) {
        return this->::QWidget::moveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "moveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[34] = true;
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMoveEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMoveEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QAbstract3DGraphWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    if (m_PyMethodCache[35]) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "nativeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[35] = true;
        gil.release();
        return this->::QWidget::nativeEvent(eventType, message, result);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &eventType),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), message)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Begin code injection
    // TEMPLATE - return_native_eventfilter_conversion - START
    bool cppResult = false;
    if (PySequence_Check(pyResult.object()) && (PySequence_Size(pyResult.object()) == 2)) {
        Shiboken::AutoDecRef pyItem(PySequence_GetItem(pyResult.object(), 0));
        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyItem, &(cppResult));
        if (result) {
            Shiboken::AutoDecRef pyResultItem(PySequence_GetItem(pyResult, 1));
            Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<long>(), pyResultItem, (result));
        }
    }
    // TEMPLATE - return_native_eventfilter_conversion - END
    // End of code injection


    return cppResult;
}

::QPaintEngine * QAbstract3DGraphWrapper::paintEngine() const
{
    if (m_PyMethodCache[36])
        return this->::QWidget::paintEngine();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintEngine";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[36] = true;
        gil.release();
        return this->::QWidget::paintEngine();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, Shiboken::SbkType< QPaintEngine >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintEngine *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DGraphWrapper::paintEvent(::QPaintEvent * event)
{
    if (m_PyMethodCache[37]) {
        return this->::QQuickWidget::paintEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[37] = true;
        gil.release();
        return this->::QQuickWidget::paintEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QPaintDevice * QAbstract3DGraphWrapper::redirected(::QPoint * offset) const
{
    if (m_PyMethodCache[38])
        return this->::QWidget::redirected(offset);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "redirected";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[38] = true;
        gil.release();
        return this->::QWidget::redirected(offset);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, Shiboken::SbkType< QPaintDevice >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintDevice *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DGraphWrapper::resizeEvent(::QResizeEvent * event)
{
    if (m_PyMethodCache[39]) {
        return this->::QAbstract3DGraph::resizeEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resizeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[39] = true;
        gil.release();
        return this->::QAbstract3DGraph::resizeEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::setVisible(bool visible)
{
    if (m_PyMethodCache[40]) {
        return this->::QWidget::setVisible(visible);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[40] = true;
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &visible)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &visible)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QPainter * QAbstract3DGraphWrapper::sharedPainter() const
{
    if (m_PyMethodCache[41])
        return this->::QWidget::sharedPainter();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sharedPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[41] = true;
        gil.release();
        return this->::QWidget::sharedPainter();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, Shiboken::SbkType< QPainter >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPainter *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DGraphWrapper::showEvent(::QShowEvent * arg__1)
{
    if (m_PyMethodCache[42]) {
        return this->::QQuickWidget::showEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "showEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[42] = true;
        gil.release();
        return this->::QQuickWidget::showEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QSize QAbstract3DGraphWrapper::sizeHint() const
{
    if (m_PyMethodCache[43])
        return this->::QQuickWidget::sizeHint();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sizeHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[43] = true;
        gil.release();
        return this->::QQuickWidget::sizeHint();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstract3DGraph", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstract3DGraphWrapper::tabletEvent(::QTabletEvent * event)
{
    if (m_PyMethodCache[44]) {
        return this->::QWidget::tabletEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "tabletEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[44] = true;
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTabletEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTabletEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::timerEvent(::QTimerEvent * arg__1)
{
    if (m_PyMethodCache[45]) {
        return this->::QQuickWidget::timerEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[45] = true;
        gil.release();
        return this->::QQuickWidget::timerEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAbstract3DGraphWrapper::wheelEvent(::QWheelEvent * event)
{
    if (m_PyMethodCache[46]) {
        return this->::QAbstract3DGraph::wheelEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "wheelEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[46] = true;
        gil.release();
        return this->::QAbstract3DGraph::wheelEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QAbstract3DGraphWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstract3DGraph::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstract3DGraphWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstract3DGraph::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstract3DGraphWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstract3DGraphWrapper *>(this));
    return QAbstract3DGraph::qt_metacast(_clname);
}

QAbstract3DGraphWrapper::~QAbstract3DGraphWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstract3DGraph_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstract3DGraph >()))
        return -1;

    QAbstract3DGraphWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAbstract3DGraph", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAbstract3DGraph::QAbstract3DGraph(QString)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // QAbstract3DGraph(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstract3DGraph(QString)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAbstract3DGraphWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAbstract3DGraphWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstract3DGraph >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QAbstract3DGraphFunc_activeInputHandler(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.activeInputHandler";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // activeInputHandler()const
            QAbstract3DInputHandler * cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->activeInputHandler();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DInputHandler_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_activeTheme(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.activeTheme";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // activeTheme()const
            Q3DTheme * cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->activeTheme();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_Q3DTheme_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_addCustomItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.addCustomItem";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::addCustomItem(QCustom3DItem*)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCustom3DItem_IDX]), (pyArg)))) {
        overloadId = 0; // addCustomItem(QCustom3DItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCustom3DItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addCustomItem(QCustom3DItem*)
            int cppResult = cppSelf->addCustomItem(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_addInputHandler(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.addInputHandler";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::addInputHandler(QAbstract3DInputHandler*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DInputHandler_IDX]), (pyArg)))) {
        overloadId = 0; // addInputHandler(QAbstract3DInputHandler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstract3DInputHandler *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addInputHandler(QAbstract3DInputHandler*)
            cppSelf->addInputHandler(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_addTheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.addTheme";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::addTheme(Q3DTheme*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_Q3DTheme_IDX]), (pyArg)))) {
        overloadId = 0; // addTheme(Q3DTheme*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Q3DTheme *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addTheme(Q3DTheme*)
            cppSelf->addTheme(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_aspectRatio(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.aspectRatio";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // aspectRatio()const
            qreal cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->aspectRatio();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_cameraPreset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.cameraPreset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cameraPreset()const
            QAbstract3DGraph::CameraPreset cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->cameraPreset();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_CameraPreset_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_cameraTargetPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.cameraTargetPosition";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cameraTargetPosition()
            QVector3D cppResult = cppSelf->cameraTargetPosition();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_cameraXRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.cameraXRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cameraXRotation()
            float cppResult = cppSelf->cameraXRotation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_cameraYRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.cameraYRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cameraYRotation()
            float cppResult = cppSelf->cameraYRotation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_cameraZoomLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.cameraZoomLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cameraZoomLevel()
            float cppResult = cppSelf->cameraZoomLevel();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_clearSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.clearSelection";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearSelection()
            cppSelf->clearSelection();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_currentFps(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.currentFps";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // currentFps()const
            int cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->currentFps();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_customItems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.customItems";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // customItems()const
            QList<QCustom3DItem*> cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->customItems();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QCustom3DItemPTR_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.event";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstract3DGraph::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_hasSeries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.hasSeries";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::hasSeries(QAbstract3DSeries*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DSeries_IDX]), (pyArg)))) {
        overloadId = 0; // hasSeries(QAbstract3DSeries*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstract3DSeries *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasSeries(QAbstract3DSeries*)const
            bool cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->hasSeries(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_horizontalAspectRatio(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.horizontalAspectRatio";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // horizontalAspectRatio()const
            qreal cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->horizontalAspectRatio();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_inputHandlers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.inputHandlers";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // inputHandlers()const
            QList<QAbstract3DInputHandler*> cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->inputHandlers();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_QAbstract3DInputHandlerPTR_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_isOrthoProjection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.isOrthoProjection";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isOrthoProjection()const
            bool cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->isOrthoProjection();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_isPolar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.isPolar";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isPolar()const
            bool cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->isPolar();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.locale";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // locale()const
            QLocale cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->locale();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_margin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.margin";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // margin()const
            qreal cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->margin();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_maxCameraXRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.maxCameraXRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maxCameraXRotation()
            float cppResult = cppSelf->maxCameraXRotation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_maxCameraYRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.maxCameraYRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maxCameraYRotation()
            float cppResult = cppSelf->maxCameraYRotation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_maxCameraZoomLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.maxCameraZoomLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maxCameraZoomLevel()
            float cppResult = cppSelf->maxCameraZoomLevel();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_measureFps(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.measureFps";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // measureFps()const
            bool cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->measureFps();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_minCameraXRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.minCameraXRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minCameraXRotation()
            float cppResult = cppSelf->minCameraXRotation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_minCameraYRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.minCameraYRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minCameraYRotation()
            float cppResult = cppSelf->minCameraYRotation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_minCameraZoomLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.minCameraZoomLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minCameraZoomLevel()
            float cppResult = cppSelf->minCameraZoomLevel();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_mouseDoubleClickEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.mouseDoubleClickEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseDoubleClickEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseDoubleClickEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstract3DGraph::mouseDoubleClickEvent(cppArg0)
                : cppSelf->mouseDoubleClickEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_mouseMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.mouseMoveEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseMoveEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseMoveEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstract3DGraph::mouseMoveEvent(cppArg0)
                : cppSelf->mouseMoveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_mousePressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.mousePressEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mousePressEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mousePressEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstract3DGraph::mousePressEvent(cppArg0)
                : cppSelf->mousePressEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_mouseReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.mouseReleaseEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseReleaseEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseReleaseEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstract3DGraph::mouseReleaseEvent(cppArg0)
                : cppSelf->mouseReleaseEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_msaaSamples(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.msaaSamples";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // msaaSamples()const
            int cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->msaaSamples();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_optimizationHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.optimizationHint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // optimizationHint()const
            QAbstract3DGraph::OptimizationHint cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->optimizationHint();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_OptimizationHint_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_queriedGraphPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.queriedGraphPosition";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // queriedGraphPosition()const
            QVector3D cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->queriedGraphPosition();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_radialLabelOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.radialLabelOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // radialLabelOffset()const
            float cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->radialLabelOffset();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_releaseCustomItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.releaseCustomItem";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::releaseCustomItem(QCustom3DItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCustom3DItem_IDX]), (pyArg)))) {
        overloadId = 0; // releaseCustomItem(QCustom3DItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCustom3DItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // releaseCustomItem(QCustom3DItem*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            Shiboken::Object::releaseOwnership(pyArg);
            // END of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            // ========================================================================
            // End of code injection

            cppSelf->releaseCustomItem(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "releaseCustomItem(QCustom3DItem*)1", pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_releaseInputHandler(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.releaseInputHandler";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::releaseInputHandler(QAbstract3DInputHandler*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DInputHandler_IDX]), (pyArg)))) {
        overloadId = 0; // releaseInputHandler(QAbstract3DInputHandler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstract3DInputHandler *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // releaseInputHandler(QAbstract3DInputHandler*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            Shiboken::Object::releaseOwnership(pyArg);
            // END of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            // ========================================================================
            // End of code injection

            cppSelf->releaseInputHandler(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "releaseInputHandler(QAbstract3DInputHandler*)1", pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_releaseTheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.releaseTheme";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::releaseTheme(Q3DTheme*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_Q3DTheme_IDX]), (pyArg)))) {
        overloadId = 0; // releaseTheme(Q3DTheme*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Q3DTheme *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // releaseTheme(Q3DTheme*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            Shiboken::Object::releaseOwnership(pyArg);
            // END of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            // ========================================================================
            // End of code injection

            cppSelf->releaseTheme(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "releaseTheme(Q3DTheme*)1", pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_removeCustomItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.removeCustomItem";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::removeCustomItem(QCustom3DItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCustom3DItem_IDX]), (pyArg)))) {
        overloadId = 0; // removeCustomItem(QCustom3DItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCustom3DItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeCustomItem(QCustom3DItem*)
            cppSelf->removeCustomItem(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_removeCustomItemAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.removeCustomItemAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::removeCustomItemAt(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // removeCustomItemAt(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // removeCustomItemAt(QVector3D)
            cppSelf->removeCustomItemAt(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_removeCustomItems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.removeCustomItems";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeCustomItems()
            cppSelf->removeCustomItems();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_renderToImage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.renderToImage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:renderToImage", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstract3DGraph::renderToImage(const QSize&=)->QSharedPointer< QQuickItemGrabResult>
    if (numArgs == 0) {
        overloadId = 0; // renderToImage(QSize)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        overloadId = 0; // renderToImage(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_imageSize = Shiboken::String::createStaticString("imageSize");
            if (PyDict_Contains(kwds, key_imageSize) != 0) {
                value = PyDict_GetItem(kwds, key_imageSize);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_imageSize);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_imageSize);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSize cppArg0_local = QSize();
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // renderToImage(QSize)
            QSharedPointer<QQuickItemGrabResult> cppResult = cppSelf->renderToImage(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSharedPointer_QQuickItemGrabResult_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.resizeEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstract3DGraph::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_scene(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.scene";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // scene()const
            Q3DScene * cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->scene();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_Q3DScene_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_selectedAxis(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.selectedAxis";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedAxis()const
            QAbstract3DAxis * cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->selectedAxis();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_selectedCustomItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.selectedCustomItem";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedCustomItem()const
            QCustom3DItem * cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->selectedCustomItem();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCustom3DItem_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_selectedCustomItemIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.selectedCustomItemIndex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedCustomItemIndex()const
            int cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->selectedCustomItemIndex();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_selectedElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.selectedElement";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedElement()const
            QAbstract3DGraph::ElementType cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->selectedElement();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_ElementType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_selectedLabelIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.selectedLabelIndex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedLabelIndex()const
            int cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->selectedLabelIndex();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_selectionMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.selectionMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectionMode()const
            QFlags<QAbstract3DGraph::SelectionFlag> cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->selectionMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QFlags_QAbstract3DGraph_SelectionFlag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setActiveInputHandler(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setActiveInputHandler";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setActiveInputHandler(QAbstract3DInputHandler*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DInputHandler_IDX]), (pyArg)))) {
        overloadId = 0; // setActiveInputHandler(QAbstract3DInputHandler*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstract3DInputHandler *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActiveInputHandler(QAbstract3DInputHandler*)
            cppSelf->setActiveInputHandler(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setActiveTheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setActiveTheme";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setActiveTheme(Q3DTheme*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_Q3DTheme_IDX]), (pyArg)))) {
        overloadId = 0; // setActiveTheme(Q3DTheme*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Q3DTheme *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActiveTheme(Q3DTheme*)
            cppSelf->setActiveTheme(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setAspectRatio(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setAspectRatio";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setAspectRatio(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setAspectRatio(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAspectRatio(qreal)
            cppSelf->setAspectRatio(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setCameraPosition(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setCameraPosition";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:setCameraPosition", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstract3DGraph::setCameraPosition(float,float,float=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setCameraPosition(float,float,float)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
            overloadId = 0; // setCameraPosition(float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_zoom = Shiboken::String::createStaticString("zoom");
            if (PyDict_Contains(kwds, key_zoom) != 0) {
                value = PyDict_GetItem(kwds, key_zoom);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_zoom);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_zoom);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2 = 100.0f;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraPosition(float,float,float)
            cppSelf->setCameraPosition(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setCameraPreset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setCameraPreset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setCameraPreset(QAbstract3DGraph::CameraPreset)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_CameraPreset_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCameraPreset(QAbstract3DGraph::CameraPreset)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QAbstract3DGraph::CameraPreset cppArg0{QAbstract3DGraph::CameraPreset::NoPreset};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraPreset(QAbstract3DGraph::CameraPreset)
            cppSelf->setCameraPreset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setCameraTargetPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setCameraTargetPosition";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setCameraTargetPosition(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setCameraTargetPosition(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0_local;
        ::QVector3D *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraTargetPosition(QVector3D)
            cppSelf->setCameraTargetPosition(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setCameraXRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setCameraXRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setCameraXRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setCameraXRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraXRotation(float)
            cppSelf->setCameraXRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setCameraYRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setCameraYRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setCameraYRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setCameraYRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraYRotation(float)
            cppSelf->setCameraYRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setCameraZoomLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setCameraZoomLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setCameraZoomLevel(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setCameraZoomLevel(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraZoomLevel(float)
            cppSelf->setCameraZoomLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setHorizontalAspectRatio(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setHorizontalAspectRatio";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setHorizontalAspectRatio(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setHorizontalAspectRatio(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHorizontalAspectRatio(qreal)
            cppSelf->setHorizontalAspectRatio(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setLocale";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setLocale(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QLocale)
            cppSelf->setLocale(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setMargin";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setMargin(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMargin(qreal)
            cppSelf->setMargin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setMaxCameraXRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setMaxCameraXRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setMaxCameraXRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxCameraXRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxCameraXRotation(float)
            cppSelf->setMaxCameraXRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setMaxCameraYRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setMaxCameraYRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setMaxCameraYRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxCameraYRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxCameraYRotation(float)
            cppSelf->setMaxCameraYRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setMaxCameraZoomLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setMaxCameraZoomLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setMaxCameraZoomLevel(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxCameraZoomLevel(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxCameraZoomLevel(float)
            cppSelf->setMaxCameraZoomLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setMeasureFps(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setMeasureFps";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setMeasureFps(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setMeasureFps(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMeasureFps(bool)
            cppSelf->setMeasureFps(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setMinCameraXRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setMinCameraXRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setMinCameraXRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinCameraXRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinCameraXRotation(float)
            cppSelf->setMinCameraXRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setMinCameraYRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setMinCameraYRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setMinCameraYRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinCameraYRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinCameraYRotation(float)
            cppSelf->setMinCameraYRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setMinCameraZoomLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setMinCameraZoomLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setMinCameraZoomLevel(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinCameraZoomLevel(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinCameraZoomLevel(float)
            cppSelf->setMinCameraZoomLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setMsaaSamples(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setMsaaSamples";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setMsaaSamples(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMsaaSamples(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMsaaSamples(int)
            cppSelf->setMsaaSamples(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setOptimizationHint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setOptimizationHint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setOptimizationHint(QAbstract3DGraph::OptimizationHint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_OptimizationHint_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setOptimizationHint(QAbstract3DGraph::OptimizationHint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QAbstract3DGraph::OptimizationHint cppArg0{QAbstract3DGraph::OptimizationHint::Default};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOptimizationHint(QAbstract3DGraph::OptimizationHint)
            cppSelf->setOptimizationHint(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setOrthoProjection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setOrthoProjection";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setOrthoProjection(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOrthoProjection(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOrthoProjection(bool)
            cppSelf->setOrthoProjection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setPolar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setPolar";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setPolar(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPolar(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPolar(bool)
            cppSelf->setPolar(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setRadialLabelOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setRadialLabelOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setRadialLabelOffset(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setRadialLabelOffset(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRadialLabelOffset(float)
            cppSelf->setRadialLabelOffset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setSelectionMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setSelectionMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setSelectionMode(QFlags<QAbstract3DGraph::SelectionFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QFlags_QAbstract3DGraph_SelectionFlag_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSelectionMode(QFlags<QAbstract3DGraph::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QAbstract3DGraph::SelectionFlag> cppArg0 = QFlags<QAbstract3DGraph::SelectionFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectionMode(QFlags<QAbstract3DGraph::SelectionFlag>)
            cppSelf->setSelectionMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setShadowQuality(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setShadowQuality";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setShadowQuality(QAbstract3DGraph::ShadowQuality)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_ShadowQuality_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setShadowQuality(QAbstract3DGraph::ShadowQuality)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QAbstract3DGraph::ShadowQuality cppArg0{QAbstract3DGraph::ShadowQuality::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShadowQuality(QAbstract3DGraph::ShadowQuality)
            cppSelf->setShadowQuality(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setWrapCameraXRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setWrapCameraXRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setWrapCameraXRotation(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setWrapCameraXRotation(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapCameraXRotation(bool)
            cppSelf->setWrapCameraXRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_setWrapCameraYRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.setWrapCameraYRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstract3DGraph::setWrapCameraYRotation(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setWrapCameraYRotation(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapCameraYRotation(bool)
            cppSelf->setWrapCameraYRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_shadowQuality(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.shadowQuality";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // shadowQuality()const
            QAbstract3DGraph::ShadowQuality cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->shadowQuality();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_ShadowQuality_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_themes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.themes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // themes()const
            QList<Q3DTheme*> cppResult = const_cast<const ::QAbstract3DGraph *>(cppSelf)->themes();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsTypeConverters[SBK_QtGraphs_QList_Q3DThemePTR_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_wheelEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.wheelEvent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::wheelEvent(QWheelEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), (pyArg)))) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWheelEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wheelEvent(QWheelEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstract3DGraph::wheelEvent(cppArg0)
                : cppSelf->wheelEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstract3DGraphFunc_wrapCameraXRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.wrapCameraXRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // wrapCameraXRotation()
            bool cppResult = cppSelf->wrapCameraXRotation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstract3DGraphFunc_wrapCameraYRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGraphs.QAbstract3DGraph.wrapCameraYRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // wrapCameraYRotation()
            bool cppResult = cppSelf->wrapCameraYRotation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAbstract3DGraph_PropertyStrings[] = {
    "activeInputHandler::",
    "activeTheme::",
    "aspectRatio::",
    "cameraPreset::",
    "cameraTargetPosition::",
    "cameraXRotation::",
    "cameraYRotation::",
    "cameraZoomLevel::",
    "currentFps:",
    "horizontalAspectRatio::",
    "locale::",
    "margin::",
    "maxCameraZoomLevel::",
    "measureFps::",
    "minCameraZoomLevel::",
    "msaaSamples::",
    "optimizationHint::",
    "orthoProjection:isOrthoProjection:",
    "polar:isPolar:",
    "queriedGraphPosition:",
    "radialLabelOffset::",
    "scene:",
    "selectedElement:",
    "selectionMode::",
    "shadowQuality::",
    "wrapCameraXRotation::",
    "wrapCameraYRotation::",
    nullptr // Sentinel
};

static const char *Sbk_QAbstract3DGraph_EnumFlagInfo[] = {
    "CameraPreset:Enum",
    "ElementType:Enum",
    "OptimizationHint:Flag:OptimizationHints",
    "QmlIsUncreatable:IntEnum",
    "RenderingMode:Enum",
    "SelectionFlag:Flag:SelectionFlags",
    "ShadowQuality:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstract3DGraph_methods[] = {
    {"activeInputHandler", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_activeInputHandler), METH_NOARGS, nullptr},
    {"activeTheme", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_activeTheme), METH_NOARGS, nullptr},
    {"addCustomItem", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_addCustomItem), METH_O, nullptr},
    {"addInputHandler", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_addInputHandler), METH_O, nullptr},
    {"addTheme", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_addTheme), METH_O, nullptr},
    {"aspectRatio", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_aspectRatio), METH_NOARGS, nullptr},
    {"cameraPreset", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_cameraPreset), METH_NOARGS, nullptr},
    {"cameraTargetPosition", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_cameraTargetPosition), METH_NOARGS, nullptr},
    {"cameraXRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_cameraXRotation), METH_NOARGS, nullptr},
    {"cameraYRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_cameraYRotation), METH_NOARGS, nullptr},
    {"cameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_cameraZoomLevel), METH_NOARGS, nullptr},
    {"clearSelection", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_clearSelection), METH_NOARGS, nullptr},
    {"currentFps", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_currentFps), METH_NOARGS, nullptr},
    {"customItems", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_customItems), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_event), METH_O, nullptr},
    {"hasSeries", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_hasSeries), METH_O, nullptr},
    {"horizontalAspectRatio", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_horizontalAspectRatio), METH_NOARGS, nullptr},
    {"inputHandlers", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_inputHandlers), METH_NOARGS, nullptr},
    {"isOrthoProjection", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_isOrthoProjection), METH_NOARGS, nullptr},
    {"isPolar", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_isPolar), METH_NOARGS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_locale), METH_NOARGS, nullptr},
    {"margin", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_margin), METH_NOARGS, nullptr},
    {"maxCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_maxCameraXRotation), METH_NOARGS, nullptr},
    {"maxCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_maxCameraYRotation), METH_NOARGS, nullptr},
    {"maxCameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_maxCameraZoomLevel), METH_NOARGS, nullptr},
    {"measureFps", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_measureFps), METH_NOARGS, nullptr},
    {"minCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_minCameraXRotation), METH_NOARGS, nullptr},
    {"minCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_minCameraYRotation), METH_NOARGS, nullptr},
    {"minCameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_minCameraZoomLevel), METH_NOARGS, nullptr},
    {"mouseDoubleClickEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_mouseDoubleClickEvent), METH_O, nullptr},
    {"mouseMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_mouseMoveEvent), METH_O, nullptr},
    {"mousePressEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_mousePressEvent), METH_O, nullptr},
    {"mouseReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_mouseReleaseEvent), METH_O, nullptr},
    {"msaaSamples", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_msaaSamples), METH_NOARGS, nullptr},
    {"optimizationHint", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_optimizationHint), METH_NOARGS, nullptr},
    {"queriedGraphPosition", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_queriedGraphPosition), METH_NOARGS, nullptr},
    {"radialLabelOffset", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_radialLabelOffset), METH_NOARGS, nullptr},
    {"releaseCustomItem", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_releaseCustomItem), METH_O, nullptr},
    {"releaseInputHandler", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_releaseInputHandler), METH_O, nullptr},
    {"releaseTheme", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_releaseTheme), METH_O, nullptr},
    {"removeCustomItem", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_removeCustomItem), METH_O, nullptr},
    {"removeCustomItemAt", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_removeCustomItemAt), METH_O, nullptr},
    {"removeCustomItems", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_removeCustomItems), METH_NOARGS, nullptr},
    {"renderToImage", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_renderToImage), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_resizeEvent), METH_O, nullptr},
    {"scene", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_scene), METH_NOARGS, nullptr},
    {"selectedAxis", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_selectedAxis), METH_NOARGS, nullptr},
    {"selectedCustomItem", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_selectedCustomItem), METH_NOARGS, nullptr},
    {"selectedCustomItemIndex", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_selectedCustomItemIndex), METH_NOARGS, nullptr},
    {"selectedElement", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_selectedElement), METH_NOARGS, nullptr},
    {"selectedLabelIndex", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_selectedLabelIndex), METH_NOARGS, nullptr},
    {"selectionMode", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_selectionMode), METH_NOARGS, nullptr},
    {"setActiveInputHandler", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setActiveInputHandler), METH_O, nullptr},
    {"setActiveTheme", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setActiveTheme), METH_O, nullptr},
    {"setAspectRatio", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setAspectRatio), METH_O, nullptr},
    {"setCameraPosition", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setCameraPosition), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setCameraPreset", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setCameraPreset), METH_O, nullptr},
    {"setCameraTargetPosition", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setCameraTargetPosition), METH_O, nullptr},
    {"setCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setCameraXRotation), METH_O, nullptr},
    {"setCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setCameraYRotation), METH_O, nullptr},
    {"setCameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setCameraZoomLevel), METH_O, nullptr},
    {"setHorizontalAspectRatio", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setHorizontalAspectRatio), METH_O, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setLocale), METH_O, nullptr},
    {"setMargin", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setMargin), METH_O, nullptr},
    {"setMaxCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setMaxCameraXRotation), METH_O, nullptr},
    {"setMaxCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setMaxCameraYRotation), METH_O, nullptr},
    {"setMaxCameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setMaxCameraZoomLevel), METH_O, nullptr},
    {"setMeasureFps", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setMeasureFps), METH_O, nullptr},
    {"setMinCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setMinCameraXRotation), METH_O, nullptr},
    {"setMinCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setMinCameraYRotation), METH_O, nullptr},
    {"setMinCameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setMinCameraZoomLevel), METH_O, nullptr},
    {"setMsaaSamples", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setMsaaSamples), METH_O, nullptr},
    {"setOptimizationHint", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setOptimizationHint), METH_O, nullptr},
    {"setOrthoProjection", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setOrthoProjection), METH_O, nullptr},
    {"setPolar", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setPolar), METH_O, nullptr},
    {"setRadialLabelOffset", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setRadialLabelOffset), METH_O, nullptr},
    {"setSelectionMode", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setSelectionMode), METH_O, nullptr},
    {"setShadowQuality", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setShadowQuality), METH_O, nullptr},
    {"setWrapCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setWrapCameraXRotation), METH_O, nullptr},
    {"setWrapCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_setWrapCameraYRotation), METH_O, nullptr},
    {"shadowQuality", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_shadowQuality), METH_NOARGS, nullptr},
    {"themes", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_themes), METH_NOARGS, nullptr},
    {"wheelEvent", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_wheelEvent), METH_O, nullptr},
    {"wrapCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_wrapCameraXRotation), METH_NOARGS, nullptr},
    {"wrapCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_QAbstract3DGraphFunc_wrapCameraYRotation), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstract3DGraph_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstract3DGraph *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstract3DGraphWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstract3DGraph_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstract3DGraph_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QAbstract3DGraphSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QAbstract3DGraph *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtQuickWidgetsTypeStructs[SBK_QQuickWidget_IDX]))
        return static_cast< ::QQuickWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstract3DGraph_Type = nullptr;
static PyTypeObject *Sbk_QAbstract3DGraph_TypeF(void)
{
    return _Sbk_QAbstract3DGraph_Type;
}

static PyType_Slot Sbk_QAbstract3DGraph_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstract3DGraph_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstract3DGraph_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstract3DGraph_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstract3DGraph_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstract3DGraph_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstract3DGraph_spec = {
    "2:PySide6.QtGraphs.QAbstract3DGraph",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstract3DGraph_slots
};

} //extern "C"

static void *Sbk_QAbstract3DGraph_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstract3DGraph *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QAbstract3DGraph *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstract3DGraph_SelectionFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstract3DGraph::SelectionFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstract3DGraph::SelectionFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstract3DGraph_SelectionFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_SelectionFlag_IDX])))
        return Enum_PythonToCpp_QAbstract3DGraph_SelectionFlag;
    return {};
}
static PyObject *QAbstract3DGraph_SelectionFlag_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAbstract3DGraph::SelectionFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_SelectionFlag_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstract3DGraph_ShadowQuality(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstract3DGraph::ShadowQuality>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstract3DGraph::ShadowQuality *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstract3DGraph_ShadowQuality_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_ShadowQuality_IDX])))
        return Enum_PythonToCpp_QAbstract3DGraph_ShadowQuality;
    return {};
}
static PyObject *QAbstract3DGraph_ShadowQuality_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAbstract3DGraph::ShadowQuality *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_ShadowQuality_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstract3DGraph_ElementType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstract3DGraph::ElementType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstract3DGraph::ElementType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstract3DGraph_ElementType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_ElementType_IDX])))
        return Enum_PythonToCpp_QAbstract3DGraph_ElementType;
    return {};
}
static PyObject *QAbstract3DGraph_ElementType_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAbstract3DGraph::ElementType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_ElementType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstract3DGraph_OptimizationHint(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstract3DGraph::OptimizationHint>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstract3DGraph::OptimizationHint *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstract3DGraph_OptimizationHint_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_OptimizationHint_IDX])))
        return Enum_PythonToCpp_QAbstract3DGraph_OptimizationHint;
    return {};
}
static PyObject *QAbstract3DGraph_OptimizationHint_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAbstract3DGraph::OptimizationHint *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_OptimizationHint_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstract3DGraph_RenderingMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstract3DGraph::RenderingMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstract3DGraph::RenderingMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstract3DGraph_RenderingMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_RenderingMode_IDX])))
        return Enum_PythonToCpp_QAbstract3DGraph_RenderingMode;
    return {};
}
static PyObject *QAbstract3DGraph_RenderingMode_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAbstract3DGraph::RenderingMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_RenderingMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstract3DGraph_CameraPreset(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstract3DGraph::CameraPreset>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstract3DGraph::CameraPreset *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstract3DGraph_CameraPreset_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_CameraPreset_IDX])))
        return Enum_PythonToCpp_QAbstract3DGraph_CameraPreset;
    return {};
}
static PyObject *QAbstract3DGraph_CameraPreset_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAbstract3DGraph::CameraPreset *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_CameraPreset_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstract3DGraph_PythonToCpp_QAbstract3DGraph_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstract3DGraph_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstract3DGraph_PythonToCpp_QAbstract3DGraph_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstract3DGraph_TypeF()))
        return QAbstract3DGraph_PythonToCpp_QAbstract3DGraph_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstract3DGraph_PTR_CppToPython_QAbstract3DGraph(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstract3DGraph *>(const_cast<void *>(cppIn)), Sbk_QAbstract3DGraph_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QAbstract3DGraph_SignatureStrings[] = {
    "PySide6.QtGraphs.QAbstract3DGraph(self,graphType:QString)",
    "PySide6.QtGraphs.QAbstract3DGraph.activeInputHandler(self)->PySide6.QtGraphs.QAbstract3DInputHandler",
    "PySide6.QtGraphs.QAbstract3DGraph.activeTheme(self)->PySide6.QtGraphs.Q3DTheme",
    "PySide6.QtGraphs.QAbstract3DGraph.addCustomItem(self,item:PySide6.QtGraphs.QCustom3DItem)->int",
    "PySide6.QtGraphs.QAbstract3DGraph.addInputHandler(self,inputHandler:PySide6.QtGraphs.QAbstract3DInputHandler)",
    "PySide6.QtGraphs.QAbstract3DGraph.addTheme(self,theme:PySide6.QtGraphs.Q3DTheme)",
    "PySide6.QtGraphs.QAbstract3DGraph.aspectRatio(self)->qreal",
    "PySide6.QtGraphs.QAbstract3DGraph.cameraPreset(self)->PySide6.QtGraphs.QAbstract3DGraph.CameraPreset",
    "PySide6.QtGraphs.QAbstract3DGraph.cameraTargetPosition(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtGraphs.QAbstract3DGraph.cameraXRotation(self)->float",
    "PySide6.QtGraphs.QAbstract3DGraph.cameraYRotation(self)->float",
    "PySide6.QtGraphs.QAbstract3DGraph.cameraZoomLevel(self)->float",
    "PySide6.QtGraphs.QAbstract3DGraph.clearSelection(self)",
    "PySide6.QtGraphs.QAbstract3DGraph.currentFps(self)->int",
    "PySide6.QtGraphs.QAbstract3DGraph.customItems(self)->QList[PySide6.QtGraphs.QCustom3DItem]",
    "PySide6.QtGraphs.QAbstract3DGraph.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtGraphs.QAbstract3DGraph.hasSeries(self,series:PySide6.QtGraphs.QAbstract3DSeries)->bool",
    "PySide6.QtGraphs.QAbstract3DGraph.horizontalAspectRatio(self)->qreal",
    "PySide6.QtGraphs.QAbstract3DGraph.inputHandlers(self)->QList[PySide6.QtGraphs.QAbstract3DInputHandler]",
    "PySide6.QtGraphs.QAbstract3DGraph.isOrthoProjection(self)->bool",
    "PySide6.QtGraphs.QAbstract3DGraph.isPolar(self)->bool",
    "PySide6.QtGraphs.QAbstract3DGraph.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtGraphs.QAbstract3DGraph.margin(self)->qreal",
    "PySide6.QtGraphs.QAbstract3DGraph.maxCameraXRotation(self)->float",
    "PySide6.QtGraphs.QAbstract3DGraph.maxCameraYRotation(self)->float",
    "PySide6.QtGraphs.QAbstract3DGraph.maxCameraZoomLevel(self)->float",
    "PySide6.QtGraphs.QAbstract3DGraph.measureFps(self)->bool",
    "PySide6.QtGraphs.QAbstract3DGraph.minCameraXRotation(self)->float",
    "PySide6.QtGraphs.QAbstract3DGraph.minCameraYRotation(self)->float",
    "PySide6.QtGraphs.QAbstract3DGraph.minCameraZoomLevel(self)->float",
    "PySide6.QtGraphs.QAbstract3DGraph.mouseDoubleClickEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtGraphs.QAbstract3DGraph.mouseMoveEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtGraphs.QAbstract3DGraph.mousePressEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtGraphs.QAbstract3DGraph.mouseReleaseEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtGraphs.QAbstract3DGraph.msaaSamples(self)->int",
    "PySide6.QtGraphs.QAbstract3DGraph.optimizationHint(self)->PySide6.QtGraphs.QAbstract3DGraph.OptimizationHint",
    "PySide6.QtGraphs.QAbstract3DGraph.queriedGraphPosition(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtGraphs.QAbstract3DGraph.radialLabelOffset(self)->float",
    "PySide6.QtGraphs.QAbstract3DGraph.releaseCustomItem(self,item:PySide6.QtGraphs.QCustom3DItem)",
    "PySide6.QtGraphs.QAbstract3DGraph.releaseInputHandler(self,inputHandler:PySide6.QtGraphs.QAbstract3DInputHandler)",
    "PySide6.QtGraphs.QAbstract3DGraph.releaseTheme(self,theme:PySide6.QtGraphs.Q3DTheme)",
    "PySide6.QtGraphs.QAbstract3DGraph.removeCustomItem(self,item:PySide6.QtGraphs.QCustom3DItem)",
    "PySide6.QtGraphs.QAbstract3DGraph.removeCustomItemAt(self,position:PySide6.QtGui.QVector3D)",
    "PySide6.QtGraphs.QAbstract3DGraph.removeCustomItems(self)",
    "PySide6.QtGraphs.QAbstract3DGraph.renderToImage(self,imageSize:PySide6.QtCore.QSize=QSize())->QSharedPointer[PySide6.QtQuick.QQuickItemGrabResult]",
    "PySide6.QtGraphs.QAbstract3DGraph.resizeEvent(self,event:PySide6.QtGui.QResizeEvent)",
    "PySide6.QtGraphs.QAbstract3DGraph.scene(self)->PySide6.QtGraphs.Q3DScene",
    "PySide6.QtGraphs.QAbstract3DGraph.selectedAxis(self)->PySide6.QtGraphs.QAbstract3DAxis",
    "PySide6.QtGraphs.QAbstract3DGraph.selectedCustomItem(self)->PySide6.QtGraphs.QCustom3DItem",
    "PySide6.QtGraphs.QAbstract3DGraph.selectedCustomItemIndex(self)->int",
    "PySide6.QtGraphs.QAbstract3DGraph.selectedElement(self)->PySide6.QtGraphs.QAbstract3DGraph.ElementType",
    "PySide6.QtGraphs.QAbstract3DGraph.selectedLabelIndex(self)->int",
    "PySide6.QtGraphs.QAbstract3DGraph.selectionMode(self)->PySide6.QtGraphs.QAbstract3DGraph.SelectionFlag",
    "PySide6.QtGraphs.QAbstract3DGraph.setActiveInputHandler(self,inputHandler:PySide6.QtGraphs.QAbstract3DInputHandler)",
    "PySide6.QtGraphs.QAbstract3DGraph.setActiveTheme(self,activeTheme:PySide6.QtGraphs.Q3DTheme)",
    "PySide6.QtGraphs.QAbstract3DGraph.setAspectRatio(self,ratio:qreal)",
    "PySide6.QtGraphs.QAbstract3DGraph.setCameraPosition(self,horizontal:float,vertical:float,zoom:float=100.0f)",
    "PySide6.QtGraphs.QAbstract3DGraph.setCameraPreset(self,preset:PySide6.QtGraphs.QAbstract3DGraph.CameraPreset)",
    "PySide6.QtGraphs.QAbstract3DGraph.setCameraTargetPosition(self,target:PySide6.QtGui.QVector3D)",
    "PySide6.QtGraphs.QAbstract3DGraph.setCameraXRotation(self,rotation:float)",
    "PySide6.QtGraphs.QAbstract3DGraph.setCameraYRotation(self,rotation:float)",
    "PySide6.QtGraphs.QAbstract3DGraph.setCameraZoomLevel(self,level:float)",
    "PySide6.QtGraphs.QAbstract3DGraph.setHorizontalAspectRatio(self,ratio:qreal)",
    "PySide6.QtGraphs.QAbstract3DGraph.setLocale(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtGraphs.QAbstract3DGraph.setMargin(self,margin:qreal)",
    "PySide6.QtGraphs.QAbstract3DGraph.setMaxCameraXRotation(self,rotation:float)",
    "PySide6.QtGraphs.QAbstract3DGraph.setMaxCameraYRotation(self,rotation:float)",
    "PySide6.QtGraphs.QAbstract3DGraph.setMaxCameraZoomLevel(self,level:float)",
    "PySide6.QtGraphs.QAbstract3DGraph.setMeasureFps(self,enable:bool)",
    "PySide6.QtGraphs.QAbstract3DGraph.setMinCameraXRotation(self,rotation:float)",
    "PySide6.QtGraphs.QAbstract3DGraph.setMinCameraYRotation(self,rotation:float)",
    "PySide6.QtGraphs.QAbstract3DGraph.setMinCameraZoomLevel(self,level:float)",
    "PySide6.QtGraphs.QAbstract3DGraph.setMsaaSamples(self,samples:int)",
    "PySide6.QtGraphs.QAbstract3DGraph.setOptimizationHint(self,hint:PySide6.QtGraphs.QAbstract3DGraph.OptimizationHint)",
    "PySide6.QtGraphs.QAbstract3DGraph.setOrthoProjection(self,enable:bool)",
    "PySide6.QtGraphs.QAbstract3DGraph.setPolar(self,enable:bool)",
    "PySide6.QtGraphs.QAbstract3DGraph.setRadialLabelOffset(self,offset:float)",
    "PySide6.QtGraphs.QAbstract3DGraph.setSelectionMode(self,selectionMode:PySide6.QtGraphs.QAbstract3DGraph.SelectionFlag)",
    "PySide6.QtGraphs.QAbstract3DGraph.setShadowQuality(self,shadowQuality:PySide6.QtGraphs.QAbstract3DGraph.ShadowQuality)",
    "PySide6.QtGraphs.QAbstract3DGraph.setWrapCameraXRotation(self,wrap:bool)",
    "PySide6.QtGraphs.QAbstract3DGraph.setWrapCameraYRotation(self,wrap:bool)",
    "PySide6.QtGraphs.QAbstract3DGraph.shadowQuality(self)->PySide6.QtGraphs.QAbstract3DGraph.ShadowQuality",
    "PySide6.QtGraphs.QAbstract3DGraph.themes(self)->QList[PySide6.QtGraphs.Q3DTheme]",
    "PySide6.QtGraphs.QAbstract3DGraph.wheelEvent(self,event:PySide6.QtGui.QWheelEvent)",
    "PySide6.QtGraphs.QAbstract3DGraph.wrapCameraXRotation(self)->bool",
    "PySide6.QtGraphs.QAbstract3DGraph.wrapCameraYRotation(self)->bool",
    nullptr}; // Sentinel

PyTypeObject *init_QAbstract3DGraph(PyObject *module)
{
    if (SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX].type != nullptr)
        return SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstract3DGraph_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickWidgetsTypeStructs[SBK_QQuickWidget_IDX]))));

    _Sbk_QAbstract3DGraph_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstract3DGraph",
        "QAbstract3DGraph*",
        &Sbk_QAbstract3DGraph_spec,
        &Shiboken::callCppDestructor< QAbstract3DGraph >,
        Sbk_QAbstract3DGraph_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QAbstract3DGraph_TypeF(); // references _Sbk_QAbstract3DGraph_Type
    InitSignatureStrings(pyType, QAbstract3DGraph_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstract3DGraph_PropertyStrings);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstract3DGraph_PythonToCpp_QAbstract3DGraph_PTR,
        is_QAbstract3DGraph_PythonToCpp_QAbstract3DGraph_PTR_Convertible,
        QAbstract3DGraph_PTR_CppToPython_QAbstract3DGraph);

    Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph");
    Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstract3DGraph).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstract3DGraphWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QAbstract3DGraph_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QAbstract3DGraph_TypeF(), &Sbk_QAbstract3DGraphSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstract3DGraph_TypeF(), &Sbk_QAbstract3DGraph_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstract3DGraph_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SelectionFlag'.
    const char *SelectionFlag_Initializer[] = {
        "SelectionNone",
        "SelectionItem",
        "SelectionRow",
        "SelectionItemAndRow",
        "SelectionColumn",
        "SelectionItemAndColumn",
        "SelectionRowAndColumn",
        "SelectionItemRowAndColumn",
        "SelectionSlice",
        "SelectionMultiSeries",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SelectionFlag_InitializerValues[] = {
        uint8_t(QAbstract3DGraph::SelectionFlag::SelectionNone),             //  0x00  0
        uint8_t(QAbstract3DGraph::SelectionFlag::SelectionItem),             //  0x01  1
        uint8_t(QAbstract3DGraph::SelectionFlag::SelectionRow),              //  0x02  2
        uint8_t(QAbstract3DGraph::SelectionFlag::SelectionItemAndRow),       //  0x03  3
        uint8_t(QAbstract3DGraph::SelectionFlag::SelectionColumn),           //  0x04  4
        uint8_t(QAbstract3DGraph::SelectionFlag::SelectionItemAndColumn),    //  0x05  5
        uint8_t(QAbstract3DGraph::SelectionFlag::SelectionRowAndColumn),     //  0x06  6
        uint8_t(QAbstract3DGraph::SelectionFlag::SelectionItemRowAndColumn), //  0x07  7
        uint8_t(QAbstract3DGraph::SelectionFlag::SelectionSlice),            //  0x08  8
        uint8_t(QAbstract3DGraph::SelectionFlag::SelectionMultiSeries)       //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstract3DGraph_TypeF(),
        "2:PySide6.QtGraphs.QAbstract3DGraph.SelectionFlag",
        SelectionFlag_Initializer, SelectionFlag_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_SelectionFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGraphsTypeStructs[SBK_QFlags_QAbstract3DGraph_SelectionFlag_IDX].type =
        EType;
    // Register converter for enum 'QAbstract3DGraph::SelectionFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstract3DGraph_SelectionFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstract3DGraph_SelectionFlag,
            is_Enum_PythonToCpp_QAbstract3DGraph_SelectionFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph::SelectionFlag");
        Shiboken::Conversions::registerConverterName(converter, "SelectionFlag");
        // Register converter for flag 'QFlags<QAbstract3DGraph::SelectionFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QAbstract3DGraph::SelectionFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph::SelectionFlags");
    }
    // End of 'SelectionFlag' enum/flags.

    // Initialization of enum 'ShadowQuality'.
    const char *ShadowQuality_Initializer[] = {
        "None_",
        "Low",
        "Medium",
        "High",
        "SoftLow",
        "SoftMedium",
        "SoftHigh",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ShadowQuality_InitializerValues[] = {
        int8_t(QAbstract3DGraph::ShadowQuality::None),       //  0x00  0
        int8_t(QAbstract3DGraph::ShadowQuality::Low),        //  0x01  1
        int8_t(QAbstract3DGraph::ShadowQuality::Medium),     //  0x02  2
        int8_t(QAbstract3DGraph::ShadowQuality::High),       //  0x03  3
        int8_t(QAbstract3DGraph::ShadowQuality::SoftLow),    //  0x04  4
        int8_t(QAbstract3DGraph::ShadowQuality::SoftMedium), //  0x05  5
        int8_t(QAbstract3DGraph::ShadowQuality::SoftHigh)    //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstract3DGraph_TypeF(),
        "2:PySide6.QtGraphs.QAbstract3DGraph.ShadowQuality",
        ShadowQuality_Initializer, ShadowQuality_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_ShadowQuality_IDX].type = EType;
    // Register converter for enum 'QAbstract3DGraph::ShadowQuality'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstract3DGraph_ShadowQuality_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstract3DGraph_ShadowQuality,
            is_Enum_PythonToCpp_QAbstract3DGraph_ShadowQuality_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph::ShadowQuality");
        Shiboken::Conversions::registerConverterName(converter, "ShadowQuality");
    }
    // End of 'ShadowQuality' enum.

    // Initialization of enum 'ElementType'.
    const char *ElementType_Initializer[] = {
        "None_",
        "Series",
        "AxisXLabel",
        "AxisYLabel",
        "AxisZLabel",
        "CustomItem",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ElementType_InitializerValues[] = {
        int8_t(QAbstract3DGraph::ElementType::None),       //  0x00  0
        int8_t(QAbstract3DGraph::ElementType::Series),     //  0x01  1
        int8_t(QAbstract3DGraph::ElementType::AxisXLabel), //  0x02  2
        int8_t(QAbstract3DGraph::ElementType::AxisYLabel), //  0x03  3
        int8_t(QAbstract3DGraph::ElementType::AxisZLabel), //  0x04  4
        int8_t(QAbstract3DGraph::ElementType::CustomItem)  //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstract3DGraph_TypeF(),
        "2:PySide6.QtGraphs.QAbstract3DGraph.ElementType",
        ElementType_Initializer, ElementType_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_ElementType_IDX].type = EType;
    // Register converter for enum 'QAbstract3DGraph::ElementType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstract3DGraph_ElementType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstract3DGraph_ElementType,
            is_Enum_PythonToCpp_QAbstract3DGraph_ElementType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph::ElementType");
        Shiboken::Conversions::registerConverterName(converter, "ElementType");
    }
    // End of 'ElementType' enum.

    // Initialization of enum 'OptimizationHint'.
    const char *OptimizationHint_Initializer[] = {
        "Default",
        "Legacy",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t OptimizationHint_InitializerValues[] = {
        int8_t(QAbstract3DGraph::OptimizationHint::Default), //  0x00  0
        int8_t(QAbstract3DGraph::OptimizationHint::Legacy)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstract3DGraph_TypeF(),
        "2:PySide6.QtGraphs.QAbstract3DGraph.OptimizationHint",
        OptimizationHint_Initializer, OptimizationHint_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_OptimizationHint_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGraphsTypeStructs[SBK_QFlags_QAbstract3DGraph_OptimizationHint_IDX].type =
        EType;
    // Register converter for enum 'QAbstract3DGraph::OptimizationHint'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstract3DGraph_OptimizationHint_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstract3DGraph_OptimizationHint,
            is_Enum_PythonToCpp_QAbstract3DGraph_OptimizationHint_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph::OptimizationHint");
        Shiboken::Conversions::registerConverterName(converter, "OptimizationHint");
        // Register converter for flag 'QFlags<QAbstract3DGraph::OptimizationHint>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QAbstract3DGraph::OptimizationHint>");
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph::OptimizationHints");
    }
    // End of 'OptimizationHint' enum/flags.

    // Initialization of enum 'RenderingMode'.
    const char *RenderingMode_Initializer[] = {
        "DirectToBackground",
        "Indirect",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t RenderingMode_InitializerValues[] = {
        int8_t(QAbstract3DGraph::RenderingMode::DirectToBackground), //  0x00  0
        int8_t(QAbstract3DGraph::RenderingMode::Indirect)            //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstract3DGraph_TypeF(),
        "2:PySide6.QtGraphs.QAbstract3DGraph.RenderingMode",
        RenderingMode_Initializer, RenderingMode_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_RenderingMode_IDX].type = EType;
    // Register converter for enum 'QAbstract3DGraph::RenderingMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstract3DGraph_RenderingMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstract3DGraph_RenderingMode,
            is_Enum_PythonToCpp_QAbstract3DGraph_RenderingMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph::RenderingMode");
        Shiboken::Conversions::registerConverterName(converter, "RenderingMode");
    }
    // End of 'RenderingMode' enum.

    // Initialization of enum 'CameraPreset'.
    const char *CameraPreset_Initializer[] = {
        "NoPreset",
        "FrontLow",
        "Front",
        "FrontHigh",
        "LeftLow",
        "Left",
        "LeftHigh",
        "RightLow",
        "Right",
        "RightHigh",
        "BehindLow",
        "Behind",
        "BehindHigh",
        "IsometricLeft",
        "IsometricLeftHigh",
        "IsometricRight",
        "IsometricRightHigh",
        "DirectlyAbove",
        "DirectlyAboveCW45",
        "DirectlyAboveCCW45",
        "FrontBelow",
        "LeftBelow",
        "RightBelow",
        "BehindBelow",
        "DirectlyBelow",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t CameraPreset_InitializerValues[] = {
        int8_t(QAbstract3DGraph::CameraPreset::NoPreset),           //  0x00  0
        int8_t(QAbstract3DGraph::CameraPreset::FrontLow),           //  0x01  1
        int8_t(QAbstract3DGraph::CameraPreset::Front),              //  0x02  2
        int8_t(QAbstract3DGraph::CameraPreset::FrontHigh),          //  0x03  3
        int8_t(QAbstract3DGraph::CameraPreset::LeftLow),            //  0x04  4
        int8_t(QAbstract3DGraph::CameraPreset::Left),               //  0x05  5
        int8_t(QAbstract3DGraph::CameraPreset::LeftHigh),           //  0x06  6
        int8_t(QAbstract3DGraph::CameraPreset::RightLow),           //  0x07  7
        int8_t(QAbstract3DGraph::CameraPreset::Right),              //  0x08  8
        int8_t(QAbstract3DGraph::CameraPreset::RightHigh),          //  0x09  9
        int8_t(QAbstract3DGraph::CameraPreset::BehindLow),          //  0x0a  10
        int8_t(QAbstract3DGraph::CameraPreset::Behind),             //  0x0b  11
        int8_t(QAbstract3DGraph::CameraPreset::BehindHigh),         //  0x0c  12
        int8_t(QAbstract3DGraph::CameraPreset::IsometricLeft),      //  0x0d  13
        int8_t(QAbstract3DGraph::CameraPreset::IsometricLeftHigh),  //  0x0e  14
        int8_t(QAbstract3DGraph::CameraPreset::IsometricRight),     //  0x0f  15
        int8_t(QAbstract3DGraph::CameraPreset::IsometricRightHigh), //  0x10  16
        int8_t(QAbstract3DGraph::CameraPreset::DirectlyAbove),      //  0x11  17
        int8_t(QAbstract3DGraph::CameraPreset::DirectlyAboveCW45),  //  0x12  18
        int8_t(QAbstract3DGraph::CameraPreset::DirectlyAboveCCW45), //  0x13  19
        int8_t(QAbstract3DGraph::CameraPreset::FrontBelow),         //  0x14  20
        int8_t(QAbstract3DGraph::CameraPreset::LeftBelow),          //  0x15  21
        int8_t(QAbstract3DGraph::CameraPreset::RightBelow),         //  0x16  22
        int8_t(QAbstract3DGraph::CameraPreset::BehindBelow),        //  0x17  23
        int8_t(QAbstract3DGraph::CameraPreset::DirectlyBelow)       //  0x18  24
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstract3DGraph_TypeF(),
        "2:PySide6.QtGraphs.QAbstract3DGraph.CameraPreset",
        CameraPreset_Initializer, CameraPreset_InitializerValues);
    SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DGraph_CameraPreset_IDX].type = EType;
    // Register converter for enum 'QAbstract3DGraph::CameraPreset'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstract3DGraph_CameraPreset_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstract3DGraph_CameraPreset,
            is_Enum_PythonToCpp_QAbstract3DGraph_CameraPreset_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAbstract3DGraph::CameraPreset");
        Shiboken::Conversions::registerConverterName(converter, "CameraPreset");
    }
    // End of 'CameraPreset' enum.

    PySide::Signal::registerSignals(pyType, &::QAbstract3DGraph::staticMetaObject);
    qRegisterMetaType< ::QAbstract3DGraph::SelectionFlag >("QAbstract3DGraph::SelectionFlag");
    qRegisterMetaType< ::QAbstract3DGraph::ShadowQuality >("QAbstract3DGraph::ShadowQuality");
    qRegisterMetaType< ::QAbstract3DGraph::ElementType >("QAbstract3DGraph::ElementType");
    qRegisterMetaType< ::QAbstract3DGraph::OptimizationHint >("QAbstract3DGraph::OptimizationHint");
    qRegisterMetaType< ::QAbstract3DGraph::RenderingMode >("QAbstract3DGraph::RenderingMode");
    qRegisterMetaType< ::QAbstract3DGraph::CameraPreset >("QAbstract3DGraph::CameraPreset");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstract3DGraph::staticMetaObject, sizeof(QAbstract3DGraphWrapper));

    return pyType;
}
