// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhigraphicspipeline_wrapper.h"

// inner classes
#include "qrhigraphicspipeline_stencilopstate_wrapper.h"
#include "qrhigraphicspipeline_targetblend_wrapper.h"

// Argument includes
#include <QList>
#include <qbytearray.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiGraphicsPipelineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QRhiGraphicsPipelineWrapper::create()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiGraphicsPipeline.create");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiGraphicsPipeline.create");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiGraphicsPipeline", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiGraphicsPipelineWrapper::destroy()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiGraphicsPipeline.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiGraphicsPipeline.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QRhiResource::Type QRhiGraphicsPipelineWrapper::resourceType() const
{
    if (m_PyMethodCache[2])
        return this->::QRhiGraphicsPipeline::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QRhiGraphicsPipeline::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiGraphicsPipeline", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiGraphicsPipelineWrapper::~QRhiGraphicsPipelineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiGraphicsPipelineFunc_cbeginShaderStages(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.cbeginShaderStages";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cbeginShaderStages()const
            const QRhiShaderStage * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->cbeginShaderStages();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_cbeginTargetBlends(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.cbeginTargetBlends";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cbeginTargetBlends()const
            const QRhiGraphicsPipeline::TargetBlend * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->cbeginTargetBlends();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_TargetBlend_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_cendShaderStages(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.cendShaderStages";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cendShaderStages()const
            const QRhiShaderStage * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->cendShaderStages();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_cendTargetBlends(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.cendTargetBlends";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cendTargetBlends()const
            const QRhiGraphicsPipeline::TargetBlend * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->cendTargetBlends();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_TargetBlend_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // create()
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QRhiGraphicsPipeline.create");
                return {};
            }
            bool cppResult = cppSelf->create();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_cullMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.cullMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cullMode()const
            QRhiGraphicsPipeline::CullMode cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->cullMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_depthBias(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.depthBias";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // depthBias()const
            int cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->depthBias();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_depthOp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.depthOp";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // depthOp()const
            QRhiGraphicsPipeline::CompareOp cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->depthOp();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.flags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // flags()const
            QFlags<QRhiGraphicsPipeline::Flag> cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->flags();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_Flag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_frontFace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.frontFace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // frontFace()const
            QRhiGraphicsPipeline::FrontFace cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->frontFace();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_hasDepthTest(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.hasDepthTest";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasDepthTest()const
            bool cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->hasDepthTest();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_hasDepthWrite(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.hasDepthWrite";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasDepthWrite()const
            bool cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->hasDepthWrite();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_hasStencilTest(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.hasStencilTest";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasStencilTest()const
            bool cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->hasStencilTest();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_lineWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.lineWidth";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // lineWidth()const
            float cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->lineWidth();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_multiViewCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.multiViewCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // multiViewCount()const
            int cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->multiViewCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_patchControlPointCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.patchControlPointCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // patchControlPointCount()const
            int cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->patchControlPointCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_polygonMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.polygonMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // polygonMode()const
            QRhiGraphicsPipeline::PolygonMode cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->polygonMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_renderPassDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.renderPassDescriptor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // renderPassDescriptor()const
            QRhiRenderPassDescriptor * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->renderPassDescriptor();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.resourceType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // resourceType()const
            QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->::QRhiGraphicsPipeline::resourceType()
                : const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->resourceType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_sampleCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.sampleCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // sampleCount()const
            int cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->sampleCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setCullMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setCullMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setCullMode(QRhiGraphicsPipeline::CullMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCullMode(QRhiGraphicsPipeline::CullMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiGraphicsPipeline::CullMode cppArg0{QRhiGraphicsPipeline::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCullMode(QRhiGraphicsPipeline::CullMode)
            cppSelf->setCullMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setDepthBias(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setDepthBias";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setDepthBias(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDepthBias(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthBias(int)
            cppSelf->setDepthBias(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setDepthOp(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setDepthOp";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setDepthOp(QRhiGraphicsPipeline::CompareOp)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDepthOp(QRhiGraphicsPipeline::CompareOp)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiGraphicsPipeline::CompareOp cppArg0{QRhiGraphicsPipeline::Never};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthOp(QRhiGraphicsPipeline::CompareOp)
            cppSelf->setDepthOp(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setDepthTest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setDepthTest";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setDepthTest(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDepthTest(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthTest(bool)
            cppSelf->setDepthTest(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setDepthWrite(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setDepthWrite";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setDepthWrite(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDepthWrite(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthWrite(bool)
            cppSelf->setDepthWrite(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setFlags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setFlags(QFlags<QRhiGraphicsPipeline::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_Flag_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QRhiGraphicsPipeline::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QRhiGraphicsPipeline::Flag> cppArg0 = QFlags<QRhiGraphicsPipeline::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QRhiGraphicsPipeline::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setFrontFace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setFrontFace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setFrontFace(QRhiGraphicsPipeline::FrontFace)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFrontFace(QRhiGraphicsPipeline::FrontFace)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiGraphicsPipeline::FrontFace cppArg0{QRhiGraphicsPipeline::CCW};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFrontFace(QRhiGraphicsPipeline::FrontFace)
            cppSelf->setFrontFace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setLineWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setLineWidth";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setLineWidth(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setLineWidth(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLineWidth(float)
            cppSelf->setLineWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setMultiViewCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setMultiViewCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setMultiViewCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMultiViewCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiViewCount(int)
            cppSelf->setMultiViewCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setPatchControlPointCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setPatchControlPointCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setPatchControlPointCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPatchControlPointCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPatchControlPointCount(int)
            cppSelf->setPatchControlPointCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setPolygonMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setPolygonMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setPolygonMode(QRhiGraphicsPipeline::PolygonMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPolygonMode(QRhiGraphicsPipeline::PolygonMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiGraphicsPipeline::PolygonMode cppArg0{QRhiGraphicsPipeline::Fill};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPolygonMode(QRhiGraphicsPipeline::PolygonMode)
            cppSelf->setPolygonMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setRenderPassDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setRenderPassDescriptor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setRenderPassDescriptor(QRhiRenderPassDescriptor*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), (pyArg)))) {
        overloadId = 0; // setRenderPassDescriptor(QRhiRenderPassDescriptor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiRenderPassDescriptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRenderPassDescriptor(QRhiRenderPassDescriptor*)
            cppSelf->setRenderPassDescriptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setSampleCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setSampleCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setSampleCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSampleCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSampleCount(int)
            cppSelf->setSampleCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setShaderResourceBindings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setShaderResourceBindings";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setShaderResourceBindings(QRhiShaderResourceBindings*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), (pyArg)))) {
        overloadId = 0; // setShaderResourceBindings(QRhiShaderResourceBindings*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiShaderResourceBindings *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShaderResourceBindings(QRhiShaderResourceBindings*)
            cppSelf->setShaderResourceBindings(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setShaderStages(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setShaderStages";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setShaderStages(QList<QRhiShaderStage>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiShaderStage_IDX], (pyArg)))) {
        overloadId = 0; // setShaderStages(QList<QRhiShaderStage>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QRhiShaderStage> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShaderStages(QList<QRhiShaderStage>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            cppSelf->setShaderStages(cppArg0.cbegin(), cppArg0.cend());
            // END of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setSlopeScaledDepthBias(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setSlopeScaledDepthBias";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setSlopeScaledDepthBias(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setSlopeScaledDepthBias(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSlopeScaledDepthBias(float)
            cppSelf->setSlopeScaledDepthBias(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setStencilBack(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setStencilBack";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setStencilBack(QRhiGraphicsPipeline::StencilOpState)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), (pyArg)))) {
        overloadId = 0; // setStencilBack(QRhiGraphicsPipeline::StencilOpState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiGraphicsPipeline::StencilOpState cppArg0_local;
        ::QRhiGraphicsPipeline::StencilOpState *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilBack(QRhiGraphicsPipeline::StencilOpState)
            cppSelf->setStencilBack(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setStencilFront(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setStencilFront";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setStencilFront(QRhiGraphicsPipeline::StencilOpState)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), (pyArg)))) {
        overloadId = 0; // setStencilFront(QRhiGraphicsPipeline::StencilOpState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiGraphicsPipeline::StencilOpState cppArg0_local;
        ::QRhiGraphicsPipeline::StencilOpState *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilFront(QRhiGraphicsPipeline::StencilOpState)
            cppSelf->setStencilFront(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setStencilReadMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setStencilReadMask";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setStencilReadMask(quint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // setStencilReadMask(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilReadMask(quint32)
            cppSelf->setStencilReadMask(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setStencilTest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setStencilTest";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setStencilTest(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setStencilTest(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilTest(bool)
            cppSelf->setStencilTest(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setStencilWriteMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setStencilWriteMask";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setStencilWriteMask(quint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // setStencilWriteMask(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilWriteMask(quint32)
            cppSelf->setStencilWriteMask(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setTargetBlends(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setTargetBlends";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setTargetBlends(QList<QRhiGraphicsPipeline::TargetBlend>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiGraphicsPipeline_TargetBlend_IDX], (pyArg)))) {
        overloadId = 0; // setTargetBlends(QList<QRhiGraphicsPipeline::TargetBlend>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QRhiGraphicsPipeline::TargetBlend> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTargetBlends(QList<QRhiGraphicsPipeline::TargetBlend>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            cppSelf->setTargetBlends(cppArg0.cbegin(), cppArg0.cend());
            // END of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setTopology(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setTopology";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setTopology(QRhiGraphicsPipeline::Topology)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTopology(QRhiGraphicsPipeline::Topology)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhiGraphicsPipeline::Topology cppArg0{QRhiGraphicsPipeline::Triangles};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTopology(QRhiGraphicsPipeline::Topology)
            cppSelf->setTopology(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setVertexInputLayout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.setVertexInputLayout";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setVertexInputLayout(QRhiVertexInputLayout)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), (pyArg)))) {
        overloadId = 0; // setVertexInputLayout(QRhiVertexInputLayout)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiVertexInputLayout cppArg0_local;
        ::QRhiVertexInputLayout *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setVertexInputLayout(QRhiVertexInputLayout)
            cppSelf->setVertexInputLayout(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_shaderResourceBindings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.shaderResourceBindings";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // shaderResourceBindings()const
            QRhiShaderResourceBindings * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->shaderResourceBindings();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_shaderStageAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.shaderStageAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::shaderStageAt(qsizetype)const->const QRhiShaderStage*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // shaderStageAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // shaderStageAt(qsizetype)const
            const QRhiShaderStage * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->shaderStageAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_shaderStageCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.shaderStageCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // shaderStageCount()const
            qsizetype cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->shaderStageCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_slopeScaledDepthBias(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.slopeScaledDepthBias";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // slopeScaledDepthBias()const
            float cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->slopeScaledDepthBias();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_stencilBack(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.stencilBack";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // stencilBack()const
            QRhiGraphicsPipeline::StencilOpState cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->stencilBack();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_stencilFront(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.stencilFront";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // stencilFront()const
            QRhiGraphicsPipeline::StencilOpState cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->stencilFront();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_stencilReadMask(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.stencilReadMask";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // stencilReadMask()const
            quint32 cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->stencilReadMask();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_stencilWriteMask(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.stencilWriteMask";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // stencilWriteMask()const
            quint32 cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->stencilWriteMask();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_targetBlendAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.targetBlendAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::targetBlendAt(qsizetype)const->const QRhiGraphicsPipeline::TargetBlend*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // targetBlendAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // targetBlendAt(qsizetype)const
            const QRhiGraphicsPipeline::TargetBlend * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->targetBlendAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_TargetBlend_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_targetBlendCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.targetBlendCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // targetBlendCount()const
            qsizetype cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->targetBlendCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_topology(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.topology";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // topology()const
            QRhiGraphicsPipeline::Topology cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->topology();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_vertexInputLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhiGraphicsPipeline.vertexInputLayout";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // vertexInputLayout()const
            QRhiVertexInputLayout cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->vertexInputLayout();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiGraphicsPipeline_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiGraphicsPipeline_EnumFlagInfo[] = {
    "BlendFactor:Enum",
    "BlendOp:Enum",
    "ColorMaskComponent:Flag:ColorMask",
    "CompareOp:Enum",
    "CullMode:Enum",
    "Flag:Flag:Flags",
    "FrontFace:Enum",
    "PolygonMode:Enum",
    "StencilOp:Enum",
    "Topology:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiGraphicsPipeline_methods[] = {
    {"cbeginShaderStages", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_cbeginShaderStages), METH_NOARGS, nullptr},
    {"cbeginTargetBlends", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_cbeginTargetBlends), METH_NOARGS, nullptr},
    {"cendShaderStages", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_cendShaderStages), METH_NOARGS, nullptr},
    {"cendTargetBlends", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_cendTargetBlends), METH_NOARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_create), METH_NOARGS, nullptr},
    {"cullMode", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_cullMode), METH_NOARGS, nullptr},
    {"depthBias", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_depthBias), METH_NOARGS, nullptr},
    {"depthOp", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_depthOp), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_flags), METH_NOARGS, nullptr},
    {"frontFace", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_frontFace), METH_NOARGS, nullptr},
    {"hasDepthTest", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_hasDepthTest), METH_NOARGS, nullptr},
    {"hasDepthWrite", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_hasDepthWrite), METH_NOARGS, nullptr},
    {"hasStencilTest", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_hasStencilTest), METH_NOARGS, nullptr},
    {"lineWidth", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_lineWidth), METH_NOARGS, nullptr},
    {"multiViewCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_multiViewCount), METH_NOARGS, nullptr},
    {"patchControlPointCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_patchControlPointCount), METH_NOARGS, nullptr},
    {"polygonMode", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_polygonMode), METH_NOARGS, nullptr},
    {"renderPassDescriptor", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_renderPassDescriptor), METH_NOARGS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_resourceType), METH_NOARGS, nullptr},
    {"sampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_sampleCount), METH_NOARGS, nullptr},
    {"setCullMode", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setCullMode), METH_O, nullptr},
    {"setDepthBias", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setDepthBias), METH_O, nullptr},
    {"setDepthOp", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setDepthOp), METH_O, nullptr},
    {"setDepthTest", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setDepthTest), METH_O, nullptr},
    {"setDepthWrite", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setDepthWrite), METH_O, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setFlags), METH_O, nullptr},
    {"setFrontFace", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setFrontFace), METH_O, nullptr},
    {"setLineWidth", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setLineWidth), METH_O, nullptr},
    {"setMultiViewCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setMultiViewCount), METH_O, nullptr},
    {"setPatchControlPointCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setPatchControlPointCount), METH_O, nullptr},
    {"setPolygonMode", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setPolygonMode), METH_O, nullptr},
    {"setRenderPassDescriptor", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setRenderPassDescriptor), METH_O, nullptr},
    {"setSampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setSampleCount), METH_O, nullptr},
    {"setShaderResourceBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setShaderResourceBindings), METH_O, nullptr},
    {"setShaderStages", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setShaderStages), METH_O, nullptr},
    {"setSlopeScaledDepthBias", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setSlopeScaledDepthBias), METH_O, nullptr},
    {"setStencilBack", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setStencilBack), METH_O, nullptr},
    {"setStencilFront", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setStencilFront), METH_O, nullptr},
    {"setStencilReadMask", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setStencilReadMask), METH_O, nullptr},
    {"setStencilTest", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setStencilTest), METH_O, nullptr},
    {"setStencilWriteMask", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setStencilWriteMask), METH_O, nullptr},
    {"setTargetBlends", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setTargetBlends), METH_O, nullptr},
    {"setTopology", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setTopology), METH_O, nullptr},
    {"setVertexInputLayout", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setVertexInputLayout), METH_O, nullptr},
    {"shaderResourceBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_shaderResourceBindings), METH_NOARGS, nullptr},
    {"shaderStageAt", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_shaderStageAt), METH_O, nullptr},
    {"shaderStageCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_shaderStageCount), METH_NOARGS, nullptr},
    {"slopeScaledDepthBias", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_slopeScaledDepthBias), METH_NOARGS, nullptr},
    {"stencilBack", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_stencilBack), METH_NOARGS, nullptr},
    {"stencilFront", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_stencilFront), METH_NOARGS, nullptr},
    {"stencilReadMask", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_stencilReadMask), METH_NOARGS, nullptr},
    {"stencilWriteMask", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_stencilWriteMask), METH_NOARGS, nullptr},
    {"targetBlendAt", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_targetBlendAt), METH_O, nullptr},
    {"targetBlendCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_targetBlendCount), METH_NOARGS, nullptr},
    {"topology", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_topology), METH_NOARGS, nullptr},
    {"vertexInputLayout", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_vertexInputLayout), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiGraphicsPipeline_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiGraphicsPipelineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_flags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_Flag_IDX])))->converter, &cppSelf->m_flags);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_flags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_flags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_Flag_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_flags", "Flags");
        return -1;
    }

    auto cppOut_local = cppSelf->m_flags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_flags = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_topology(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiGraphicsPipeline::Topology cppOut_local = cppSelf->m_topology;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_topology(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_topology");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_topology", "Topology");
        return -1;
    }

    auto cppOut_local = cppSelf->m_topology;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_topology = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_cullMode(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiGraphicsPipeline::CullMode cppOut_local = cppSelf->m_cullMode;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_cullMode(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_cullMode");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_cullMode", "CullMode");
        return -1;
    }

    auto cppOut_local = cppSelf->m_cullMode;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_cullMode = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_frontFace(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiGraphicsPipeline::FrontFace cppOut_local = cppSelf->m_frontFace;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_frontFace(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_frontFace");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_frontFace", "FrontFace");
        return -1;
    }

    auto cppOut_local = cppSelf->m_frontFace;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_frontFace = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_depthTest(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->m_depthTest;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_depthTest(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_depthTest");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_depthTest", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->m_depthTest;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_depthTest = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_depthWrite(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->m_depthWrite;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_depthWrite(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_depthWrite");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_depthWrite", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->m_depthWrite;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_depthWrite = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_depthOp(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiGraphicsPipeline::CompareOp cppOut_local = cppSelf->m_depthOp;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_depthOp(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_depthOp");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_depthOp", "CompareOp");
        return -1;
    }

    auto cppOut_local = cppSelf->m_depthOp;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_depthOp = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_stencilTest(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->m_stencilTest;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_stencilTest(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_stencilTest");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_stencilTest", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->m_stencilTest;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_stencilTest = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_stencilFront(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_stencilFront)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_stencilFront))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_stencilFront)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), &(cppSelf->m_stencilFront), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_stencilFront(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_stencilFront");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_stencilFront", "StencilOpState");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_stencilFront;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_stencilBack(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_stencilBack)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_stencilBack))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_stencilBack)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), &(cppSelf->m_stencilBack), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_stencilBack(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_stencilBack");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_stencilBack", "StencilOpState");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_stencilBack;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_stencilReadMask(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint32 cppOut_local = cppSelf->m_stencilReadMask;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_stencilReadMask(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_stencilReadMask");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_stencilReadMask", "quint32");
        return -1;
    }

    auto cppOut_local = cppSelf->m_stencilReadMask;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_stencilReadMask = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_stencilWriteMask(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint32 cppOut_local = cppSelf->m_stencilWriteMask;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_stencilWriteMask(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_stencilWriteMask");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_stencilWriteMask", "quint32");
        return -1;
    }

    auto cppOut_local = cppSelf->m_stencilWriteMask;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_stencilWriteMask = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_sampleCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_sampleCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_sampleCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_sampleCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_sampleCount", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_sampleCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_sampleCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_lineWidth(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppSelf->m_lineWidth);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_lineWidth(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_lineWidth");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_lineWidth", "float");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_lineWidth;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_depthBias(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_depthBias;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_depthBias(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_depthBias");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_depthBias", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_depthBias;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_depthBias = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_slopeScaledDepthBias(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppSelf->m_slopeScaledDepthBias);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_slopeScaledDepthBias(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_slopeScaledDepthBias");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_slopeScaledDepthBias", "float");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_slopeScaledDepthBias;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_patchControlPointCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_patchControlPointCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_patchControlPointCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_patchControlPointCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_patchControlPointCount", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_patchControlPointCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_patchControlPointCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_polygonMode(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiGraphicsPipeline::PolygonMode cppOut_local = cppSelf->m_polygonMode;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_polygonMode(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_polygonMode");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_polygonMode", "PolygonMode");
        return -1;
    }

    auto cppOut_local = cppSelf->m_polygonMode;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_polygonMode = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_multiViewCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_multiViewCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_multiViewCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_multiViewCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_multiViewCount", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_multiViewCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_multiViewCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_vertexInputLayout(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_vertexInputLayout)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_vertexInputLayout))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_vertexInputLayout)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), &(cppSelf->m_vertexInputLayout), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_vertexInputLayout(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_vertexInputLayout");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_vertexInputLayout", "QRhiVertexInputLayout");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_vertexInputLayout;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_shaderResourceBindings(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), cppSelf->m_shaderResourceBindings);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_shaderResourceBindings(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_shaderResourceBindings");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_shaderResourceBindings", "QRhiShaderResourceBindings");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->m_shaderResourceBindings;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "m_shaderResourceBindings", pyIn);
    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_renderPassDesc(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), cppSelf->m_renderPassDesc);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_renderPassDesc(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_renderPassDesc");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_renderPassDesc", "QRhiRenderPassDescriptor");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->m_renderPassDesc;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "m_renderPassDesc", pyIn);
    return 0;
}

// Getters and Setters for QRhiGraphicsPipeline
static PyGetSetDef Sbk_QRhiGraphicsPipeline_getsetlist[] = {
    {const_cast<char *>("m_flags"), Sbk_QRhiGraphicsPipeline_get_m_flags, Sbk_QRhiGraphicsPipeline_set_m_flags, nullptr, nullptr},
    {const_cast<char *>("m_topology"), Sbk_QRhiGraphicsPipeline_get_m_topology, Sbk_QRhiGraphicsPipeline_set_m_topology, nullptr, nullptr},
    {const_cast<char *>("m_cullMode"), Sbk_QRhiGraphicsPipeline_get_m_cullMode, Sbk_QRhiGraphicsPipeline_set_m_cullMode, nullptr, nullptr},
    {const_cast<char *>("m_frontFace"), Sbk_QRhiGraphicsPipeline_get_m_frontFace, Sbk_QRhiGraphicsPipeline_set_m_frontFace, nullptr, nullptr},
    {const_cast<char *>("m_depthTest"), Sbk_QRhiGraphicsPipeline_get_m_depthTest, Sbk_QRhiGraphicsPipeline_set_m_depthTest, nullptr, nullptr},
    {const_cast<char *>("m_depthWrite"), Sbk_QRhiGraphicsPipeline_get_m_depthWrite, Sbk_QRhiGraphicsPipeline_set_m_depthWrite, nullptr, nullptr},
    {const_cast<char *>("m_depthOp"), Sbk_QRhiGraphicsPipeline_get_m_depthOp, Sbk_QRhiGraphicsPipeline_set_m_depthOp, nullptr, nullptr},
    {const_cast<char *>("m_stencilTest"), Sbk_QRhiGraphicsPipeline_get_m_stencilTest, Sbk_QRhiGraphicsPipeline_set_m_stencilTest, nullptr, nullptr},
    {const_cast<char *>("m_stencilFront"), Sbk_QRhiGraphicsPipeline_get_m_stencilFront, Sbk_QRhiGraphicsPipeline_set_m_stencilFront, nullptr, nullptr},
    {const_cast<char *>("m_stencilBack"), Sbk_QRhiGraphicsPipeline_get_m_stencilBack, Sbk_QRhiGraphicsPipeline_set_m_stencilBack, nullptr, nullptr},
    {const_cast<char *>("m_stencilReadMask"), Sbk_QRhiGraphicsPipeline_get_m_stencilReadMask, Sbk_QRhiGraphicsPipeline_set_m_stencilReadMask, nullptr, nullptr},
    {const_cast<char *>("m_stencilWriteMask"), Sbk_QRhiGraphicsPipeline_get_m_stencilWriteMask, Sbk_QRhiGraphicsPipeline_set_m_stencilWriteMask, nullptr, nullptr},
    {const_cast<char *>("m_sampleCount"), Sbk_QRhiGraphicsPipeline_get_m_sampleCount, Sbk_QRhiGraphicsPipeline_set_m_sampleCount, nullptr, nullptr},
    {const_cast<char *>("m_lineWidth"), Sbk_QRhiGraphicsPipeline_get_m_lineWidth, Sbk_QRhiGraphicsPipeline_set_m_lineWidth, nullptr, nullptr},
    {const_cast<char *>("m_depthBias"), Sbk_QRhiGraphicsPipeline_get_m_depthBias, Sbk_QRhiGraphicsPipeline_set_m_depthBias, nullptr, nullptr},
    {const_cast<char *>("m_slopeScaledDepthBias"), Sbk_QRhiGraphicsPipeline_get_m_slopeScaledDepthBias, Sbk_QRhiGraphicsPipeline_set_m_slopeScaledDepthBias, nullptr, nullptr},
    {const_cast<char *>("m_patchControlPointCount"), Sbk_QRhiGraphicsPipeline_get_m_patchControlPointCount, Sbk_QRhiGraphicsPipeline_set_m_patchControlPointCount, nullptr, nullptr},
    {const_cast<char *>("m_polygonMode"), Sbk_QRhiGraphicsPipeline_get_m_polygonMode, Sbk_QRhiGraphicsPipeline_set_m_polygonMode, nullptr, nullptr},
    {const_cast<char *>("m_multiViewCount"), Sbk_QRhiGraphicsPipeline_get_m_multiViewCount, Sbk_QRhiGraphicsPipeline_set_m_multiViewCount, nullptr, nullptr},
    {const_cast<char *>("m_vertexInputLayout"), Sbk_QRhiGraphicsPipeline_get_m_vertexInputLayout, Sbk_QRhiGraphicsPipeline_set_m_vertexInputLayout, nullptr, nullptr},
    {const_cast<char *>("m_shaderResourceBindings"), Sbk_QRhiGraphicsPipeline_get_m_shaderResourceBindings, Sbk_QRhiGraphicsPipeline_set_m_shaderResourceBindings, nullptr, nullptr},
    {const_cast<char *>("m_renderPassDesc"), Sbk_QRhiGraphicsPipeline_get_m_renderPassDesc, Sbk_QRhiGraphicsPipeline_set_m_renderPassDesc, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiGraphicsPipeline_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiGraphicsPipeline_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiGraphicsPipeline_Type = nullptr;
static PyTypeObject *Sbk_QRhiGraphicsPipeline_TypeF(void)
{
    return _Sbk_QRhiGraphicsPipeline_Type;
}

static PyType_Slot Sbk_QRhiGraphicsPipeline_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiGraphicsPipeline_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiGraphicsPipeline_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiGraphicsPipeline_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiGraphicsPipeline_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiGraphicsPipeline_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiGraphicsPipeline_spec = {
    "2:PySide6.QtGui.QRhiGraphicsPipeline",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiGraphicsPipeline_slots
};

} //extern "C"

static void *Sbk_QRhiGraphicsPipeline_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiGraphicsPipeline *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRhiGraphicsPipeline_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Flag_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_Flag;
    return {};
}
static PyObject *QRhiGraphicsPipeline_Flag_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiGraphicsPipeline::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Flag_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_Topology(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::Topology>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::Topology *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_Topology_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_Topology;
    return {};
}
static PyObject *QRhiGraphicsPipeline_Topology_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiGraphicsPipeline::Topology *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_CullMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::CullMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::CullMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_CullMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_CullMode;
    return {};
}
static PyObject *QRhiGraphicsPipeline_CullMode_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiGraphicsPipeline::CullMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_FrontFace(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::FrontFace>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::FrontFace *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_FrontFace_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_FrontFace;
    return {};
}
static PyObject *QRhiGraphicsPipeline_FrontFace_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiGraphicsPipeline::FrontFace *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::ColorMaskComponent>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::ColorMaskComponent *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_ColorMaskComponent_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent;
    return {};
}
static PyObject *QRhiGraphicsPipeline_ColorMaskComponent_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiGraphicsPipeline::ColorMaskComponent *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_ColorMaskComponent_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_BlendFactor(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::BlendFactor>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::BlendFactor *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_BlendFactor_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendFactor_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_BlendFactor;
    return {};
}
static PyObject *QRhiGraphicsPipeline_BlendFactor_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiGraphicsPipeline::BlendFactor *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendFactor_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_BlendOp(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::BlendOp>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::BlendOp *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_BlendOp_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendOp_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_BlendOp;
    return {};
}
static PyObject *QRhiGraphicsPipeline_BlendOp_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiGraphicsPipeline::BlendOp *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendOp_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_CompareOp(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::CompareOp>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::CompareOp *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_CompareOp_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_CompareOp;
    return {};
}
static PyObject *QRhiGraphicsPipeline_CompareOp_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiGraphicsPipeline::CompareOp *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_StencilOp(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::StencilOp>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::StencilOp *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_StencilOp_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOp_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_StencilOp;
    return {};
}
static PyObject *QRhiGraphicsPipeline_StencilOp_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiGraphicsPipeline::StencilOp *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOp_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_PolygonMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::PolygonMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::PolygonMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_PolygonMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_PolygonMode;
    return {};
}
static PyObject *QRhiGraphicsPipeline_PolygonMode_CppToPython_Enum(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhiGraphicsPipeline::PolygonMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiGraphicsPipeline_PythonToCpp_QRhiGraphicsPipeline_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiGraphicsPipeline_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiGraphicsPipeline_PythonToCpp_QRhiGraphicsPipeline_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiGraphicsPipeline_TypeF()))
        return QRhiGraphicsPipeline_PythonToCpp_QRhiGraphicsPipeline_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiGraphicsPipeline_PTR_CppToPython_QRhiGraphicsPipeline(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QRhiGraphicsPipeline *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QRhiGraphicsPipeline_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRhiGraphicsPipeline_SignatureStrings[] = {
    "PySide6.QtGui.QRhiGraphicsPipeline.cbeginShaderStages(self)->PySide6.QtGui.QRhiShaderStage",
    "PySide6.QtGui.QRhiGraphicsPipeline.cbeginTargetBlends(self)->PySide6.QtGui.QRhiGraphicsPipeline.TargetBlend",
    "PySide6.QtGui.QRhiGraphicsPipeline.cendShaderStages(self)->PySide6.QtGui.QRhiShaderStage",
    "PySide6.QtGui.QRhiGraphicsPipeline.cendTargetBlends(self)->PySide6.QtGui.QRhiGraphicsPipeline.TargetBlend",
    "PySide6.QtGui.QRhiGraphicsPipeline.create(self)->bool",
    "PySide6.QtGui.QRhiGraphicsPipeline.cullMode(self)->PySide6.QtGui.QRhiGraphicsPipeline.CullMode",
    "PySide6.QtGui.QRhiGraphicsPipeline.depthBias(self)->int",
    "PySide6.QtGui.QRhiGraphicsPipeline.depthOp(self)->PySide6.QtGui.QRhiGraphicsPipeline.CompareOp",
    "PySide6.QtGui.QRhiGraphicsPipeline.flags(self)->PySide6.QtGui.QRhiGraphicsPipeline.Flag",
    "PySide6.QtGui.QRhiGraphicsPipeline.frontFace(self)->PySide6.QtGui.QRhiGraphicsPipeline.FrontFace",
    "PySide6.QtGui.QRhiGraphicsPipeline.hasDepthTest(self)->bool",
    "PySide6.QtGui.QRhiGraphicsPipeline.hasDepthWrite(self)->bool",
    "PySide6.QtGui.QRhiGraphicsPipeline.hasStencilTest(self)->bool",
    "PySide6.QtGui.QRhiGraphicsPipeline.lineWidth(self)->float",
    "PySide6.QtGui.QRhiGraphicsPipeline.multiViewCount(self)->int",
    "PySide6.QtGui.QRhiGraphicsPipeline.patchControlPointCount(self)->int",
    "PySide6.QtGui.QRhiGraphicsPipeline.polygonMode(self)->PySide6.QtGui.QRhiGraphicsPipeline.PolygonMode",
    "PySide6.QtGui.QRhiGraphicsPipeline.renderPassDescriptor(self)->PySide6.QtGui.QRhiRenderPassDescriptor",
    "PySide6.QtGui.QRhiGraphicsPipeline.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiGraphicsPipeline.sampleCount(self)->int",
    "PySide6.QtGui.QRhiGraphicsPipeline.setCullMode(self,mode:PySide6.QtGui.QRhiGraphicsPipeline.CullMode)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setDepthBias(self,bias:int)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setDepthOp(self,op:PySide6.QtGui.QRhiGraphicsPipeline.CompareOp)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setDepthTest(self,enable:bool)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setDepthWrite(self,enable:bool)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setFlags(self,f:PySide6.QtGui.QRhiGraphicsPipeline.Flag)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setFrontFace(self,f:PySide6.QtGui.QRhiGraphicsPipeline.FrontFace)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setLineWidth(self,width:float)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setMultiViewCount(self,count:int)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setPatchControlPointCount(self,count:int)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setPolygonMode(self,mode:PySide6.QtGui.QRhiGraphicsPipeline.PolygonMode)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setRenderPassDescriptor(self,desc:PySide6.QtGui.QRhiRenderPassDescriptor)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setSampleCount(self,s:int)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setShaderResourceBindings(self,srb:PySide6.QtGui.QRhiShaderResourceBindings)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setShaderStages(self,stages:QList[PySide6.QtGui.QRhiShaderStage])",
    "PySide6.QtGui.QRhiGraphicsPipeline.setSlopeScaledDepthBias(self,bias:float)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setStencilBack(self,state:PySide6.QtGui.QRhiGraphicsPipeline.StencilOpState)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setStencilFront(self,state:PySide6.QtGui.QRhiGraphicsPipeline.StencilOpState)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setStencilReadMask(self,mask:quint32)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setStencilTest(self,enable:bool)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setStencilWriteMask(self,mask:quint32)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setTargetBlends(self,blends:QList[PySide6.QtGui.QRhiGraphicsPipeline.TargetBlend])",
    "PySide6.QtGui.QRhiGraphicsPipeline.setTopology(self,t:PySide6.QtGui.QRhiGraphicsPipeline.Topology)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setVertexInputLayout(self,layout:PySide6.QtGui.QRhiVertexInputLayout)",
    "PySide6.QtGui.QRhiGraphicsPipeline.shaderResourceBindings(self)->PySide6.QtGui.QRhiShaderResourceBindings",
    "PySide6.QtGui.QRhiGraphicsPipeline.shaderStageAt(self,index:qsizetype)->PySide6.QtGui.QRhiShaderStage",
    "PySide6.QtGui.QRhiGraphicsPipeline.shaderStageCount(self)->qsizetype",
    "PySide6.QtGui.QRhiGraphicsPipeline.slopeScaledDepthBias(self)->float",
    "PySide6.QtGui.QRhiGraphicsPipeline.stencilBack(self)->PySide6.QtGui.QRhiGraphicsPipeline.StencilOpState",
    "PySide6.QtGui.QRhiGraphicsPipeline.stencilFront(self)->PySide6.QtGui.QRhiGraphicsPipeline.StencilOpState",
    "PySide6.QtGui.QRhiGraphicsPipeline.stencilReadMask(self)->quint32",
    "PySide6.QtGui.QRhiGraphicsPipeline.stencilWriteMask(self)->quint32",
    "PySide6.QtGui.QRhiGraphicsPipeline.targetBlendAt(self,index:qsizetype)->PySide6.QtGui.QRhiGraphicsPipeline.TargetBlend",
    "PySide6.QtGui.QRhiGraphicsPipeline.targetBlendCount(self)->qsizetype",
    "PySide6.QtGui.QRhiGraphicsPipeline.topology(self)->PySide6.QtGui.QRhiGraphicsPipeline.Topology",
    "PySide6.QtGui.QRhiGraphicsPipeline.vertexInputLayout(self)->PySide6.QtGui.QRhiVertexInputLayout",
    nullptr}; // Sentinel

PyTypeObject *init_QRhiGraphicsPipeline(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiGraphicsPipeline_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]))));

    _Sbk_QRhiGraphicsPipeline_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiGraphicsPipeline",
        "QRhiGraphicsPipeline*",
        &Sbk_QRhiGraphicsPipeline_spec,
        &Shiboken::callCppDestructor< QRhiGraphicsPipeline >,
        Sbk_QRhiGraphicsPipeline_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiGraphicsPipeline_TypeF(); // references _Sbk_QRhiGraphicsPipeline_Type
    InitSignatureStrings(pyType, QRhiGraphicsPipeline_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiGraphicsPipeline_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiGraphicsPipeline_PythonToCpp_QRhiGraphicsPipeline_PTR,
        is_QRhiGraphicsPipeline_PythonToCpp_QRhiGraphicsPipeline_PTR_Convertible,
        QRhiGraphicsPipeline_PTR_CppToPython_QRhiGraphicsPipeline);

    Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline");
    Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiGraphicsPipeline).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiGraphicsPipelineWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiGraphicsPipeline_TypeF(), &Sbk_QRhiGraphicsPipeline_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiGraphicsPipeline_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "UsesBlendConstants",
        "UsesStencilRef",
        "UsesScissor",
        "CompileShadersWithDebugInfo",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::Flag::UsesBlendConstants),         //  0x01  1
        uint8_t(QRhiGraphicsPipeline::Flag::UsesStencilRef),             //  0x02  2
        uint8_t(QRhiGraphicsPipeline::Flag::UsesScissor),                //  0x04  4
        uint8_t(QRhiGraphicsPipeline::Flag::CompileShadersWithDebugInfo) //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_Flag_IDX].type =
        EType;
    // Register converter for enum 'QRhiGraphicsPipeline::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_Flag,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_Flag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::Flag");
        Shiboken::Conversions::registerConverterName(converter, "Flag");
        // Register converter for flag 'QFlags<QRhiGraphicsPipeline::Flag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRhiGraphicsPipeline::Flag>");
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::Flags");
    }
    // End of 'Flag' enum/flags.

    // Initialization of enum 'Topology'.
    const char *Topology_Initializer[] = {
        "Triangles",
        "TriangleStrip",
        "TriangleFan",
        "Lines",
        "LineStrip",
        "Points",
        "Patches",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Topology_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::Topology::Triangles),     //  0x00  0
        uint8_t(QRhiGraphicsPipeline::Topology::TriangleStrip), //  0x01  1
        uint8_t(QRhiGraphicsPipeline::Topology::TriangleFan),   //  0x02  2
        uint8_t(QRhiGraphicsPipeline::Topology::Lines),         //  0x03  3
        uint8_t(QRhiGraphicsPipeline::Topology::LineStrip),     //  0x04  4
        uint8_t(QRhiGraphicsPipeline::Topology::Points),        //  0x05  5
        uint8_t(QRhiGraphicsPipeline::Topology::Patches)        //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.Topology",
        Topology_Initializer, Topology_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::Topology'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_Topology_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_Topology,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_Topology_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::Topology");
        Shiboken::Conversions::registerConverterName(converter, "Topology");
    }
    // End of 'Topology' enum.

    // Initialization of enum 'CullMode'.
    const char *CullMode_Initializer[] = {
        "None_",
        "Front",
        "Back",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CullMode_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::CullMode::None),  //  0x00  0
        uint8_t(QRhiGraphicsPipeline::CullMode::Front), //  0x01  1
        uint8_t(QRhiGraphicsPipeline::CullMode::Back)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.CullMode",
        CullMode_Initializer, CullMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::CullMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_CullMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_CullMode,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_CullMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::CullMode");
        Shiboken::Conversions::registerConverterName(converter, "CullMode");
    }
    // End of 'CullMode' enum.

    // Initialization of enum 'FrontFace'.
    const char *FrontFace_Initializer[] = {
        "CCW",
        "CW",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FrontFace_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::FrontFace::CCW), //  0x00  0
        uint8_t(QRhiGraphicsPipeline::FrontFace::CW)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.FrontFace",
        FrontFace_Initializer, FrontFace_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::FrontFace'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_FrontFace_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_FrontFace,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_FrontFace_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::FrontFace");
        Shiboken::Conversions::registerConverterName(converter, "FrontFace");
    }
    // End of 'FrontFace' enum.

    // Initialization of enum 'ColorMaskComponent'.
    const char *ColorMaskComponent_Initializer[] = {
        "R",
        "G",
        "B",
        "A",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ColorMaskComponent_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::ColorMaskComponent::R), //  0x01  1
        uint8_t(QRhiGraphicsPipeline::ColorMaskComponent::G), //  0x02  2
        uint8_t(QRhiGraphicsPipeline::ColorMaskComponent::B), //  0x04  4
        uint8_t(QRhiGraphicsPipeline::ColorMaskComponent::A)  //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.ColorMaskComponent",
        ColorMaskComponent_Initializer, ColorMaskComponent_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_ColorMaskComponent_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_ColorMaskComponent_IDX].type =
        EType;
    // Register converter for enum 'QRhiGraphicsPipeline::ColorMaskComponent'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_ColorMaskComponent_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::ColorMaskComponent");
        Shiboken::Conversions::registerConverterName(converter, "ColorMaskComponent");
        // Register converter for flag 'QFlags<QRhiGraphicsPipeline::ColorMaskComponent>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRhiGraphicsPipeline::ColorMaskComponent>");
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::ColorMask");
    }
    // End of 'ColorMaskComponent' enum/flags.

    // Initialization of enum 'BlendFactor'.
    const char *BlendFactor_Initializer[] = {
        "Zero",
        "One",
        "SrcColor",
        "OneMinusSrcColor",
        "DstColor",
        "OneMinusDstColor",
        "SrcAlpha",
        "OneMinusSrcAlpha",
        "DstAlpha",
        "OneMinusDstAlpha",
        "ConstantColor",
        "OneMinusConstantColor",
        "ConstantAlpha",
        "OneMinusConstantAlpha",
        "SrcAlphaSaturate",
        "Src1Color",
        "OneMinusSrc1Color",
        "Src1Alpha",
        "OneMinusSrc1Alpha",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t BlendFactor_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::BlendFactor::Zero),                  //  0x00  0
        uint8_t(QRhiGraphicsPipeline::BlendFactor::One),                   //  0x01  1
        uint8_t(QRhiGraphicsPipeline::BlendFactor::SrcColor),              //  0x02  2
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusSrcColor),      //  0x03  3
        uint8_t(QRhiGraphicsPipeline::BlendFactor::DstColor),              //  0x04  4
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusDstColor),      //  0x05  5
        uint8_t(QRhiGraphicsPipeline::BlendFactor::SrcAlpha),              //  0x06  6
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusSrcAlpha),      //  0x07  7
        uint8_t(QRhiGraphicsPipeline::BlendFactor::DstAlpha),              //  0x08  8
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusDstAlpha),      //  0x09  9
        uint8_t(QRhiGraphicsPipeline::BlendFactor::ConstantColor),         //  0x0a  10
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusConstantColor), //  0x0b  11
        uint8_t(QRhiGraphicsPipeline::BlendFactor::ConstantAlpha),         //  0x0c  12
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusConstantAlpha), //  0x0d  13
        uint8_t(QRhiGraphicsPipeline::BlendFactor::SrcAlphaSaturate),      //  0x0e  14
        uint8_t(QRhiGraphicsPipeline::BlendFactor::Src1Color),             //  0x0f  15
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusSrc1Color),     //  0x10  16
        uint8_t(QRhiGraphicsPipeline::BlendFactor::Src1Alpha),             //  0x11  17
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusSrc1Alpha)      //  0x12  18
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.BlendFactor",
        BlendFactor_Initializer, BlendFactor_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendFactor_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::BlendFactor'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_BlendFactor_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_BlendFactor,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_BlendFactor_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::BlendFactor");
        Shiboken::Conversions::registerConverterName(converter, "BlendFactor");
    }
    // End of 'BlendFactor' enum.

    // Initialization of enum 'BlendOp'.
    const char *BlendOp_Initializer[] = {
        "Add",
        "Subtract",
        "ReverseSubtract",
        "Min",
        "Max",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t BlendOp_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::BlendOp::Add),             //  0x00  0
        uint8_t(QRhiGraphicsPipeline::BlendOp::Subtract),        //  0x01  1
        uint8_t(QRhiGraphicsPipeline::BlendOp::ReverseSubtract), //  0x02  2
        uint8_t(QRhiGraphicsPipeline::BlendOp::Min),             //  0x03  3
        uint8_t(QRhiGraphicsPipeline::BlendOp::Max)              //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.BlendOp",
        BlendOp_Initializer, BlendOp_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendOp_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::BlendOp'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_BlendOp_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_BlendOp,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_BlendOp_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::BlendOp");
        Shiboken::Conversions::registerConverterName(converter, "BlendOp");
    }
    // End of 'BlendOp' enum.

    // Initialization of enum 'CompareOp'.
    const char *CompareOp_Initializer[] = {
        "Never",
        "Less",
        "Equal",
        "LessOrEqual",
        "Greater",
        "NotEqual",
        "GreaterOrEqual",
        "Always",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CompareOp_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::CompareOp::Never),          //  0x00  0
        uint8_t(QRhiGraphicsPipeline::CompareOp::Less),           //  0x01  1
        uint8_t(QRhiGraphicsPipeline::CompareOp::Equal),          //  0x02  2
        uint8_t(QRhiGraphicsPipeline::CompareOp::LessOrEqual),    //  0x03  3
        uint8_t(QRhiGraphicsPipeline::CompareOp::Greater),        //  0x04  4
        uint8_t(QRhiGraphicsPipeline::CompareOp::NotEqual),       //  0x05  5
        uint8_t(QRhiGraphicsPipeline::CompareOp::GreaterOrEqual), //  0x06  6
        uint8_t(QRhiGraphicsPipeline::CompareOp::Always)          //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.CompareOp",
        CompareOp_Initializer, CompareOp_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::CompareOp'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_CompareOp_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_CompareOp,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_CompareOp_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::CompareOp");
        Shiboken::Conversions::registerConverterName(converter, "CompareOp");
    }
    // End of 'CompareOp' enum.

    // Initialization of enum 'StencilOp'.
    const char *StencilOp_Initializer[] = {
        "StencilZero",
        "Keep",
        "Replace",
        "IncrementAndClamp",
        "DecrementAndClamp",
        "Invert",
        "IncrementAndWrap",
        "DecrementAndWrap",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StencilOp_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::StencilOp::StencilZero),       //  0x00  0
        uint8_t(QRhiGraphicsPipeline::StencilOp::Keep),              //  0x01  1
        uint8_t(QRhiGraphicsPipeline::StencilOp::Replace),           //  0x02  2
        uint8_t(QRhiGraphicsPipeline::StencilOp::IncrementAndClamp), //  0x03  3
        uint8_t(QRhiGraphicsPipeline::StencilOp::DecrementAndClamp), //  0x04  4
        uint8_t(QRhiGraphicsPipeline::StencilOp::Invert),            //  0x05  5
        uint8_t(QRhiGraphicsPipeline::StencilOp::IncrementAndWrap),  //  0x06  6
        uint8_t(QRhiGraphicsPipeline::StencilOp::DecrementAndWrap)   //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.StencilOp",
        StencilOp_Initializer, StencilOp_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOp_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::StencilOp'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_StencilOp_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_StencilOp,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_StencilOp_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::StencilOp");
        Shiboken::Conversions::registerConverterName(converter, "StencilOp");
    }
    // End of 'StencilOp' enum.

    // Initialization of enum 'PolygonMode'.
    const char *PolygonMode_Initializer[] = {
        "Fill",
        "Line",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PolygonMode_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::PolygonMode::Fill), //  0x00  0
        uint8_t(QRhiGraphicsPipeline::PolygonMode::Line)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.PolygonMode",
        PolygonMode_Initializer, PolygonMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::PolygonMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_PolygonMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_PolygonMode,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_PolygonMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::PolygonMode");
        Shiboken::Conversions::registerConverterName(converter, "PolygonMode");
    }
    // End of 'PolygonMode' enum.

    qRegisterMetaType< ::QRhiGraphicsPipeline *>();
    qRegisterMetaType< ::QRhiGraphicsPipeline::Flag >("QRhiGraphicsPipeline::Flag");
    qRegisterMetaType< ::QRhiGraphicsPipeline::Topology >("QRhiGraphicsPipeline::Topology");
    qRegisterMetaType< ::QRhiGraphicsPipeline::CullMode >("QRhiGraphicsPipeline::CullMode");
    qRegisterMetaType< ::QRhiGraphicsPipeline::FrontFace >("QRhiGraphicsPipeline::FrontFace");
    qRegisterMetaType< ::QRhiGraphicsPipeline::ColorMaskComponent >("QRhiGraphicsPipeline::ColorMaskComponent");
    qRegisterMetaType< ::QRhiGraphicsPipeline::BlendFactor >("QRhiGraphicsPipeline::BlendFactor");
    qRegisterMetaType< ::QRhiGraphicsPipeline::BlendOp >("QRhiGraphicsPipeline::BlendOp");
    qRegisterMetaType< ::QRhiGraphicsPipeline::CompareOp >("QRhiGraphicsPipeline::CompareOp");
    qRegisterMetaType< ::QRhiGraphicsPipeline::StencilOp >("QRhiGraphicsPipeline::StencilOp");
    qRegisterMetaType< ::QRhiGraphicsPipeline::PolygonMode >("QRhiGraphicsPipeline::PolygonMode");

    return pyType;
}
