// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopenglshaderprogram_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qcolor.h>
#include <QtGui/qgenericmatrix.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qopenglcontext.h>
#include <QtGui/qtransform.h>
#include <QtGui/qvectornd.h>
#include <QtOpenGL/qopenglshaderprogram.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QOpenGLShaderProgramWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QOpenGLShaderProgramWrapper::QOpenGLShaderProgramWrapper(::QObject * parent) : QOpenGLShaderProgram(parent)
{
    resetPyMethodCache();
    // ... middle
}

void QOpenGLShaderProgramWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QOpenGLShaderProgramWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QOpenGLShaderProgramWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QOpenGLShaderProgramWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QOpenGLShaderProgramWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOpenGLShaderProgram", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QOpenGLShaderProgramWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOpenGLShaderProgram", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QOpenGLShaderProgramWrapper::link()
{
    if (m_PyMethodCache[6])
        return this->::QOpenGLShaderProgram::link();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "link";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QOpenGLShaderProgram::link();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOpenGLShaderProgram", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QOpenGLShaderProgramWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QOpenGLShaderProgramWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QOpenGLShaderProgram::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QOpenGLShaderProgramWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QOpenGLShaderProgram::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QOpenGLShaderProgramWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QOpenGLShaderProgramWrapper *>(this));
    return QOpenGLShaderProgram::qt_metacast(_clname);
}

QOpenGLShaderProgramWrapper::~QOpenGLShaderProgramWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLShaderProgram_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLShaderProgram >()))
        return -1;

    QOpenGLShaderProgramWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QOpenGLShaderProgram", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::QOpenGLShaderProgram(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QOpenGLShaderProgram(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QOpenGLShaderProgram(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QOpenGLShaderProgram(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QOpenGLShaderProgramWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QOpenGLShaderProgramWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QOpenGLShaderProgram >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_addCacheableShaderFromSourceCode(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.addCacheableShaderFromSourceCode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addCacheableShaderFromSourceCode", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QByteArray)->bool
    // 1: QOpenGLShaderProgram::addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QString)->bool
    // 2: QOpenGLShaderProgram::addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,const char*)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QFlags_QOpenGLShader_ShaderTypeBit_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 2; // addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,const char*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 0; // addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const QByteArray &source)
        {
            ::QFlags<QOpenGLShader::ShaderTypeBit> cppArg0 = QFlags<QOpenGLShader::ShaderTypeBit>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QByteArray)
                bool cppResult = cppSelf->addCacheableShaderFromSourceCode(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const QString &source)
        {
            ::QFlags<QOpenGLShader::ShaderTypeBit> cppArg0 = QFlags<QOpenGLShader::ShaderTypeBit>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QString)
                bool cppResult = cppSelf->addCacheableShaderFromSourceCode(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const char *source)
        {
            ::QFlags<QOpenGLShader::ShaderTypeBit> cppArg0 = QFlags<QOpenGLShader::ShaderTypeBit>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,const char*)
                bool cppResult = cppSelf->addCacheableShaderFromSourceCode(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_addCacheableShaderFromSourceFile(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.addCacheableShaderFromSourceFile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addCacheableShaderFromSourceFile", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::addCacheableShaderFromSourceFile(QFlags<QOpenGLShader::ShaderTypeBit>,QString)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QFlags_QOpenGLShader_ShaderTypeBit_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // addCacheableShaderFromSourceFile(QFlags<QOpenGLShader::ShaderTypeBit>,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QOpenGLShader::ShaderTypeBit> cppArg0 = QFlags<QOpenGLShader::ShaderTypeBit>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addCacheableShaderFromSourceFile(QFlags<QOpenGLShader::ShaderTypeBit>,QString)
            bool cppResult = cppSelf->addCacheableShaderFromSourceFile(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_addShader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.addShader";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::addShader(QOpenGLShader*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShader_IDX]), (pyArg)))) {
        overloadId = 0; // addShader(QOpenGLShader*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QOpenGLShader *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addShader(QOpenGLShader*)
            bool cppResult = cppSelf->addShader(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_addShaderFromSourceCode(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.addShaderFromSourceCode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addShaderFromSourceCode", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QByteArray)->bool
    // 1: QOpenGLShaderProgram::addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QString)->bool
    // 2: QOpenGLShaderProgram::addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,const char*)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QFlags_QOpenGLShader_ShaderTypeBit_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 2; // addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,const char*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 0; // addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const QByteArray &source)
        {
            ::QFlags<QOpenGLShader::ShaderTypeBit> cppArg0 = QFlags<QOpenGLShader::ShaderTypeBit>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QByteArray)
                bool cppResult = cppSelf->addShaderFromSourceCode(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const QString &source)
        {
            ::QFlags<QOpenGLShader::ShaderTypeBit> cppArg0 = QFlags<QOpenGLShader::ShaderTypeBit>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,QString)
                bool cppResult = cppSelf->addShaderFromSourceCode(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const char *source)
        {
            ::QFlags<QOpenGLShader::ShaderTypeBit> cppArg0 = QFlags<QOpenGLShader::ShaderTypeBit>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit>,const char*)
                bool cppResult = cppSelf->addShaderFromSourceCode(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_addShaderFromSourceFile(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.addShaderFromSourceFile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addShaderFromSourceFile", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::addShaderFromSourceFile(QFlags<QOpenGLShader::ShaderTypeBit>,QString)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QFlags_QOpenGLShader_ShaderTypeBit_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // addShaderFromSourceFile(QFlags<QOpenGLShader::ShaderTypeBit>,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QOpenGLShader::ShaderTypeBit> cppArg0 = QFlags<QOpenGLShader::ShaderTypeBit>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addShaderFromSourceFile(QFlags<QOpenGLShader::ShaderTypeBit>,QString)
            bool cppResult = cppSelf->addShaderFromSourceFile(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_attributeLocation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.attributeLocation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::attributeLocation(QByteArray)const->int
    // 1: QOpenGLShaderProgram::attributeLocation(QString)const->int
    // 2: QOpenGLShaderProgram::attributeLocation(const char*)const->int
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 2; // attributeLocation(const char*)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // attributeLocation(QString)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // attributeLocation(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // attributeLocation(const QByteArray &name) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // attributeLocation(QByteArray)const
                int cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->attributeLocation(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 1: // attributeLocation(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // attributeLocation(QString)const
                int cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->attributeLocation(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 2: // attributeLocation(const char *name) const
        {
            const char* cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // attributeLocation(const char*)const
                int cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->attributeLocation(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_bind(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.bind";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // bind()
            bool cppResult = cppSelf->bind();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_bindAttributeLocation(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.bindAttributeLocation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "bindAttributeLocation", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::bindAttributeLocation(QByteArray,int)
    // 1: QOpenGLShaderProgram::bindAttributeLocation(QString,int)
    // 2: QOpenGLShaderProgram::bindAttributeLocation(const char*,int)
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 2; // bindAttributeLocation(const char*,int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // bindAttributeLocation(QString,int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // bindAttributeLocation(QByteArray,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // bindAttributeLocation(const QByteArray &name, int location)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bindAttributeLocation(QByteArray,int)
                cppSelf->bindAttributeLocation(*cppArg0, cppArg1);
            }
            break;
        }
        case 1: // bindAttributeLocation(const QString &name, int location)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bindAttributeLocation(QString,int)
                cppSelf->bindAttributeLocation(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // bindAttributeLocation(const char *name, int location)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bindAttributeLocation(const char*,int)
                cppSelf->bindAttributeLocation(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // create()
            bool cppResult = cppSelf->create();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_defaultInnerTessellationLevels(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.defaultInnerTessellationLevels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultInnerTessellationLevels()const
            QList<float> cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->defaultInnerTessellationLevels();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_QList_float_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_defaultOuterTessellationLevels(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.defaultOuterTessellationLevels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultOuterTessellationLevels()const
            QList<float> cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->defaultOuterTessellationLevels();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_QList_float_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_disableAttributeArray(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.disableAttributeArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::disableAttributeArray(const char*)
    // 1: QOpenGLShaderProgram::disableAttributeArray(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 1; // disableAttributeArray(int)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // disableAttributeArray(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // disableAttributeArray(const char *name)
        {
            const char* cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // disableAttributeArray(const char*)
                cppSelf->disableAttributeArray(cppArg0);
            }
            break;
        }
        case 1: // disableAttributeArray(int location)
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // disableAttributeArray(int)
                cppSelf->disableAttributeArray(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_enableAttributeArray(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.enableAttributeArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::enableAttributeArray(const char*)
    // 1: QOpenGLShaderProgram::enableAttributeArray(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 1; // enableAttributeArray(int)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // enableAttributeArray(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // enableAttributeArray(const char *name)
        {
            const char* cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // enableAttributeArray(const char*)
                cppSelf->enableAttributeArray(cppArg0);
            }
            break;
        }
        case 1: // enableAttributeArray(int location)
        {
            int cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // enableAttributeArray(int)
                cppSelf->enableAttributeArray(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_hasOpenGLShaderPrograms(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.hasOpenGLShaderPrograms";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:hasOpenGLShaderPrograms", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOpenGLShaderProgram::hasOpenGLShaderPrograms(QOpenGLContext*=)->bool
    if (numArgs == 0) {
        overloadId = 0; // hasOpenGLShaderPrograms(QOpenGLContext*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), (pyArgs[0])))) {
        overloadId = 0; // hasOpenGLShaderPrograms(QOpenGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_context = Shiboken::String::createStaticString("context");
            if (PyDict_Contains(kwds, key_context) != 0) {
                value = PyDict_GetItem(kwds, key_context);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_context);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_context);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QOpenGLContext *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasOpenGLShaderPrograms(QOpenGLContext*)
            bool cppResult = ::QOpenGLShaderProgram::hasOpenGLShaderPrograms(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_isLinked(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.isLinked";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isLinked()const
            bool cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->isLinked();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_link(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.link";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // link()
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QOpenGLShaderProgram::link()
                : cppSelf->link();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_log(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.log";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // log()const
            QString cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->log();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_maxGeometryOutputVertices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.maxGeometryOutputVertices";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maxGeometryOutputVertices()const
            int cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->maxGeometryOutputVertices();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_patchVertexCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.patchVertexCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // patchVertexCount()const
            int cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->patchVertexCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_programId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.programId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // programId()const
            unsigned int cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->programId();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_release(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.release";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // release()
            cppSelf->release();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_removeAllShaders(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.removeAllShaders";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAllShaders()
            cppSelf->removeAllShaders();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_removeShader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.removeShader";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::removeShader(QOpenGLShader*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShader_IDX]), (pyArg)))) {
        overloadId = 0; // removeShader(QOpenGLShader*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QOpenGLShader *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeShader(QOpenGLShader*)
            cppSelf->removeShader(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_setAttributeArray(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:setAttributeArray", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::setAttributeArray(const char*,const float*,int,int=)
    // 1: QOpenGLShaderProgram::setAttributeArray(const char*,uint,const void*,int,int=)
    // 2: QOpenGLShaderProgram::setAttributeArray(int,const float*,int,int=)
    // 3: QOpenGLShaderProgram::setAttributeArray(int,uint,const void*,int,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 3; // setAttributeArray(int,uint,const void*,int,int)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                overloadId = 3; // setAttributeArray(int,uint,const void*,int,int)
            }
        } else if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // setAttributeArray(int,const float*,int,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 2; // setAttributeArray(int,const float*,int,int)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 1; // setAttributeArray(const char*,uint,const void*,int,int)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                overloadId = 1; // setAttributeArray(const char*,uint,const void*,int,int)
            }
        } else if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // setAttributeArray(const char*,const float*,int,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 0; // setAttributeArray(const char*,const float*,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setAttributeArray(const char *name, const float *values, int tupleSize, int stride)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stride = Shiboken::String::createStaticString("stride");
                if (PyDict_Contains(kwds, key_stride) != 0) {
                    value = PyDict_GetItem(kwds, key_stride);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_stride);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_stride);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::ArrayHandle<float> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 0;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeArray(const char*,const float*,int,int)
                cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // setAttributeArray(const char *name, unsigned int type, const void *values, int tupleSize, int stride)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stride = Shiboken::String::createStaticString("stride");
                if (PyDict_Contains(kwds, key_stride) != 0) {
                    value = PyDict_GetItem(kwds, key_stride);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_stride);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_stride);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            unsigned int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            void* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = 0;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeArray(const char*,uint,const void*,int,int)
                cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 2: // setAttributeArray(int location, const float *values, int tupleSize, int stride)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stride = Shiboken::String::createStaticString("stride");
                if (PyDict_Contains(kwds, key_stride) != 0) {
                    value = PyDict_GetItem(kwds, key_stride);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_stride);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_stride);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::ArrayHandle<float> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 0;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeArray(int,const float*,int,int)
                cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 3: // setAttributeArray(int location, unsigned int type, const void *values, int tupleSize, int stride)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stride = Shiboken::String::createStaticString("stride");
                if (PyDict_Contains(kwds, key_stride) != 0) {
                    value = PyDict_GetItem(kwds, key_stride);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_stride);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_stride);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            unsigned int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            void* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = 0;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeArray(int,uint,const void*,int,int)
                cppSelf->setAttributeArray(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_setAttributeBuffer(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeBuffer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:setAttributeBuffer", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::setAttributeBuffer(const char*,uint,int,int,int=)
    // 1: QOpenGLShaderProgram::setAttributeBuffer(int,uint,int,int,int=)
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 1; // setAttributeBuffer(int,uint,int,int,int)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
            overloadId = 1; // setAttributeBuffer(int,uint,int,int,int)
        }
    } else if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // setAttributeBuffer(const char*,uint,int,int,int)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
            overloadId = 0; // setAttributeBuffer(const char*,uint,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setAttributeBuffer(const char *name, unsigned int type, int offset, int tupleSize, int stride)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stride = Shiboken::String::createStaticString("stride");
                if (PyDict_Contains(kwds, key_stride) != 0) {
                    value = PyDict_GetItem(kwds, key_stride);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_stride);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_stride);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            unsigned int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = 0;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeBuffer(const char*,uint,int,int,int)
                cppSelf->setAttributeBuffer(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 1: // setAttributeBuffer(int location, unsigned int type, int offset, int tupleSize, int stride)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stride = Shiboken::String::createStaticString("stride");
                if (PyDict_Contains(kwds, key_stride) != 0) {
                    value = PyDict_GetItem(kwds, key_stride);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_stride);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_stride);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            unsigned int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = 0;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeBuffer(int,uint,int,int,int)
                cppSelf->setAttributeBuffer(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_setAttributeValue(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setAttributeValue", 2, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::setAttributeValue(const char*,QColor)
    // 1: QOpenGLShaderProgram::setAttributeValue(const char*,QVector2D)
    // 2: QOpenGLShaderProgram::setAttributeValue(const char*,QVector3D)
    // 3: QOpenGLShaderProgram::setAttributeValue(const char*,QVector4D)
    // 4: QOpenGLShaderProgram::setAttributeValue(const char*,const float*,int,int)
    // 5: QOpenGLShaderProgram::setAttributeValue(const char*,float)
    // 6: QOpenGLShaderProgram::setAttributeValue(const char*,float,float)
    // 7: QOpenGLShaderProgram::setAttributeValue(const char*,float,float,float)
    // 8: QOpenGLShaderProgram::setAttributeValue(const char*,float,float,float,float)
    // 9: QOpenGLShaderProgram::setAttributeValue(int,QColor)
    // 10: QOpenGLShaderProgram::setAttributeValue(int,QVector2D)
    // 11: QOpenGLShaderProgram::setAttributeValue(int,QVector3D)
    // 12: QOpenGLShaderProgram::setAttributeValue(int,QVector4D)
    // 13: QOpenGLShaderProgram::setAttributeValue(int,const float*,int,int)
    // 14: QOpenGLShaderProgram::setAttributeValue(int,float)
    // 15: QOpenGLShaderProgram::setAttributeValue(int,float,float)
    // 16: QOpenGLShaderProgram::setAttributeValue(int,float,float,float)
    // 17: QOpenGLShaderProgram::setAttributeValue(int,float,float,float,float)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 14; // setAttributeValue(int,float)
            } else if (numArgs >= 3
                && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 15; // setAttributeValue(int,float,float)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 16; // setAttributeValue(int,float,float,float)
                    } else if (numArgs == 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))) {
                        overloadId = 17; // setAttributeValue(int,float,float,float,float)
                    }
                }
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 13; // setAttributeValue(int,const float*,int,int)
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[1])))) {
            overloadId = 12; // setAttributeValue(int,QVector4D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
            overloadId = 11; // setAttributeValue(int,QVector3D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArgs[1])))) {
            overloadId = 10; // setAttributeValue(int,QVector2D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[1])))) {
            overloadId = 9; // setAttributeValue(int,QColor)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // setAttributeValue(const char*,float)
            } else if (numArgs >= 3
                && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 6; // setAttributeValue(const char*,float,float)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 7; // setAttributeValue(const char*,float,float,float)
                    } else if (numArgs == 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))) {
                        overloadId = 8; // setAttributeValue(const char*,float,float,float,float)
                    }
                }
            } else if (numArgs == 4
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 4; // setAttributeValue(const char*,const float*,int,int)
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[1])))) {
            overloadId = 3; // setAttributeValue(const char*,QVector4D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
            overloadId = 2; // setAttributeValue(const char*,QVector3D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArgs[1])))) {
            overloadId = 1; // setAttributeValue(const char*,QVector2D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[1])))) {
            overloadId = 0; // setAttributeValue(const char*,QColor)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setAttributeValue(const char *name, const QColor &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QColor cppArg1_local;
            ::QColor *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(const char*,QColor)
                cppSelf->setAttributeValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // setAttributeValue(const char *name, const QVector2D &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector2D cppArg1_local;
            ::QVector2D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(const char*,QVector2D)
                cppSelf->setAttributeValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // setAttributeValue(const char *name, const QVector3D &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector3D cppArg1_local;
            ::QVector3D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(const char*,QVector3D)
                cppSelf->setAttributeValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // setAttributeValue(const char *name, const QVector4D &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector4D cppArg1_local;
            ::QVector4D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(const char*,QVector4D)
                cppSelf->setAttributeValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 4: // setAttributeValue(const char *name, const float *values, int columns, int rows)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::ArrayHandle<float> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(const char*,const float*,int,int)
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 5: // setAttributeValue(const char *name, float value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(const char*,float)
                cppSelf->setAttributeValue(cppArg0, cppArg1);
            }
            break;
        }
        case 6: // setAttributeValue(const char *name, float x, float y)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(const char*,float,float)
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 7: // setAttributeValue(const char *name, float x, float y, float z)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(const char*,float,float,float)
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 8: // setAttributeValue(const char *name, float x, float y, float z, float w)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            float cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(const char*,float,float,float,float)
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 9: // setAttributeValue(int location, const QColor &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QColor cppArg1_local;
            ::QColor *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(int,QColor)
                cppSelf->setAttributeValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 10: // setAttributeValue(int location, const QVector2D &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector2D cppArg1_local;
            ::QVector2D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(int,QVector2D)
                cppSelf->setAttributeValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 11: // setAttributeValue(int location, const QVector3D &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector3D cppArg1_local;
            ::QVector3D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(int,QVector3D)
                cppSelf->setAttributeValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 12: // setAttributeValue(int location, const QVector4D &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector4D cppArg1_local;
            ::QVector4D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(int,QVector4D)
                cppSelf->setAttributeValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 13: // setAttributeValue(int location, const float *values, int columns, int rows)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::ArrayHandle<float> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(int,const float*,int,int)
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 14: // setAttributeValue(int location, float value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(int,float)
                cppSelf->setAttributeValue(cppArg0, cppArg1);
            }
            break;
        }
        case 15: // setAttributeValue(int location, float x, float y)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(int,float,float)
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 16: // setAttributeValue(int location, float x, float y, float z)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(int,float,float,float)
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 17: // setAttributeValue(int location, float x, float y, float z, float w)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            float cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setAttributeValue(int,float,float,float,float)
                cppSelf->setAttributeValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_setDefaultInnerTessellationLevels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.setDefaultInnerTessellationLevels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::setDefaultInnerTessellationLevels(QList<float>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_QList_float_IDX], (pyArg)))) {
        overloadId = 0; // setDefaultInnerTessellationLevels(QList<float>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultInnerTessellationLevels(QList<float>)
            cppSelf->setDefaultInnerTessellationLevels(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_setDefaultOuterTessellationLevels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.setDefaultOuterTessellationLevels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::setDefaultOuterTessellationLevels(QList<float>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_QList_float_IDX], (pyArg)))) {
        overloadId = 0; // setDefaultOuterTessellationLevels(QList<float>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultOuterTessellationLevels(QList<float>)
            cppSelf->setDefaultOuterTessellationLevels(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_setPatchVertexCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.setPatchVertexCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::setPatchVertexCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPatchVertexCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPatchVertexCount(int)
            cppSelf->setPatchVertexCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_setUniformValue(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setUniformValue", 2, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::setUniformValue(const char*,QColor)
    // 1: QOpenGLShaderProgram::setUniformValue(const char*,QMatrix2x2)
    // 2: QOpenGLShaderProgram::setUniformValue(const char*,QMatrix2x3)
    // 3: QOpenGLShaderProgram::setUniformValue(const char*,QMatrix2x4)
    // 4: QOpenGLShaderProgram::setUniformValue(const char*,QMatrix3x2)
    // 5: QOpenGLShaderProgram::setUniformValue(const char*,QMatrix3x3)
    // 6: QOpenGLShaderProgram::setUniformValue(const char*,QMatrix3x4)
    // 7: QOpenGLShaderProgram::setUniformValue(const char*,QMatrix4x2)
    // 8: QOpenGLShaderProgram::setUniformValue(const char*,QMatrix4x3)
    // 9: QOpenGLShaderProgram::setUniformValue(const char*,QMatrix4x4)
    // 10: QOpenGLShaderProgram::setUniformValue(const char*,QPoint)
    // 11: QOpenGLShaderProgram::setUniformValue(const char*,QPointF)
    // 12: QOpenGLShaderProgram::setUniformValue(const char*,QSize)
    // 13: QOpenGLShaderProgram::setUniformValue(const char*,QSizeF)
    // 14: QOpenGLShaderProgram::setUniformValue(const char*,QTransform)
    // 15: QOpenGLShaderProgram::setUniformValue(const char*,QVector2D)
    // 16: QOpenGLShaderProgram::setUniformValue(const char*,QVector3D)
    // 17: QOpenGLShaderProgram::setUniformValue(const char*,QVector4D)
    // 18: QOpenGLShaderProgram::setUniformValue(const char*,const float[2][2])
    // 19: QOpenGLShaderProgram::setUniformValue(const char*,const float[3][3])
    // 20: QOpenGLShaderProgram::setUniformValue(const char*,const float[4][4])
    // 21: QOpenGLShaderProgram::setUniformValue(const char*,float,float)
    // 22: QOpenGLShaderProgram::setUniformValue(const char*,float,float,float)
    // 23: QOpenGLShaderProgram::setUniformValue(const char*,float,float,float,float)
    // 24: QOpenGLShaderProgram::setUniformValue(int,QColor)
    // 25: QOpenGLShaderProgram::setUniformValue(int,QMatrix2x2)
    // 26: QOpenGLShaderProgram::setUniformValue(int,QMatrix2x3)
    // 27: QOpenGLShaderProgram::setUniformValue(int,QMatrix2x4)
    // 28: QOpenGLShaderProgram::setUniformValue(int,QMatrix3x2)
    // 29: QOpenGLShaderProgram::setUniformValue(int,QMatrix3x3)
    // 30: QOpenGLShaderProgram::setUniformValue(int,QMatrix3x4)
    // 31: QOpenGLShaderProgram::setUniformValue(int,QMatrix4x2)
    // 32: QOpenGLShaderProgram::setUniformValue(int,QMatrix4x3)
    // 33: QOpenGLShaderProgram::setUniformValue(int,QMatrix4x4)
    // 34: QOpenGLShaderProgram::setUniformValue(int,QPoint)
    // 35: QOpenGLShaderProgram::setUniformValue(int,QPointF)
    // 36: QOpenGLShaderProgram::setUniformValue(int,QSize)
    // 37: QOpenGLShaderProgram::setUniformValue(int,QSizeF)
    // 38: QOpenGLShaderProgram::setUniformValue(int,QTransform)
    // 39: QOpenGLShaderProgram::setUniformValue(int,QVector2D)
    // 40: QOpenGLShaderProgram::setUniformValue(int,QVector3D)
    // 41: QOpenGLShaderProgram::setUniformValue(int,QVector4D)
    // 42: QOpenGLShaderProgram::setUniformValue(int,const float[2][2])
    // 43: QOpenGLShaderProgram::setUniformValue(int,const float[3][3])
    // 44: QOpenGLShaderProgram::setUniformValue(int,const float[4][4])
    // 45: QOpenGLShaderProgram::setUniformValue(int,float)
    // 46: QOpenGLShaderProgram::setUniformValue(int,float,float)
    // 47: QOpenGLShaderProgram::setUniformValue(int,float,float,float)
    // 48: QOpenGLShaderProgram::setUniformValue(int,float,float,float,float)
    // 49: QOpenGLShaderProgram::setUniformValue(int,int)
    // 50: QOpenGLShaderProgram::setUniformValue(int,uint)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
            overloadId = 50; // setUniformValue(int,uint)
        } else if (numArgs >= 2
            && PyFloat_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 45; // setUniformValue(int,float)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 46; // setUniformValue(int,float,float)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 47; // setUniformValue(int,float,float,float)
                    } else if (numArgs == 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))) {
                        overloadId = 48; // setUniformValue(int,float,float,float,float)
                    }
                }
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 49; // setUniformValue(int,int)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<const float>(2), 4, 4, (pyArgs[1])))) {
            overloadId = 44; // setUniformValue(int,const float[4][4])
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<const float>(2), 3, 3, (pyArgs[1])))) {
            overloadId = 43; // setUniformValue(int,const float[3][3])
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<const float>(2), 2, 2, (pyArgs[1])))) {
            overloadId = 42; // setUniformValue(int,const float[2][2])
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[1])))) {
            overloadId = 41; // setUniformValue(int,QVector4D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
            overloadId = 40; // setUniformValue(int,QVector3D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArgs[1])))) {
            overloadId = 39; // setUniformValue(int,QVector2D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[1])))) {
            overloadId = 38; // setUniformValue(int,QTransform)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
            overloadId = 36; // setUniformValue(int,QSize)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[1])))) {
            overloadId = 37; // setUniformValue(int,QSizeF)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[1])))) {
            overloadId = 34; // setUniformValue(int,QPoint)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
            overloadId = 35; // setUniformValue(int,QPointF)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArgs[1])))) {
            overloadId = 33; // setUniformValue(int,QMatrix4x4)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x3_IDX]), (pyArgs[1])))) {
            overloadId = 32; // setUniformValue(int,QMatrix4x3)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x2_IDX]), (pyArgs[1])))) {
            overloadId = 31; // setUniformValue(int,QMatrix4x2)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x4_IDX]), (pyArgs[1])))) {
            overloadId = 30; // setUniformValue(int,QMatrix3x4)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x3_IDX]), (pyArgs[1])))) {
            overloadId = 29; // setUniformValue(int,QMatrix3x3)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), (pyArgs[1])))) {
            overloadId = 28; // setUniformValue(int,QMatrix3x2)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x4_IDX]), (pyArgs[1])))) {
            overloadId = 27; // setUniformValue(int,QMatrix2x4)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), (pyArgs[1])))) {
            overloadId = 26; // setUniformValue(int,QMatrix2x3)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x2_IDX]), (pyArgs[1])))) {
            overloadId = 25; // setUniformValue(int,QMatrix2x2)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[1])))) {
            overloadId = 24; // setUniformValue(int,QColor)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 21; // setUniformValue(const char*,float,float)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 22; // setUniformValue(const char*,float,float,float)
                } else if (numArgs == 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))) {
                    overloadId = 23; // setUniformValue(const char*,float,float,float,float)
                }
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<const float>(2), 4, 4, (pyArgs[1])))) {
            overloadId = 20; // setUniformValue(const char*,const float[4][4])
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<const float>(2), 3, 3, (pyArgs[1])))) {
            overloadId = 19; // setUniformValue(const char*,const float[3][3])
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<const float>(2), 2, 2, (pyArgs[1])))) {
            overloadId = 18; // setUniformValue(const char*,const float[2][2])
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector4D_IDX]), (pyArgs[1])))) {
            overloadId = 17; // setUniformValue(const char*,QVector4D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArgs[1])))) {
            overloadId = 16; // setUniformValue(const char*,QVector3D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector2D_IDX]), (pyArgs[1])))) {
            overloadId = 15; // setUniformValue(const char*,QVector2D)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[1])))) {
            overloadId = 14; // setUniformValue(const char*,QTransform)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
            overloadId = 12; // setUniformValue(const char*,QSize)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[1])))) {
            overloadId = 13; // setUniformValue(const char*,QSizeF)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[1])))) {
            overloadId = 10; // setUniformValue(const char*,QPoint)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
            overloadId = 11; // setUniformValue(const char*,QPointF)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArgs[1])))) {
            overloadId = 9; // setUniformValue(const char*,QMatrix4x4)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x3_IDX]), (pyArgs[1])))) {
            overloadId = 8; // setUniformValue(const char*,QMatrix4x3)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x2_IDX]), (pyArgs[1])))) {
            overloadId = 7; // setUniformValue(const char*,QMatrix4x2)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x4_IDX]), (pyArgs[1])))) {
            overloadId = 6; // setUniformValue(const char*,QMatrix3x4)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x3_IDX]), (pyArgs[1])))) {
            overloadId = 5; // setUniformValue(const char*,QMatrix3x3)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x2_IDX]), (pyArgs[1])))) {
            overloadId = 4; // setUniformValue(const char*,QMatrix3x2)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x4_IDX]), (pyArgs[1])))) {
            overloadId = 3; // setUniformValue(const char*,QMatrix2x4)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x3_IDX]), (pyArgs[1])))) {
            overloadId = 2; // setUniformValue(const char*,QMatrix2x3)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix2x2_IDX]), (pyArgs[1])))) {
            overloadId = 1; // setUniformValue(const char*,QMatrix2x2)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[1])))) {
            overloadId = 0; // setUniformValue(const char*,QColor)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValue(const char *name, const QColor &color)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QColor cppArg1_local;
            ::QColor *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QColor)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // setUniformValue(const char *name, const QMatrix2x2 &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix2x2 cppArg1_local;
            ::QMatrix2x2 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QMatrix2x2)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // setUniformValue(const char *name, const QMatrix2x3 &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix2x3 cppArg1_local;
            ::QMatrix2x3 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QMatrix2x3)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // setUniformValue(const char *name, const QMatrix2x4 &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix2x4 cppArg1_local;
            ::QMatrix2x4 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QMatrix2x4)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 4: // setUniformValue(const char *name, const QMatrix3x2 &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix3x2 cppArg1_local;
            ::QMatrix3x2 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QMatrix3x2)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 5: // setUniformValue(const char *name, const QMatrix3x3 &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix3x3 cppArg1_local;
            ::QMatrix3x3 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QMatrix3x3)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 6: // setUniformValue(const char *name, const QMatrix3x4 &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix3x4 cppArg1_local;
            ::QMatrix3x4 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QMatrix3x4)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 7: // setUniformValue(const char *name, const QMatrix4x2 &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x2 cppArg1_local;
            ::QMatrix4x2 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QMatrix4x2)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 8: // setUniformValue(const char *name, const QMatrix4x3 &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x3 cppArg1_local;
            ::QMatrix4x3 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QMatrix4x3)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 9: // setUniformValue(const char *name, const QMatrix4x4 &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x4 cppArg1_local;
            ::QMatrix4x4 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QMatrix4x4)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 10: // setUniformValue(const char *name, const QPoint &point)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPoint cppArg1_local;
            ::QPoint *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QPoint)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 11: // setUniformValue(const char *name, const QPointF &point)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QPointF)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 12: // setUniformValue(const char *name, const QSize &size)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QSize cppArg1_local;
            ::QSize *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QSize)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 13: // setUniformValue(const char *name, const QSizeF &size)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QSizeF cppArg1_local;
            ::QSizeF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QSizeF)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 14: // setUniformValue(const char *name, const QTransform &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTransform cppArg1_local;
            ::QTransform *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QTransform)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 15: // setUniformValue(const char *name, const QVector2D &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector2D cppArg1_local;
            ::QVector2D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QVector2D)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 16: // setUniformValue(const char *name, const QVector3D &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector3D cppArg1_local;
            ::QVector3D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QVector3D)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 17: // setUniformValue(const char *name, const QVector4D &value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector4D cppArg1_local;
            ::QVector4D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,QVector4D)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 18: // setUniformValue(const char *name, const float[2][2] value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::Array2Handle<const float, 2> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,const float[2][2])
                cppSelf->setUniformValue(cppArg0, cppArg1);
            }
            break;
        }
        case 19: // setUniformValue(const char *name, const float[3][3] value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::Array2Handle<const float, 3> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,const float[3][3])
                cppSelf->setUniformValue(cppArg0, cppArg1);
            }
            break;
        }
        case 20: // setUniformValue(const char *name, const float[4][4] value)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::Array2Handle<const float, 4> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,const float[4][4])
                cppSelf->setUniformValue(cppArg0, cppArg1);
            }
            break;
        }
        case 21: // setUniformValue(const char *name, float x, float y)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,float,float)
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 22: // setUniformValue(const char *name, float x, float y, float z)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,float,float,float)
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 23: // setUniformValue(const char *name, float x, float y, float z, float w)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            float cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(const char*,float,float,float,float)
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 24: // setUniformValue(int location, const QColor &color)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QColor cppArg1_local;
            ::QColor *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QColor)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 25: // setUniformValue(int location, const QMatrix2x2 &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix2x2 cppArg1_local;
            ::QMatrix2x2 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QMatrix2x2)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 26: // setUniformValue(int location, const QMatrix2x3 &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix2x3 cppArg1_local;
            ::QMatrix2x3 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QMatrix2x3)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 27: // setUniformValue(int location, const QMatrix2x4 &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix2x4 cppArg1_local;
            ::QMatrix2x4 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QMatrix2x4)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 28: // setUniformValue(int location, const QMatrix3x2 &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix3x2 cppArg1_local;
            ::QMatrix3x2 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QMatrix3x2)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 29: // setUniformValue(int location, const QMatrix3x3 &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix3x3 cppArg1_local;
            ::QMatrix3x3 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QMatrix3x3)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 30: // setUniformValue(int location, const QMatrix3x4 &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix3x4 cppArg1_local;
            ::QMatrix3x4 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QMatrix3x4)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 31: // setUniformValue(int location, const QMatrix4x2 &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x2 cppArg1_local;
            ::QMatrix4x2 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QMatrix4x2)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 32: // setUniformValue(int location, const QMatrix4x3 &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x3 cppArg1_local;
            ::QMatrix4x3 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QMatrix4x3)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 33: // setUniformValue(int location, const QMatrix4x4 &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x4 cppArg1_local;
            ::QMatrix4x4 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QMatrix4x4)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 34: // setUniformValue(int location, const QPoint &point)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPoint cppArg1_local;
            ::QPoint *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QPoint)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 35: // setUniformValue(int location, const QPointF &point)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QPointF)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 36: // setUniformValue(int location, const QSize &size)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QSize cppArg1_local;
            ::QSize *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QSize)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 37: // setUniformValue(int location, const QSizeF &size)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QSizeF cppArg1_local;
            ::QSizeF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QSizeF)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 38: // setUniformValue(int location, const QTransform &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTransform cppArg1_local;
            ::QTransform *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QTransform)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 39: // setUniformValue(int location, const QVector2D &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector2D cppArg1_local;
            ::QVector2D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QVector2D)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 40: // setUniformValue(int location, const QVector3D &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector3D cppArg1_local;
            ::QVector3D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QVector3D)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 41: // setUniformValue(int location, const QVector4D &value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QVector4D cppArg1_local;
            ::QVector4D *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,QVector4D)
                cppSelf->setUniformValue(cppArg0, *cppArg1);
            }
            break;
        }
        case 42: // setUniformValue(int location, const float[2][2] value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::Array2Handle<const float, 2> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,const float[2][2])
                cppSelf->setUniformValue(cppArg0, cppArg1);
            }
            break;
        }
        case 43: // setUniformValue(int location, const float[3][3] value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::Array2Handle<const float, 3> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,const float[3][3])
                cppSelf->setUniformValue(cppArg0, cppArg1);
            }
            break;
        }
        case 44: // setUniformValue(int location, const float[4][4] value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::Array2Handle<const float, 4> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,const float[4][4])
                cppSelf->setUniformValue(cppArg0, cppArg1);
            }
            break;
        }
        case 45: // setUniformValue(int location, float value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,float)
                cppSelf->setUniformValue(cppArg0, cppArg1);
            }
            break;
        }
        case 46: // setUniformValue(int location, float x, float y)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,float,float)
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 47: // setUniformValue(int location, float x, float y, float z)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,float,float,float)
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 48: // setUniformValue(int location, float x, float y, float z, float w)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            float cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,float,float,float,float)
                cppSelf->setUniformValue(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 49: // setUniformValue(int location, int value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,int)
                cppSelf->setUniformValue(cppArg0, cppArg1);
            }
            break;
        }
        case 50: // setUniformValue(int location, unsigned int value)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            unsigned int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue(int,uint)
                cppSelf->setUniformValue(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_setUniformValue1f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue1f";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setUniformValue1f", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::setUniformValue1f(const char*,float)
    // 1: QOpenGLShaderProgram::setUniformValue1f(int,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 1; // setUniformValue1f(int,float)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // setUniformValue1f(const char*,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValue1f(const char *arg__1, float arg__2)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue1f(const char*,float)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtopengl.cpp (qopenglshaderprogram_setuniformvalue_float)]
                float value = cppArg1;
                cppSelf->setUniformValue(cppArg0, value);
                // END of custom code block [file: ../glue/qtopengl.cpp (qopenglshaderprogram_setuniformvalue_float)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // setUniformValue1f(int arg__1, float arg__2)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue1f(int,float)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtopengl.cpp (qopenglshaderprogram_setuniformvalue_float)]
                float value = cppArg1;
                cppSelf->setUniformValue(cppArg0, value);
                // END of custom code block [file: ../glue/qtopengl.cpp (qopenglshaderprogram_setuniformvalue_float)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_setUniformValue1i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue1i";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setUniformValue1i", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::setUniformValue1i(const char*,int)
    // 1: QOpenGLShaderProgram::setUniformValue1i(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 1; // setUniformValue1i(int,int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setUniformValue1i(const char*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValue1i(const char *arg__1, int arg__2)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue1i(const char*,int)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtopengl.cpp (qopenglshaderprogram_setuniformvalue_int)]
                int value = cppArg1;
                cppSelf->setUniformValue(cppArg0, value);
                // END of custom code block [file: ../glue/qtopengl.cpp (qopenglshaderprogram_setuniformvalue_int)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // setUniformValue1i(int arg__1, int arg__2)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValue1i(int,int)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtopengl.cpp (qopenglshaderprogram_setuniformvalue_int)]
                int value = cppArg1;
                cppSelf->setUniformValue(cppArg0, value);
                // END of custom code block [file: ../glue/qtopengl.cpp (qopenglshaderprogram_setuniformvalue_int)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_setUniformValueArray(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValueArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setUniformValueArray", 3, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::setUniformValueArray(const char*,const float*,int,int)
    // 1: QOpenGLShaderProgram::setUniformValueArray(const char*,const int*,int)
    // 2: QOpenGLShaderProgram::setUniformValueArray(const char*,const uint*,int)
    // 3: QOpenGLShaderProgram::setUniformValueArray(int,const float*,int,int)
    // 4: QOpenGLShaderProgram::setUniformValueArray(int,const int*,int)
    // 5: QOpenGLShaderProgram::setUniformValueArray(int,const uint*,int)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned int>(1), -1, -1, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 5; // setUniformValueArray(int,const uint*,int)
        } else if (numArgs == 4
            && PyFloat_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 3; // setUniformValueArray(int,const float*,int,int)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 4; // setUniformValueArray(int,const int*,int)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned int>(1), -1, -1, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 2; // setUniformValueArray(const char*,const uint*,int)
        } else if (numArgs == 4
            && PyFloat_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 0; // setUniformValueArray(const char*,const float*,int,int)
        } else if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 1; // setUniformValueArray(const char*,const int*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setUniformValueArray(const char *name, const float *values, int count, int tupleSize)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::ArrayHandle<float> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValueArray(const char*,const float*,int,int)
                cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // setUniformValueArray(const char *name, const int *values, int count)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::ArrayHandle<int> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValueArray(const char*,const int*,int)
                cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // setUniformValueArray(const char *name, const unsigned int *values, int count)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::ArrayHandle<unsigned int> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValueArray(const char*,const uint*,int)
                cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 3: // setUniformValueArray(int location, const float *values, int count, int tupleSize)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::ArrayHandle<float> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValueArray(int,const float*,int,int)
                cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 4: // setUniformValueArray(int location, const int *values, int count)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::ArrayHandle<int> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValueArray(int,const int*,int)
                cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 5: // setUniformValueArray(int location, const unsigned int *values, int count)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            Shiboken::Conversions::ArrayHandle<unsigned int> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setUniformValueArray(int,const uint*,int)
                cppSelf->setUniformValueArray(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_shaders(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.shaders";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // shaders()const
            QList<QOpenGLShader*> cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->shaders();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_QList_QOpenGLShaderPTR_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLShaderProgramFunc_uniformLocation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLShaderProgram.uniformLocation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLShaderProgram::uniformLocation(QByteArray)const->int
    // 1: QOpenGLShaderProgram::uniformLocation(QString)const->int
    // 2: QOpenGLShaderProgram::uniformLocation(const char*)const->int
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 2; // uniformLocation(const char*)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // uniformLocation(QString)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // uniformLocation(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // uniformLocation(const QByteArray &name) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // uniformLocation(QByteArray)const
                int cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->uniformLocation(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 1: // uniformLocation(const QString &name) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // uniformLocation(QString)const
                int cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->uniformLocation(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 2: // uniformLocation(const char *name) const
        {
            const char* cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // uniformLocation(const char*)const
                int cppResult = const_cast<const ::QOpenGLShaderProgram *>(cppSelf)->uniformLocation(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLShaderProgram_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLShaderProgram_methods[] = {
    {"addCacheableShaderFromSourceCode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_addCacheableShaderFromSourceCode), METH_VARARGS, nullptr},
    {"addCacheableShaderFromSourceFile", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_addCacheableShaderFromSourceFile), METH_VARARGS, nullptr},
    {"addShader", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_addShader), METH_O, nullptr},
    {"addShaderFromSourceCode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_addShaderFromSourceCode), METH_VARARGS, nullptr},
    {"addShaderFromSourceFile", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_addShaderFromSourceFile), METH_VARARGS, nullptr},
    {"attributeLocation", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_attributeLocation), METH_O, nullptr},
    {"bind", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_bind), METH_NOARGS, nullptr},
    {"bindAttributeLocation", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_bindAttributeLocation), METH_VARARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_create), METH_NOARGS, nullptr},
    {"defaultInnerTessellationLevels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_defaultInnerTessellationLevels), METH_NOARGS, nullptr},
    {"defaultOuterTessellationLevels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_defaultOuterTessellationLevels), METH_NOARGS, nullptr},
    {"disableAttributeArray", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_disableAttributeArray), METH_O, nullptr},
    {"enableAttributeArray", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_enableAttributeArray), METH_O, nullptr},
    {"hasOpenGLShaderPrograms", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_hasOpenGLShaderPrograms), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"isLinked", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_isLinked), METH_NOARGS, nullptr},
    {"link", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_link), METH_NOARGS, nullptr},
    {"log", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_log), METH_NOARGS, nullptr},
    {"maxGeometryOutputVertices", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_maxGeometryOutputVertices), METH_NOARGS, nullptr},
    {"patchVertexCount", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_patchVertexCount), METH_NOARGS, nullptr},
    {"programId", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_programId), METH_NOARGS, nullptr},
    {"release", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_release), METH_NOARGS, nullptr},
    {"removeAllShaders", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_removeAllShaders), METH_NOARGS, nullptr},
    {"removeShader", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_removeShader), METH_O, nullptr},
    {"setAttributeArray", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_setAttributeArray), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setAttributeBuffer", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_setAttributeBuffer), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setAttributeValue", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_setAttributeValue), METH_VARARGS, nullptr},
    {"setDefaultInnerTessellationLevels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_setDefaultInnerTessellationLevels), METH_O, nullptr},
    {"setDefaultOuterTessellationLevels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_setDefaultOuterTessellationLevels), METH_O, nullptr},
    {"setPatchVertexCount", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_setPatchVertexCount), METH_O, nullptr},
    {"setUniformValue", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_setUniformValue), METH_VARARGS, nullptr},
    {"setUniformValue1f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_setUniformValue1f), METH_VARARGS, nullptr},
    {"setUniformValue1i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_setUniformValue1i), METH_VARARGS, nullptr},
    {"setUniformValueArray", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_setUniformValueArray), METH_VARARGS, nullptr},
    {"shaders", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_shaders), METH_NOARGS, nullptr},
    {"uniformLocation", reinterpret_cast<PyCFunction>(Sbk_QOpenGLShaderProgramFunc_uniformLocation), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QOpenGLShaderProgram_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QOpenGLShaderProgram *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QOpenGLShaderProgramWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QOpenGLShaderProgram_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLShaderProgram_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLShaderProgram_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLShaderProgram_TypeF(void)
{
    return _Sbk_QOpenGLShaderProgram_Type;
}

static PyType_Slot Sbk_QOpenGLShaderProgram_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QOpenGLShaderProgram_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLShaderProgram_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLShaderProgram_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLShaderProgram_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLShaderProgram_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLShaderProgram_spec = {
    "2:PySide6.QtOpenGL.QOpenGLShaderProgram",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLShaderProgram_slots
};

} //extern "C"

static void *Sbk_QOpenGLShaderProgram_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QOpenGLShaderProgram *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLShaderProgram_PythonToCpp_QOpenGLShaderProgram_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLShaderProgram_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLShaderProgram_PythonToCpp_QOpenGLShaderProgram_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLShaderProgram_TypeF()))
        return QOpenGLShaderProgram_PythonToCpp_QOpenGLShaderProgram_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLShaderProgram_PTR_CppToPython_QOpenGLShaderProgram(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QOpenGLShaderProgram *>(const_cast<void *>(cppIn)), Sbk_QOpenGLShaderProgram_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QOpenGLShaderProgram_SignatureStrings[] = {
    "PySide6.QtOpenGL.QOpenGLShaderProgram(self,parent:PySide6.QtCore.QObject=nullptr)",
    "2:PySide6.QtOpenGL.QOpenGLShaderProgram.addCacheableShaderFromSourceCode(self,type:PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit,source:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.addCacheableShaderFromSourceCode(self,type:PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit,source:QString)->bool",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.addCacheableShaderFromSourceCode(self,type:PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit,source:char*)->bool",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.addCacheableShaderFromSourceFile(self,type:PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit,fileName:QString)->bool",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.addShader(self,shader:PySide6.QtOpenGL.QOpenGLShader)->bool",
    "2:PySide6.QtOpenGL.QOpenGLShaderProgram.addShaderFromSourceCode(self,type:PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit,source:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.addShaderFromSourceCode(self,type:PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit,source:QString)->bool",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.addShaderFromSourceCode(self,type:PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit,source:char*)->bool",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.addShaderFromSourceFile(self,type:PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit,fileName:QString)->bool",
    "2:PySide6.QtOpenGL.QOpenGLShaderProgram.attributeLocation(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])->int",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.attributeLocation(self,name:QString)->int",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.attributeLocation(self,name:char*)->int",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.bind(self)->bool",
    "2:PySide6.QtOpenGL.QOpenGLShaderProgram.bindAttributeLocation(self,name:typing.Union[PySide6.QtCore.QByteArray, char*],location:int)",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.bindAttributeLocation(self,name:QString,location:int)",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.bindAttributeLocation(self,name:char*,location:int)",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.create(self)->bool",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.defaultInnerTessellationLevels(self)->QList[float]",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.defaultOuterTessellationLevels(self)->QList[float]",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.disableAttributeArray(self,name:char*)",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.disableAttributeArray(self,location:int)",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.enableAttributeArray(self,name:char*)",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.enableAttributeArray(self,location:int)",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.hasOpenGLShaderPrograms(context:PySide6.QtGui.QOpenGLContext=nullptr)->bool",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.isLinked(self)->bool",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.link(self)->bool",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.log(self)->QString",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.maxGeometryOutputVertices(self)->int",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.patchVertexCount(self)->int",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.programId(self)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.release(self)",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.removeAllShaders(self)",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.removeShader(self,shader:PySide6.QtOpenGL.QOpenGLShader)",
    "3:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeArray(self,name:char*,values:array float*,tupleSize:int,stride:int=0)",
    "2:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeArray(self,name:char*,type:unsigned int,values:void,tupleSize:int,stride:int=0)",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeArray(self,location:int,values:array float*,tupleSize:int,stride:int=0)",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeArray(self,location:int,type:unsigned int,values:void,tupleSize:int,stride:int=0)",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeBuffer(self,name:char*,type:unsigned int,offset:int,tupleSize:int,stride:int=0)",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeBuffer(self,location:int,type:unsigned int,offset:int,tupleSize:int,stride:int=0)",
    "17:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,name:char*,value:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "16:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,name:char*,value:PySide6.QtGui.QVector2D)",
    "15:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,name:char*,value:PySide6.QtGui.QVector3D)",
    "14:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,name:char*,value:PySide6.QtGui.QVector4D)",
    "13:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,name:char*,values:array float*,columns:int,rows:int)",
    "12:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,name:char*,value:float)",
    "11:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,name:char*,x:float,y:float)",
    "10:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,name:char*,x:float,y:float,z:float)",
    "9:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,name:char*,x:float,y:float,z:float,w:float)",
    "8:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,location:int,value:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "7:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,location:int,value:PySide6.QtGui.QVector2D)",
    "6:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,location:int,value:PySide6.QtGui.QVector3D)",
    "5:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,location:int,value:PySide6.QtGui.QVector4D)",
    "4:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,location:int,values:array float*,columns:int,rows:int)",
    "3:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,location:int,value:float)",
    "2:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,location:int,x:float,y:float)",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,location:int,x:float,y:float,z:float)",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.setAttributeValue(self,location:int,x:float,y:float,z:float,w:float)",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.setDefaultInnerTessellationLevels(self,levels:QList[float])",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.setDefaultOuterTessellationLevels(self,levels:QList[float])",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.setPatchVertexCount(self,count:int)",
    "50:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "49:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QMatrix2x2)",
    "48:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QMatrix2x3)",
    "47:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QMatrix2x4)",
    "46:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QMatrix3x2)",
    "45:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QMatrix3x3)",
    "44:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QMatrix3x4)",
    "43:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QMatrix4x2)",
    "42:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QMatrix4x3)",
    "41:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])",
    "40:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,point:PySide6.QtCore.QPoint)",
    "39:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "38:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,size:PySide6.QtCore.QSize)",
    "37:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "36:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QTransform)",
    "35:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QVector2D)",
    "34:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QVector3D)",
    "33:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:PySide6.QtGui.QVector4D)",
    "32:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:float[2][2])",
    "31:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:float[3][3])",
    "30:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,value:float[4][4])",
    "29:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,x:float,y:float)",
    "28:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,x:float,y:float,z:float)",
    "27:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,name:char*,x:float,y:float,z:float,w:float)",
    "26:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "25:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QMatrix2x2)",
    "24:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QMatrix2x3)",
    "23:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QMatrix2x4)",
    "22:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QMatrix3x2)",
    "21:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QMatrix3x3)",
    "20:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QMatrix3x4)",
    "19:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QMatrix4x2)",
    "18:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QMatrix4x3)",
    "17:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform])",
    "16:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,point:PySide6.QtCore.QPoint)",
    "15:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "14:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,size:PySide6.QtCore.QSize)",
    "13:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "12:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QTransform)",
    "11:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QVector2D)",
    "10:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QVector3D)",
    "9:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:PySide6.QtGui.QVector4D)",
    "8:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:float[2][2])",
    "7:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:float[3][3])",
    "6:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:float[4][4])",
    "5:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:float)",
    "4:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,x:float,y:float)",
    "3:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,x:float,y:float,z:float)",
    "2:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,x:float,y:float,z:float,w:float)",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:int)",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue(self,location:int,value:unsigned int)",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue1f(self,arg__1:char*,arg__2:float)",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue1f(self,arg__1:int,arg__2:float)",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue1i(self,arg__1:char*,arg__2:int)",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValue1i(self,arg__1:int,arg__2:int)",
    "5:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValueArray(self,name:char*,values:array float*,count:int,tupleSize:int)",
    "4:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValueArray(self,name:char*,values:array int*,count:int)",
    "3:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValueArray(self,name:char*,values:array unsigned int*,count:int)",
    "2:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValueArray(self,location:int,values:array float*,count:int,tupleSize:int)",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValueArray(self,location:int,values:array int*,count:int)",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.setUniformValueArray(self,location:int,values:array unsigned int*,count:int)",
    "PySide6.QtOpenGL.QOpenGLShaderProgram.shaders(self)->QList[PySide6.QtOpenGL.QOpenGLShader]",
    "2:PySide6.QtOpenGL.QOpenGLShaderProgram.uniformLocation(self,name:typing.Union[PySide6.QtCore.QByteArray, char*])->int",
    "1:PySide6.QtOpenGL.QOpenGLShaderProgram.uniformLocation(self,name:QString)->int",
    "0:PySide6.QtOpenGL.QOpenGLShaderProgram.uniformLocation(self,name:char*)->int",
    nullptr}; // Sentinel

PyTypeObject *init_QOpenGLShaderProgram(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLShaderProgram_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QOpenGLShaderProgram_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLShaderProgram",
        "QOpenGLShaderProgram*",
        &Sbk_QOpenGLShaderProgram_spec,
        &Shiboken::callCppDestructor< QOpenGLShaderProgram >,
        Sbk_QOpenGLShaderProgram_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOpenGLShaderProgram_TypeF(); // references _Sbk_QOpenGLShaderProgram_Type
    InitSignatureStrings(pyType, QOpenGLShaderProgram_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLShaderProgram_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLShaderProgram_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLShaderProgram_PythonToCpp_QOpenGLShaderProgram_PTR,
        is_QOpenGLShaderProgram_PythonToCpp_QOpenGLShaderProgram_PTR_Convertible,
        QOpenGLShaderProgram_PTR_CppToPython_QOpenGLShaderProgram);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLShaderProgram");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLShaderProgram*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLShaderProgram&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLShaderProgram).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOpenGLShaderProgramWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QOpenGLShaderProgram_TypeF(), &Sbk_QOpenGLShaderProgram_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QOpenGLShaderProgram::staticMetaObject, sizeof(QOpenGLShaderProgramWrapper));

    return pyType;
}
